(* ::Package:: *)

(* This file contains the Pade approximants for the form factor for gg -> H *)
(* at two and three loops as determined in                                  *)
(* J. Davies, R. Groeber, A. Maier, T. Rauh and M. Steinhauser              *)
(* Top quark mass dependence of the Higgs-gluon form factor at three loops  *)
(* (arXiv:1906.00982).                                                      *)

(* ------------------------------------------------------------ *)
(* ***
The following functions, which are defined in this file,
can be used to reproduce the plots in these papers.

Notation for Pade results:
41: information up to z^4 from z->0 and up to (1-z)^1 from threshold is used
61: information up to z^6 from z->0 and up to (1-z)^1 from threshold is used
43: information up to z^4 from z->0 and up to (1-z)^3 from threshold is used
63: information up to z^6 from z->0 and up to (1-z)^3 from threshold is used

z>0:

F_\triangle^{(1),fin}(z):   Ftri2Loop41[z_], Ftri2Loop43[z_], Ftri2Loop61[z_], Ftri2Loop63[z_]
                            Ftri2Loop (exact result from hep-ph/0509189)

F_\triangle^{(2),fin}(z):   Ftri3Loop41[z_], Ftri3Loop61[z_]
F_\triangle^{(2,0),fin}(z): Ftri3LoopNl041[z_], Ftri3LoopNl061[z_]
F_\triangle^{(2,1),fin}(z): Ftri3LoopNl141[z_], Ftri3LoopNl161[z_]

z<0:

F_\triangle^{(2),fin}(z): Ftri3Loop41Spacelike[z_], Ftri3Loop61Spacelike[z_]
*** *)
(* ------------------------------------------------------------ *)


(* For convenience we provide the two-loop form factor from hep-ph/0509189 *)
HPLNum[{1,0,-1,0},t_?NumericQ] := NIntegrate[(2PolyLog[3,-x]-PolyLog[2,-x]Log[x])/(1-x),{x,0,t}];
Ftri2Loop[z_?NumericQ] := 2/3 ((t (1+t)^2)/(1-t)^4 (72HPLNum[{1,0,-1,0},t]+6Log[1-t]Log[t]^3-36Zeta[2]PolyLog[2,t]-36Zeta[2]Log[1-t]Log[t]-108Zeta[3]Log[1-t]-64PolyLog[3,-t]+32PolyLog[2,-t]Log[t]-8Zeta[2]Log[t])-(36t(5+5t+11t^2+11t^3))/(1-t)^5 PolyLog[4,-t]-(36t(5+5t+7t^2+7t^3))/(1-t)^5 PolyLog[4,t]+(4t(1+t)(23+41t^2))/(1-t)^5 (PolyLog[3,t]+PolyLog[3,-t])Log[t]-(16t(1+t+t^2+t^3))/(1-t)^5 PolyLog[2,-t]Log[t]^2-(2t(5+5t+23t^2+23t^3))/(1-t)^5 PolyLog[2,t]Log[t]^2+(t(5+5t-13t^2-13t^3))/(24(1-t)^5) Log[t]^4+(t(1+t-17t^2-17t^3))/(1-t)^5 Zeta[2]Log[t]^2+(2t(11+11t-43t^2-43t^3))/(1-t)^5 Zeta[3]Log[t]+(36t(1+t-3t^2-3t^3))/(1-t)^5 Zeta[4]-(2t(55+82t+55t^2))/(1-t)^4 PolyLog[3,t]+(2t(51+74t+51t^2))/(1-t)^4 PolyLog[2,t]Log[t]+(t(47+66t+47t^2))/(1-t)^4 Log[1-t]Log[t]^2+(t(6+59t+58t^2+33t^3))/(3(1-t)^5) Log[t]^3+(2t(31+34t+31t^2))/(1-t)^4 Zeta[3]+(3t(3+22t+3t^2))/(2(1-t)^4) Log[t]^2-(24t(1+t))/(1-t)^3 Log[t]-(94t)/(1-t)^2)/.{t->(Sqrt[1-1/z]-1)/(Sqrt[1-1/z]+1)};


(* Auxiliary functions *)
(* Conformal transformation *)
w[z_] = (1-Sqrt[1-z])/(1+Sqrt[1-z]);
(* Threshold subtraction functions *)
pi1full[z_]=3/(16Pi^2)*(5/6+13/(6z)-(1-z)(3+2z)/z g[z]+(1-z)(1-16z)/(6z) g[z]^2 - (1+2z)/(6z) (iii[z]/z+2z*(1-z)D[iii[z]/z,z]));
g[z_]= 1/(2z)*Log[u]/Sqrt[1-1/z]/.u ->((1-1/z)^(1/2)-1)/((1-1/z)^(1/2)+1);
iii[z_]=6(Zeta[3]+4 PolyLog[3,-u]+2 PolyLog[3,u])-8(2 PolyLog[2,-u]+PolyLog[2,u])Log[u]-2(2 Log[1+u]+Log[1-u])Log[u]^2 /.u ->((1-1/z)^(1/2)-1)/((1-1/z)^(1/2)+1);
THRSub[2,1] = -((16 pi1 (1-z))/(3 z));
THRSub[2,2] = (256 pi1^2 (1-z))/(9 z);
THRSub[3,1] = -((32 g[z] pi1 (1-z)^2)/(3 \[Pi] z));
THRSub[4,1] = -((16 pi1 (1-z)^2)/(3 z^2))+328/(81 \[Pi]^2 z);
THRSub[5,1] = -((32 g[z] pi1 (1-z)^3)/(3 \[Pi] z^2))+656/(81 \[Pi]^3 z);
THRSub[6,1] = -((16 pi1 (1-z)^3)/(3 z^3))-(-(328/(81 \[Pi]^2))+(6404 z)/(675 \[Pi]^2))/z^2;


(* Pade approximants for the timelike region at two loops *)
(* In the construction Pade approximants with poles w0 in the region *)
(* Re[z[w0]]\[GreaterEqual]-2 && Abs[w0]\[LessEqual]1.2 were excluded. *)

(* Sample Pades for the 2-loop triangle form factor with LME to z^4 and THR to (1-z) *)
(* Mean and weighted standard deviation *)
Ftri2Loop41[z_] := Module[{const},
const = Ftri2LoopPade41[z];
{Mean[const],(StandardDeviation[Re[const]] + I*StandardDeviation[Im[const]])*80/Length[const]}
];
(* from 20 each of [4/1], [3/2], [2/3] and [1/4] Pades *)
Ftri2LoopPade41[z_] = {((9.68009727715079073184052312680349465352726369069965954186415528078913422833832`50.+ 3.84599644139344919713972479331289825141057458463266214309615918062568313650967`48.910540948828256 w+1.60996339914766673389883749557833941248119805698653019060902006263551084302824`48.910540948828256 w^2-0.72419370105703121855457241346139458933178467741286026780494313761536850705016`48.910540948828256 w^3-0.12138989896708363485482749251957604459287536810126026129730816084150763473849`48.910540948828256 w^4)/(1+0.44601035799858251759357884492466317853882084715006789259387078748497043615733`49.52287874528033 w)+14.65659963027209127108068624590456616150492941586166265854205795676747600656725`50.99077455409383 THRSub[2,1])/(1+0.11376801703326383219302371936985457378591850368903755234221779725515151309691`50. z),((13.20613245896117063795537127401720879371736351126765623165023914955043666538596`50.- 2.17324381349598310019345906567539400941040062370196584559023202758632111009788`49.15927795370501 w-2.78647367958557356235091896155760158310466611476816945779101202719309160343981`49.15927795370501 w^2-1.14845911262479705460808217277892909199542221120620474479997515028950431863645`49.15927795370501 w^3+0.89416511570824570506574740846144293031718635097127590178463819413106379706702`49.15927795370501 w^4)/(1-0.48791528737302977272348385531512880936459847416178885793233391343456866767877`49.52287874528033 w)+23.25064341152856391290141536384883243645156456057593676012547305590797232570112`50.36249341528635 THRSub[2,1])/(1+0.76683703317649730565789269785532144578759095521192108558765863483098137286749`50. z),((9.98715315084281065661187235059011522556749363071772967790799171949589210827892`50.+ 3.5309628156041042272138703160195886942178384371413370690249`48.28338776466921 w+1.57946963003582038990468184571164866299412466681890839601804154763744545382347`48.28338776466921 w^2-0.9569158524417583121828318621870680044360169564230736157981069442940900341287`48.28338776466921 w^3-0.02156400846680707475057833993830291448566578139052015586088267168134112285259`48.28338776466921 w^4)/(1+0.3594092043648707438920349374429188100805462529320969501932640860304850946382`49.52287874528033 w)+15.40499024061373438878608824942661825399561134295117151538540696076398313582764`50.83634494370941 THRSub[2,1])/(1+0.17063888388323398594259526005594359741836962825031121321009296552396481392312`50. z),((11.39150627001701983075805411399557373468825114681095148595703098031578578642247`50.+ 1.59942196915392171073913332875116203014673689583224463931001334606938132155088`49.69897000433602 w+0.55851980381836431127184166531661866798644727092165111733749619840824417623344`49.69897000433602 w^2-1.52644671110972366331595365286589189590717567580788033608223984179118358248791`49.69897000433602 w^3+0.40154858350757425824843753626487165523755054109316757210366803255225469552623`49.69897000433602 w^4)/(1-0.02024126514162948762248738773441063902838744004872578431316809121462701488682`49.52287874528033 w)+18.82783532531041980305613964366068046747945176610505161104714806229132886818808`50.52134275267853 THRSub[2,1])/(1+0.43074392043760352048338959580863141579972944258769909381673666997417754487906`50. z),((10.38337560187429040280680650320748802006514963004896545349064637679176347377755`50.+ 3.06730313357600728593197414108501491609767097378074046239776253063094150106956`49.075833745517464 w+1.43541479161547292012721785670236196070117719315064183275016105445369756141469`49.075833745517464 w^2-1.19825956614488375918299979604230606753003532952457257866481797680171003741455`49.075833745517464 w^3+0.10310223281289679913965648672355381076379609126570003387421220098781967525565`49.075833745517464 w^4)/(1+0.24972539068154620195572032242014677274825939257154635189517526112480664308152`49.52287874528033 w)+16.37070751673375614509287259739218596241572653920550360696951483403689390539027`50.70739536315057 THRSub[2,1])/(1+0.24402459699348518893449236301785029639926170739473979054742917714625816775377`50. z),((10.98378100147557913733696168146738648697268643676172847222049756488113423186837`50.+ 2.24303447280251459318930517589458775138289097191461144703740374102796362819604`49.69897000433602 w+0.99950265048648828991129786397307085707525753359077513032309192684522638690955`49.69897000433602 w^2-1.44188691550132883452040235346252356262392139707926461870354427200118952860341`49.69897000433602 w^3+0.28383406662786308763047374847148622456926415424912956159041694263689342264848`49.69897000433602 w^4)/(1+0.08752223353199469765435602354870996863683860420289197548972200367852233407646`49.52287874528033 w)+17.83408210734887273437340383020001113149437333242152400583328850019147236221026`50.58150541771136 THRSub[2,1])/(1+0.35522773121841900180859884801568210086460579583315550209571714306901486439073`50. z),((9.71964178195927448311569691179167749419529566394025351526710862556640077849553`50.+ 3.8076106468284568652149936990871801511498993641603144691596732344423291842894`48.875464220749436 w+1.61008270159570882192778181237968612996734802504757813337144285548766259147995`48.875464220749436 w^2-0.75644707469494117023050889510613517294404803133310985833206276649937465524809`48.875464220749436 w^3-0.10837001267676445921440307714402125444214347634897777763731147731789855688367`48.875464220749436 w^4)/(1+0.4347752971056566762407383118918793670235076393754334044516994373831773699049`49.52287874528033 w)+14.75298188062097405589905389303527695465178385706549555923289251902961240140405`50.96652519409247 THRSub[2,1])/(1+0.12109218979885952697950788838824514564745186458649512515999039660581895961392`50. z),((10.77251602347201719480704353594510061937828692053902220973812842879604793407142`50.+ 2.54976967398243344813247916888733886044802105063222242989369896838860429779575`49.52546402321527 w+1.18224400293825217490887545370129853409098028625118342774429975064616815849663`49.52546402321527 w^2-1.37258607767542415142338974290046716685530664542869046833251433882427329490548`49.52546402321527 w^3+0.22129939484434733046081606606327909076269262435104947095254555164044957758236`49.52546402321527 w^4)/(1+0.14408519894932215756532859859542401879602298309677063907136366652540002921213`49.52287874528033 w)+17.31916368572478700097930987825756533862918806273091051566592213873486664528986`50.61946583051827 THRSub[2,1])/(1+0.31609862324977147739185333783129531288789917811812682695607103198102263055008`50. z),((10.44898328267762027949401215577486255186151184995111317622812847228507822973591`50.+ 2.98435793915562873769132567422999518897009596390023160442691705818566226808095`49.17149932761444 w+1.40040175434776287230480252633860725711012574690537038291664540095465837059838`49.17149932761444 w^2-1.23195045186671802134316956281653848049599806801202248974988343485988984996025`49.17149932761444 w^3+0.12331498955910410979605687603492986489356334837607300217367615760076174655523`49.17149932761444 w^4)/(1+0.23177575655219098734654396492408653649632783735410883542057028761748376486312`49.52287874528033 w)+16.53061382853664224457463023511153471412473694996574641633540785717536469398846`50.69051202508384 THRSub[2,1])/(1+0.25617601958129704871725987336378932934630135635527477273127685274932513425274`50. z),((10.05663189600681794998707886732568462078664149796468667271917658102306001283261`50.+ 3.4542958340027501268830106456626455781036020483086625226899`46.779339025898594 w+1.5626544428567632480889904823046089215107317346782923499117`46.779339025898594 w^2-1.0039872170904199907191640886791947460039944713851853304974`46.779339025898594 w^3+0.00062686910814019940120827298591005354413400052165994633876126668615582635952`46.779339025898594 w^4)/(1+0.34001202941123045230258197257735611264327755456162558568417641657220772742683`49.52287874528033 w)+15.57433153955666439582894769211270437175207872681287755547124169398497190775967`50.809517636647975 THRSub[2,1])/(1+0.18350727951955545872474097923791262412435509451632535173076213549886777620271`50. z),((10.58575031258929461781101133657236672734052365332188630829691525524733373660354`50.+ 2.805828667558157601820048355298862942504281110786520095574265436080802678092`49.337858096890265 w+1.31736742715535885649335767968405414925931001303146958124155939011487398752616`49.337858096890265 w^2-1.29654815537017699820659308583391275063137595458208686704505619133050473774116`49.337858096890265 w^3+0.16507395207947900058522931063134041583992432145895310894564289099181834587661`49.337858096890265 w^4)/(1+0.1945420377125422059196610928651264383725475811588971200983214850762147723996`49.52287874528033 w)+16.86395759349869913876305975808628909375239983644993740970638724721742506410408`50.65823165396329 THRSub[2,1])/(1+0.2815071082006086830244479838316197520912707681076359549665780644591642308904`50. z),((10.4226371917938621662754575243429967701043208018192233902923606905062358430486`50.+ 3.01787639785741179816016670955499980623916599057120511360045297989536450283987`49.134705696106785 w+1.41483882736989917480999757324269162379344774831221396471690798936740402383104`49.134705696106785 w^2-1.2186327161061785416327387128585150567344048266155499298789237595727139723401`49.134705696106785 w^3+0.1152123990717981873103412727922569128582184252801156244559942809103140261833`49.134705696106785 w^4)/(1+0.2389768045048608765649820530517968669329273036391417890702409738980604530161`49.52287874528033 w)+16.46640021555626119695669286671778516855189305056027266300061041412811895708508`50.697173969295385 THRSub[2,1])/(1+0.25129637012645465427205501403608857860926063631255433219591741337402504454659`50. z),((9.61449876286152354937795518009274502139315011584494479039653072617376048808521`50.+ 3.90823989353064806667221116412079699368039996157700075763423444003088190098945`48.95932581917244 w+1.60709967698949668352417703193634961379026334591724540762064944823238176596704`48.95932581917244 w^2-0.66918556912548356789170962893159496321885511172969789730072974769266361861594`48.95932581917244 w^3-0.14309693792337868123467444719141062015599924156684494424266907174163002321297`48.95932581917244 w^4)/(1+0.46470244746612279257230218052032568179121745301966358625629716569701728640778`49.52287874528033 w)+14.49671566011332224772006110222630092260436681966340889203215088920504759912418`51.03505924680463 THRSub[2,1])/(1+0.10161829220682181592899627192266542698059106566335486590423549841743897773024`50. z),((10.35636163906078501844013903400816853690283435298067071805060177040272987668277`50.+ 3.100947375184455494055842859986157204366101311745330310377451159803769619911`49.03193684455258 w+1.44891831200058013328553614660156571710420786615946618025084032678729006026954`49.03193684455258 w^2-1.18387476935163134748858462835528298542115977464237109391004123248371700484503`49.03193684455258 w^3+0.09474500032493178297776026888460568133260898232651551492800524960313687888`49.03193684455258 w^4)/(1+0.25713315683653457681518967312180829933836718316779181892214485461782098413476`49.52287874528033 w)+16.30486609225729883366212187035499303848276237598085705105410852911610282837685`50.71464224349425 THRSub[2,1])/(1+0.23902124869799600570194648267072023968550971629138946988284772858726701269584`50. z),((9.64464344531331887172427866358667113323262640591838911407156710360997970596599`50.+ 3.87985926445031038950007373049671527123828324309393780746406862075784570777652`48.938171584876244 w+1.60882960424781737697390135340681827158182827946591707181940701810651961522366`48.938171584876244 w^2-0.69469728129161926316534191041908048331866463074416664313198115149728741897481`48.938171584876244 w^3-0.13310488396793671663998199837717411971417975524295665668139383634983338503577`48.938171584876244 w^4)/(1+0.45610428800070844610205239708445261033960279307909613999787184750642131863004`49.52287874528033 w)+14.57018762151042621707535487168209324856385361422754986266849043843207009079807`51.01402583337328 THRSub[2,1])/(1+0.10720149177678085810137173418564107117037211634006749597514542848783928637759`50. z),((9.81568487602554691607633545638917984038387430651899998803690422222567973837471`50.+ 3.71168434538925851407285048377168969964132189139842756037059398128061699245203`48.76311836956781 w+1.60536763741730251831104302365124431083466324633991836035977998738610871774524`48.76311836956781 w^2-0.8319584623546582272258768236863458245849906055714945741534111814811813802614`48.76311836956781 w^3-0.07695163609823825404848111610881491614129594374670785171469264072937896505075`48.76311836956781 w^4)/(1+0.40759043879558675950453055306062891119338309265496014142430234721625363724908`49.52287874528033 w)+14.9870687551793534922650891253952846981818814808550764087641051414599897782222`50.913836448466256 THRSub[2,1])/(1+0.13888065920290236326718713102330083933939135402752819900378638820270488643306`50. z),((9.74515190296962363872965173271954433089566545047714850587884899404423740692382`50.+ 3.78250390345882038422482282810951084693163908644988046972453364516083314287767`48.84992858554001 w+1.60952059438341620411467127861778155447777798396085476202720497117042081446732`48.84992858554001 w^2-0.77689310960245280113584825153380215439104654998167833483891963146065135711202`48.84992858554001 w^3-0.09999692800075749802258310229026719766740218064153797154342327743052666612103`48.84992858554001 w^4)/(1+0.42754064286000931261925699442910909536484712900198289382266720856815887791392`49.52287874528033 w)+14.81515797516451428608163480446950134434881609224356207122267603939854188129919`50.951728457015065 THRSub[2,1])/(1+0.12581700641891657333178763037412292104241364669660601137847585777859919232744`50. z),((11.72357620467994000265696227937090686400572623220184240361114724016725721230673`50.+ 1.02411241181018237972607134653823569719434219541431216233637192077328113189191`49.28069827851243 w+0.11472967277796169014208871048610391624859162184702947837978331410481355109265`49.28069827851243 w^2-1.54843138722878352055897308202678929173961903886225873538586676560736216669429`49.28069827851243 w^3+0.49482092261996878090763720604379334961319154265237663726473106602078902266386`49.28069827851243 w^4)/(1-0.10683097919151689244888469978353069729965683490256400803636499897402393106956`49.52287874528033 w)+19.63719297768269915657763165705647979290247282711042508821069840805837202075528`50.48165720666424 THRSub[2,1])/(1+0.49224772693386083890673920265787375606203618477518879883956461419209578576154`50. z),((10.83775174147881220013437043665991055126151721040660103564336639309521776449935`50.+ 2.45699208460876344581386007606250929651833800226944833746022355880906399754655`49.58506836491229 w+1.12918448630119023172009016433993488068287877329888857550292315475711157354281`49.58506836491229 w^2-1.39586640306600554472159204567792687546029720463582338920065187033213623618025`49.58506836491229 w^3+0.24072747604521452044384931704566618707596018201253403866507707087832705949615`49.58506836491229 w^4)/(1+0.1265628174739392803594925162384996343193307177826440594464447148839607901697`49.52287874528033 w)+17.47816340857050393024027503806286362320406129329606255630759917880855901722228`50.6071436764472 THRSub[2,1])/(1+0.32818115333792024743342379276551696947907673942744211254675154159440429379949`50. z),((11.2200706659121229801470221760408228381252213139695409683633487639166634937561`50.+ 1.87837807212382148014848137713396361815957288823873044809531057871006886704365`49.69897000433602 w+0.75799913944013451055491310193867355017078004177767604625578231726859498952265`49.69897000433602 w^2-1.49870512899616475000095747140452096513309497574201191529936387461154406676651`49.69897000433602 w^3+0.3525089630065860229007819534580640478631978371935644236110231433275755707866`49.69897000433602 w^4)/(1+0.02485872740556271386655875891112165675174437104373329337313610219269063759131`49.52287874528033 w)+18.40999346855753769156001893294598536862362093367087820836786840292410314118874`50.54485124007964 THRSub[2,1])/(1+0.39899174681146789952418169876365849821983900860868784703680927008803576889117`50. z),((15.46880201620217263459659909426671482878050340821655411742087427861519419360546`50.+ 0.5318770783527182378870435903423671651863306295051110846002576980700170458557`50. w-1.84521653581046559496476218259265387911645742469867574490537242155171712599457`50. w^2+1.29612343528863663972469402212701182288948006892754805556774751365696613714297`50. w^3)/(1-0.43837213112653998457864098028111883982289166194187565361097741510831000361171`50. w+0.23807190488406075357351795792185144461570562753748387842613375168544165981909`50. w^2)+28.76547245740933526585059315821747690296792727636567600014198229196440965167123`50.26557991104708 THRSub[2,1])/(1+1.18591378806183532790165669200214306661102311600352336168694547849827056511946`50. z),((9.90097082123977813743590762656632844460789683871957163039438036671730833223579`50.+ 3.1208111813511867873783245394097518048242057229478619700126`48.43440164600418 w+1.43421374464060765439774393225313871312565494630992693961183877092441807576768`48.43440164600418 w^2-0.97704728770943414180303511446038140422314121263048018653194130865274061281766`48.43440164600418 w^3)/(1+0.33281760004062680768085472489414267512390829902013450481236673263748937100999`49.52287874528033 w-0.01716106527191846052075469101201897941386642182240400641974263301474482747256`48.43440164600418 w^2)+15.19493711420140481281088941066984687666187501058500720027746142191981703690446`50.873035357737365 THRSub[2,1])/(1+0.15467676033633085929643715949361113722539552729333529434895915927366019144278`50. z),((9.7958154903393654639874342225370454946886437085961598104045719383654461978498`50.+ 2.87155005333072782068321284728551392756029123301024531321552300137741028809628`48.689289594259115 w+1.3451866502626300962018637416582334456786760940837372181057812442426665344513`48.689289594259115 w^2-0.95991553547753964656774626066904250955706580983555736039004963758215984760329`48.689289594259115 w^3)/(1+0.32538020896163154127225352744233714027740482308708752555150634780877276318626`49.52287874528033 w-0.02955056191665375135483661828318626189451632676364154895457313805064376618253`48.689289594259115 w^2)+14.93864088600362926181405566047485611669025952119484029390963133313993526780882`50.92409404275589 THRSub[2,1])/(1+0.13520058243328186566230679579001681037297288200370947707950533657230197340912`50. z),((11.12201331044157425395955869120013919609846307496540655377425033277599347316823`50.+ 4.94917638944699909384642477718879510573356652491191116718539486238847208884619`48.85811095358962 w+2.28987832008651853438848072197835719163744022482204002376245742272354192067998`48.85811095358962 w^2-1.13349602608998895597306795851589963680762359939820735602467432445191254991394`48.85811095358962 w^3)/(1+0.31303489080429215326805356166340131844036620424914469783011015258794667311597`49.52287874528033 w+0.0936936183829543483405482406856598586712073449505500252563526411571108389126`48.85811095358962 w^2)+18.17099721283797603393499543978995861060091476759295232745715314655696557979511`50.55940888849045 THRSub[2,1])/(1+0.38083020917477328026842436125124529317982204818337941506641985044473252479083`50. z),((9.91165641234976126155340931961345468151346872902090961453214308942253086881021`50.+ 3.1452378136478896402473491177330754649295443058158832865244`48.40023235652155 w+1.44324108439042139917559273546465775539023450784577690053587324522815964571155`48.40023235652155 w^2-0.97881514962472117055551672973252905696777905025385433964946859503949673631755`48.40023235652155 w^3)/(1+0.33347347080902529704777384196166212356427160794761360209198964357233293882192`49.52287874528033 w-0.01593223621930206463311038524462010939447866358212409735153547988769661129327`48.40023235652155 w^2)+15.22098122127711759355965835832522620835559141083679993181766275087720939417363`50.86825748104201 THRSub[2,1])/(1+0.15665587515319511170539517123938223140836349173176908256959663322424127683804`50. z),((10.25375328095399647291757191570486926007106044853769542027208008106765248240182`50.+ 3.8428372918709868912430345520158302371836718859822167862834`48.428933168650445 w+1.72538289986494286891236602136991138865869271335596732762282121194818758200012`48.428933168650445 w^2-1.03549389823493828197534459789080193803675705926314531141234565448074321141533`48.428933168650445 w^3)/(1+0.3455161243331789451715051093532478429953457960833247516360107916759832761113`49.52287874528033 w+0.02067578955219116712522108895412344725991240721671239294194276849119701901933`48.428933168650445 w^2)+16.05477762846612697683223042348420729571911351793784690091392997754695144409845`50.74390996022587 THRSub[2,1])/(1+0.22001680432303440771262955450936221813816134831910059994368557543349005417044`50. z),((10.35488561579860792809681768037126722150189287366675557745699024339001488605143`50.+ 4.0189358979639051069019974558382551310376529530484985451682`48.57071519333404 w+1.80458205788921387372206779113419439902374152412571009003180685199824047132758`48.57071519333404 w^2-1.05143562207090959057363260343535692361538467434409493566213409306630356989793`48.57071519333404 w^3)/(1+0.34601419161862576979067217277665463743183229511278630585426288081694327624459`49.52287874528033 w+0.0305523319949839142156188591573026993329574039668600445312786819585324164524`48.57071519333404 w^2)+16.30126856475594530948344664063015719509240621205308368153556861700691773051868`50.71504341593546 THRSub[2,1])/(1+0.23874786938952875497524900634925147471414631730260793088570778731615476510225`50. z),((10.48222944593765827624786829709096140150974416425060608639569330237746010152854`50.+ 4.22204813340160655495562765629711738903360506653715882877856016934795290160546`50. w+1.90035850005942294676273104745102844156623219942799241881190633531740143432161`50. w^2-1.0703639038858709447876002333393371613047960768112670129349798988956098255261`50. w^3)/(1+0.34485061004138166425974017560961203391711744912934950951211190680633849893222`50. w+0.04242617878737486375895969954717685350231692663117460486310760098234667996585`50. w^2)+16.61164506273688344721177403903683526691666239458652231644183781287871536667859`50.68232015090457 THRSub[2,1])/(1+0.26233365500217298866481097270815824738328340847019609679432428393422060755618`50. z),((10.87047553315826351066237088098834518351645643952181865592088879072395063844699`50.+ 4.71934221250149219484728765368070700403164861718717548659423104116337630089487`48.82927304096096 w+2.1576036670193045570173602715478355152955534718667216952892568369713704890654`48.82927304096096 w^2-1.11636349201602673851702540596401997722442246862610277240650701726711483533398`48.82927304096096 w^3)/(1+0.33025243413045958510225053894101427881946458049161063344059910671296269367175`49.52287874528033 w+0.07508699928402737374909684683452903294371951051299457978719471154589141521232`48.82927304096096 w^2)+17.5579214608533312566636586049603050790314553342954769616428763953058282436487`50.6011735486376 THRSub[2,1])/(1+0.33424203853464789107542387506110356676409978262484903459510365641060631982156`50. z),((9.64170659579310508654980800188772259572460553058115683013698784909740989965203`50.+ 2.47634699303273192319677546239856203978529838533470557640818057971053760893891`50. w+1.21517327958231731400575288221905724000423633396240535389617007675960259466524`50. w^2-0.93623894729115304171166708830984059824910933976302725928265485336187315979815`50. w^3)/(1+0.3110860382161375113592449498661440568815313047377555913085138624638504647121`50. w-0.04872673277601720354564768918641592723478433051248562359674179969303678481042`50. w^2)+14.5630296063306909403061789747524483408863391891475739846284198053366566615219`51.01602165578011 THRSub[2,1])/(1+0.10665754784887540856067328083743642588496885970367462631348176162736439935468`50. z),((9.82090894841970554939111073372674391737499266070552248022932552483171565356247`50.+ 2.93250933465796175990669911138908881767373566708525901358783994301466797771445`48.63816496123811 w+1.36644505761341194477139235852452985543293027352538535500322703860220664093116`48.63816496123811 w^2-0.9639508048962077304229154608069587878512120079654152439740377253960401510835`48.63816496123811 w^3)/(1+0.32731992615391038848033791630808489894303959796433226456611258186404325219661`49.52287874528033 w-0.0265443407880844236230442093014478409533463943678217798799173726702526365696`48.63816496123811 w^2)+14.99980144347000225770993138453533339694629173537111736650742592558369281457344`50.91119006195711 THRSub[2,1])/(1+0.13984822748932046379728651546920638103820367115201369107905953049480389451561`50. z),((10.14098556053155857636977270780066914547191409212882998318068794485729263944016`50.+ 3.63058765992461694117262432139112995276733868317767226682031421631440693584091`50. w+1.63437543808063878580218498123180103298970331222189322921030882357626282604497`50. w^2-1.01706102403673470763111267222498148042894612469185256039722380769583358131415`50. w^3)/(1+0.34338206285948697011906978591353672239461124538841955353822387571391358648786`50. w+0.00917210567188766706429279565807552716043796162957700647384459473260509015976`50. w^2)+15.77992764074554557358913349564618096234108890302105905037069795409476114331542`50.779728283707286 THRSub[2,1])/(1+0.19913070976308592534897467072832515422993530822203177279947192412312170631206`50. z),((9.8677786377994017555745735154660983790420793985874665862003989167774152611127`50.+ 3.0438810326076893325520617089199352652598561914998677896117481244617489168133`48.528272609638314 w+1.40613964651152938036697308229499906351511903290404629176883488886999476306447`48.528272609638314 w^2-0.9715824008613222613799658799390805813571656086928558531037995067615101530583`48.528272609638314 w^3)/(1+0.33066434796456554190277425473848908891431036096485435586357633118319912498972`49.52287874528033 w-0.02101318275882501243509568030920726074989829517193334970685945544621604388639`48.528272609638314 w^2)+15.11403744560092545475644905163938085431646057738482668204539559292387486260497`50.88833039600008 THRSub[2,1])/(1+0.1485291227021757824730345764163581601427022056835018143648604575543585881414`50. z),((12.88094242735507778649645662038139347729141930807251852302157518563120066706354`50.+ 4.84260702585921657897665747754976138343685424643766508051283790031825974051468`49.42824718630302 w+2.18227689339777233208556525492442888700128044298793046276297023438223269657306`49.42824718630302 w^2-0.83251690323086401327444043489697560391619330449381934585235645286288961905631`49.42824718630302 w^3)/(1+0.07838542941384195751425682270976844568980077893706289909675272144973725197595`49.52287874528033 w+0.18260249441982234557366040322705045830501364301669947173803591869541532415426`49.42824718630302 w^2)+22.45805422147514802077402124878214107144026726259793354542107339400093384500372`50.38295541539779 THRSub[2,1])/(1+0.70660747701774687661481627953710260288248086269940701302914843918326630461558`50. z),((10.33467313808589088400197224270383178078317440072913157582339337221042560714147`50.+ 3.98480052983607737020110722398528686512664178015484633585659768531052792526039`50. w+1.78895886302267836901762376987821992939699881200347023051159179629721290627616`50. w^2-1.04830560030945190421286089826953919840080182787932423493956139738129831842143`50. w^3)/(1+0.3460179932540538240295378433651522674242052441529518444178559043964551572275`50. w+0.0286107075961481394159232813831885458056541895702445014215709269183383764452`50. w^2)+16.25200447366381552410605596225525450796851551104599643917299095223494001192051`50.72059273959542 THRSub[2,1])/(1+0.2350042473741398512290238223910298191542007464765083635099730002805264155779`50. z),((11.42978904293773636951861373951917317564621836027981035892299810203217065927534`50.+ 5.13841515079043217783125870742182923884478289327199193210000981856401215794986`48.84427005186585 w+2.40802660147453170575213448433626127235837935156972851389230375901719196216517`48.84427005186585 w^2-1.13739825530291267685476651048795257978037837179784762963875648752075721035554`48.84427005186585 w^3)/(1+0.28495133884892538150010951953021166108695908452999657361755612609237712015478`49.52287874528033 w+0.11406416114123416028405837505408580334788072507404100439840473653878728126297`48.84427005186585 w^2)+18.92114234284834933393962299703125720042278804559081292708796275997359949654277`50.516398986955636 THRSub[2,1])/(1+0.43783440353191306234224324596277369030642611398475146129442722305741104798174`50. z),((9.72415547607479944330213618445844793892376210867940733423418622573604748340872`50.+ 2.69228068327982045991135958329914419209198813181659867960289617839417467937883`48.815123775914806 w+1.284554599255157172875747229639992168335500962088881984038352319936680355631`48.815123775914806 w^2-0.94863823068784359589017245768503027122466945206738713129910773826071207063325`48.815123775914806 w^3)/(1+0.31925243995913710083022953239764702334839522050117810593163266373418991285619`49.52287874528033 w-0.03831215363959306243040059145391037487128183680271720759131202842117735094749`48.815123775914806 w^2)+14.7639831562305114316406035149274064336746742477590359863332587839092907564759`50.963860944692804 THRSub[2,1])/(1+0.12192818649860995786769747928613022039517850031181096205709394246009537789626`50. z),((12.90751650166232188642751012805506414967170888944532898940210558526451299887105`50.+ 4.8209497613816346315164137922612670693382403740097885472543634358377643522771`50. w+2.16495892169113794802408903990972408714476620945752554821955891757138633364109`50. w^2-0.82133360971133381775369828589124074868781872692621358504474181789648004651604`50. w^3)/(1+0.0737775768375949429183551098831193770135251681474753726722485629359940964457`50. w+0.18352216802691656321001911421516617013069181729532275378724952124373426072512`50. w^2)+22.52282350092560476898272401376366092192580333095980143665191203504193299177211`50.381191531181145 THRSub[2,1])/(1+0.71152935206093309329411963499800349723340339949330407349444485422906817982921`50. z),((9.70707463162589324965965341577579876842586055252248003388673028903328696805746`50.+ 2.64840357414652639355949978005209374905002070625422866156187291071178415717275`48.841742379723584 w+1.27013697302897996969307025213385479697650456671402366807361888971489140580045`48.841742379723584 w^2-0.94601333815173402840614471071636919592757682059816179858050908698220565199326`48.841742379723584 w^3)/(1+0.31766036008659649138448897222723684910062784522876039021743481704285047941409`49.52287874528033 w-0.04043993950329413165479051727623516987353558297003749198863561841764329952446`48.841742379723584 w^2)+14.72235182884841682177670881143342821059728883720420879353945118857367851843739`50.97405175468847 THRSub[2,1])/(1+0.11876458497339333816104861283042614384716777001750201847139899079128572489038`50. z),((10.25062777462261282753797168335799086532010284172727402551733409204576019309498`50.+ 3.8371822671326023325825490835691782188671305746716544036365`48.42321445609115 w+1.7228961983390196092269182505765915766475024334969986083168263781965837523398`48.42321445609115 w^2-1.03499101617735772754038651984471595634967783892347090221812196375418353381548`48.42321445609115 w^3)/(1+0.34547982721896574521709822925369130307095319566646084690675270719761438424838`49.52287874528033 w+0.02036403326724091146565227649124747846053671768602593639623730379987127164439`48.42321445609115 w^2)+16.04715979799493066212267130723364242776382048192658850499739710866598591626978`50.74484802003809 THRSub[2,1])/(1+0.21943791862293819900284079196340836911035441352113383247005503599167776698508`50. z),((28.60040329882551587665742330387263847504370261327700359430277626409943027047084`50.+ 40.46773774133455520591197795299923586504012993638148768691874383257384378524624`50. w+5.5698395547510473791397059725853331203414607806094865306331382882758021976955`50. w^2)/(1+0.54180942484310525810884780926477826797127842267481597577576337664341570398162`50. w+0.13142527136084329587623692659790951337464455161205741209935109791966722797914`50. w^2+0.15259506522904161556753253986673025450191261067015633534037789147204570536246`50. w^3)+60.77126664886888166314048121236934543433375378656879233386840806797597791113856`50.10598374146765 THRSub[2,1])/(1+3.61806250123064051678944654179958166877714918828224990351796935927449521650533`50. z),((9.64757059444177295565376780345005253080770638725567799374228192563840524716281`50.+ 2.825111119612589213327014434536733574868650203104071620756`48.09549943553002 w+1.7318766436786712993536964108832199671547923061957189902926`48.09549943553002 w^2)/(1+0.34623004335340920340115461321317789043926881982828062720463571790542627563277`49.52287874528033 w+0.00691807838735183641050593738598359593023767606701834741151221708174299116895`48.09549943553002 w^2+0.09346734767603888739971109368381349249127584986170716887701952421289005371572`48.09549943553002 w^3)+14.57732199382014469229941646006390495087847009925981396000163294514877814808135`51.01204762504767 THRSub[2,1])/(1+0.10774363906200520443892193310850820502002488727372694548732812475235412780551`50. z),((56.91157718308075560680010423538113156893086247402888770523925761888765209082286`50.+ 92.5116306711015028434676695560666920047745623798692934896672`48.96061324277975 w+8.5682739843462607624760886838189967477109799134402001624792`48.96061324277975 w^2)/(1+0.51778985471841359913720769186674830179030275544104262867450715162588692745276`49.52287874528033 w+0.13886617505970718146028658059965817491094663046108496136278282488456536087669`48.96061324277975 w^2+0.15360842576607555505023820285979812705841874564413552236931895804273330333292`48.96061324277975 w^3)+129.7743977336621185824951144475478736449978373280034968887065`50.04643488400584 THRSub[2,1])/(1+8.86167168863462165583264125701037726467240821736967965882099352690253713941779`50. z),((44.51512182411886528396293513420984884281376467599714310063897028115594378786738`50.+ 69.6627527430478649431859526162491725631058459021301106955794`49.01129625449321 w+7.26377296888720527542268169731976908876975899282895269707115611689461948443686`49.01129625449321 w^2)/(1+0.52318329886850665685710120510990763249384568323752621028268360516723050608793`49.52287874528033 w+0.13724309311613106738696714526007146187446124990533898818053821236551219946298`49.01129625449321 w^2+0.15321738438736764444410709201178831209906465389466277429512225154067510277211`49.01129625449321 w^3)+99.56038267309455440651725834962207808862350573711752577381123250508891456099989`50.061568239889844 THRSub[2,1])/(1+6.56568186224152764024618387013185462561261037825251964440188269109759314779936`50. z),((10.65165147124839612028914325078669090542684323653665547867076822931621514723207`50.+ 5.0376203164664338369664704013762639977739159311190945900480233908967826076017`50. w+2.08056800620431960482038719363652788155103422985260283818900157096600761143382`50. w^2)/(1+0.39454389883448478325822993663708670183535849264485961691893281011706329098048`50. w+0.05877974369651959034551258934420457141281773955699783035121472055279064965691`50. w^2+0.09677399863456473713416862902392056736930727248207909046236466077438797313424`50. w^3)+17.02457920206162370891727165512976992309084520560108996541488263025674890295217`50.643914902363605 THRSub[2,1])/(1+0.29371288682420751313282150147954717227036806896220067173551576812811654492423`50. z),((51.89150912848549397416012111966924018692571253137070570737095142068043119811775`50.+ 83.2543257501051080504374307271357257005536773098275538775968`48.97847330843391 w+8.0410171076093851341403399578461556759706481046536472910296`48.97847330843391 w^2)/(1+0.5195782496950810687532901702104332569240019184533136810779982963904674985681`49.52287874528033 w+0.13833364714437836283504737966096742016187278025903270784004643551518771362461`48.97847330843391 w^2+0.15346858509781725898669792842428033969280694343787751662180945410920526182766`48.97847330843391 w^3)+117.53893143184040945043362593208580945718917970217792526574005246672561847647266`50.0515666970015 THRSub[2,1])/(1+7.93188774254723706990922975006069006510895437890478771866702944572161373798786`50. z),((10.34924483609006995817743103522005996594554985952130843424129616783804368867241`50.+ 4.42775335623922838466854059920975849050278339719404519010277145116397200723864`49.55183690445955 w+1.97780142111727111758404196769058998250013243546407515375597866165484055779365`49.55183690445955 w^2)/(1+0.38643788703217251025515829941620476462030377526511739015804908608775633769866`49.52287874528033 w+0.04549659835043688326224939285060062727546073317839107950697720282659067148515`49.52287874528033 w^2+0.09563168569874897653148600648687761187593472318526381211396361593468200138714`49.55183690445955 w^3)+16.28752023120962240187507170607033564051345423567689663371535463517669473893287`50.716581601616994 THRSub[2,1])/(1+0.23770312131851143280267968106591049674143949379853502250048397320197824058405`50. z),((18.68581048433405641867695367185928663011142919419305821296200961534335486060007`50.+ 23.0775001769961159386048646782309616043701245168161206082585`49.29973319299243 w+4.58983983248744171358327123241269324262614839969208429034743277113705785210437`49.29973319299243 w^2)/(1+0.6121457588896413941505268772988110565001868968144964199184539648422030488005`49.52287874528033 w+0.11180636045240521989129358647693688968880760771784042952561529337967309445609`49.52287874528033 w^2+0.15795352199166800349787603232447601906518051014570145492109063485946089882598`49.29973319299243 w^3)+36.60632207865540308920108515025235237541818468156581297041614324872577884814783`50.19347159988918 THRSub[2,1])/(1+1.7817469113515058763250760230654014109124064742293545318214682767704777143206`50. z),((9.77283321963285328820201810162249376678971232934564089993786472171238696645757`50.+ 3.1325418368732442103848339878922339341716215476863872770622023268040289139617`49.491959855515404 w+1.77342598875677715432871968291966108833860021986238004083468057304554466447065`49.491959855515404 w^2)/(1+0.35601362933499593024227192396469918031611476859113642108045678345227164430217`49.52287874528033 w+0.01463228956252547314284365177669923489397062683854404584449177739450961268744`49.52287874528033 w^2+0.09368152769481240200249013304826140021705037379438640207533725623040929845127`49.491959855515404 w^3)+14.88262594841499027190476519111197299600056504253751217578036132315080174444521`50.936355621848875 THRSub[2,1])/(1+0.13094395759968243066546524290721492784291165856020635570495514205254979623382`50. z),((9.73706873646634647889503099054570165233182775060174173850669200001087371065168`50.+ 3.0457707942164091610563222173668363660580975124043106804656`48.31838710674276 w+1.76132009651463496049502481750591671216929565597117628369638723170481181600209`48.31838710674276 w^2)/(1+0.35334918348467579372373590944596980440075421957497723941386067479266903082805`49.52287874528033 w+0.01246481306236399595649211133056619376307719862233718601387462173520729134145`48.31838710674276 w^2+0.09360764934917844819028954731250392911942815652357488824864245831850971533656`48.31838710674276 w^3)+14.79545678580069090377703503117076538219286240425464795225096981876109459883725`50.95634925927232 THRSub[2,1])/(1+0.12431989554978825790510101425503468103401992636907259333622418772183308809411`50. z),((22.8336935512303212833777482406989018399969348449877854391405348511900195207645`50.+ 30.0808788846698699321627193800165934707369463646840470538292`49.21731300399488 w+4.95745917226350522375297349137018335801600311017918231557461397935357344334778`49.21731300399488 w^2)/(1+0.56337478962980294115039044244125976176532758247184624831092987720277442698355`49.52287874528033 w+0.12482394098474961856233778690635309102333393956176769664975163255706881605004`49.52287874528033 w^2+0.15319214768774466262612467936701333919826407879465840050619365423378613639308`49.21731300399488 w^3)+46.71600245289843839379149311890625460232548739155359126250445900912478448664915`50.14368862849749 THRSub[2,1])/(1+2.54999049767451834745487257811725087432870058485673160191398739416393362294275`50. z),((41.41390533438004744301180136654873582460058832283431007594401336920253759802503`50.+ 63.9545589602595305179330076710661451944047573862663621349917`49.02826219025164 w+6.93580426345447976884442944783076186100702070972003629703916965893349062376312`49.02826219025164 w^2)/(1+0.52522828048923886277291796060677169260359366832337773892344097976845760228834`49.52287874528033 w+0.1366159626099815310821404300033325294008464627801143455712904378949153005175`49.02826219025164 w^2+0.15309349530199835163322868256260346892538849543793058082307452194839932171098`49.02826219025164 w^3)+92.00175409631276356995843700450712263024312953502801452266558868263360509314626`50.06703692410709 THRSub[2,1])/(1+5.99129496665728012854563089334706006507465164820787907656584911237842046098929`50. z),((58.67038385991132794718330046054895323085095196244322004519101732659592468098602`50.+ 95.7559542799212764758421961566423408960538744146624347156474`48.974917266421755 w+8.7527518846496649981609930976895188224482749988891020809828`48.974917266421755 w^2)/(1+0.51725236636605734550145916053814432058748909520247628036151175680164161286435`49.52287874528033 w+0.13902498122599477827593875406625019319046356252117673015238125715686398029628`49.52287874528033 w^2+0.15365238785949041973443674188844651105986636559419308533479728868751553508352`48.974917266421755 w^3)+134.061156317757550439300295167584606537227916652364506797519`50.044870611725216 THRSub[2,1])/(1+9.18742627893174747802251677737301496577498576743422444434559595506596615424943`50. z),((20.13365549449630638462284398847492539902827675411991882003318437864379887696376`50.+ 25.4079292385336513889672291426640294467298701174084341334553`49.28249054650815 w+4.69562364720974882949396264126970630696789709023978224967016213559076912354454`49.28249054650815 w^2)/(1+0.58716959264704351536892465996332724661897130990995854041304519864461118305595`49.52287874528033 w+0.11813639269507444081449428666132020481384227761834283718178383960592381162766`49.28249054650815 w^2+0.15508082098132012383012892979066655224855513117717895569230786036101963485996`49.28249054650815 w^3)+40.1351704208377243175146508899236112812436493543735545195317282547599680643904`50.17255242230883 THRSub[2,1])/(1+2.04990722954466650263974930579223084753343845369751545218602443790093968659138`50. z),((23.45575797202305660006733011743562442468687326713640769609888594873400056913174`50.+ 31.1847949090842423821999254257039630155485864849969202367386`49.20754575004358 w+5.02201742768891573637165119832536946402247207771738303886083562779440214816128`49.20754575004358 w^2)/(1+0.55983347108355247888637771767351494254601507111052471166328064742253580010799`49.52287874528033 w+0.12587730817649636612283707677757355342357192385000026967710139939412575197368`49.52287874528033 w^2+0.15300974604309239901161183783165348056784483522174804930360694924355235292081`49.20754575004358 w^3)+48.23216681071119369818038074707784840949368403541466034705425548072237745528846`50.13836764330473 THRSub[2,1])/(1+2.66520517317195331845759239217748226768209619200773404737197445544153252474785`50. z),((30.75964705269348676009909915768976721310938453981749064356698166623656493069361`50.+ 44.4053443248854741739630465961986617207780590858433220693609`49.110437827219435 w+5.80126286423126874299960053855690979655372117848554958900301373479653777347687`49.110437827219435 w^2)/(1+0.53738973053614949144164415663556193099903114744566334263728371156647203146203`49.52287874528033 w+0.13281492585866295359610778950873167387045196380602155008255796277666216269256`49.110437827219435 w^2+0.15264049142310937389392041197897513387454501390405273407636470954735960724839`49.110437827219435 w^3)+66.03401486274754840930513276473926258478142972151624788805257063742499619854254`50.096521081916556 THRSub[2,1])/(1+4.01798340991197963620737888362699194572071680120095291645333723221159214315484`50. z),((42.86392462635004788308364333133794323841446488688102443894766034618980151897532`50.+ 66.6229259874432599114430728498665986347435766052262250057771`49.02004894889274 w+7.08925516042807482147456504819713178443958609515866622639992146428329930320984`49.02004894889274 w^2)/(1+0.5242216905176551470337690562757846528982241908580676232746934106361943783946`49.52287874528033 w+0.13692532937193094267736367712065900622351166479763415587040581256114982382034`49.02004894889274 w^2+0.15315277657623896532292935981746511053546975940972710008408116799507234106414`49.02004894889274 w^3)+95.5359018391207481857694806441188335383622758496294778810242404811804129609729`50.06436364454755 THRSub[2,1])/(1+6.25985799100843112468698576944750015772463031060372632520143397382729277821052`50. z),((46.36106414050597451056352093294159592590966030533084842076805743392140894454654`50.+ 73.0624352613789128990383629077166166174867050843141581078977`49.00218946483435 w+7.45861823026820825172024959495384417728969697858771843961235623399320182042172`49.00218946483435 w^2)/(1+0.52213876162842162510894401455176777976396948844418321485470853567337885448614`49.52287874528033 w+0.1375611999965942202396768936068549882690525786757717168619275326578636496094`49.00218946483435 w^2+0.15328589201949192253585628169651598124341671102256255964699206906022004612159`49.00218946483435 w^3)+104.05951789628868604788186998695137401341947736472924308114884733061663535527508`50.058717709548844 THRSub[2,1])/(1+6.9075751418772498521851643191347620503018654376489300047611573214989948325`50. z),((9.66122033028828275713523829982769215867697156940552030129770567611947489769933`50.+ 2.8590925487887561743319657100401930327465424982467296061508`48.14113077700332 w+1.7362780566141693120649723991905631073113547451576261623548`48.14113077700332 w^2)/(1+0.34735825642173194641326894306017607656529625339493508578010953875177315186505`49.52287874528033 w+0.00777509536475817894282115553806048656625527502149678861221973304110876196874`48.14113077700332 w^2+0.09348425791599234712330369068079447642799016674022429289138052059010879935948`48.14113077700332 w^3)+14.61059064300227288076722877830965618209377068522913678114800018092738654418711`51.0029650113201 THRSub[2,1])/(1+0.11027175324699139480477355705650091048666470378471145824340127376281028743424`50. z),((11.32556291426037667998742168108221910044655465593949352536323267030709520688236`50.+ 6.24857156902465354327001073605163751119758233900429922280377302739883995205211`50. w+2.27353823320512406076553879968829800153832448376903352470872210686132002287028`50. w^2)/(1+0.39797128539800354516755378303989704879939070579267123302031613006013922562356`50. w+0.08280314178858822310853049135236193682793436780240076214776667151813527656552`50. w^2+0.0984712895316283636745135119896013893925321457633703112196634692120498793136`50. w^3)+18.66711086930411587264470883060704488062044967979836923947474539463683957306219`50.530111692813996 THRSub[2,1])/(1+0.41853032634548135155254837538336832424429327850098851117626946903985826941297`50. z),((62.95185789875626857955727369762505542117506683036509480826487330149702766084121`50.+ 97.67766825766594657568138583785959266823036174935135102943776252872071002726303`50. w)/(1+0.42114039886226735636870496013150116798021783268915079395815073708837596670016`50. w+0.10054478952072272131666015288112238106552807196472136744252742110989055505863`50. w^2+0.14288042079182616428581002912909846613274679718063287504700279487257806679076`50. w^3-0.01139794625516043482047600437325438428274023807273618872746904543469580460112`50. w^4)+144.4964394164515823536675300798015660416017051228326365685397`50.04147016323699 THRSub[2,1])/(1+9.98041270533366864697592797905707962450117472544109606586002900153648882681051`50. z),((62.50959271406352999783665561667949947708393384660168248951172000803951591720818`50.+ 96.8848359240834857802783317625273310496688654675497200152393`47.69506926702302 w)/(1+0.42095102323319031746368050706143406027585225841469758689842628759953754477503`49.52287874528033 w+0.10041394396762186453159479502665475796466689990723544739434366290290522783285`47.69506926702302 w^2+0.14284392339131046010861012148777757502424418861246939352362518810109592349589`47.69506926702302 w^3-0.01142435175465760764638446432264602781739071666485333695219715553933187540296`47.69506926702302 w^4)+143.4185016863398259196999758147879786577738342035238926665172`50.041797344092316 THRSub[2,1])/(1+9.89849926030292514441639277046731583302697860116174454645681711863940609772922`50. z),((10.04142380381940799069952033054446166782724312770588010931786771822891925319499`50.- 1.83337271722582541260123371462617620658045841554145080541512191679267487538928`49.52059978894279 w)/(1-0.184021867080387894739713803813641043842750288861913289990253585590849677089`49.52287874528033 w-0.15525700256533586847400287243564718528106598175991285688289027197240500501803`49.52059978894279 w^2+0.18135779684148829035950731606265817798978216891907496359748721687584785165385`49.52059978894279 w^3-0.05626477840863729243432124922178431541989724127326838543033477276932702716597`49.52059978894279 w^4)+15.53726469156767733475521554814798291142659351122740055151661041295150977365476`50.815200674218836 THRSub[2,1])/(1+0.18069053683545437632620689048956111683080798782967139219835508881431891893744`50. z),((12.54405954088323049504729720089852865890840944839825757121423543446984164381851`50.+ 6.12190583010831421908446397231305682098870789316084357075301490441937792676015`49.40899542395513 w)/(1+0.21858970889627925238460693844968115769832211346641912534691391333537669034185`49.52287874528033 w-0.04062642783136232493747423856189818950302907244525287917951229102685105661588`49.40899542395513 w^2+0.13450430082429015527037505641287041024045520904775188366258529845422528502169`49.40899542395513 w^3-0.03006450355656993846076561917069141491198548324485747904568414076833665976956`49.40899542395513 w^4)+21.63696590947236541968199989251769786197068389235990856671025230187742144044854`50.40692890177597 THRSub[2,1])/(1+0.64421224728248857492110763705666346350209107923839679100995366768158198466875`50. z),((10.19678390556335511531825439176492106290581914270539936342068173261737601549632`50.- 0.94194926211702132211572233451681736341565815475119331998066703829616760782858`49.45913082156473 w)/(1-0.11428500950358989002741085267693986160091612004579643379288500635478847474703`49.52287874528033 w-0.13974602136489624060719074851411325189963082820160232656379187942283422703371`49.45913082156473 w^2+0.16931676121468945624904442949148927964522376363424926504130815446959529536645`49.45913082156473 w^3-0.05054641728790195526235179908669220699090226454457554273690633991132170637722`49.45913082156473 w^4)+15.91592555211031708325929005481912268984054227195502903296861406408228993287726`50.76148130453843 THRSub[2,1])/(1+0.20946531177735921724263400701133827613270888085168601014575127653257593337737`50. z),((9.9259577842396777400029078835653424236013314317311970559567328003168399133934`50.- 2.64439889085054472225634834204419590192199483364593620853159957545075670213926`50. w)/(1-0.25222695387978158052817582554677265921512424835272321968189577618682576020518`50. w-0.16923352146699722109003091490512252966413807105995259615704921631888375057772`50. w^2+0.19381799673471039450295991108214371680473444669364269276854836011011992105729`50. w^3-0.06216872133314350241588981187344806983002771847066433784066389881666269760324`50. w^4)+15.25583811005349918026525664106252561024561545119974450585927837801041530866789`50.86196905199737 THRSub[2,1])/(1+0.15930468107487933751578248148351997632250269657826286935783998089092399931595`50. z),((50.39171116761737023726989659996664041807711918803590762368808773234615219358902`50.+ 75.15056943903787116817989204926501368578280214652663488740715091329185099448627`50. w)/(1+0.41425077944860571090379050806355373042364418364069062144197564832648346066445`50. w+0.09582397679804849059578186484088727967883813872235705235756461164868360417567`50. w^2+0.14158157750693013344844147034613265386203846006089971818143051134428825901092`50. w^3-0.01233299378543967137730135396403746230985489878797281349911526871395560157198`50. w^4)+113.88345759957931416149581713098102476074197882552688895267788160279773670600166`50.05332774427118 THRSub[2,1])/(1+7.65410504095352207900654334892674818718958838619872374432637707579689902418463`50. z),((10.02177262306492634064682893087211262086137182024505731567232875710302759783016`50.- 1.960635872747236633686107681679174504932382516577029438552837521716205066517`50. w)/(1-0.19444450998788367417591935390957187355736002940038707294072270656337906149946`50. w-0.15746227366688597427060508027129868397483700321119737278806642212220322143023`50. w^2+0.18322315171021868707400803951591973883594775463491925246771419961682656379651`50. w^3-0.05714852389012799165132837515864155208522282637430825274900654447793080407294`50. w^4)+15.48936865563797062044862329564265432106909855625420480380166738503469521937739`50.82269715803924 THRSub[2,1])/(1+0.17705087454632400973870383399536841986990346975575375587528648267355324459054`50. z),((19.30210307254812743358457379412606951959713893589221021408940417469606842691975`50.+ 18.8905488160252905955250218615383522517006645520394910003264`37.93242396313661 w)/(1+0.3327474233458993207950780021833647229819759137614546141838`38.45759516021352 w+0.0474833977578538680542917620775840318779834741281283393667`37.93242396313661 w^2+0.1299219714501434963536731440141778903391266797820147420952`37.93242396313661 w^3-0.0201233785791997617026204184617280283181371267863583539023`38.45759516021352 w^4)+38.1084186863404766042635903575946547674449343079213805160339669111371940201289`50.18396872237994 THRSub[2,1])/(1+1.89589256602834982192153310363767903449855545840076759300588681917584010505845`50. z),((9.85799459001043469167076045163509798396565956612710551515474080140648543237998`50.- 3.21021468006007389901796328007430655812449373901181702072883489636784949398642`49.544342538959576 w)/(1-0.30209145870660917171466939835198634506797988505787155668675194946352504839786`49.52287874528033 w-0.17884660961612009785242082367456822099309875680587683367281327385127735577131`49.544342538959576 w^2+0.20325362247995330096278299488168563917608651670511210137030707657506800106286`49.544342538959576 w^3-0.066649388642076467689890308173274158279102093772687531267066494391833213778`49.544342538959576 w^4)+15.09019067983691602392157555459912515350169311734545743770594882822939819319883`50.89297584942266 THRSub[2,1])/(1+0.14671698580223752292377651657570793453022505683604164648064178553623020342505`50. z),((9.85055363222601393470774454965160101616459970687547978467247772468619804222414`50.- 3.27729005304051055154996985031358000456051429830129916034155595009692928976193`49.54482125594239 w)/(1-0.30811314557153400523022644677890441889794276842163804733580455598713443092168`49.52287874528033 w-0.1799771797152425474728447412550292053208701999301601258242498817578413898422`49.54482125594239 w^2+0.20440867730519583533066861517733883862022495872598237877153874432846287837028`49.54482125594239 w^3-0.06719893171900276359761591934081794302139436867533372227223153221675308407143`49.54482125594239 w^4)+15.07205475274699962972847575760092083680034386235252845742985329397959499109302`50.8965523494773 THRSub[2,1])/(1+0.14533882060283642235821793107114256625609582985574816133796652649011700812778`50. z),((44.21289196537586888331407380261419842778031392006215124246367479053259046133353`50.+ 64.0560232388830491106636781159304455839745995398121652136489`47.86011201137797 w)/(1+0.40914003636963858178007668545869328278777702390262128732649163104183112840726`49.52287874528033 w+0.09237536864098649588257481005311931830202017291037194683138362962456962545087`47.86011201137797 w^2+0.14065576884272816116926205468294498742846396697827970739023856804341426677601`47.86011201137797 w^3-0.01299361058246625343453347847972724651294860703589516270915560250155762930915`47.86011201137797 w^4)+98.82375456131641450356592523789223260927136348103539033844410750817388128546426`50.06206157049259 THRSub[2,1])/(1+6.5097048380993415690894206814293065685599209470846819755477704694735222325496`50. z),((10.45583683452751068819314054908062221333840083837001870321418020372749934490186`50.+ 0.2419339595891778551640632572108194098522747061436884626792041046673339186825`50. w)/(1-0.03154403945685175711140078882256213357118915343033378275367020907588821337772`50. w-0.11927114241802489292830767772459913998873044987173910700881140491149884985855`50. w^2+0.15630733442554115928207282101004908218980058272267152009945412102845068417141`50. w^3-0.04427434757992177101529092105181383233636771111476574169635129223492343272746`50. w^4)+16.5473180647731135004659530012841208788768750302587941109157435356892888554698`50.68880401448529 THRSub[2,1])/(1+0.2574453893217874216699185620629506081106946674724958421349434468835122793996`50. z),((37.67344827013943889620350922561777305464631125205821580796697177840395926300592`50.+ 52.29712532421064034608400159634179360138056568805090416310734931513629286397987`50. w)/(1+0.40145842205429379037796905539920085564367717451961597692546269059976116954156`50. w+0.08728010810183573288051284356568903233500039127994452203280386332284377068881`50. w^2+0.1393224555912787575840267570587151014374701543601506898275626080825458142505`50. w^3-0.01393624284152770506955414591750348791811688812131579222719743654779718745862`50. w^4)+82.88509753604292745715668450406031190607006603224111536694858181477001175504199`50.07508403701907 THRSub[2,1])/(1+5.29851214149686253946452190687890156423708356269066039735973520362421344181991`50. z),((9.61106569138378411842469068496974481985657491060190512561648567390291236946229`50.- 6.43653680002980871900959804635555094110080683347683755519212155785575098477523`50. w)/(1-0.61099144798896531384253607410903512877029680132447933763718191596597065802929`50. w-0.23039897742976715361184623744777057754177103573065921848010895309631164122599`50. w^2+0.26523853240951770967709054334189571908515103439621444017581568129646638065543`50. w^3-0.09677257944474115164342527608672590262701492612948279262483657110329858771409`50. w^4)+14.48834819777599887485649998294970554462581745542082009278259568275680606393077`51.03753452697726 THRSub[2,1])/(1+0.10098244131574660120213402168265852989721623725324919628415092836124551161503`50. z),((43.78644780047834731798812908872063098313663321731407635893303366069003136362585`50.+ 63.28983830110150582735024601534868293983484713453642186306772371839665361947189`50. w)/(1+0.40872332831161905123321220356741216820811600238022458273430256732210091198289`50. w+0.09209622420147358710473877133193871050311890197204355228274528828433000728258`50. w^2+0.1405816656805210378302694797472748986713564930025498190130511213203054534622`50. w^3-0.01304627378744536662264593687626034333813529151027523763879778000992707886043`50. w^4)+97.78437757429809786833967982410299581773214935004025645731897756828991207618828`50.06277128133847 THRSub[2,1])/(1+6.43072165816786463282859403091395832995594654863362847196701721456480433856758`50. z),((9.61813675614809263312653060183033924019855436326285158674661204915681168689528`50.- 6.2947162771280427466830437233597821441247522154305415252203`33.12585538660857 w)/(1-0.5967857833153429094686507017383878032779332402657106985522`33.099559050204185 w-0.2282801114250038275653257839043413335037871824908153358311`33.12585538660857 w^2+0.2623088986793192277485589538208223843270652149514388129038`33.12585538660857 w^3-0.0953062748805329522284544909584561819709884844234385502194`33.099559050204185 w^4)+14.50558258059726345901909298157992798583835093823149275073325638044173732595407`51.03245461050768 THRSub[2,1])/(1+0.10229209736584337640986809164997899037214078526895803016724597479296181470483`50. z),((10.66146803544691740605651520299827475459855547189780266561072377268306018736981`50.+ 1.0217998936358764354522015496082026251779024254061674204232`35.5530919443072 w)/(1+0.0162756941653698479465099395242602887863479201424328115675`35.37700068525152 w-0.1061555610806498455116118797529364267696012383058457973599`35.5530919443072 w^2+0.1496488912175172405903254199950555642761379623050632680968`35.5530919443072 w^3-0.0409517804762622021732869431375191408563775387555935157893`35.37700068525152 w^4)+17.04850522042321351092930013480393925067819918582526932697899288384540450400812`50.641844713687334 THRSub[2,1])/(1+0.2955310461993909524936990810431255833593361125542424144385715472906588200113`50. z),((10.91500480286818350215641416337333355291282163988975290320892241958837875540454`50.+ 1.8665313857764643940605960802677529260702714131289416918164`36.716637455766026 w)/(1+0.0620530346551714300954693374698273596874672997023377377514`36.540546196710345 w-0.0925638473505802440736368179638215685124111675609696617201`36.716637455766026 w^2+0.1440568367498580892045692755582891975400143505593165197498`36.716637455766026 w^3-0.0380078336733058833483723583323619655942315820123451087999`36.540546196710345 w^4)+17.66645313274605087450257570749357466413443673253258608373135174116510942487146`50.593263677121136 THRSub[2,1])/(1+0.34248945662878703584147000129551833335199364214421490509128670892211378431691`50. z),((9.71934568761167767067901066590747350042523417136304553057431298087197444808736`50.- 4.69419957749754576894740636958384820283834253207128432860737163260187462679716`50. w)/(1-0.43990120771034603549218238369609840044778339141199886655253588457499150629686`50. w-0.20333701589152761171036202247715534584314374766233355479343142256757818601013`50. w^2+0.23034206150678866268665843001288184311616765005361835582818720940318784804504`50. w^3-0.07962666090905003625262123659526667650145573571909997779801398808996481336781`50. w^4)+14.75226020665703956268920169601157339410246181939915622151812876221030432888571`50.96670067844229 THRSub[2,1])/(1+0.1210373491536872515053350547374360218013200485070274877511875373167873904393`50. z)} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};

(* Sample Pades for the 2-loop triangle form factor with LME to z^6 and THR to (1-z) *)
(* Mean and weighted standard deviation *)
Ftri2Loop61[z_] := Module[{const},
const = Ftri2LoopPade61[z];
{Mean[const],(StandardDeviation[Re[const]] + I*StandardDeviation[Im[const]])*80/Length[const]}
];
(* from 20 each of [5/2], [4/3], [3/4] and [2/5] Pades *)
Ftri2LoopPade61[z_] = {((11.56519789141182246126591406855287307283519566607467537854273981652733406111283`50.+ 23.1082745239054623011863764599260345121471282691124690572411`48.463726356575634 w+8.5299471942926477809838787424108042878644674786352242486656`48.463726356575634 w^2+0.11325797842050491400969486817686441718383848059175498446293497639808888817922`48.463726356575634 w^3-2.2249796792690066911289994652698044802314598028430032118981`48.463726356575634 w^4+0.33365383831139544701055680393969876773800881953368517484884951645038949575555`48.463726356575634 w^5)/(1+1.819657682177597785060449940850769545074311696418179642928171427488846077693`49.52287874528033 w+0.37212336955673567074640961158589668703672978030003676967111270200117610454876`48.463726356575634 w^2)+19.25117579746587633403844105643597976774053612519597587201974382941276153857059`50.49971851996007 THRSub[2,1])/(1+0.46291393872947626378629353556276536333761627046962356477582756678927256334223`50. z),((10.40480711767882615681923496152220449371648457944687475498999317258368194737105`50.+ 31.1314531502899458709334860754221319504811454128746888679309`49.09564851664926 w+10.55861715791333472512315812555416465502912225221065915157303840700020012888196`49.09564851664926 w^2+2.68071465319120596839394282958928271795394427520403174306935348882975905324121`49.09564851664926 w^3-3.03978302467298425874721632568344929244545696224473175552191060030669250230187`49.09564851664926 w^4+0.20168478274586311300507610140966367310007532035349456292932297709920204356756`49.09564851664926 w^5)/(1+2.94367036673716614526346940053505929797587020732120433867544469915391822825501`49.52287874528033 w+0.74734059789109570516127128092900734251603137991213123004084368440977101902174`49.09564851664926 w^2)+16.42294278258504712119468343972300038044119642084788859795677970745729835598018`50.70177132210566 THRSub[2,1])/(1+0.24799400121642892995966013387949366766242816524816354074890879829946641373725`50. z),((32.01091135074920725868833440879722053735452442004850555135139563013054236950272`50.+ 78.2366673797214814309648217162595417873237882594671881866254`48.47297829895721 w+40.1522384463564706480149716186206388636755586637123526141152`48.47297829895721 w^2-14.1400996967157789458849344125240280583307026570455858494932`48.47297829895721 w^3-8.0000187322460719105603477111891199788311467776797773772455`48.47297829895721 w^4+2.79482277297895354641115395742208071082393344363671925777638932038531809724477`48.47297829895721 w^5)/(1+1.52068760767287341450078940691640141396524694475239989618906113097061419613334`49.52287874528033 w+0.29249652762588644333827767419077408978538997177436314936921877881050552330602`48.47297829895721 w^2)+69.08373490379741062903514888032224343713381419006767247381264759081265473644297`50.09177554444014 THRSub[2,1])/(1+4.24973434316467786879669608333668032818380292231081314708718587725033582991753`50. z),((30.90565898498821830992611776262205356825012119579209405897791545976310780306954`50.+ 75.1009900360442626079377226747052764027483492080035715370358`48.46751283012055 w+38.3920622953665704547396002000337978022317033515453750772493`48.46751283012055 w^2-13.3961099717105046024368438864374822663640164724666049581684`48.46751283012055 w^3-7.6683969986260194230406248004928288130829409343247316383132`48.46751283012055 w^4+2.66059364070449628285057336403943408039560853930418945334809051153914998417151`48.46751283012055 w^5)/(1+1.52170234385768214743052090253471349759316770697178017356871276940112452673515`49.52287874528033 w+0.29262290849002247490722599661488290584565524611293495996326115655918498753593`48.46751283012055 w^2)+66.3898913285298629232961388283338482125009392833505899346854460057455519811568`50.09594207473891 THRSub[2,1])/(1+4.04502677846961665343905992097344437277803311781820034781374592366167583406421`50. z),((10.35837756293862642566514522162431461357641236639774510269186052722651380542632`50.+ 33.21801362479799014677912091106681163337577167633492415187078094359485169338921`50. w+11.24861929969219399424710417949492586536310241357855249050018767416716218397572`50. w^2+3.05891695002334766344357059539007030593141499094753968959011542869562057601213`50. w^3-3.24823575094986782514810347351751337920910834640610695684101180459560728128554`50. w^4+0.19610199522237750968334733209518519950537724846048324870694308098790820802929`50. w^5)/(1+3.16432946048939865150394530310116983323294110229442362327950070609846034597509`50. w+0.82245134266818067737071010497209284099837555412027842940698550278465139419055`50. w^2)+16.30977952538332742824568786216646033231123754343251771876838479862999748438189`50.714095213404285 THRSub[2,1])/(1+0.23939462484305352243645601284657656333770442456909455789186136766718822674565`50. z),((17.04942288396298114238879173853517337008988521145413466119908556430637493783919`50.+ 36.0976033325718537739456091884619793180216277299910737501153`48.13853751411014 w+16.4189428710719673187855011777588757312169490774569903888192`48.13853751411014 w^2-4.011414489319382181813480972390797770304124274582320757018`48.13853751411014 w^3-3.5583189875998766293870688490239756381041986384827151115492`48.13853751411014 w^4+0.98289444035176227828308200059071362575153242237316696176849170833720322612509`48.13853751411014 w^5)/(1+1.56363562450108835565270506712382290067300915515903563381482248476691785737699`49.52287874528033 w+0.29993475318057514569982350793654485093763126242883498908644889059892314137178`48.13853751411014 w^2)+32.61793683699886666121315404945522201948471061193654788198313631503238098234391`50.224347925436255 THRSub[2,1])/(1+1.47866597622180214756133871376832860436878209327999597764586637576794663804559`50. z),((50.42828421110751435181404199904782147643351506463033628280505760936067294798727`50.+ 130.5770878465422445247470763884258449434531141362700689853783`50. w+69.50879071325981607864311580626484999603113448335005754234279920108187798867116`50. w^2-26.51997161895545112316225103638978709286628816534503468368844687525102720523869`50. w^3-13.5413991035043095342158196520848213836085205326273287497943508250516845883855`50. w^4+5.03354609132803767211135087398421479014188816390080015613238860747181051280032`50. w^5)/(1+1.51209075236399921350788857242442951451281188085472372432740504685065598531344`50. w+0.29156704177809133441517198085584367226795122233016805565891676451806488599386`50. w^2)+113.97259747503759546772826190470203979607710473576763861200234101219943578919161`50.053283369177535 THRSub[2,1])/(1+7.66087885922189480753872881537242425211382939078138088164758288377397224539076`50. z),((9.66533338354455737595368155939330274949070688452606547136668448866691030882159`50.- 0.42747019919218679841337160125743705358534236839239988185223220356286332205189`49.69897000433602 w-0.85787240049926488196744073211576220694452764695942627946613785174765389713977`49.69897000433602 w^2-1.38763493409345408309852511417029913719446941486957140383455910061993380421151`49.69897000433602 w^3+0.04655066735576690509806155433766623742703953781452261508359033389252190887518`49.69897000433602 w^4+0.14191884881646791923835676954393189331396296396332456493164980537138442994573`49.69897000433602 w^5)/(1+0.0066020327365898427059052463820211122169942021391315597613759976552388519793`49.52287874528033 w-0.27784024838817827055482238797396684663197032229449941143386103617856789086312`49.69897000433602 w^2)+14.62061543230142981532995911990022959579828573700670817922149327974390855743193`51.00027296262431 THRSub[2,1])/(1+0.11103354588515811155239681321080226229134281474072706519977464407604295740077`50. z),((10.84131770689545707759929295104915518015465989560698012807918209883809170779859`50.+ 24.2097626415235553168012619647613316976657306635267143900027`48.94806628631739 w+8.4503730620303737016321721790654653399414702641480133128042`48.94806628631739 w^2+1.10479292831455937727014966568570574282230328995753967455154810406740706886845`48.94806628631739 w^3-2.3427809821483407864250714219384231324217180825272591809492389474733793933851`48.94806628631739 w^4+0.25150809813800359483956384461843596544388899147669769760134641630007613468257`48.94806628631739 w^5)/(1+2.13254811119102465002107463180604979659216293810100667806646397955090370865368`49.52287874528033 w+0.47377511871268269994346778322570538112421686050267362434321764407204817018813`48.94806628631739 w^2)+17.48685477474608414125592802991739872939120900941998046516605948129205739128714`50.606486444960595 THRSub[2,1])/(1+0.32884161796920432153706416700072005242193777029915866701466557978869056971786`50. z),((28.31469782923172521938750723796261821823522008114215585032951657439738736455118`50.+ 67.7555607366547638477123023158112062973276988628920560942788`48.451647758541746 w+34.2673762304652969206684018185561916998816034658816074234901`48.451647758541746 w^2-11.650999227356769662469703884174832201512365628847652258263`48.451647758541746 w^3-6.8918867651856917491552047308433956486682183689014877175466`48.451647758541746 w^4+2.3460394025835612922772376289252951571013780021186846416936`48.451647758541746 w^5)/(1+1.52457905394683066687090814838966883164997734192043574465180119429077144200048`49.52287874528033 w+0.29299828427168097730015701546198164037926753692254651882173497208812824179759`48.451647758541746 w^2)+60.07491360993725838828366178929766073355673893534814291285727427999278306431397`50.1073773512469 THRSub[2,1])/(1+3.56514601562752227767619227044582029499326103637007917044974943849925187436551`50. z),((59.37334147820240431497425616022270258334909931274755950460426190638982196148512`50.+ 156.0234173307181968851556499985827070193569911682571898924695`48.52575191041171 w+83.7740897072951595548465827524457242992622902508084482338537`48.52575191041171 w^2-32.5276066768545907579481229705358812882665919992276621961914`48.52575191041171 w^3-16.2373046309810257458558067742300527633519885162318123413018`48.52575191041171 w^4+6.1214779793015994205892626814502271035265005394624876851666`48.52575191041171 w^5)/(1+1.51026620974898808394569519087243680432550747939272195436115300227847169898229`49.52287874528033 w+0.29140595521860712470252989992392726191047121183075215008651626256419477770833`48.52575191041171 w^2)+135.7744825429540655611788231541401592446111310115320870534333`50.04427451838538 THRSub[2,1])/(1+9.31762345975852457967892091991929628639773714405309219483142567118309275104877`50. z),((34.33070177305695147569306503402723171709518983014358965230891518524470366396534`50.+ 84.8213679838753489190515297867744507090506361842071561279217`48.4826279945948 w+43.84759927574878961100991264575362728106075813735337887631`48.4826279945948 w^2-15.7009988987018565992768544299656115983141978101561254250363`48.4826279945948 w^3-8.6966110688617821433697880665151810128665469488038476945018`48.4826279945948 w^4+3.07662381110525523575771335847100502274759628265977146780560758567481391793409`48.4826279945948 w^5)/(1+1.51886625664652465436272838194331980541336102236453914569838433920373093813208`49.52287874528033 w+0.29227797436190340696528408587931145947065563410162812003497280874103312032976`48.4826279945948 w^2)+74.73778525346414778653838733215822147711876058444105959464559472605328568307242`50.08411243920267 THRSub[2,1])/(1+4.67939064851588354313522469761327538662662433591836302249319104206183865110626`50. z),((28.24092540914813581661783374489717577184243944827702305653955174140121920800257`50.+ 67.5465463319204362367570846696551710871600074127010050501464`48.45111792943613 w+34.1499731409272975111186638553710458963322436871498096040997`48.45111792943613 w^2-11.6012851962786015485809092663729059213538545587417637870186`48.45111792943613 w^3-6.8697989993035431470110096292246913083911490581623127230222`48.45111792943613 w^4+2.337085746268451826454351628935129389185058991354879844458`48.45111792943613 w^5)/(1+1.5246733636546298723674653349381620768671416462124397592750418954999447127893`49.52287874528033 w+0.29301100411619726148995608307840738606507112465624834425574538586628962238708`48.45111792943613 w^2)+59.89510729055672008437951069369179876809117542142979446437551677288957897799026`50.10774320162305 THRSub[2,1])/(1+3.55148237379801600871808963415397386627874450147204009355115205202408649582868`50. z),((53.04684663151134466051432281402612801058126213410113521566375919595247955301666`50.+ 138.0253409931931736831124573912045585464301763180967970202836`48.51990029175608 w+73.6845484645668728493423314736001846527423030399407099104896`48.51990029175608 w^2-28.2788144312187983211192537208948612096066234634316437685323`48.51990029175608 w^3-14.3304345548747131436397458337378372934511193855872111357456`48.51990029175608 w^4+5.352003114243007479668700286397714585995311121876982443811`48.51990029175608 w^5)/(1+1.51147660359775910254248689959475285744270811504626446878857172856064944639934`49.52287874528033 w+0.29151127522288242057296180262031991349254650719754259923166827784227658966625`48.51990029175608 w^2)+120.35484805523434120428679276429493518893711618291382522272201216000179555229644`50.05028753892047 THRSub[2,1])/(1+8.1458717465375432564824546065612416970817429105080608669255291731405102441364`50. z),((59.76725659312365887344692305133075408918992203845837807858891956480094680692233`50.+ 157.1441681258828716771358365561226891730273210086492459741734`48.52606440746416 w+84.4023399819164498660803764382544341752784736498303425570046`48.52606440746416 w^2-32.792132001300531529739203950916550367562142947075524979305`48.52606440746416 w^3-16.3560554935564576762754038781174580369483722619567794758524`48.52606440746416 w^4+6.1693917896617067642971766481770568048509270557466590247849`48.52606440746416 w^5)/(1+1.51020119680806414071638349142242324336722138082785420154198520765239275867982`49.52287874528033 w+0.29140047381815849655651969377022402945429698366509024041293243963016514919389`48.52606440746416 w^2)+136.7345761237543009026952670119724735195179230526979179207906`50.043947365476654 THRSub[2,1])/(1+9.39058182326909230659116029075714424060453586535471484229962925419217209641656`50. z),((47.79014771255973660031453495079743081267980647599325177386900261280821211238265`50.+ 123.07410901257162243312303115722094319852922026904668397918988024622681267259533`50. w+65.30208767454247648343203167823743879344125647628169411517978308033294781890274`50. w^2-24.74778797332423247513953136400928448149359371455120046227490068074541582607226`50. w^3-12.74663939606865786219150704679644469483006738593350116316465876171393856582205`50. w^4+4.71273278817198966570548958762186590563537214854030287681763649859044140106966`50. w^5)/(1+1.5127974484759433031506088915446423210926659961522535038909535219787736707046`50. w+0.2916331021445562879107053262181335003562526751472265845042187092311845367517`50. w^2)+107.5426387819398179410791850600992337988678326951163678039530379310577255474124`50.05668614617509 THRSub[2,1])/(1+7.1722605900548902392350853605516582983850556201725306258004336167035324320084`50. z),((10.38820994533801635578864344793940485320864170430933410552076551215049306302676`50.+ 31.8079531683928457931877109246008374745316834011925334524199`49.10261489685295 w+10.78133775522877536502033501016745017323241043362817863134263402494190352735704`49.10261489685295 w^2+2.80509578831831006594102180645977324053419911527082075987397844299188487666583`49.10261489685295 w^3-3.10740468945236187726824856578627932382896326780514887580595797146187577032199`49.10261489685295 w^4+0.19970563059826792509261209210052556768097107319126546710906912648869849235305`49.10261489685295 w^5)/(1+3.01564386122139006724693176095724255201513323094591518709237717978085014955302`49.52287874528033 w+0.77182432788457805374171810225717866543149367723683091816421968328757526803112`49.10261489685295 w^2)+16.38249031447644927439973270025325443065374647511541450262812966329585529238319`50.70611721857544 THRSub[2,1])/(1+0.24491998225391613906756124836072818546471031566095136253166616102700355004462`50. z),((56.11295172464392659493743764556593971214283628962930511447625391828427994980502`50.+ 146.7475638724671520896910330714354228498372441633999200012836`48.522948496135896 w+78.5742671100680675785432042943053015120912383193772279867204`48.522948496135896 w^2-30.338064649369607822283656047699356763197868650138930193579`48.522948496135896 w^3-15.2545051315085209716215551833326252947917502995487265877417`48.522948496135896 w^4+5.7249133872233675387407478090402667837937515165083326511624`48.522948496135896 w^5)/(1+1.51084775140167773750606353471547664473518193251394651820148257774183325630247`49.52287874528033 w+0.29145578766183405998990081694478516106824097868357823950721957293477449055357`48.522948496135896 w^2)+127.82789924435656713317927651380818437931676667129975977795015022657520356581349`50.04718179779619 THRSub[2,1])/(1+8.71375554046377603854405285661015499241669909937493989544034419416091826208381`50. z),((57.33567429140427609619387280374552561478510809734327522471772191482740113844675`50.+ 150.2261226950119020311082136911605019742392689880200381652681`48.52404766773775 w+80.5242933604804844611666832578739915356405663747954432466802`48.52404766773775 w^2-31.1592154517416959146817500078592341190799665744804044366953`48.52404766773775 w^3-15.6230587278761588997639491113363920214675139163727504822416`48.52404766773775 w^4+5.8736316699715622705877700072500024687097178552064427642434`48.52404766773775 w^5)/(1+1.51062010176694490288642474736876213329434728927016986552277762191478854300987`49.52287874528033 w+0.29143610936749874083312108504033168929316926153419188227729564308447793635477`48.52404766773775 w^2)+130.8080542142436007506312674193777141787204351929716966048943`50.04604778964911 THRSub[2,1])/(1+8.94022016220368833184078589276689232042132718571220722530976445808062686748026`50. z),((18.19973381483236659818724112361734401117139033545870480260815342103944489966243`50.+ 39.2759706117359563068182528794788587083139952449562674945462`48.23692234470623 w+18.2245282135465550873264880297478586899721210188911462458006`48.23692234470623 w^2-4.8013300930659464993588730433072857892620863760458805088037`48.23692234470623 w^3-3.8909133125851141188923152524249771926907826169709572974634`48.23692234470623 w^4+1.12135935068757990500944991716116793860046198242987334000277096795060691396838`48.23692234470623 w^5)/(1+1.55444936322524094447180590256924480550443053589452761599894456156165021205808`49.52287874528033 w+0.29805900264587222946040027356045201504076996972110973098689728592756133356625`48.23692234470623 w^2)+35.4216021415729653666547525552388786824915120106842506613247954123675618838268`50.2017014938939 THRSub[2,1])/(1+1.69171899161910448426791127518217575816665232585096438036111292496395048974094`50. z),((24.31663656909132531731817681333493892575448568555353812211313434995478072915263`50.+ 58.52883844454459458989433662383473600224716139335686992284169782771677460653827`50. w+31.22871205311783164622419024642939342950951404063900551765164493216112700369729`50. w^2-3.66776098111799786231915464607688692626513429576800633786141610942528517585124`50. w^3-2.68927884951734495391826496762626025428983402682583334622377707667798669528025`50. w^4)/(1+1.61690495654908229845317456860529328108504303328940534339813952274719647465958`50. w+0.36269885170917640882706430125729097599862716793704830403549396138993893247221`50. w^2+0.19358039784823833527983971761014330650174253410289534089040129099955944800454`50. w^3)+50.33039554981094376428852054116161722211989906923814757496498169058255673438556`50.131626998084386 THRSub[2,1])/(1+2.82465143772042077142402207746980957237678355304078488084869794457132584004062`50. z),((51.48271719027593335037723186306466984180402530562401241772198087182329210437154`50.+ 134.0699576246710068868833344826595231564989701343037917330486`48.031960197964395 w+70.8322423659988828315482208613723759939315194965062828258131`48.031960197964395 w^2-19.0456600525089113607297284636602523070211325867271632205827`48.031960197964395 w^3-3.1838653997640773867214121771386503398068249731735037408303`48.031960197964395 w^4)/(1+1.52142429708267653223633555705712709222638915415210714737984991300878603118871`49.52287874528033 w+0.27420582549432765946253175741073764433885635267044523674158161652282474558751`48.031960197964395 w^2+0.18294401736067657148569774160779075139476433582522604668426438803094076624607`48.031960197964395 w^3)+116.54257840833090572257999120636088796759029370628599366406389184344924875499034`50.052035047004 THRSub[2,1])/(1+7.85617399179653338730310010878408138076095895523371571456283517369528263308688`50. z),((19.54519099616669228783800127782582892069504737282427571070689253289804946438804`50.+ 45.683429685576939067755124137625238103517622664806178215045`47.40236385861118 w+24.5551187625064473539276284061104186548385670669034815275642`47.40236385861118 w^2-0.970943422520763863439467499695601385205356633841964951004`47.40236385861118 w^3-2.620058493640249873186188153324276579427885844038089359334`47.40236385861118 w^4)/(1+1.68270097595975465801421571236225526105706290772458744659124131495529888592908`49.52287874528033 w+0.4228432047591937021019500473572263208054751234534864778839`47.40236385861118 w^2+0.19677733910897489947365963370107267238155272532644119218210118018856860211391`47.40236385861118 w^3)+38.70089951836667899477648518556609937622019013015186306737445486225879376863752`50.18047590200153 THRSub[2,1])/(1+1.94091571041806876977487371228024117967141502408254496776049952899978251398519`50. z),((45.36714447648777683841986637847189609181115813080654490673380943067810354337948`50.+ 116.9499394501169562398921680654803682733143559179670835788365`48.066131092818864 w+61.8262942596033178836574872116880195913234396434798360620381`48.066131092818864 w^2-15.5961602723997691988782622953707620060514122114450407359496`48.066131092818864 w^3-3.0634193497582385554688772409856515307022261586974800627693`48.066131092818864 w^4)/(1+1.53042456466475577889530188553251995377702057334612206746415732295092204666037`49.52287874528033 w+0.28256402695174749678612048461130527452173433301504893083839138485332400082432`48.066131092818864 w^2+0.18424187180652894493293615311448160339556582814994669107963201909765584503879`48.066131092818864 w^3)+101.63702672215397845466122327357930977179275986354762840064166542490019901257724`50.06021884297482 THRSub[2,1])/(1+6.72348788703241598455489903198831612066319468428810244842706892165732474211139`50. z),((9.73213692237382081478580835198923349310796374956973357154483325251549141784309`50.- 1.22435289549784078741076568167941173451573273577564228877500231607918891085531`49.629999668940556 w+0.32060869881886074581416803612992843852702402070893605479044960471288182476563`49.629999668940556 w^2-1.1847345830648248141639967858729467819628859302892078884521815006542949604013`49.629999668940556 w^3+0.39538683716317426473460929550679988463799963704609408004533330015736173929642`49.629999668940556 w^4)/(1-0.084555562836863766949501063998854455365517226679116770221503177562694232241`49.52287874528033 w-0.15375058270658815312486329953827173215191315376938331299772120412298742841737`49.629999668940556 w^2+0.04517804506714935497221070628892599976494915796644531311452462197935706542301`49.629999668940556 w^3)+14.78343642183755489438900901385124714457300843172993476587969590613485628616413`50.95919903052461 THRSub[2,1])/(1+0.12340645742137077590926176031507906922655121276329669046142871232310058728933`50. z),((33.82118339913639033538502101628028764668291511872693100997881357746216007463647`50.+ 84.742732961157303728676617589475746084454827989141330543384`48.13887944916798 w+44.9187171692682007275865115596421191277883327966333370336476`48.13887944916798 w^2-9.0666487636236367335553023993739559834757503226173084062734`48.13887944916798 w^3-2.8466415551578342701731476107121465923844462692433671247335`48.13887944916798 w^4)/(1+1.55968189477572087544920419542813812309747780603048563468401549363564793946778`49.52287874528033 w+0.3097325766207134000686754841914326161338715435155566348298056023355498130175`48.13887944916798 w^2+0.18803756268904777281061585443042967282394960692514608927001846995396220735761`48.13887944916798 w^3)+73.49593059602432046718474973434219042278033051430399643278970076756570060819636`50.08568348110955 THRSub[2,1])/(1+4.58502101066321863681292691078971791017069235811786908187869886945468931630682`50. z),((9.70644287770493469766742119726873957655468805257639043218588905656297314462462`50.+ 0.00597949301446856223388431663439445990804166810321194610853922906366261443152`50. w+0.68900493466339831341488322083950239764345774632493646688852425712094623125814`50. w^2-0.9819115561105643360216757446352405366987650308486157156156129905555465874077`50. w^3+0.26906022434558565074044151144856024568603677471576946345047935135279806932257`50. w^4)/(1+0.04553452817306036539247325823555678327748818616311693950595201334531465705154`50. w-0.11255557835682756177431707118868328059007344967606978296762460737912455231827`50. w^2+0.04354730121167926039135299916103480885165459093224041842420868681613398136808`50. w^3)+14.72081204816678713681739677877643545351184249241536082689051150268463339542192`50.97443441707156 THRSub[2,1])/(1+0.11864757567248409415638974918925588193810152193297475230272183685969545953416`50. z),((60.10953986215007586707927528007642126374461577194214404718049356658967824817637`50.+ 158.2552326392061485121934634653941659578025026032627270473667`50. w+83.56664670563749995737053941971652645548252833292024293679299290366360078250064`50. w^2-23.9052831280829602651297028318842696833384909261569547860029920522530961157112`50. w^3-3.35739737807360563839537299106654523469304243493179168920099791942262912194793`50. w^4)/(1+1.51242813778919310749114332892513131669699283765628999526845225240895363657228`50. w+0.26585380317895168077676793718136020535629954515129265935256223183799350383961`50. w^2+0.18158537024249046758176276270847079125393974160559227941401450261517697184803`50. w^3)+137.5688268467134247641849561007815290000253336552765529622403`50.04366699764902 THRSub[2,1])/(1+9.45397727629761313696666455263610546272099209800452820386041702502887244055079`50. z),((10.82972970047219975952522452078049360192597783939325664883453325247048927148224`50.+ 27.2547160199883748823046823730618968900440261828813406160836`49.09969010624391 w+12.07025168259843976924314153922070387880528747506112975220640868361574350576629`49.09969010624391 w^2+2.76495937459990512175858183349512924158262946854462016983895237547319299649324`49.09969010624391 w^3-2.36067395165270727961189813238207219667470519364964567244159872791394085422635`49.09969010624391 w^4)/(1+2.41743503702417207499138292789872321912334064140278769922833437923964645900812`49.52287874528033 w+0.78257169040912431644978761630514230042915901243280182138790338209107628135804`49.09969010624391 w^2+0.09547820790836994105045861953669514448153664348291633132011380188728131869323`49.09969010624391 w^3)+17.45861120104248229107015632655990332277128064540744537821202400472723280636112`50.60862824018962 THRSub[2,1])/(1+0.32669536373075041277791887084577739730793644433884250431920091729248674078252`50. z),((45.48653766181317981448842637307900022844017435064096512685611914161014298971182`50.+ 117.2838938026682143932576254729347068390528311185880020749879`48.065424946758284 w+62.0018806982060215661191516057774424188129734075123322465383`48.065424946758284 w^2-15.6635507481561320441780925670583741813409072600932220124237`48.065424946758284 w^3-3.0657433964753691420161646927532069687049749448115766007537`48.065424946758284 w^4)/(1+1.53021961116472933100949075283606435522883966963496074663069588806168258933839`49.52287874528033 w+0.28237367909961875099485903263635709169121765146382374995039277322034427272799`48.065424946758284 w^2+0.18421299955042858570927756718817536552674050022675932182007163299919350934151`48.065424946758284 w^3)+101.92802502732215420413481642045949360812209309608520615234467511720038642914517`50.06003447123852 THRSub[2,1])/(1+6.74560110657058132234808506757484531670042863354097143736740737468442062324238`50. z),((12.06779597973417942083063327679844970672846586096017119141679465242456614160924`50.+ 27.3721260257827344986940044767960002492771858866981910617905`49.0156678228821 w+13.872064333019535621736410711718166755329838847076873152276`49.0156678228821 w^2+2.33927961068184704789633699193661063549864267051810127839767617610111574573974`49.0156678228821 w^3-2.30324875362634002405434462999335799741120011594212075833731396335801326817716`49.0156678228821 w^4)/(1+2.04119135659580165282448711722903715092640986541754732947238112150662895365646`49.52287874528033 w+0.67690205402295551503075149635854942391549127077461108695739312471687368225691`49.0156678228821 w^2+0.1460873769265206099618574493564972802192192013753359047675407034800744807294`49.0156678228821 w^3)+20.4761635677808764148035511767275331149647408410666180382677185333753719121043`50.44693387395995 THRSub[2,1])/(1+0.55600184685625426773006393769971286488949482028454390206881181903463777442013`50. z),((15.87444838878287542093216077292468694930685638153363175908947870764068538195569`50.+ 36.19923752003207541264519012745000565345394689401945528389290190079740440818167`50. w+19.56053421446345661393940343019930759367649129509566809660357618734518980820894`50. w^2+0.99427565844029871040822217687236409516283321289240739933956536055629651825275`50. w^3-2.54961122454127935306790190737282612092442362398749713708497944073745193772689`50. w^4)/(1+1.78530759676077428735528535481019902643008679120066613778212826379232221642905`50. w+0.51297127018736526219223639271271030338720799585146812016028306856938373378377`50. w^2+0.19431926737623751077705250535253727697420877157630891725654278837574121776207`50. w^3)+29.75415875970440683209948299659462897801935461974906931100007771486418925374809`50.2535786308423 THRSub[2,1])/(1+1.26104493786146244457813648461943515905607172310417112611184704352593259875238`50. z),((10.57869274673662371093721560685917076508155980553735022311401288096884136643953`50.+ 29.4754522795122550954828988990270226619242296306594581025648`49.129739333918465 w+12.38899692166934347037029834067935492204614929748731752322344196309294441195149`49.129739333918465 w^2+3.18933937035335881341759718068273312326107424548331077165913693660753074083646`49.129739333918465 w^3-2.5937374929607867408014973739918409609560782389351332867456927604300036333384`49.129739333918465 w^4)/(1+2.71663885521782751901715226458675608777871299936882728609864323223866998705879`49.52287874528033 w+0.87059241261588609814077086703595170153685806584387666637102372186004592377508`49.129739333918465 w^2+0.08265521479754502739110513143587133821437309756865211150013034934889610296095`49.129739333918465 w^3)+16.84675611172113694635976861908828718660315302332705325300493025113488141900796`50.65980974962429 THRSub[2,1])/(1+0.28019995233003015377876782962406897554483157983656715260419599494140211731121`50. z),((40.92846039768833440943087800701304750501149586755417830898920033842974700673984`50.+ 104.5448548396674717500128335274683836030282022513599474405336`48.093392106384684 w+55.3071867027408285418544941208640077315222031838254004098742`48.093392106384684 w^2-13.0891668692865002341847627257787465156258815905662593545725`48.093392106384684 w^3-2.9780028037191551187574443915129121940276396211815876304681`48.093392106384684 w^4)/(1+1.53914548930193237644515930819640868309189014941268479106996688307801111957921`49.52287874528033 w+0.2906636696801566865820129645739934417166574638649199334868578943889949234376`48.093392106384684 w^2+0.18544097104181435049750865973685013395758631121053642697289628658279110522082`48.093392106384684 w^3)+90.81857388845793077097274450255995528709213025917594017688347007006402266626041`50.06798231723012 THRSub[2,1])/(1+5.90138405231575096150282267965256901198002553034730589107040861824795457544909`50. z),((16.07312962214374028916224701987655812978105601357058077601476362662645138109809`50.+ 36.6975924011492721835037822756905165375281236811828446178185`48.59007422245555 w+19.8301662028275569048793678590015162089689420748955818327751`48.59007422245555 w^2+0.89534273169488095487844330907699930582438159788633214723831120885924680480085`48.59007422245555 w^3-2.55512801197668295081756260904985485119933898524784338729092581983792413927821`48.59007422245555 w^4)/(1+1.77762209698115900266871745503850807608368519100579604219881164690555888004279`49.52287874528033 w+0.50645997852560468374299276316293559730320655448650515559784879009553032036471`48.59007422245555 w^2+0.19484530155653768801969190757599671844270430849359124917576376884938005443569`48.59007422245555 w^3)+30.23840668406590853400607981106438065954185414682949303430176441923053797770138`50.24809813963752 THRSub[2,1])/(1+1.29784336751595189806892227578506373897621692934272189677712466558976820091333`50. z),((10.5036453161930910284656966263192687088579719419285004917137847130477534075591`50.+ 30.8142800230719155395900032956332746064881066610466882269556`49.14170329186519 w+12.71103896236707192043027444548359285066965289614098774472265403324122820041194`49.14170329186519 w^2+3.42193853611763561755819699050999075349998090812897560819059595412879809197352`49.14170329186519 w^3-2.73113565700218809371468684568747928466784298112957532941130153182730976479928`49.14170329186519 w^4)/(1+2.87312024331784880485525395381316328167035222919786943128717941507944166183002`49.52287874528033 w+0.91898610732189755338620464531969840591116318824146799249267685441652734395919`49.14170329186519 w^2+0.0786876423004212764913933350900458083959719019558155976756301766800839844069`49.14170329186519 w^3)+16.66384219552170173995841609549928928870689718995096766562818961145338469087928`50.67716523249414 THRSub[2,1])/(1+0.26630016145954353652222887210029138433878596180535489290125736471768674160204`50. z),((34.82854992733494909908301073087433526391181129487054475201031187833923556730186`50.+ 87.5430600494343790286021443193231747190154724479556940712002`48.132611965379176 w+46.3860427203215164564730860384049335153890485648975648780107`48.132611965379176 w^2-9.6375392644489537801161183151982359183886776478189659101194`48.132611965379176 w^3-2.8647330612308093753580949669210510464719641129644308100741`48.132611965379176 w^4)/(1+1.55607834169375256983536811939992642744336857005498626828752747290569698570371`49.52287874528033 w+0.30638751668478684533221147628835683164335085257153693407411648018269587449026`48.132611965379176 w^2+0.187605003984515474968518262856143407355365752638801865392447123379538328057`48.132611965379176 w^3)+75.95119595802952427106075018248492740842506340676652263686899108367471384612716`50.08263221367192 THRSub[2,1])/(1+4.77159880513901877368686860335553618073976382976641949294093493782842506029333`50. z),((17.76751440295063875667873923712519001026538664073381952229570594987541202117191`50.+ 41.025741446965712110553220362239164900467344702616276436262`45.60007613724175 w+22.1257261351763332043528339421833561793591806994032489566778`45.60007613724175 w^2+0.0076848215203529387010847907710867171703485730478809473714`45.60007613724175 w^3-2.5916468277880003235264698635839755352852199457582313732122`45.60007613724175 w^4)/(1+1.72345801836477946116391113410523581397645491573531662241608659184530525360942`49.52287874528033 w+0.4593550658595123569474225043561277617680124587689056528899`45.60007613724175 w^2+0.1969467476885008321462423527591291801708441098857344965095`45.60007613724175 w^3)+34.368149082459317252682266034512999334816218950380136247975854197300580537506`50.209642574820485 THRSub[2,1])/(1+1.61166615847332714776900429468096125952323853178225468286421937106880847160314`50. z),((19.87575845193890866727912763333058377580271257524622145636844859735948415339711`50.+ 46.5595618406528840726974185736571414102716642681144551885178`47.56197250491652 w+25.0104750901980517344785315681143037702761242988388135301788`47.56197250491652 w^2-1.1556562472064878308733064783804710023720230374845824790452`47.56197250491652 w^3-2.6249157572109548230657054292991405422484980191307696241314`47.56197250491652 w^4)/(1+1.67642968686762729958036062722092513800667619715715033396207920833495887352161`49.52287874528033 w+0.417164926104304902949669666903501819378369339345907652334`47.56197250491652 w^2+0.19662494246302005681776552519746014240818865622407481151342325702297237303913`47.56197250491652 w^3)+39.50659516264733958425881734121062874137644521414575660533465040999615435483932`50.17593640925764 THRSub[2,1])/(1+2.00214123766856311444270427964888098896345972239697546790970611116199997775149`50. z),((27.05447628151452989566336794085518701891373929264509315293171903997413127034402`50.+ 66.0262000242433838692558822240874241105049781209070384490641`48.16548697325745 w+35.1338777667878318804682902131039151165870306330434292120203`48.16548697325745 w^2-5.2245851336168933721689140558039028476117681954610391373628`48.16548697325745 w^3-2.7316686807509469076081357219409096446426901233675126821873`48.16548697325745 w^4)/(1+1.59431380887277319972733681871510516514584219340149416773085755249183482907585`49.52287874528033 w+0.3418333024570454814062822097289974745906124063707517278310630975998955428714`48.16548697325745 w^2+0.19169193726856753385254042692947355018722896144663538170944489534862376918215`48.16548697325745 w^3)+57.0033619671644559361067029329279651972667362037053746061549000040727859979737`50.113991396567776 THRSub[2,1])/(1+3.33173607957929174134618781221631893719210262813472380805061581783532477114542`50. z),((10.99859369664550241172804941991577591443263454418768524641420686323575062429181`50.+ 13.8295440579591508900859106036066398628835370020209301286677`46.90800665711703 w+7.236040419418111251450996571256718811162662681102275009721`46.90800665711703 w^2+0.00746870271221391247388856078477483474861007044388668884359325470389713058449`46.90800665711703 w^3)/(1+1.13904700131817148721765365163557419156252848283407959446282927121186844000467`49.52287874528033 w+0.4433929715966666348513654769845158056284977152926633063621`46.90800665711703 w^2-0.00444919700608101867665015561008150643051508331274608689378584521948074282186`46.90800665711703 w^3+0.0847854572953131961436667532349233176418319875924148900383`46.90800665711703 w^4)+17.87018524989986863843828516033791257611313232209560571766885523939019509383679`50.57904243520339 THRSub[2,1])/(1+0.35797124107077521802585061664598593537128825780305450829165569391851421699705`50. z),((10.58535239905861281156314861144502282264666105933670584408950180206070940508798`50.+ 11.8174275576158233193392743137602555470417578684827138831332`47.46543210898182 w+5.516206696377456997349814736137462217867514875622186373464`47.46543210898182 w^2-0.02175743920377569866823575318002156146564583028523122344947748898869810791698`47.46543210898182 w^3)/(1+1.04592714591308991341786875090558629138752149217663196796775669612725857611839`49.52287874528033 w+0.3366532541627662105366594341516003306290314549277653827079`47.46543210898182 w^2+0.00240237659629339838772350803988492960532273886408272949293407672236396009525`47.46543210898182 w^3+0.06956742108389557639651409659626197821685706304667916841796211588560790173778`47.46543210898182 w^4)+16.86298775453581108084012605382772015338302416973823243171280516106076075423693`50.65832039089679 THRSub[2,1])/(1+0.28143340927686197653189414068684492827983127852044170740377204758746282103121`50. z),((59.78431367457929460751971705964758272947200426502068850292363900918096351421677`50.+ 150.8450584843485340337073934620314023366610726247930040985382`48.435571248125285 w+65.8818665879120451504935577205986121728747554565868086638924`48.435571248125285 w^2-32.22846825730591167906877119080155618716433798980960690753`48.435571248125285 w^3)/(1+1.40402272806776172701178840140259875688649849837901757997451709241031784420497`49.52287874528033 w+0.09998159633358916437310313563663977021572495254834449386557820752191333191799`48.435571248125285 w^2+0.16339935128772285769512453087028488336591907577279956826222101026594331655373`48.435571248125285 w^3-0.01976767635700961631187701710571347864221811550902377694337890757573693414198`48.435571248125285 w^4)+136.7761495333352364273426232613709395977087831938812789842322`50.04393330856057 THRSub[2,1])/(1+9.39374102356918337624031344930972759394946420457319154436771377659599627836749`50. z),((53.12972846640087671639494127350611818225129052291900405796511503707451263185349`50.+ 132.3040399708609224746510362439200876852236201409761212946715`48.463552859281435 w+56.4853658334086531816018732600068174194740438925112404906208`48.463552859281435 w^2-28.2094118308564239663757997267711690914046365411969426848422`48.463552859281435 w^3)/(1+1.39933541632924864536076242545968056731586685676527132899949543452697003754645`49.52287874528033 w+0.087613212099990435100217370747675079206149635860958218599374082561649064747`48.463552859281435 w^2+0.16300483018537558850991720209504492702313656781736125381778221300102318408153`48.463552859281435 w^3-0.02204069347317608828908870829516445952862535582101125809511933397919009525284`48.463552859281435 w^4)+120.55685685009435052697341553883602205552002665006956309509111815488577479382268`50.05019821239524 THRSub[2,1])/(1+8.16122257418857701378351427550456304747489603435161431866274637034202337558919`50. z),((9.69795690754079408897964441088962548709236659671045180628957811816190496893522`50.+ 4.0018330862446976082103906535496456085411217608267165985997`48.73874057723557 w+1.82127707592214923941798222517772997849042545322383571702403917558390928218612`48.73874057723557 w^2-0.38570823102493019788209968417943055061877227694609748709313206924930280238896`48.73874057723557 w^3)/(1+0.45878152403086645124425641616385196122316699517859357981536970592292316794767`49.52287874528033 w+0.02259197509642861143945351130568349081009682749954722388957372328560042802904`48.73874057723557 w^2+0.03412929295264581145656501369435257121095985603023141055237432164817307455964`48.73874057723557 w^3+0.01210061839809814427021482564102347827690390173705173462159398775873333593509`48.73874057723557 w^4)+14.70012910107276053250232314565496482170718864628107176592152126119147575070656`50.979615309628585 THRSub[2,1])/(1+0.1170758601619001247119310913461730132343331425309754488783288647823669648034`50. z),((60.96444799443709345327833084344353049976070004934515346671274496990581423886324`50.+ 154.131714971932038789609104098216055372161743205616943518402`48.428140901752755 w+67.5431999586005380433883364979787640139975078292720183866133`48.428140901752755 w^2-32.9428060430630342196234804041927881054226946555495507152799`48.428140901752755 w^3)/(1+1.40472359979163126245277763210223531773494441121967741188720149360131184641257`49.52287874528033 w+0.10181302901994013452446024907355219354241887570290653009604654356123041264136`48.428140901752755 w^2+0.16346369591683810528480373663926003428866830403492306479835827692499792488129`48.428140901752755 w^3-0.01943079316617904446864961842731295271401305570631800741679088358555634729417`48.428140901752755 w^4)+139.6525037072643687345554962438304499586722641615099794757699`50.04298212642458 THRSub[2,1])/(1+9.61231773067699215636176402054632462762336136584670144238658619382949697201919`50. z),((45.2451546918821823049584893686199954968226493194834021617822161319520402154908`50.+ 110.3097843888354917111031265732114745655956968169953722256655`48.342391038542914 w+45.2576389220173809182667768956068010414431496454454167521495`48.342391038542914 w^2-23.4769365126498515419640025333617909734589795100407155996995`48.342391038542914 w^3)/(1+1.39141714089916052433704627191066618994216143026985604882315663253675592047852`49.52287874528033 w+0.06623729875411630017561419282886598528699386459867351412730101639763404703361`48.342391038542914 w^2+0.1624809853337952879699750583995179416326946876046867053983772292283665100545`48.342391038542914 w^3-0.02596212345587527846688916390321981047146173991630430411395207457888851754344`48.342391038542914 w^4)+101.33969969740539060611782716483260470408879340962396673224588535695292325747309`50.06040839971498 THRSub[2,1])/(1+6.70089374247512980190923240592580709278041446999578256502521346197349650372089`50. z),((31.07425528467186066052953657075190615936355442724713544339226124196441208403396`50.+ 70.5980778014275580836837491273307424054071082394465834153338`47.83906673603881 w+24.3791328935675833151600893143386544215125585522266769091725`47.83906673603881 w^2-15.1831583045086092719810809606443630673596282132625972076555`47.83906673603881 w^3)/(1+1.36124197319527113742513371119045664088046289319383687147140611976327276427719`49.52287874528033 w-0.02100756671388164704169490625655172146451954368763656581469999776136944029586`47.83906673603881 w^2+0.16215531449744693890065109571835409904872088891816451373810643371185296589668`47.83906673603881 w^3-0.04193119835487086324232808572993856671753657877945079221494496028743450630747`47.83906673603881 w^4)+66.80081291783038004427227206743218294290223049407358966496552432463220757309804`50.09528212614821 THRSub[2,1])/(1+4.07625307482870589977795532522310457067480466907092523837219359430338326410783`50. z),((9.6782219641569272330708284913030939743587690274681620827967709796842719461864`50.+ 3.6199985695037080229174399319788858139874303588204834904065`48.404966394821976 w+1.71102707272124100841477523044367747414137242279386895144525212568801232406463`48.404966394821976 w^2-0.42523379193866459240080896310740592672921819629982661764206013314946422944747`48.404966394821976 w^3)/(1+0.42300617137099780333655115392391607915424264854925821797927071738706368010125`49.52287874528033 w+0.00929340910483759505455496654581074299309743253701921371641458248662003689009`48.404966394821976 w^2+0.03561536036302326793311386860003795244766717911405016143740819792588028552621`48.404966394821976 w^3+0.00886575854657169699465713461224164276576843529083491587260762548609455045572`48.404966394821976 w^4)+14.65202890957821909072946163493792814165188930800187481393069949443808693133279`50.99196702320296 THRSub[2,1])/(1+0.11342068391016258966174643550811877726309517810576477600580438531942697765017`50. z),((59.15273604953988089723458136568486603084763499169067119437306602703689522624984`50.+ 149.0859691782273203307269557889118338470181554463739355438704`48.439648827295564 w+64.9922215959296174572378592815893359929230718733606981385842`48.439648827295564 w^2-31.8463442372745349466676278235734239684599435601155555540469`48.439648827295564 w^3)/(1+1.40363353045477715993425269706173977132534540629749138515403439488019777271558`49.52287874528033 w+0.09896258612680469095039172077003425198528312683745737397256364169426777200346`48.439648827295564 w^2+0.16336422019254288060156705882544662743104747148751915923416860492278531212319`48.439648827295564 w^3-0.01995508161025398142815194463942504111021714591650978320675525418467978968732`48.439648827295564 w^4)+135.2367985396608353819835789170421709697300846278791754088161`50.04445987328234 THRSub[2,1])/(1+9.27676437502910903813110005477242564443290800532075693615293377435775469489532`50. z),((9.69902194499675388299052159894421693525337853953143413854871149010060559217594`50.+ 4.0217207649025620240237859804914735647245411293707032968305`48.74934171443378 w+1.82710926813868742501538963935647565928432947476758040503235970570648904572225`48.74934171443378 w^2-0.38369548220667987935785974841110099631217431402011147035216917535734303126356`48.74934171443378 w^3)/(1+0.46063396272412094680578194544911124881719275962377794981139402384673186115907`49.52287874528033 w+0.02328682164277512765290678414613153762451752708655196050356152944258786290367`48.74934171443378 w^2+0.034051279271120224487980311331376420770042882508538394988391800028684057772`48.74934171443378 w^3+0.01226806397663722569455735705635990112371756412002558218762384785533684323277`48.74934171443378 w^4)+14.70272492841232129332828399580765544839185323194844102866710467284203301490319`50.9789608729006 THRSub[2,1])/(1+0.11727311938583170241364081443860115492878886059919092657571409394822713448276`50. z),((42.03747072656872286960967386668896869527343786448245356765309594500964341551827`50.+ 101.3488646427621311998532273723883433012239441202642661825189`48.25504623422393 w+40.6418201982873028910420571686483479117440430538992302096061`48.25504623422393 w^2-21.5664163054121913489175828894043242351675260486427110088832`48.25504623422393 w^3)/(1+1.38703674599046779641158924702246673611999222725921424067278574576412756374392`49.52287874528033 w+0.05414710890325290564147465993550725050150915023342322070886626696784929060645`48.25504623422393 w^2+0.16226884765031447704058937437520907874884264100693385968717061089761558698288`48.25504623422393 w^3-0.0281772257483343371257878619888644206724516418268481228050217703614870563307`48.25504623422393 w^4)+93.52157678798380442162825557923957465189320166940968742175398088558937597594422`50.06586052041434 THRSub[2,1])/(1+6.10678764219222534856337709573583795194469923861984467754550520860103873303756`50. z),((26.56911696913517092272618715187465362501027620812027678265714469846513217137872`50.+ 57.8293420901840003346399917140645122618128391336961386036853`48.45189975117761 w+17.1398895673562855144184004752768762654280071671341838939674`48.45189975117761 w^2-12.7236560976820297934505275425673654125615332080666116172022`48.45189975117761 w^3)/(1+1.33949340994484419267444286370276924084004358735363959266724471620830565585428`49.52287874528033 w-0.08977863777163692318746550288335351218157207694514789999621602389477477969806`48.45189975117761 w^2+0.16356878210071222040793922776861627977379052318459746623287986652120196221493`48.45189975117761 w^3-0.05453741311901912434926592834297147460855601583968286761747563359172586955172`48.45189975117761 w^4)+55.82039045237454399332975874661692683130119130203247059533638859371040513691231`50.11676267421419 THRSub[2,1])/(1+3.24184102400902937059638984596458904792492158427837443459274883457357932981776`50. z),((38.40208501991330999286365043824577148007434858854678099511246885517179390229574`50.+ 91.1789048741925006590175138371929356713366947892608734993224`48.08582957908474 w+35.3564137712505082818072781128074548795039795916452146186929`48.08582957908474 w^2-19.4176274551168253252738430901099305316250729677226565049583`48.08582957908474 w^3)/(1+1.38081731515864402314547046715264700624266242366637758522634453166942760712588`49.52287874528033 w+0.03665080458388973891344396116528510215919526849644348001059493653988849994235`48.08582957908474 w^2+0.16206340357742768979017994838842822846205096406470928177287658415995765447421`48.08582957908474 w^3-0.0313804497302559431677452195623074977718672264565815313429312094601819714883`48.08582957908474 w^4)+84.6610117868400468358872735906994261602719657974080822933166704009651600684898`50.073368063245816 THRSub[2,1])/(1+5.43346544195040726239776452476655676041011181937261263857647115112472439778556`50. z),((24.48819181363651571297084161204351719099643267758684080214550726073864665617027`50.+ 51.8641382352859449025996970077363742412471580538959511556436`48.63742013021403 w+13.4919679110576423948074951501646082810367339357375394170688`48.63742013021403 w^2-11.675320154778879015823382915601486704766941748680092467164`48.63742013021403 w^3)/(1+1.32399689905574701234163209185685293819228139816226274410421178182197952510706`49.52287874528033 w-0.14181165662665592455840631697355682631606593746474028654440442640500777812918`48.63742013021403 w^2+0.16539784237266740084368845717037878831922481992592868471569798923263064054285`48.63742013021403 w^3-0.06410855300100753222741167610095856981248035790864014800458314037518538535823`48.63742013021403 w^4)+50.74852900750620887792830806948502769879714662463136776565816964551525869628089`50.13036203377091 THRSub[2,1])/(1+2.85642577036103149257005679247452338217388196696158713027542506335356249604712`50. z),((43.45378762035826896211690872990861557525402031647362324970505381616753861629926`50.+ 105.3066723020623438557058858873117264650303270982422686144305`48.29813172724461 w+42.6844455799205467214519136323364410320598310126957153729763`48.29813172724461 w^2-22.4085894691878032512988924353394505219178263007755628253819`48.29813172724461 w^3)/(1+1.38907853128706996569561986572180527993757900220189333883039134512029515777987`49.52287874528033 w+0.0598063126964407567931168550754959825082720098065033804921610878689056022301`48.29813172724461 w^2+0.16236081446443570917876832096967969932112211667115860336970718250244691229832`48.29813172724461 w^3-0.02714058004797757201335955842378385654580627774733809656147959708208782919196`48.29813172724461 w^4)+96.97358131027308374514314167949518831658765016405091733278204518307272979895604`50.06333630337152 THRSub[2,1])/(1+6.36910853029501475441647013823764754938012723849320918420604364069622446215258`50. z),((10.09178790455623932821393108017654589997104334121050601987312110178747161400656`50.+ 8.6748201469280119346042873016609876565037783282092627451551`48.13487939126604 w+3.577592850545702417212931309888153845966953625222249465817`48.13487939126604 w^2-0.06772492983296084443739128881421047453260389351985388294931533008713398246666`48.13487939126604 w^3)/(1+0.8514471327906240637622323166314826630052529173988324725046259994884294602088`49.52287874528033 w+0.19639563225514902132748486729050980801783128794768695430402724757481179165787`48.13487939126604 w^2+0.0146624989623595478637102448424539717643061775644400082275000865207639836519`48.13487939126604 w^3+0.04808563858018589100875926935270762062408455996318532773328246737285918277068`48.13487939126604 w^4)+15.66001766038908040981197762588464002311070885079716005228748238152393685307194`50.79675755112672 THRSub[2,1])/(1+0.19001864390790103411279363756318647385134415542237268508320763807822574009511`50. z),((41.3109366585927000234074642402777908990220954615432035103028089179581399526153`50.+ 99.3177649285083413965931103039069980474770370497068803880628`48.2292509180826 w+39.5907981353500561560021745022903634488915988685031193662468`48.2292509180826 w^2-21.1353810749027472542652668897305476760984207651693495109528`48.2292509180826 w^3)/(1+1.3859145456602332132541775215232778217202958267059249227362506238234257793662`49.52287874528033 w+0.05101896961517142895691224580223932365835034034121273444255751597631811882768`48.2292509180826 w^2+0.16222345384459049407277619526967413402007248228354058052831150271765382461673`48.2292509180826 w^3-0.02875009968505068552781636860550952014341816695088918710274897163964753071328`48.2292509180826 w^4)+91.7507874263318582739985065395912903008785854699960985624946696095729761612444`50.06723524524909 THRSub[2,1])/(1+5.97222378661434916592074223352706035705973261978277321113077983177548151189642`50. z),((21.4682379550545583974346455925167278955197360827660322032748022050915397415168`50.+ 43.0341354225429155230512673141835047052261511973590588329789`48.80132397114606 w+7.36729475422842580292377775230044458238475701007266697239023448276584265519875`48.80132397114606 w^2-10.3906297712459212584962480523667232281603144794010532796855`48.80132397114606 w^3)/(1+1.28810704611945657671477865619911611149716812875979789279430295688519176762882`49.52287874528033 w-0.27154199443422553689958898482222690106253009272480334742657095872791281972552`48.80132397114606 w^2+0.17206709986123180746000750608332506349004587261237747800399329856789773451679`48.80132397114606 w^3-0.08812799184985588327885269641195896142400385147282842023981759810731941439919`48.80132397114606 w^4)+43.38796272276983877989503407272417945197731076300833215273871692083083462021821`50.15695280219399 THRSub[2,1])/(1+2.29708980417550128854925219434570493796592672874401358642970799316351523183118`50. z),((61.79963485452344090463148917898813063128493558266676421973236299325149546249837`50.+ 156.4574819728021819992091487137040364638521261890247902872237`48.42302524996734 w+68.7181807952332138477159396778969237498509186556571702062116`48.42302524996734 w^2-33.4485846170188430171188964995554468909221694410687654343465`48.42302524996734 w^3)/(1+1.40519994056025157897645238987062774955929157256029504275130357334076833031185`49.52287874528033 w+0.10305509799740964537405106929543993582278009755078672776741041993353362450216`48.42302524996734 w^2+0.16350821909657132276164233901734292063729652860802059476904848791774195939548`48.42302524996734 w^3-0.01920227119083517782834333094456620816861097685514838259354997584548032801376`48.42302524996734 w^4)+141.6881136972438126138368376836173207815312317752760007296221`50.04233350245139 THRSub[2,1])/(1+9.767005540891155594379155389096124804422438526362822946185180762618648267977`50. z),((9.95432675474304865066450504316445466296304511134803122881472358914307498491807`50.+ 7.8094542958351833200028105089504909148564510125586278900811`47.68559095518845 w+3.3126866059209496098761463562710108059399209294864638110668`47.68559095518845 w^2)/(1+0.79484127247397636007185592546673617431504703297463827575245283885503164918005`49.52287874528033 w+0.17784144546229563284879548410522407366404457448159725140038796591886258050669`47.68559095518845 w^2+0.02612006235141624035345388365516196738228952212895806386457344250174003534887`47.68559095518845 w^3+0.04010435211706050204584321300205599670454516911828860749195668996542681868171`47.68559095518845 w^4+0.00164599527950362432068089966343704124278629568528989893309967671033940028714`47.68559095518845 w^5)+15.32498210946474900561606212213369080551603664190378158820782740592840321007697`50.84983986791233 THRSub[2,1])/(1+0.16455899497146404124350207735439213650916155644631980838565383555076128377316`50. z),((9.65446211080301227905313673315192307049275030795186472059346784901265713034318`50.+ 5.087308049852286399166274129579760740728996675957115763772`47.95679429680722 w+2.7405511465722643243157518223255886191592634148915145256013`47.95679429680722 w^2)/(1+0.57933919493055152104514638496018195428248949633753212361798917034274794045839`49.52287874528033 w+0.12378420968236662315119552420704551754702086321336269157064250051427666383286`47.95679429680722 w^2+0.05529301778244714820997608718916801152759364870506957653450810475552787927937`47.95679429680722 w^3+0.01283076537161988750577639851556948523103379621267422934224931156453356244116`47.95679429680722 w^4+0.00606176418524403583596608187989756243439916062654199648042721696748271596568`47.95679429680722 w^5)+14.59411876137177403017152484572173054577625162936378178552558712478940252122765`51.00743305566921 THRSub[2,1])/(1+0.10902004033927742668438431871640038576961762563437738346357673096718860282656`50. z),((10.36786109756556835497025389193547160357044843197404626972973151819966033314542`50.+ 10.656443000475407268807423544935406229757812198620238282336`47.173985974029485 w+4.7292898207228692565895602272657082676881336187807599446312`47.173985974029485 w^2)/(1+0.98409840987705770894983268198815540423966841184414326760310650134919062828763`49.52287874528033 w+0.2850138100219016680593440726293042183091702462212349734255`47.173985974029485 w^2+0.00879122633669791766523308126722750423085136123115554125041750317038735773621`47.173985974029485 w^3+0.06118222271779268977873096567872885007397142840586195066338617244863075542907`47.173985974029485 w^4+0.00041015936911289934385481780268632528922079301187852969745935079515799613811`47.173985974029485 w^5)+16.3328938471590832237638652536323781989918653946181798778046309991412561818126`50.71153540536264 THRSub[2,1])/(1+0.24115110267411060233061867053378018267349006781226619172585727873662812989624`50. z),((9.95290995492997693556763831356465860015822735283725200207804766315956351105536`50.+ 7.7980079261125399122771455418679259333667681215545805599609`47.687658826648715 w+3.3086124753352744864206850519928072460809509137257642610258`47.687658826648715 w^2)/(1+0.79399579224690357755162890612115917255436156232571948878898389464337050950146`49.52287874528033 w+0.17749882786272953794825883960141968415871748165740529170398311883426231941891`47.687658826648715 w^2+0.02621309978959657268830038515360813838724005258518562048591068488555575183608`47.687658826648715 w^3+0.04000906582020043774894295738686472024614520295408969372397404728938603656646`47.687658826648715 w^4+0.00165603370916941703546583632915186342966503073504084772459801764303373919037`47.687658826648715 w^5)+15.32152892791805702520821968125005189014708165015688339934355609206695981563898`50.85043508798289 THRSub[2,1])/(1+0.16429658464023200864553057179589332304759851123433859489707741912484768092131`50. z),((9.61328342121652560126569037690335482543552242357837945892662708353174353895386`50.+ 4.6738713702334347161752464815300944997973612628622379133586`47.7386439992575 w+2.7303981548671119370389408738102635841805128975087422609897`47.7386439992575 w^2)/(1+0.54457428244529886111339445294662863938361005600902553227947165590033487635332`49.52287874528033 w+0.12150046264750564754385376591984977523286970430075473152973416672990366384844`47.7386439992575 w^2+0.06114337247853475727988028516667690248285986957965107088758825215625750190023`47.7386439992575 w^3+0.00760109148046873153077202307136557100127694634630899756554369193034890411425`47.7386439992575 w^4+0.00720815750923130635918447519339512297792894908329783149084194463948355848041`47.7386439992575 w^5)+14.49375349474407769498950445807068423026149791918243812358523118653648433979558`51.03593358196468 THRSub[2,1])/(1+0.10139319463080466547832527560024026111343898546459314673717254105144842694913`50. z),((56.32100753039609827140002528545993283365514538160335008295551259508633599542242`50.+ 146.3906005571095457476086774724700565977645026959129004247585`48.74156397672601 w+88.8898938860506270713535643971060301005616267547655145716716`48.74156397672601 w^2)/(1+1.49396083270532385048842325559410242354624669204978722501768001921805708590941`49.52287874528033 w+0.48733928541879727169754960552747020865673999982042450675780924794901345245964`48.74156397672601 w^2+0.31519958026646051431750424671032940939958638961399094613425203917593595981658`48.74156397672601 w^3+0.03305418031870503039622172854075286895688440728638894303060181635812940025393`48.74156397672601 w^4+0.03985687844433775390561776051578346320619410850357417384901886640314641373982`48.74156397672601 w^5)+128.334995915655438865173125165044375900215915037227003630717`50.04698490666744 THRSub[2,1])/(1+8.75229026668159442069375468320637475501387220101342535835228386936754103704713`50. z),((9.9373958672008221589735920249373403669510783161884394746556245545846386227563`50.+ 7.6717875328584026815446966865321109820686909254978908846666`47.71018315991171 w+3.2645731470018327287897998439921477110497439884313212432386`47.71018315991171 w^2)/(1+0.78463321778090620611831309381921689642912369352993238990400230732419367720715`49.52287874528033 w+0.17377584980275127141226538002332912254326956832482399439075399394641528101442`47.71018315991171 w^2+0.02725386124254171644685844475448274717157249375029127863101543650126394066537`47.71018315991171 w^3+0.03895003620059752315661413629972022814320770992301183876543794946287219308422`47.71018315991171 w^4+0.00177043952220445088456754979128466726280898192967821882486680427918957062766`47.71018315991171 w^5)+15.28371627367728036630787589971000212198090495734170769471449772598518098709997`50.85702462000067 THRSub[2,1])/(1+0.16142316747698154316355401071629093686670124301356005513819873821624941243749`50. z),((40.07236972500502613213874583023930969840251549542746034032207384619833164704618`50.+ 100.0818771729554834735787588614974792629032664751926512306356`48.62712269058301 w+58.4222867863593347603005584293736627943859313832345854619908`48.62712269058301 w^2)/(1+1.48938311111101267113029704370756951947726019544307937504310694805042036689745`49.52287874528033 w+0.45370819403740322052960770569009880809304105509902726048809769043983033615448`48.62712269058301 w^2+0.31201215069794689653531935992196967636081737211665000805007332936358243553404`48.62712269058301 w^3+0.02525884759835284024467964678248410443044943672816737974214847337807177202547`48.62712269058301 w^4+0.03828963905694461970432574435752751471551660378258147021885323493549272558267`48.62712269058301 w^5)+88.73201480937687880888210921700868624089173176505614259065801368497365386336678`50.0697163108044 THRSub[2,1])/(1+5.7428245755916321266080146621556038542010756595951774868127004732162588245831`50. z),((10.26103518241109519666544225786161930784125509795747404325528632689032843387597`50.+ 10.0031450451267799812697907463348098064646975869023926494903`47.271777655730496 w+4.3343914581299964654991197968316867219914468689027379466974`47.271777655730496 w^2)/(1+0.94467588240893844509489266563758757242607421360744337360564736388550097192514`49.52287874528033 w+0.2570135589419792261051541438299207933012744461829018482677`47.271777655730496 w^2+0.01191464577485086035906533492142973184368982811198407870993571993162859818754`47.271777655730496 w^3+0.05664081593957643812881047128578289257562179805478516220061207949078152840452`47.271777655730496 w^4+0.00053159489841755044156982206628962925260531956731832416380869769824772066971`47.271777655730496 w^5)+16.07252588584482126572632470329133754866212283592688195600540284645204650654527`50.74173569531514 THRSub[2,1])/(1+0.22136551015693302804093175964967491753462270488084313453584954277514097273723`50. z),((9.82631929811727353928204873584696319448923791268334829557963797002388956900483`50.+ 6.7199042227856917820002029150413246298410745297726475481087`47.85909030440418 w+2.9857032887394666119794394445816866161334814458257812774984`47.85909030440418 w^2)/(1+0.71183301365783939940472443163068848404052953389398357997826879937724590780904`49.52287874528033 w+0.14916274874212285333776124769930105084359151405903015562582518613410071759029`47.85909030440418 w^2+0.03602154556627734782494896437322471095175619997192697340677482930829922126241`47.85909030440418 w^3+0.03041375579798617097089808890094475692732737430626547788147110959553786725563`47.85909030440418 w^4+0.00287656596583691089466830277107082851423438661423636428261886802698851757453`47.85909030440418 w^5)+15.01298814745204649729974123602996469655733665438647947188383227332079509718622`50.90847089316818 THRSub[2,1])/(1+0.14085029683117185216885506311799699410128415608388234437946038364202812508522`50. z),((41.38593604346831840137191368674255937614705046872535139055548882000216245692506`50.+ 103.8295536427729983637131417680989842383219202284102250690881`48.64280415574142 w+60.9037471124214096226957034476641746829827827780749474864448`48.64280415574142 w^2)/(1+1.48998347601380684585214665446470815856081594642568423341349322141291964329584`49.52287874528033 w+0.45779790710223557104356490322154327524255632981209916077686130533249874797398`48.64280415574142 w^2+0.31230603101493039398994751405798515190553128215369656451091092539403069399647`48.64280415574142 w^3+0.02620179012388468739642618346103800947165013930676196383578768825287285444825`48.64280415574142 w^4+0.03845265122919542036973177569028375910939115592590233790793740412876974068612`48.64280415574142 w^5)+91.93358424030392907765163764131650935839661609219530420629222777333025674442109`50.06709067784515 THRSub[2,1])/(1+5.98611467878262299659556023313905634786869913407032041761050581256328737186535`50. z),((9.65839930348633375420925966120907121597306334315385058079501164196862117767654`50.+ 5.126519751719653094153509819752500382660397915635060176822`47.95892222374991 w+2.7426882105816947009063317159255844434985676904564422378652`47.95892222374991 w^2)/(1+0.58261470332129865501681212027017925464759778339099681550910470655475408264861`49.52287874528033 w+0.12409890973503400062354366077384366806305678686976902452850377415136511569108`47.95892222374991 w^2+0.05476020549509552438089359024006067877933551626017693466642034157361894670179`47.95892222374991 w^3+0.01330785633266820958484987450443006496699894336371332303035506358019853162101`47.95892222374991 w^4+0.00596132179231785776120136732805370093327123543113512515665696323131910200007`47.95892222374991 w^5)+14.60371492378962452608772893277557193041169217774463695757145910122068825671273`51.004823259048315 THRSub[2,1])/(1+0.10974926124022797429333086712942401332427926248962324019297851770811976888424`50. z),((9.66942565860738907897967428671631701670888322626672814321076539267144261051503`50.+ 5.235983655552573993139363353354204710348119054725075450189`47.96297697324368 w+2.7496963098286360297430477858047820711106987628019107444107`47.96297697324368 w^2)/(1+0.59173748186543243477968339255243694026441516689152772444711339623109160302781`49.52287874528033 w+0.12506306637271308990992932105371804767950343782069667588551758992633222832725`47.96297697324368 w^2+0.05329236939603060505388283385065815578412193112274916550688166489519288076761`47.96297697324368 w^3+0.01462335950371558237319820685302468975758784670664435071467544330100230319233`47.96297697324368 w^4+0.00568808125526185809658028388022888132376686216481597215707927268617101251323`47.96297697324368 w^5)+14.63058957868441137822071714763489881165879248274191753186319556083654274027443`50.99761460042371 THRSub[2,1])/(1+0.11179149012316733703663174670126908160080687803568211798796951435167617760326`50. z),((10.41803294710345175152849276192608662794340409733385610144545671477980205090605`50.+ 10.9477465499490866888074094584426875018906990603089372142339`47.13669695182992 w+4.9185595369594452866581963261614337840348359701038664306978`47.13669695182992 w^2)/(1+1.00084443212681288219897878039099955528065218844131472910729649955536542842688`49.52287874528033 w+0.2980443983954765421786039236149294350008288526072090927071`47.13669695182992 w^2+0.00750498420146382880369530132613477597519156941135081396060353006745236564067`47.13669695182992 w^3+0.06319759901002886330088038609526552706570196338797362669034856258144550523648`47.13669695182992 w^4+0.00037135547803937308606520945484227073348076364111533366898986652184394835513`47.13669695182992 w^5)+16.45517824004871997071533806019718170431693971889840824561287632442841178789198`50.698354167057374 THRSub[2,1])/(1+0.25044360224553260336998760758234683734012743571046267732564481921336000899184`50. z),((30.68493488313774892575435190865485241246692585700147185439837960000411893559066`50.+ 73.2554801751107776717243836839797899111122601808049085352494`48.39450212708175 w+40.4701136070835425108830637364736874545401341793580834425727`48.39450212708175 w^2)/(1+1.48217762592757726361404821333205452985984177989988869436922943456934697719735`49.52287874528033 w+0.40779870705053827020753354316259090309676576773395631300500407411704267462602`48.39450212708175 w^2+0.31038883108576390265003088686402231166911679955105937987198770103025028057092`48.39450212708175 w^3+0.01472543926868306030228145591712070686102899127649286618361912292845362307015`48.39450212708175 w^4+0.03690010783639500675714198799803392584325747848190652568305375995481157951232`48.39450212708175 w^5)+65.851918081788884366026007183462832610156230169364116647390531226999685687834`50.09682007386872 THRSub[2,1])/(1+4.00414571387383611963285633674018989041879800552694943644725973896430886381825`50. z),((56.15348385185357475002985368573627327172159855141057766606549460033383209072869`50.+ 145.9135377704003969350637932524587753339333354248624912976609`48.74090368437244 w+88.5774812147057719895345392797588877664140865015082731206957`48.74090368437244 w^2)/(1+1.49393393349789474201570960285962703034425015381859206976001713085544696197084`49.52287874528033 w+0.48711803327733742103447860516958456981628334025652639542814968798666707593724`48.74090368437244 w^2+0.31517274755126294334676778138560337430506679302966653297904563724520267889083`48.74090368437244 w^3+0.03300252775290970645037432185079335977918794342571641634946947653391029818709`48.74090368437244 w^4+0.03984476110293566370310796767237656064145808630746490812394196120939865985009`48.74090368437244 w^5)+127.9266886374925501553179013765124911800873626030463233939238224356636252177403`50.04714331125743 THRSub[2,1])/(1+8.72126263414666056726924881526975183310087534145790424760206891745454974828185`50. z),((9.84195190766212822892371541712130180084902004581718829650952844179105098799158`50.+ 6.8590274562558772638955256947096216931223480285976927708967`47.840075724642105 w+3.0204973425884401711516771059354351925191765903417264152323`47.840075724642105 w^2)/(1+0.72270213595227180795413290803416655011187504193621635125435585069273314986811`49.52287874528033 w+0.15235752664449000398329036752542342457920124204230198830110276982276081772223`47.840075724642105 w^2+0.03463480892887840953935681309571259041547210926469670121464343655205288211796`47.840075724642105 w^3+0.03172775280197729906205473916048376240222755763887091454395112914183563145994`47.840075724642105 w^4+0.00268569964776259049724401373486482686929936322004660798708097337819170932887`47.840075724642105 w^5)+15.05108967619935490637119783544675116672448374938765754373589234879250892209732`50.90073470249262 THRSub[2,1])/(1+0.14374566582461673752169424265280208659017673104693350308827394166290693964371`50. z),((57.75311442533743748168323799064210450449335649480041415785308032331896756250827`50.+ 150.4686511117153722584319085186406559922444994287318441094005`48.74697372704799 w+91.55969935829649006791352120790206081753046782582955721031`48.74697372704799 w^2)/(1+1.49418081159496746325297530198054107143142982835190728209286907302829859663493`49.52287874528033 w+0.48916504638703124400148718987649263590303832682428190486696839499502147254736`48.74697372704799 w^2+0.31542404738343978069887842459762721975052000865363380985845453244537076606928`48.74697372704799 w^3+0.03348064194886871282400493263442690282679833528324024037828131001967919429381`48.74697372704799 w^4+0.03995786324800190641157011653739007492335697974971510518361438488464558463691`48.74697372704799 w^5)+131.8254855789622072592732165738096816681296265985803737908189`50.045673028600596 THRSub[2,1])/(1+9.01753567481478453357395337783996295319503477761928402466333306570743910994176`50. z),((9.70741023172817646662139999757334427642897250767806174669055888566082636374167`50.+ 5.608625927727746341220434579593593715322405511283692757485`47.96011680775757 w+2.7847600165588373896692920424030079443683905905371207607494`47.96011680775757 w^2)/(1+0.6225474902064799029662953868781375096142086520575401768067833207632753717028`49.52287874528033 w+0.12925178846230466801794224906660781582417781655488737917754270719937042601354`47.96011680775757 w^2+0.04850563734309355026223400450653934934130572762694512966731418555662084326609`47.96011680775757 w^3+0.01893016596119218577625971879048210093861432972450016129141428805930219870674`47.96011680775757 w^4+0.00483289245683972294461690150787425409728730943159343581123714981985184464661`47.96011680775757 w^5)+14.72316979061660748836174760721748490807200884341396144571754423813506628955563`50.973848646476746 THRSub[2,1])/(1+0.11882674261428878154649405442859958778371975561415320460808370050565368014832`50. z),((26.81869185855272648013248842495551198683385401171325891408177819937083882875815`50.+ 62.1679696641933474987779432825168154343798286868067091424275`48.038700762986295 w+32.8556681121104248222230109959780211545772652290164196162364`48.038700762986295 w^2)/(1+1.47629002625088785147784351869496368024406982346625622717178040726794571098981`49.52287874528033 w+0.37179969931460567157645368814976287218263604195423837791516503632620882116142`48.038700762986295 w^2+0.31112361841417116369667857381311038706540275508821864788508262658259702145199`48.038700762986295 w^3+0.00648634367618987827600557695083346533265330495207407833948055596056523140039`48.038700762986295 w^4+0.03628606225207858544248046964941516713257477232648629046536953987969053861343`48.038700762986295 w^5)+56.42868203648048485369476601813497204204488833151406910587782365390103233011708`50.11532094587577 THRSub[2,1])/(1+3.28806564148499430996356302382941266219559948540115999704411101749155869192954`50. z)} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};

(* Sample Pades for the 2-loop triangle form factor with LME to z^4 and THR to (1-z)^3 *)
(* Mean and weighted standard deviation *)
Ftri2Loop43[z_] := Module[{const},
const = Ftri2LoopPade43[z];
{Mean[const],(StandardDeviation[Re[const]] + I*StandardDeviation[Im[const]])*80/Length[const]}
];
(* from 20 each of [5/2], [4/3], [3/4] and [2/5] Pades *)
Ftri2LoopPade43[z_] = {((118.90056289471833860742603948225064057752894046473065170203727695115672008679581`49.11873502411788+ 188.83214444641325385142013606119012716777129676374928987423471696962146589424754`49.11873502411788 w-27.27165265828539031507803687700709781456843159858938673973247540422471636803645`49.11873502411788 w^2-47.84672117086533420733425474702713843026562227718967518739170418928705881046576`49.11873502411788 w^3+21.58992043316244179314569347235625718306559293777274984090561871745198854013908`49.11873502411788 w^4-3.20969401303125014706039887355331517431560394545803526515445664035936626383056`49.69897000433602 w^5)/(1+0.91986211605009870450938326393447628971097560951886072070134900081053011000871`49.69897000433602 w-0.25775978141223983822113737598396286613701934913991297715267552041751206229765`49.69897000433602 w^2)+127.38694482164124073240906552415095941639501644920399113370678936806782827445371`50.04735435535827 THRSub[2,1]-71.7651573463083489964933890162657714305117450898149399205867270770851590864142`49.219115156050215 THRSub[4,1]+121.64557172243233741303700209254140996859973826973306725110186084862556479125974`49.639869028780005 THRSub[5,1]+122.45459341429492521029086167870911712580896791159988295389884345669709124713526`49.04761466417259 THRSub[6,1])/(1+8.68024702243239557027971158493913357545123949937986257344875814613022822723086`50. z),((5.70751059900847542691458463675582218277196679279434761155811394997580066785951`48.99624663599612+ 10.23512847968622364175122908782691576839727168986511060790376213622003492562613`48.99624663599612 w-3.3484645317339301720804033254685167091559570886293287606123016285587179783899`48.99624663599612 w^2-1.7444102366513051729018909340559335500665588084119445017753720330029592630717`48.99624663599612 w^3+0.7832618673617503864770997929380460423463148021047584787473911491417947971931`48.99624663599612 w^4-0.08812228014545317218631078103381298861463494522777465870782315921958789673658`49.69897000433602 w^5)/(1+0.63149872495484960173335513959369222791923888896984881536874338386270089996618`49.69897000433602 w-0.25634728224082323777472642255166720614181154700883883858108165817276232804936`49.69897000433602 w^2)+14.71728297012859411542187111516794327652502750763662087272494568297625637214887`50.97531303143253 THRSub[2,1]+3.34795055470008208149807392305623932940158087122997358673450204630922218179311`49.98753858138168 THRSub[4,1]+14.05397000146882055553447230576586764352630580509572893194135852191400106566304`50.56782770485426 THRSub[5,1]+6.38801741405965167451503330996706684544289539612452841709089447904226124110145`49.80371924645483 THRSub[6,1])/(1+0.11837939789948717198205718820936980889861874019483224234402849619209632687642`50. z),((57.52168060942669755986441808502897778407946491872648133607707186885473207787119`49.12540878839923+ 91.68997510548405286331965960602017920929615761426164711817798776133200415980392`49.12540878839923 w-13.35460501939796173348041489728559321938005121650449061713197020300467564753876`49.12540878839923 w^2-22.55999673241881182875820845920054069640714179650701019603726544813128303971845`49.12540878839923 w^3+10.06145066546704747924245195324802383046884090432075847635124777829802832123554`49.12540878839923 w^4-1.47727395308257996990888083971569192660162862960229828698861956464212325855362`49.69897000433602 w^5)/(1+0.8991660713461136054902383689215628904306816108172292558997056032248990073183`49.69897000433602 w-0.24490483216153532232986608783542058364582269493986305098949323443370911247695`49.69897000433602 w^2)+66.29187077203267468817267266204876908088752412030631033708520375518793218321229`50.09610085597817 THRSub[2,1]-31.03510797990263830033579377486431120684008353721648605617233666849856169224979`49.20983152940533 THRSub[4,1]+63.3040735210688403448623530598393025219486769931727149865052389456066841867469`49.688615529399904 THRSub[5,1]+59.51754417770228924416426429828307392847437823253612808039487911216630191654054`49.084261504859086 THRSub[6,1])/(1+4.03757810936543483795969653566349377682508899574427081186023517707698518794455`50. z),((127.04234347764638726528087953401089983357457805773017495483925628557703651287338`49.11840655372701+ 201.72795323586296597441858872699444709761585556267660745097415549224215211177526`49.11840655372701 w-29.12610527481422953802147644817972015710870500613630346463043831469962470393548`49.11840655372701 w^2-51.20691548765715589373414326334902930229071976726354278737936710787910420341059`49.11840655372701 w^3+23.12263497431633439055094718805494193637519911172271980948063089390683620126747`49.11840655372701 w^4-3.44014218538960953203677416291652512335390279129172225886546624347575361399874`49.69897000433602 w^5)/(1+0.92118463870324735630200186271994409313285204675805849557001828525857918918185`49.69897000433602 w-0.25861588267828692066000310325479619582896341981805440820052683318962151942383`49.69897000433602 w^2)+135.4910788346656656045989893358979327002184247359466297206052912158424859203837`50.044372022453146 THRSub[2,1]-77.16791335499129891128667155743042028639401728097669897851906164226826418369271`49.219457656617784 THRSub[4,1]+129.38444964834431169934148542286885765294860222747709085965173905659744140605292`49.63688669587488 THRSub[5,1]+130.80306159003537459378129808780564280637603537105303385462033411652512102076564`49.04537353073653 THRSub[6,1])/(1+9.2960873603792182082948812682339979177647763833445338439526346588650694620668`50. z),((66.95790354261055788662271480916832735842378881175451810292855859425226436868122`49.123370531784076+ 106.60881318794292443162876011004773634643851593530935700004025737659942075535733`49.123370531784076 w-15.48093451076673282113654814135026154222622636843310201992667977022272440900368`49.123370531784076 w^2-26.43828647289060674455075083083083914921466320402106028473625396476989143202301`49.123370531784076 w^3+11.82837389885175987203664979713255442875100355457159141434469975129791130376773`49.123370531784076 w^4-1.74260794748612205648207234533227832412758361867668717612303116995884275691563`49.69897000433602 w^5)/(1+0.90458405291146151043539639528264368153858481975341778732895048742227733025355`49.69897000433602 w-0.24816601674131352340832697173474155632340348301938047784105280498005892639665`49.69897000433602 w^2)+75.6844617966110432509527987289984542738029554484440895509020046302471035587953`50.08295310112607 THRSub[2,1]-37.29683532962155067552254448616410133545037108930833886538353725187134260930462`49.21305734651158 THRSub[4,1]+72.27333726108214326637652925990963917795064264052395504457475519524570610062685`49.67546777454781 THRSub[5,1]+69.19331547299633727659661503815388715398305865273103111639903030995169326985262`49.074372536530184 THRSub[6,1])/(1+4.75132943942444361231145594683611204483202628372802867729820069728314728450838`50. z),((107.80032348680514263177995941322042259933599109893924128666579132397433719557091`49.11928078252526+ 171.25260795809573383779137836399973456526646729664918909689086483829235438117276`49.11928078252526 w-24.74512072033312304676818505813343213187378767679626308592311864145002543808501`49.11928078252526 w^2-43.2668267359873739285935529680366750130730260674342708331744077665761593481838`49.11928078252526 w^3+19.50101321680691197443484780729564913545263041091412530107246958308409598318254`49.11928078252526 w^4-2.89564718933745668291469273835218213435609276196654052806755658134951632386238`49.69897000433602 w^5)/(1+0.91775750836025143451039512161525512362152947408108078304611451321528498646823`49.69897000433602 w-0.25640546843332122971553629889965631891096147888049634971092596715039501806007`49.69897000433602 w^2)+116.33803152532741658381505329727273322936664142303451038873031899974589164114432`50.05213225298217 THRSub[2,1]-64.39921514876579956409738086501362063915949507236861942393574683153720133086711`49.21851548313079 THRSub[4,1]+111.09463672101966307467172178560563166442583603508988141309709708592639742586008`49.644646926403894 THRSub[5,1]+111.07256285032016062938442441097877121556457544914085850010117765879257086300932`49.051205167965236 THRSub[6,1])/(1+7.84063029257433516106442423844696894098607690128698488937558585749804316819596`50. z),((77.07920572075356883549426237814451075060601554662883384989803919347179915335913`49.12185293668636+ 122.62004143588761266006562336006239254951613990518172081401561230097750548610688`49.121852936686366 w-17.76968089035132813667235102761143377040400224949717662239382194105634401586065`49.12185293668636 w^2-30.60366797204567996400084976182545243657013255526218597655536941209816622552385`49.12185293668635 w^3+13.72684773995737927103975244630307673410598246228464441106075703035533734245525`49.12185293668636 w^4-2.02780824687207120238819054869724479576423325343037657066670123959835072517975`49.69897000433602 w^5)/(1+0.90904109382984675180407349581328917841916063901183050199644933120323390078046`49.69897000433602 w-0.25090614886247717472727441534071097126044405403245246333092016086417765543053`49.69897000433602 w^2)+85.75896434584190671070566015214440778346605185185823926765434365878911330123254`50.072345946999604 THRSub[2,1]-44.01317036244212631535778543492807034189243535825110534321842993756601577092826`49.215257345036186 THRSub[4,1]+81.89377854049409863983929972802698280884007762818335600364693921550647117713516`49.66486062042133 THRSub[5,1]+79.57155746449095723221921011134411458676018641414889755277458362709195316295183`49.06639763235813 THRSub[6,1])/(1+5.51689983159630886861065708920774292758583716594729296901654919097485147918392`50. z),((112.7216684404730504240305754691121510872828299450850498635063449155806415306726`49.119022809118434+ 179.04623248717884871988952767297737939760878096766012774467550578182323437863191`49.119022809118434 w-25.86498885586765091105946507053135234785122855525268153647724285036698316177239`49.119022809118434 w^2-45.29714068001348912944885510047579035991872321098566950181686889359719103637863`49.119022809118434 w^3+20.42702158724524430485048870772522148739490257103604623298143832135250832239386`49.119022809118434 w^4-3.03485929353245771104317989422768963566571955553006604184392893461803042590469`49.69897000433602 w^5)/(1+0.91873865508047279885569955425352790909053530486659860316742531974010797018447`49.69897000433602 w-0.25703559490105960925861268352263129667453297987270194730750564616121125573298`49.69897000433602 w^2)+121.23662079859703546615572633643223732439107251951823211094336952691293643101684`50.04989994605014 THRSub[2,1]-67.66494133094554548565782955778662336917578247002443390541111384964856452412088`49.218803527415496 THRSub[4,1]+115.77244490312643381214142649935681634267628191052509330918466668780487259997012`49.642414619471865 THRSub[5,1]+116.11884127910602159381214436983448853291517639207495977910868473766901397834283`49.0495276175648 THRSub[6,1])/(1+8.2128784400833378961610203784594042228619459335059955694680576867571156381467`50. z),((8.29110948891161686462830154080494315561958316272597763461974655386637082219978`49.05730242952701+ 14.38714269065661035966406604522143961785211421927830533375633611446202434921926`49.05730242952701 w-3.15283726417763508779537032613717489881529084053448120297569096824306545694921`49.05730242952701 w^2-2.71163119754310490378951916952029278693139025011405310280844279033643179679489`49.05730242952701 w^3+1.11888490079357177883243388836129579818690628213363723512053415300682022356587`49.05730242952701 w^4-0.14022435874630837135083107696974038971346693027338511155315990311148011577251`49.69897000433602 w^5)/(1+0.73500353851897833648518260332607756920145688719093873631248103650868545500776`49.69897000433602 w-0.20780806327401721633012909580204082476540014294700376828265847981097858839242`49.69897000433602 w^2)+17.28893562355176838294515578662823198518965651515583434137228451288387680265297`50.62187466865882 THRSub[2,1]+1.63351545241796590314921747541604685695849486621716460763627615970414189479027`49.20318092120504 THRSub[4,1]+16.50971739171494219249846384209021035047131619640961143846256835838903191151209`50.21438934208055 THRSub[5,1]+9.0372036567424264918385016265408137485924734351126451474798722206216875066131`49.49655527981179 THRSub[6,1])/(1+0.31380156597083316002820625900957293439057168633816612279737449786662242067763`50. z),((5.88907404163222161886819278355112527390248194152203018788716489592084186202601`48.99881570991692+ 10.54454999489078409838483561965989146441526484210022208254178702917259412019807`48.99881570991692 w-3.28587730325688058130092620435166073764757341826154858030846903493848852691187`48.99881570991692 w^2-1.81250677530800188063392172630590001388118306838964203110440843252849831938299`48.99881570991692 w^3+0.79986947246896052308993878416803322048884135563663377311107291050085777209889`48.99881570991692 w^4-0.09100921717265806617452834301509671746022429878354939127493821658342136924648`49.69897000433602 w^5)/(1+0.64473429995791674454420819132651999947102934076800152539995117605177248925922`49.69897000433602 w-0.24817363442030230387608763750746601304388748919261595725168559738409920314248`49.69897000433602 w^2)+14.89800688621818022406919196050797937065704361959769728170621066499021618319843`50.93294489441784 THRSub[2,1]+3.22746794397369134239986002616288193331357012992258931408032539163324897442666`49.91971379533867 THRSub[4,1]+14.22654862895231582532972978442192768002804425842822319909952241469015155890193`50.52545956783956 THRSub[5,1]+6.574190034063751518707219718206536929140132080985997324256885956033647444897`49.765612319870044 THRSub[6,1])/(1+0.13211276871749371899413855573524610883713914211568126748798844565417172343435`50. z),((74.42361594986442659329996279915400778026428721026500888299191251436282365174071`49.122201828064696+ 118.41833083081138436136426882214770219833577486278012703027552977190946207492513`49.122201828064696 w-17.16853246210091714850495042751703454586863771544875388456012411266396196042974`49.122201828064696 w^2-29.5103287597319720848134343236722474792970670934502166571169329636430480434438`49.122201828064696 w^3+13.22847275205834402130590360207770066693449997778346979263764428133023054850879`49.122201828064696 w^4-1.95293034993249884487050516005782999644470462367622906055517854253600125473075`49.69897000433602 w^5)/(1+0.90797898621612531067963744940672152688161445910309817464824073583280950569596`49.69897000433602 w-0.2502486179294329450849579588174729627371828435376410179781598333265996584113`49.69897000433602 w^2)+83.11565368821636122901314440345271479268870078599594073490594846092150810635977`50.074856731170556 THRSub[2,1]-42.25096325735842932756277493580027501470753464767623965471949980565427897434645`49.21476806212276 THRSub[4,1]+79.36960279676253387839940968619515843434932792619021218740825643961032263772382`49.66737140459229 THRSub[5,1]+76.84855277721445670894507011543784570290905487335295606438263798082652954465178`49.068285133529685 THRSub[6,1])/(1+5.31603230817253898140182792090040978050658369626831048330705462063468602329248`50. z),((38.36723923343540172566408341358136048157286010876499715253664024177450365365013`49.13380901897442+ 61.4522312495727347907552493121433515889041044561738783564447565255829992747214`49.13380901897441 w-9.08039134391905820904427333584507044729260828742310041564330161195139019719012`49.13380901897441 w^2-14.71515177797224125921858542361229462355787982294543884690797911148591210487767`49.13380901897441 w^3+6.49141385268860894069088931415673617691215294680008455726869027437740425467948`49.13380901897441 w^4-0.94171873250398415327063730459944656464293389540760742728824633882752239631422`49.69897000433602 w^5)/(1+0.88116575495202866244727084762799310305579260428597530438717555365643326389821`49.69897000433602 w-0.23467402998125982649334794997098052111375485523926382850107789592702529103196`49.69897000433602 w^2)+47.22599712503890846689530498188161045924923319345438323769098876451726979516778`50.141853306508956 THRSub[2,1]-18.32452554857346081948421532141953879241455625264853465657619334138478676688566`49.193805454030894 THRSub[4,1]+45.09750530936148127594037658886874316324787452049494068015878622238950531709863`49.734367979930674 THRSub[5,1]+39.8768473273284953823899568577501446633380293267694990638109856939918174738582`49.11872675238662 THRSub[6,1])/(1+2.58874544554893715580532473316125543482506629255173833725527651320168181420059`50. z),((22.60761019111717423785028400420210899234305962245024338960433505070846929750723`49.15647054936689+ 36.6789005813061992610528766152627973760098121669933791123537967745097068451223`49.15647054936689 w-5.67568840981111634466842779333266926323978170597855115897624384366133228796272`49.15647054936689 w^2-8.32665334740406946920514491747773139060877494689010034162937860795276836836811`49.15647054936689 w^3+3.59546394570246650424768293209011255246584506601321880875175480676650709780932`49.15647054936689 w^4-0.50852554308049955620844104364231574131296519477883266907842073816058048443986`49.69897000433602 w^5)/(1+0.84814002023953072953144812150964018368610140695857559547271148729411074409356`49.69897000433602 w-0.21882185361469787655048026650830201619272588563818229549484103440685847395496`49.69897000433602 w^2)+31.53923862625275000835836759101415717245007307879882208714248849017296628462661`50.23451122494965 THRSub[2,1]-7.86668654938268851379292372750790326788178284287816055621052649182191775985901`49.131007157376374 THRSub[4,1]+30.11775437233778192776782157840340914943829150190035283568470038640087276710763`49.82702589837138 THRSub[5,1]+23.71714366285658211612046880999422793374523485323641425024246892094539038893782`49.18896868334913 THRSub[6,1])/(1+1.39669474159255080505553264504310365598481154496692401850482720882793889164181`50. z),((8.34570463019687344497701368592143822517768387681498663807016811917295586130661`49.05862743690664+ 14.47235024608228745176152295260979816780870843661543216026453498273059707325395`49.05862743690664 w-3.1567386679622805202767882200363849321719962188026807593192556741676686740961`49.05862743690664 w^2-2.73221558470117632062323970943856576559610095842210856054407580084681597786949`49.05862743690664 w^3+1.12718899921009753413254267554178732904209497851274610432074006517070919198302`49.05862743690664 w^4-0.14146669997780666186335705766088192750410582154156578579770156762155114923493`49.69897000433602 w^5)/(1+0.7361961339100850040970479561311266146672298780926665754304238387409668735722`49.69897000433602 w-0.20752172760300789835680595361778498245984597348110131056643484727857971218028`49.69897000433602 w^2)+17.34327832376693480507378096640098064785236752060553919484157339028295384766329`50.61755967717283 THRSub[2,1]+1.59728698560785495506346735556754774851668752925069470532341690810475719811664`49.18692742689665 THRSub[4,1]+16.56161084787617063449199857879392732025200642496139172183480565299080418955841`50.21007435059456 THRSub[5,1]+9.09318475263755840458722509555730028357381580795676086487789023499547263845605`49.492965767666384 THRSub[6,1])/(1+0.31793111600192419906500814148196090517826306876716838687235872557839427367135`50. z),((5.73148075275379546670210358304110670644044942703355788466473290979997675106812`48.996535486282674+ 10.27633397591090772203978214543085981627811305901020714582931569341682642621492`48.996535486282674 w-3.33929116016959447991514394699124346459401033817770526003997300982688497012991`48.996535486282674 w^2-1.75341448589341965415070560390307186355140034297023283020777314763719773831544`48.996535486282674 w^3+0.78532883688830729353711197215080528719434263343842395063850521701150914318483`48.996535486282674 w^4-0.08848994535199017222804057250581548423786820226873565495158695479921869991901`49.69897000433602 w^5)/(1+0.63335615334336368884409602171059158404379411526086021964617436712045887090047`49.69897000433602 w-0.25517636060223427143090819434160722228347561883728428501045530916489687080103`49.69897000433602 w^2)+14.7411422888963091372456364867852967394625127794927973239628144681903168774293`50.969415328446985 THRSub[2,1]+3.33204434218827206694889700864467035410992402332585595257592285616651517827269`49.978301125303055 THRSub[4,1]+14.07675397259294300342235911988058439827626749876819175892441319359528919634287`50.56193000186872 THRSub[5,1]+6.412596075161133062910379545159898020705959121248158537281107739385818590703`49.79839584770359 THRSub[6,1])/(1+0.12019248871332071937966562855089116192924553870954336133025096784874335779789`50. z),((69.23066350468290000771222768699629331272483469101086475567787918630403101114749`49.12298145827418+ 110.20345580660686526094162037862602038306998785420995377540377292965058329190481`49.12298145827418 w-15.99426590159616595316313509253090837623514041639734821636275083930555905687976`49.12298145827418 w^2-27.37320799784820288771025044539397269786758230906732669408426056445716842537032`49.12298145827418 w^3+12.25443017826386279605130969230140177265120835270107472904974008480586554346815`49.12298145827418 w^4-1.80660412375610757528491152525607900454726796329799117193385360042769897272498`49.69897000433602 w^5)/(1+0.90568805811619405163536882159212675745007550299971876037478682271494842398144`49.69897000433602 w-0.24884002677389033826209372119638941496118323803743750093175459818560949642248`49.69897000433602 w^2)+77.94671280232981792722397609591207741045931717004474662427624774645405322218901`50.08030832392139 THRSub[2,1]-38.80500266676740045970332939743985009322127890370877691429969932934264238490154`49.213638751969306 THRSub[4,1]+74.43362784153067070675135606796838610322626367109080087885651089284371760995494`49.672822997343125 THRSub[5,1]+71.52377181742834718306630824250128663198275357850784894650065757012577212371346`49.072383850656635 THRSub[6,1])/(1+4.92323990162106507603918879190354020292512461414342956052170794033842924233957`50. z),((51.98448091383703514341076685176442151793990280245043641363783687411189073513918`49.127050480444105+ 82.9409963959498340845204719002105798676104023448481230025724243978832366580676`49.127050480444105 w-12.11170903127009018463787666128479279521835086833600731003204065559047047187542`49.127050480444105 w^2-20.28746431753726099145031670743770820690822794490066273240781356632317864649869`49.127050480444105 w^3+9.02655814932428802417211635655294739351674877963782707242593053133004145008219`49.127050480444105 w^4-1.32193224291381509775023714184733060047617529795603478609331788916528800258034`49.69897000433602 w^5)/(1+0.89517555847807552958146011178009582081790909381438993774099982257839501066223`49.69897000433602 w-0.24255413147855395792228054562908837196817989529160485954231682747567111059759`49.69897000433602 w^2)+60.78027439174819737162785490432011634631500706690193140356641797221447441702472`50.1059659524209 THRSub[2,1]-27.36071039304632008930591526971187605045840550161356676715981281318292318145721`49.20702973189538 THRSub[4,1]+58.04088667157080647833261406457569045300265377121218536380561597803848084771388`49.698480625842635 THRSub[5,1]+53.83977689197113511829091910991215006351022519351820815513632865576291983624686`49.09168508801757 THRSub[6,1])/(1+3.61874700760849909726539376877502941025145271035226193158307450857238381001226`50. z),((6.17858394894259489741934345051908449367325705558159628104589667340898731595792`49.004315557074044+ 11.02743909730306251214689333828926454686062205648142889816831036630913911601779`49.004315557074044 w-3.21338435120795594187545865299966122632525066430148327200221473792857735206079`49.004315557074044 w^2-1.92073767290491064984116293481397971964820359119751857785330536229555905064695`49.004315557074044 w^3+0.83014401248046945175032216679439783518624428109824477189440542886805296457001`49.004315557074044 w^4-0.09602221568039390347909266305858080449473438557977544805187181664205878569179`49.69897000433602 w^5)/(1+0.6625311764303611881002344374101197837294372416973834239693957852747611503068`49.69897000433602 w-0.23787654242833446720228324321646558144808554641626494445096614553925838274301`49.69897000433602 w^2)+15.18617813611174653231687351239997328321462622997350633107313835503034322435622`50.874657822127524 THRSub[2,1]+3.03535377737798047023473899156821932494184838967204994783570693160649761365484`49.819983507465544 THRSub[4,1]+14.50173190221750119907246002019342168630896668063514029132549733084197536834647`50.467172495549256 THRSub[5,1]+6.87104945235981664976036690089414259563211183880024703419640035638855289123321`49.71372019410118 THRSub[6,1])/(1+0.15401115781567474966270987166578602731920864073929478140272878427975042149861`50. z),((6.26037201999879445283627207179993432271371219531855946492039431069952422288372`49.006090266490794+ 11.16203509018963440194098995555363789828181754453921954037106708835981882594667`49.006090266490794 w-3.19775460199485356645287737677589921987248970033520172391695304639598255515376`49.006090266490794 w^2-1.95126921929610716380482319432512066495193923951273258834420792325578771749496`49.006090266490794 w^3+0.83937747039722204009765144932235176610864392496732305063105014428422441061143`49.006090266490794 w^4-0.09751266500484499144379927227225672952222728779337176104205587923052852357326`49.69897000433602 w^5)/(1+0.6669695461843989510546711430922567814396338401544511714712731408373498092423`49.69897000433602 w-0.23544894025491250333129948488486467992043499129445765218180428099187484355509`49.69897000433602 w^2)+15.26758802940904700881126109727742753090647189921252571855440413341148022075597`50.85987603238968 THRSub[2,1]+2.98108051517978015257181393498324982648061794351270368951486307935240628272167`49.793277344909654 THRSub[4,1]+14.57947262382659597229126915764366261480272627146795923022142018025672525379928`50.45239070581142 THRSub[5,1]+6.95491379891315027746056840991219458679687398286223592975099696086610335885672`49.700662164949804 THRSub[6,1])/(1+0.16019756787748392797692015998006577425328983175942848122998655486932866625265`50. z),((7.69567392065820292850807290884973664166098205956712060521342890151292837069582`49.04239088942129+ 13.45498233784191306177828365763614938490976989729365390090468708219323316020138`49.04239088942129 w-3.12192753739080930347129761743935216002224531125386238614277459378547802683832`49.04239088942129 w^2-2.48770595998032948206764120350522340266282075085068453201191074523404297156999`49.04239088942129 w^3+1.03021287291322753128128583592851610213303705425507187262103503730184555207097`49.04239088942129 w^4-0.12691045307223445593954952341030017728647978351948222226040198395495666622401`49.69897000433602 w^5)/(1+0.72052711739493579273346751437818198524111061044606017739275691527793117298288`49.69897000433602 w-0.21190376114478276161498015349870291683404651544833182202335790228345282944109`49.69897000433602 w^2)+16.69625327451312411576014867019616301293762835421786338838949567875700415322482`50.67401088729206 THRSub[2,1]+2.02863701844372874793922221970409283845984697350914524295813538245539032774245`49.37412422619772 THRSub[4,1]+15.94374743851804453283664250631562458863801438608585871942244100276935899195188`50.266525560713795 THRSub[5,1]+8.42665233548834370206707630341229020830761611209592607590374197371689216168502`49.540243126132275 THRSub[6,1])/(1+0.26876310812444570318598680254131113205715489612169137248000540547133017017034`50. z),((60.84056852207897407999309918587163654060129523175075083336059393281034122526006`48.34561261667103+ 115.23067277907730346713490674086560016460761922371328983173346757010749679759335`48.345612616671026 w+42.22075342860211282766287704272211158949003418451341504672988435626187841210305`48.345612616671026 w^2+6.38039412609285242201968552284527662444656462529381685447094766262297167447638`48.345612616671026 w^3-2.17695452256138895799277651195403476552414214323115719580109331145115760125813`48.345612616671026 w^4)/(1+1.20194219100470231923989113597746297723759347240617608323869540771264484981994`49.69897000433602 w+0.47149420641854332859941190419195183496586637350357382574123541333190493511188`49.69897000433602 w^2+0.18467445434706915405035730277230481931029753054656547545880082539809179617525`49.69897000433602 w^3)+69.59541256419775161671586512232565174403268654801339216999464508503761701615506`50.091024850396 THRSub[2,1]-33.23746917467935625269792208171556631560352515568787394477863088839835158087781`49.21114420507783 THRSub[4,1]+66.45872355667122482908509286576476124240365232985942338774347858420472469592054`49.68353952381774 THRSub[5,1]+62.92068552195878300401583940031372003112837735577771136252354392534384286765796`49.08044303763963 THRSub[6,1])/(1+4.28861718281100638671247493245826684354639975802048384761165331964877777398451`50. z),((6.89289918794814174649936025061612629471045517236819369235740366022701340358218`48.515388905784505+ 17.31502320765961677205726655749385047812429925621687410271629802112629802903076`48.515388905784505 w+8.94352981543765537165345154680280146093547628216834747197699720080016695621718`48.515388905784505 w^2+1.07040406802611763676230978756860479080961001973179098924888070706836952798152`48.515388905784505 w^3-1.10814317476848868260732787989320972990235200793395453655357956468383029640166`48.51538890578449 w^4)/(1+1.43937885327323815420143729298965301673531663816989153830079475704285285826414`49.69897000433602 w+0.73128283626884082009433429543287522514473073432241821185092439110358520136427`49.69897000433602 w^2+0.17819984304536235658055379469752685323802865259645652016234356963786661776499`49.69897000433602 w^3)+15.89719047124945480743869764094188734228931525044027086663208418391180283209859`50.76393167643455 THRSub[2,1]+2.56134555395284162015352290587360995222538904269420692412974304568552454182662`49.601042591841235 THRSub[4,1]+15.18069866863636664877810032231541629119337818428050974167339613284853043445237`50.356446349856284 THRSub[5,1]+7.60349832881180214980598560497682907969322224931246158528316867167717317525105`49.61695958588539 THRSub[6,1])/(1+0.20804161635101611153698260289196526248679441041757569424518601605541758881442`50. z),((43.39344215636915523738147319919560621422806403663053229169486999054767862702578`48.39318585277426+ 83.29134131655072148178113273838801633365159917949694163442840633488739023585754`48.39318585277427 w+31.07652736831951832253407946402131229946601400700405411535727788159126805645453`48.39318585277427 w^2+4.8636261859305371524170189587755646844491740940023216680376982738077591646796`48.393185852774266 w^3-1.81929120635553663044534935807556634403367253047982390273742317687842535622856`48.393185852774266 w^4)/(1+1.2078579551739824095310878606210502910802984137794912470829434577686356108638`49.69897000433602 w+0.48490880102555442360184540725888738576190294508828512533514126480553482881626`49.69897000433602 w^2+0.18552342685206650243646104857482895332926019907100879653486058969365303267086`49.69897000433602 w^3)+52.22895951750629385367982622334062538386740355256837345045122381436142179732393`50.126073665510845 THRSub[2,1]-21.65983381021838441067389614905888207549333649205786146508301670794755476832336`49.20023540212334 THRSub[4,1]+49.87498247854571683286604763181383346926820299661522385908706188670924725458653`49.71858833893258 THRSub[5,1]+45.03064565430766526408251494952671825785870533811821380926604756101365101876675`49.10682862959697 THRSub[6,1])/(1+2.96892499904111027338104476244521245756308069168375597476370239672652520720034`50. z),((5.47478404857235849726950970684511407417143650530217797193031588152916173315308`48.06125393968069+ 14.2880045402684136568801494280449586603306857402067085979009466432955843014106`48.061253939680675 w+6.93731121331539728764633009054213102633624268076673146832191037699413148286669`48.06125393968069 w^2+0.31170653496699171447698561242761490395293833449617318961073796646828971351116`48.06125393968069 w^3-0.85558903737824850363686519153317503077343540107048931858255847396220149239075`48.0612539396807 w^4)/(1+1.42597397443534825889109784020393606925390592596793492084749006057807042000793`49.69897000433602 w+0.66437340571550122519002564544564957489665410404112695063100898006475338782047`49.69897000433602 w^2+0.13813884284844807548456032194981817056406354105624457625688880624125998026373`49.69897000433602 w^3)+14.48563251800539335557032290465940897530082507388296147341932374068775262111979`51.03834154453865 THRSub[2,1]+3.50238418944888258806577273006192886355104916039907985293825000783489134914577`50.08269422615507 THRSub[4,1]+13.83276011431954150359084164324897917737629964323955679456138849482857901492744`50.630856217960385 THRSub[5,1]+6.14938285738297896625617422025286277488819437679986501941422676425821421963939`49.86097553717553 THRSub[6,1])/(1+0.10077607439918312355297595754971138819944735233847023037557507879820592494239`50. z),((5.47860893281877155920030108152718409048037235409220547490571554547990672942083`48.064408818268106+ 14.29724142738059154464849401028861837625072021922764175169747413515956429677791`48.064408818268106 w+6.94516958333960204090491347356378158460543777078182363143332111367721368605402`48.064408818268106 w^2+0.3142204092706421263917577555063040685709072797709118791928770106108826913803`48.064408818268106 w^3-0.856632619965219798666311420727807747938725650287067361759819145588328653384`48.06440881826811 w^4)/(1+1.42621523006222703858271679518906974343824602557280378727203267893993378637556`49.69897000433602 w+0.66481043705145019348262955566073097448424237860526583890458245649349592747683`49.69897000433602 w^2+0.13830374926391363465667583840776639860415718648764055871066489766941686004225`49.69897000433602 w^3)+14.48943971646788124153118320808988378193499015728087299425436274684601025315956`51.03721066788759 THRSub[2,1]+3.49984605714055733075853252777494565912827243813380550571489067039605292778584`50.081039417406416 THRSub[4,1]+13.83639572104736236904688358796297145532011017463649598252353849343148805085093`50.629725341309324 THRSub[5,1]+6.15330484030573499584480129217061947418813327089884191686841993435707446820516`49.859942505625604 THRSub[6,1])/(1+0.1010653867901185443813978255250448052618032235881747900688332775133220809888`50. z),((62.24626282657015405941907445662246656083811185025850227069014316565849594481907`48.3426631941349+ 117.80611913236911172952090018387261336487068353229564943550087802956529450730475`48.3426631941349 w+43.12147165004292988876145327252813814501477401691822341083069653592295121742528`48.3426631941349 w^2+6.50272545774333130606542213556230927284667090754777775914227751172705207852001`48.3426631941349 w^3-2.2060669116270228164076083064288228646988783963171963754439202614476429314286`48.3426631941349 w^4)/(1+1.20164417798289871833031812147141337554622559600392907047818896695997660788337`49.69897000433602 w+0.47075586868433342484957866665763805819475459711362409750487581947740268032388`49.69897000433602 w^2+0.18463028853376969165087985787163761598707582973900008947181522285475755510147`49.69897000433602 w^3)+70.99460711493627993346991765978311939896753586094561911826905362527591838169668`50.08903360963324 THRSub[2,1]-34.1702655418383751305339571066872114188934246976426919102949032485572191579061`49.21163583171512 THRSub[4,1]+67.7948559312549080403030130990965765230903769096007007892397413219806020228518`49.68154828305498 THRSub[5,1]+64.36206484265324862693394930843699407874124727936662307510080445550758409539734`49.07894532310449 THRSub[6,1])/(1+4.39494321883105892841521923149675419548755811806434138941377265740666841093719`50. z),((6.10330859468888705688322923741160201962023845677499642126984625873917509560107`48.364301036037375+ 15.71722548595031587322090927316769119356721307672728353902020699018253449368452`48.364301036037375 w+8.02670367529608412859040092776072323440316062472216462251048769328034763250501`48.364301036037375 w^2+0.6944636092856689554824968882098441432895806824591090971738336334251765561844`48.364301036037375 w^3-0.99827868394988346473574745445948152391737819818136372925038650704782281073682`48.364301036037375 w^4)/(1+1.44703867057069814671663148948141183839550972002593242241830554664735940799925`49.69897000433602 w+0.71410188239758240382660962436757522309000840586437105082002685551736973326368`49.69897000433602 w^2+0.16079854750539133923995651158810337903379454739811473610220404543700744161703`49.69897000433602 w^3)+15.11125084563316355625272529608444861527948740707195498638048411977954563947289`50.88886992730182 THRSub[2,1]+3.08530530436370245427750446911190243689860760493975084429747642177369600357701`49.84508194458061 THRSub[4,1]+14.43018161030460849031420835796678575596604822896005751112175164574797927478531`50.48138460072355 THRSub[5,1]+6.79386315471843964069102049276399906248328077013659995071296205655359375212197`49.72631442800305 THRSub[6,1])/(1+0.14831736649687228059909383762172633203884819503169855027052241477195040164521`50. z),((104.89314842968991691508304110695370086043491904438204082651426044987219774569919`48.284728950640506+ 196.00569366793003831390489537568998185292459130933473380559317529551204036845473`48.28472895064052 w+70.52936086170812680248564106195843283513521570411903686451788016320982296269347`48.28472895064051 w^2+10.2187833703402423806608808753104311395174066575746616439249378731281453489321`48.28472895064052 w^3-3.09767150149976414677752301748386155785031399705426020707119464655962309829225`48.28472895064051 w^4)/(1+1.19700990998989996892776030910132057870917204798986616545164680075779189458546`49.69897000433602 w+0.45802159474664160506044556663248289465841007779895570580014612102247736861637`49.69897000433602 w^2+0.18392216695010771848006950253822367355809105904160576987784480044227948677743`49.69897000433602 w^3)+113.44429888021224501008795130715300600916170948674528548813603677785794459165517`50.053547448580545 THRSub[2,1]-62.47006005202235184827931287160046915902287378150913615687289201694523663121474`49.21832566811414 THRSub[4,1]+108.33132559428087371487174538652838380606717353095705911525265722570720993334927`49.64606212200227 THRSub[5,1]+108.09158612189739094160554681752723249606564936583601487933734167071722792323232`49.05226868377955 THRSub[6,1])/(1+7.62073298001367856092766158874406775989286032640025519542258236514382250611295`50. z),((7.16840209399933964902331322808868296756044715928921683795773539994089498570521`48.546262954049986+ 17.83868888684932358984175440652096123875294529153233308694745931610711576456388`48.546262954049986 w+9.18553343997934427805327469623310825794253816056715059977498910408140461298449`48.54626295404997 w^2+1.17561162342246469171007195618968471066061875469709884995699579889720953936382`48.546262954049986 w^3-1.1334448221029543051440740372784501167512272720667173816732142109119585955516`48.54626295404997 w^4)/(1+1.43238317737221068407597707670425913337254814952347041778147282401524706599248`49.69897000433602 w+0.73034175338431132060487573278549809845756993931909613877572989058372315954019`49.69897000433602 w^2+0.18211837977840482977680006516169676364440123220818814610923533584311199450547`49.69897000433602 w^3)+16.17141948649683324569021559866939080430183533119784037601314054866215906468786`50.7299008243254 THRSub[2,1]+2.37852621045458932798584426738860764421704232218916058454237213585195372010041`49.52225394749186 THRSub[4,1]+15.44256808853142473081656560401445770819475191453585355002191992324932427077517`50.32241549774713 THRSub[5,1]+7.88599516351098438803503716171371016650491573036163751443169008505009364848714`49.58772449604467 THRSub[6,1])/(1+0.22888052266146891818567282193734604895426198017540651683808432903187495791562`50. z),((34.54560302546219321422352780856658374559066343509309797347742723950527511734071`48.42911174185841+ 67.12726963947940035040151620440423927819383839547266588861370988940138985801389`48.42911174185841 w+25.47095117434282055208244492832574383601323115235935831195501393495132545831945`48.42911174185841 w^2+4.09585877914381102128269988723503524104170765111172203114630082681856831917938`48.42911174185841 w^3-1.64271681981362656514369685752440823377641835857711018021756473276254426150846`48.42911174185841 w^4)/(1+1.21409958780054324151706234496356583076032132611782832828958911832669589743499`49.69897000433602 w+0.49732486232300556980510282885473847295882719788211066883779068783932593030379`49.69897000433602 w^2+0.18636951113842574029705549738946460932850419775143597183370819959328963745797`49.69897000433602 w^3)+43.42203168246944438566101002975951855025366019866225866026571432419655979492998`50.156804488616444 THRSub[2,1]-15.78854858686048476532801868667147751975084092278711827162601038117098010006106`49.186740024648685 THRSub[4,1]+41.46498588814740421001511852594390092338580984438245052186419871873684216904865`49.749319162038184 THRSub[5,1]+35.95819489785615314226009654483261407432383614701716382068804446731828189927802`49.13001399180868 THRSub[6,1])/(1+2.29967873466717164674312442763078562861750294203005856234013167755108289516834`50. z),((6.07308378448085462209186314382081871009715578665730089747063242579950978946055`48.35544467748223+ 15.65224487398124869847390417292848033493105324981359299120665332466274134585002`48.35544467748223 w+7.98286439983952896552657625680876090345929842959758043500388654730801368685891`48.35544467748223 w^2+0.67768528283403318004586647584164365324135064930542956059418073001579330131956`48.35544467748223 w^3-0.99268190253946599282471792136182411801761937570952173843353843386206882257406`48.35544467748223 w^4)/(1+1.44674272623917233206453622663492108488324145600822535737183091985090179413669`49.69897000433602 w+0.71260718329180175835393843599822166674821464296253515984625078586625140176838`49.69897000433602 w^2+0.15990724986812300793595566306085935345017760709010180716880223327885211021333`49.69897000433602 w^3)+15.08116579114794025214849425537285781751079207297915691656459169072933633623117`50.89475084817487 THRSub[2,1]+3.10536200735385132368032516291962963541107116100161622417473804114050220573821`49.85531113325885 THRSub[4,1]+14.40145249949753477737105646594109733939556263392961586853998506042415580196402`50.487265521596605 THRSub[5,1]+6.7628710561756897351456745559978351033233319096765820161883101658692664079179`49.73153707163468 THRSub[6,1])/(1+0.14603117649908199456698223378573424035942461899576065102855747330294830795746`50. z),((98.92675795470848206066134166322553192650471562372864036371828140897291981409493`48.29034147729472+ 185.06076811168072357569099306345305949095464310538390403985009395292445930425426`48.29034147729472 w+66.68918325283095579217101159844749582666631891277206410517648371595643942462696`48.29034147729472 w^2+9.69853454447336038980910645861318620801942339926063738709139854105002491634277`48.29034147729472 w^3-2.97234563482503219182494782251965370402460222671699983073549864378202010041491`48.29034147729472 w^4)/(1+1.19737097613484679727327119247794356121376722380177410622846584627639490815052`49.69897000433602 w+0.45912315353632415665613183808248143207554175641489831618214839783964563967124`49.69897000433602 w^2+0.18397897555694387144600737217308981275958079797878122864380199438685204288702`49.69897000433602 w^3)+107.50549624474587667103758702662411998089990121136917172692028749382047529705712`50.05670706703879 THRSub[2,1]-58.5108582950447729555790700179145451401816682645917269827290591609202571014776`49.217881516169015 THRSub[4,1]+102.66018682139098635285247065914103082655617640510988398219404431889276122339119`49.64922174046054 THRSub[5,1]+101.97373260114946629580772764876189987832194449918674282213059682944443601965685`49.05464317883934 THRSub[6,1])/(1+7.16943809568091297587503675189853683416649265482505774789145936108670106427022`50. z),((11.23143030058462531161802753522150661272114490085675738287123112756558046510231`48.62011213500922+ 25.04528790860505538837009124349628956699293707689997138636293614700788522305868`48.62011213500922 w+11.5100448017914081972675922794468792392439386021742336780716421994746907159321`48.62011213500922 w^2+1.98381611896180893211789354286939217391192643380647559414480264145007762311412`48.62011213500922 w^3-1.25280226086086845267249829431028670260130055243485794971107272118995906945692`48.62011213500922 w^4)/(1+1.32310108886282070059281066064792182535917966670207682984791546086065681127724`49.69897000433602 w+0.64220508995829589188145685438683986660109158665925657020889845972711265981077`49.69897000433602 w^2+0.19478460660665119462762975901232793996533751245954453324883682585571594823155`49.69897000433602 w^3)+20.21566076142243530989100626825623571488729518700775661543088065135184351275645`50.45711778382956 THRSub[2,1]-0.31763463949581204814801617900262229617326424835078357506945459927450257861207`48.222301062867125 THRSub[4,1]+19.30453402829549534476592120075866802667218156017531181808288988840371438329374`50.04963245725129 THRSub[5,1]+12.05216757927686025468126887390024329614683232359400983038394048240610186282902`49.36229947558125 THRSub[6,1])/(1+0.53620600734446329257252116728802365321193561749504081036284601217053152772693`50. z),((43.9532944010828813943016115142687893943622086384537440629508903891762794470733`48.391252016827885+ 84.31516046060365691659555206211650467764253135190461829212523663665929028159032`48.391252016827885 w+31.43267693008962202493531301423874531442963420139927652986034930642520763442837`48.391252016827885 w^2+4.91224201240761684705811603597162633208690649690922307221104485026782129200216`48.391252016827885 w^3-1.83061635668962077881785125236571268421762645898307515270767180836116894986351`48.391252016827885 w^4)/(1+1.20757093281585948950571770520325726682252058477561691194370499833395628081293`49.69897000433602 w+0.4843020783298505908195649328466840769664319751633000354411657815333070286946`49.69897000433602 w^2+0.18548336130816195183578269260871039079765561102639826452132546571121631475765`49.69897000433602 w^3)+52.78622307582008067668391006141079635188350151326162474282598919559538881259783`50.12453212783742 THRSub[2,1]-22.0313428490942422926766187077723293875040684658533623266661936287701994451737`49.20081015617125 THRSub[4,1]+50.40712997800942387126029420665676331273165791696405868880712284792570475428823`49.71704680125915 THRSub[5,1]+45.60471033223693804564207007340162296935214866286223560618377334916713700921063`49.10566699979498 THRSub[6,1])/(1+3.0112719515379306220841069503647609676322448260179482145030832806805849190885`50. z),((51.48079941489460533027391113179075138519152200986763476896176908929140855087776`48.36822344366621+ 98.08902046346919127405083575573899528278914794694312419293095062750647511685746`48.36822344366621 w+36.23239864052789917897792387124050489752072080546310845950836451824570680786537`48.36822344366621 w^2+5.56629321776560715971616469272167526934601918797429207605534279116393102522373`48.36822344366621 w^3-1.98405086980911753406461588585889914407818369718446593339169927594452225386143`48.36822344366621 w^4)/(1+1.20447494215554246612530487572537620156723205440906914558447688798588041127882`49.69897000433602 w+0.47749680242336547350383922991051554780331851016136653435883056970477208737902`49.69897000433602 w^2+0.1850441292685876893064748397462028286994286417168154681211316521885612196371`49.69897000433602 w^3)+60.2789218527385441902368632276999352267145402723344899201442151282552243087866`50.106965269695664 THRSub[2,1]-27.02647536703988463504525415196508863739142763856860577821167758387675644263304`49.20672699050754 THRSub[4,1]+57.56213026268045494766305557269284390799499513467403920412929954709716054273689`49.69947994311738 THRSub[5,1]+53.32330891278642970901852628788953389929916032170036864964540488838354957290669`49.09243728462679 THRSub[6,1])/(1+3.58064878310258706123531367117715639325953868219942473835510307663670072725164`50. z),((5.51927594932427085376608340124626456085648674178644956419079335462181394614573`48.09623231957504+ 14.39501594864445344172625013577873640377573172454760949036243636571518900441352`48.09623231957504 w+7.0277328801762700423010693902428470653579268744584939246949835452735447835071`48.09623231957504 w^2+0.34084117580016431972740327758581029957721353996923799758924934225478369031903`48.09623231957504 w^3-0.86759272838978319535997224301837037112257978755608404730213138660000101273292`48.09623231957504 w^4)/(1+1.42868098256366857037924437396639270032046593773492545743680646642659601002947`49.69897000433602 w+0.66934432190789769649372890403776301943722790432573812150969883416099803277467`49.69897000433602 w^2+0.14003659376516669130224440699334603583978438015168393503356443502106937779444`49.69897000433602 w^3)+14.52991869380135270018672306406562294553270920171662704215786922103869380816896`51.025401206090336 THRSub[2,1]+3.47286007225157635832150595712445288339645974184330280711255302093426389111295`50.06365140574849 THRSub[4,1]+13.87505029705092299629542177144957166754427515405358796890222783561578547077438`50.61791587951207 THRSub[5,1]+6.19500423144510841705879698289913632762878572356270061396481439828374514416597`49.84916703979879 THRSub[6,1])/(1+0.10414142021216256171521601668961206719644960838149233023319752158843095008062`50. z),((92.66605188055900579966465039282763486105776345079254345045648057751404614745096`48.29686666573664+ 173.57704218300007802493791568983177307003500521849502084216086591300621120042175`48.29686666573664 w+62.66091242323318427123993396290630799793798354060169998935658498883300523381213`48.296866665736644 w^2+9.15271329372437036906516850680797518715103288103761602318295824873665208835511`48.29686666573664 w^3-2.84097350999188932566686378908134382370810878710703943877452912686147109185832`48.29686666573664 w^4)/(1+1.19781172657348270904156574525541934997715252864350798050447474535264779430156`49.69897000433602 w+0.46043639478424459026999808901675127278426313014484860296281328339528863701882`49.69897000433602 w^2+0.18404789686238183364433878985725599806814248020445191883014755073794048693209`49.69897000433602 w^3)+101.27373888844329515448186432781116874335374336871638103371348524783679614738015`50.06045061423119 THRSub[2,1]-54.35635339084305194454192155203924431515089636948986652059119099693113766836193`49.217318462256664 THRSub[4,1]+96.70929689696196143260497021421888663986711849165821152086622896735396537307618`49.652965287652925 THRSub[5,1]+95.55409197274717046965762809310440760404635076130164371731464389705340264266552`49.05745661558561 THRSub[6,1])/(1+6.69588132204659557764671522765647828186364621261831764637537980752029384726796`50. z),((62.62211388708647485754485537973161136483981346219193561758556352449892357653423`48.34189163611166+ 118.49477335433698199133122504193336995403914327017674434384301382142235729912742`48.34189163611166 w+43.36235257740143699319590049648110420661141677900692923407093444964016368601642`48.34189163611166 w^2+6.53543665036262119440931859332896665250464317716817562921464783630820285757843`48.34189163611166 w^3-2.21385600138119393018322250716861793514593058453530475979949303598027839402572`48.34189163611166 w^4)/(1+1.20156736581285373018820911740515917302181649467841811284381057589598317922841`49.69897000433602 w+0.47056433094228231817107450766535152246282495054502391250337006819120627076328`49.69897000433602 w^2+0.18461888088039985727529573786035231460334430424400671570892399286824413980716`49.69897000433602 w^3)+71.36872028739740701328068146596835273812741075836951700777299109860151188901845`50.088515922627586 THRSub[2,1]-34.41967432347912651707446631081070031166667462925862383663086156410761482945343`49.211761518380484 THRSub[4,1]+68.15210769529278267451451003393136228044099239843438084395505104318856435410975`49.68103059604932 THRSub[5,1]+64.7474572743920998039803911414968712423543188874385198984639155208208980467292`49.078555962734455 THRSub[6,1])/(1+4.42337241091852250744490081530279597026130978282040054816589817392309299752285`50. z),((64.52696258398128430760395557622265033822728640789316614835024426731716364824354`48.338087054182274+ 121.98516937866108493089227127711982846570364962065623299701748260293122111432012`48.338087054182274 w+44.58345986060546701004301881480592228542327732957505870744589265631555527789426`48.338087054182274 w^2+6.70123587092863594631501133737634076114886844313250227334682349885504799411778`48.338087054182274 w^3-2.25336291189160166256370533731679775398421201659710910387658370512363162321813`48.338087054182274 w^4)/(1+1.20119541913807563669055270260296121451442585678938346712849942274536851297023`49.69897000433602 w+0.46962945684618429963105074007146606041236671568856788505801263174678687020879`49.69897000433602 w^2+0.18456350041324859247725850459702589350238803578603926693720628509818176322168`49.69897000433602 w^3)+73.26476120337831623769321342334749616469225285539417530092070253275422973050211`50.085982451136886 THRSub[2,1]-35.68370160079973266668282094906346259604323602727506269872933585354276005710757`49.212364040897064 THRSub[4,1]+69.96269339978986295434545991752340186064635744775444457428399353822822790069161`49.67849712455862 THRSub[5,1]+66.70066254241074517948975852270267481279755404044624952043138909916422315657448`49.07665060675598 THRSub[6,1])/(1+4.56745424329963852587291032909184440238690306627006534099570315663572630573089`50. z),((5.73486570403671226787088069840052247160415603833434640320769375201603161712862`48.22624046073574+ 14.90036932372398524446236962566460859900940468201541555873663398039318503416672`48.22624046073574 w+7.43586030414452382772736586049085459564066469590835342528809641048649786472796`48.22624046073574 w^2+0.47815406522393437688629687916751548068889641676940473585588505929644024629086`48.22624046073574 w^3-0.92156329612928631350131819450189891357986082796233401390016109471331615001599`48.22624046073574 w^4)/(1+1.43890484547814451995420790037226704403526321379302276993066336210541311032294`49.69897000433602 w+0.69007581091379416191275871499237257448395033249586986597648329084925741468026`49.69897000433602 w^2+0.14859222998822371582631395406660867586113011511132316331926548652979740346476`49.69897000433602 w^3)+14.74451158859001953170549549855149132547417608346651988073615675322504819034162`50.968590423862445 THRSub[2,1]+3.32979814239246513730899100080054063010214848734337424806036133281002763633118`49.977004100929165 THRSub[4,1]+14.07997141679901511271491446423649934619447414435378359524276345484445498984019`50.561105097284184 THRSub[5,1]+6.41606695696321913804491093259123144581386076899023177780651617868449968735785`49.79765175001262 THRSub[6,1])/(1+0.12044852478808009684165615969214757025045101474535604812177840216202323114272`50. z),((5.81065253080440032941616551312068956964187705626676091672938751182231697368147`48.579746643756444+ 12.20049087785083650312715004446356978684219662034554976225486385187203757588224`48.579746643756444 w+0.76000871613466921733717290328982544794372261213304777912632885061261747594029`48.579746643756444 w^2-1.18438389175595774061723465703885241242818208361052213732296047441360647202132`48.579746643756444 w^3)/(1+0.94710289693658342270683283719167316991393818962725884718632051154779226005588`49.69897000433602 w+0.09427289212427170282050848724087177509068140512705320085078343902372742841522`48.579746643756444 w^2+0.02931168448438590281369763049261347607343202042341088248946826956219547208869`49.69897000433602 w^3-0.00773459166272070917937972069384528880420000330683877800291124971204287258913`49.69897000433602 w^4)+14.81994798659797583412897111417680645989671096808431964764143830783029866578304`50.9506142199618 THRSub[2,1]+3.27950721038716093569334059038366387382045856426484107012350696307319398603684`49.9484244483709 THRSub[4,1]+14.15200787059109822461192639707006632957436307388400715674403898296351225973288`50.54312889338353 THRSub[5,1]+6.49377771138186220827104171377951342521207871589472250721157157408771474003072`49.781465993233375 THRSub[6,1])/(1+0.12618100363999056465868351651601340780292780586470017937740935564992578207853`50. z),((15.40813380155602042966421629717759445392774032934211031065671849153308145447009`48.79823367288764+ 27.94603257985393018465451512386183986024108409113002240359605614234352723531779`48.79823367288764 w+2.82649219212127993603783669893962875167391074446962802881584231958728610933564`48.79823367288764 w^2-2.43612786125846302547686168565502561840126292539644698106026161157402568750317`48.79823367288764 w^3)/(1+0.97829777050507519567594457945976182921807128028485281164654185519890409692607`49.69897000433602 w+0.11425888212217941635962400639969972398490663799580320852036080911877201426789`48.79823367288764 w^2+0.04891815529024424025423252441803854089780943073264971596580032553868122701139`49.69897000433602 w^3-0.01957498512878427113231151118740886308629892070430631245607911832224213123371`49.69897000433602 w^4)+24.3730517104631467677389881141519058659089007438627450315445350724716794427254`50.337165656078845 THRSub[2,1]-3.08922860552295302004667074293306906352100128625410918581189088002105986525801`48.97469883432828 THRSub[4,1]+23.27454994772750638839306296144920887058571474875634827320415887935771295107516`49.92968032950058 THRSub[5,1]+16.33490105535186389400855025319665650434240825331417049362128282522332802232416`49.267917532967715 THRSub[6,1])/(1+0.85212983621002342054645452005558160182135342654271428241707093279691567913771`50. z),((72.60111695949600639412753510732717721193798475808671397092942260275181711063554`48.542232647532884+ 117.38779521620956261687048171892786145614818405034203037273474084561558475298137`48.54223264753289 w+6.31055517428985235307622063623429732868127086119008739118242524629922132782868`48.542232647532884 w^2-11.65596603828057070622210447190129460432421761576166543478503102563588076935783`48.54223264753289 w^3)/(1+0.93272878991877066967149236806097384270946638773095819470274063299703416767456`49.69897000433602 w+0.0504859404980275475923809424641146507741121068896479952881833046388880473784`48.54223264753289 w^2+0.04552134692726386600312207870953826654425141106070309231792700842191398768056`49.69897000433602 w^3-0.03615766909860429530311388322374875202518889560160535040359753184482198123471`49.69897000433602 w^4)+81.30158170407113180750655132463789974485995067778554172533696605732466792304317`50.07668342283417 THRSub[2,1]-41.04158193459494304655837954992373164948836790886930698167351153658971885213709`49.21439993436692 THRSub[4,1]+77.63729165635512000003687466946076337748625927029153054340495567046234976549271`49.6691980962559 THRSub[5,1]+74.97978774892158899834049128680313245119920985248612161344901888757359247006783`49.06965844042448 THRSub[6,1])/(1+5.17817936768803984815577020203629697378937043548217168022315963861234656531105`50. z),((29.45310500116426315866240371064231750665522984727139060869415924470505494246716`48.76219901125319+ 50.38039796695131629645580510936672308056641299561350903427281314078445854437014`48.76219901125319 w+4.60630206117726782457944074270691833299127744079580689049104062591804488789394`48.76219901125319 w^2-4.39407902459593239760715035337982726503393026810134678702921690023018021901602`48.76219901125319 w^3)/(1+0.96667154511276517701659180734299867820236198495090235890726868207335233515337`49.69897000433602 w+0.09681118719207593076919428680548650125102641138705361045653730021094721786734`48.76219901125319 w^2+0.05275521052206947653351297236519623810331685004383927901527216353199164114778`49.69897000433602 w^3-0.02676983381323731432675203169298162411310728423023502639621957222117698648753`49.69897000433602 w^4)+38.35308072885256320146323083456243203098501310687685439292052956587007956625242`50.18250988357662 THRSub[2,1]-12.40924795111589730919616588987341984023840952826351542672922054228665994760912`49.17213242354361 THRSub[4,1]+36.62449428479638429849073717284666352314953265815881680711739820096459299497304`49.77502455699835 THRSub[5,1]+30.73641849921206594996219328573552960522347997644595512273902277218855119655949`49.14945711128385 THRSub[6,1])/(1+1.91448465183310725464965819999016296960802590610844270031749982790487523606431`50. z),((88.18855409348752989448396543441828336954427403883251208576346586404498340283292`48.452650069353375+ 141.19379502149272179172537529560899559476005978069343511068549937773934094728413`48.452650069353375 w+6.14353350419554693657975888899461213806453214899775887548195086720205347948916`48.452650069353375 w^2-14.56181974017610732175358806998022493430292823053701201614086140047201594407768`48.452650069353375 w^3)/(1+0.92408918306143585769937024046044637763409944691527571186600846168321255146916`49.69897000433602 w+0.0388238695906460928745309843349673529906503573220833192763330044137803644831`48.452650069353375 w^2+0.0427453123071477744879720291975171070590704108426234054733294683073060046094`49.69897000433602 w^3-0.03807365515838436360724998184982401004420472192186751225796546579618230035634`49.69897000433602 w^4)+96.81694448826826231237877149934467401811484846679198767629477647917099697300342`50.06344663583568 THRSub[2,1]-51.38515712405969671647319299972824783165829976820693761564538515115393821877742`49.21683868280034 THRSub[4,1]+92.45337174216915047341490246291796704947918749097947539232442619788787759953494`49.655961309257414 THRSub[5,1]+90.96292823386004945404105523346853973454895633051203497869784479356528948917123`49.05970836240195 THRSub[6,1])/(1+6.35720555913938773958341796392661535311963580637118175902315621570830799283995`50. z),((47.62159232832117321993177848804046738722350842692974902746413766016806357880755`48.67585699772559+ 78.85540955250988640989979902838362242898947921041904867888937002326798346666587`48.67585699772559 w+5.83275898005306592231849529683782628011369044358858326495173606815525524030965`48.67585699772559 w^2-7.27071072121813827076446966953229659001091034636437796825824507076071077103873`48.67585699772559 w^3)/(1+0.95034121731610740737300549915260356738380592368510410917621837881541270578828`49.69897000433602 w+0.07437227998019760992981868398233848735621968725507024072138537931557700516182`48.67585699772559 w^2+0.05034814667149786059033331494686774213965002434708072677813738235268804911927`49.69897000433602 w^3-0.03184654473102815942438983659408169089037560891841908731096087224222195665282`49.69897000433602 w^4)+56.4375592545884291170587520071411211726154989933320271998900316895781836972605`50.115300170824156 THRSub[2,1]-24.46556696827314125292651333825921260132540011923363063137555529142539603494737`49.2040621527402 THRSub[4,1]+53.89389918845695429357021763646466043909875142676227583044059571132624245703758`49.70781484424589 THRSub[5,1]+49.36613182877030553191840333574975554606801483200173961549760475435034147877818`49.09871263941546 THRSub[6,1])/(1+3.2887402291696053901821986165780659519608726746011149748778210747016157477607`50. z),((8.11139921569199718586363671186215674532497143657886240886066006349204698421207`48.72509387951276+ 16.03747146092358310006068523484003029464260774951092060805345068394685650075689`48.725093879512755 w+1.39267439285805002517188863489449295528059243447090481191671236836659089147389`48.725093879512755 w^2-1.50289203951705973600938504318018668435830948934536886414932505596268260539832`48.725093879512755 w^3)/(1+0.9690005612592269781501745400362077404114313657994018030393288583688053917606`49.69897000433602 w+0.1100894788306854299340818395844651793164479476502733790122102446262914446628`48.72509387951276 w^2+0.03704063418607481870168502572153802262965465740681591683899608469759019344323`49.69897000433602 w^3-0.01181439040562122970326988554326639310239414971146751476488561430919112867337`49.69897000433602 w^4)+17.11005630804394798939129344688038441976166596156488519635860919363625818128501`50.63659016320866 THRSub[2,1]+1.75276832942317949885179236858127856724382190194446403764539303920255430903569`49.255813118690874 THRSub[4,1]+16.33890022803515611919245316452002046172261200775427637221709640503670685891781`50.22910483663039 THRSub[5,1]+8.85293125078082325445092045337777480353271299406392048133527518063082402429079`49.5088268505708 THRSub[6,1])/(1+0.30020836798854549834787912473977390998902335486882007773835495416138880151512`50. z),((56.60514022337734675074466607208817299307572330503640045056505744389141053730768`48.62915318125336+ 92.77933930791227068751301405559822655703810241320285096432590219648220378308922`48.629153181253365 w+6.13402016206977643480288980596485957083039622173095181099833697167162429607018`48.62915318125336 w^2-8.80094324328665924679462218139597244094965869561917858494149204282302641074709`48.62915318125336 w^3)/(1+0.9433881069589082771986333594445569386993956673059402231193295378718190302332`49.69897000433602 w+0.06491983335758384066371988561608043674804773790409056500481235661591232268633`48.62915318125336 w^2+0.04861446999074129144270036805060582115701632481946312534561165788320912751122`49.69897000433602 w^3-0.03363349958801828895006301886621202969155971836025882199367859170638135416837`49.69897000433602 w^4)+65.37956835350915620022699299317742970252989324364845430229237090948960005317511`50.09760438459618 THRSub[2,1]-30.42690636755362597503867399561675162126832961944458203297711477136634027222357`49.209426105442496 THRSub[4,1]+62.43288888405258594777380732876641367894680263553542480386406820454055171923302`49.69011905801791 THRSub[5,1]+58.57773645790715958463304037536422172610240655597194010662157118034552638237874`49.085392704936304 THRSub[6,1])/(1+3.96825143870200710627098219448906905205302305466402305030819341912235577525974`50. z),((40.62706440917692282676853406936247470081180672189882895021716807353530194079863`48.710843470793066+ 67.94953623147552125305907577361550317736985145729846716620149006797714820164561`48.710843470793066 w+5.47139965850494519584725536357924701432218981725695898095951516174610057367323`48.710843470793066 w^2-6.12462401929281213970282482514932063961181281937036345777835943196953841907075`48.710843470793066 w^3)/(1+0.95628901602284592961214635412063464434714295465897864052465810542724049668203`49.69897000433602 w+0.08249257282069338539211637173055876333378699317934162123033831765781103983322`48.710843470793066 w^2+0.0515711498314269153642633691410113029675130544901368225003639678260391197271`49.69897000433602 w^3-0.03018509849247269017211031159447691592410358092140703016238047614407038032231`49.69897000433602 w^4)+49.47537315325281018966615904805179185504255716017540237032911404698416624464482`50.1342922594831 THRSub[2,1]-19.82410956738272863466478469886632638961010556379588074500161019636271773320434`49.19701283720354 THRSub[4,1]+47.24550119193742379121072701234931523906335410485496744896625752469323075841871`49.72680693290483 THRSub[5,1]+42.19404052238636350686548536823008577488235196138834241892131879259913973754679`49.11302386466854 THRSub[6,1])/(1+2.75967752677543696932963738792337738899012563474659552464372264950851089566143`50. z),((15.58057983909188495315581442323102821220594229978401149878014071371591765775727`48.79837119393901+ 28.22468451362177216291596394197662062089125433248102923861309313519697405261818`48.79837119393901 w+2.85469630704402319059968992729707510522003497233950971113335474737471739990302`48.79837119393901 w^2-2.45857326591582493988098014018853911077948571308469430965436662631276429287454`48.79837119393901 w^3)/(1+0.97823329334937117638694730659804557275873107282440714055567710174686924105324`49.69897000433602 w+0.11411456374238312339516554892016246252869347901708746234501756702891052739204`48.79837119393901 w^2+0.0490584384692195196874439258293357941751346050543535354920379460273157438897`49.69897000433602 w^3-0.01970374514268493016935236784598923627050210742475880420316797491044307879915`49.69897000433602 w^4)+24.54470037919981895038552501705710584220198466858030969654866792143209485575591`50.333616008708375 THRSub[2,1]-3.20366105134740114181102867820320238104972390273248562914797944599467014061153`48.98277622472741 THRSub[4,1]+23.43846235235501432011286432945856621137808241470680792711156953715945835994144`49.926130682130115 THRSub[5,1]+16.5117248154295346907186817061910857410954150798342077511310126478678686885551`49.26516234398451 THRSub[6,1])/(1+0.86517357092529679382887594847099970211112207271984747117501348248790578228441`50. z),((5.6344557209592040977222096697801528280944447118853613226788638685450560293405`48.55674386701298+ 11.90320515347010043469795880226090824480934045837527177567111657554059555865408`48.55674386701298 w+0.70303881024327777591104766550475366217576397135733821428117255157910654680847`48.55674386701298 w^2-1.15750619800216478559198874496100046435111245705438894441589379303209466369914`48.55674386701298 w^3)/(1+0.94407811643648633757368723587636299668966401459949724864357579079108254273661`49.69897000433602 w+0.09211779776254548729030385963834152475428306289743979736910890806797507648748`48.55674386701298 w^2+0.0286326465529232321384002188836409062119596185285934067020263822278289735114`49.69897000433602 w^3-0.00737453641671306189556652195952703785774002431188479108476724282933048998272`49.69897000433602 w^4)+14.64456588865161674494954317222952406559525224397388823054271764997446170676368`50.99392274781857 THRSub[2,1]+3.3964286090180669951462925516818521366880977136717953481893207349770852920498`50.01629005003758 THRSub[4,1]+13.98453030368315825656483220366509266995530828087572484504543835938976683153817`50.586437421240305 THRSub[5,1]+6.31310796172734592085730038982975873235075560950046561543046379460002340354148`49.820555847010006 THRSub[6,1])/(1+0.11285356232478942510532454795840064200561718356013528158498114015635576007672`50. z),((31.73268886494376766740222320446803872181136865605297223012891443978040106059188`48.75241698450692+ 53.98142721385335574899727462137255531870655934572824098208617669514033992144878`48.75241698450692 w+4.8157616387014330607744367894550145298181711555307849414531258573077061214532`48.75241698450692 w^2-4.73589601385814311008196048646658004100057438281740809220722937880267526940441`48.75241698450692 w^3)/(1+0.96448832824356297870043042532638462048919525212649286872552522673979937534653`49.69897000433602 w+0.0937763302709972435502178041621577637379477109501713952042507000015166084519`48.75241698450692 w^2+0.05264812917743739020378662349814093244630986478247115768665981446120973631733`49.69897000433602 w^3-0.02756797088997371176350859558060441840074444102651696115708281745455672765593`49.69897000433602 w^4)+40.622124083414846236747843873700545382556708087120596166281383142316073385673`50.170020161887834 THRSub[2,1]-13.9219435208240859993859079159654954079528728484260099423031229265839891605564`49.1796400231685 THRSub[4,1]+38.79127108060680498272420686459439654835688013749803105572218185623363728208403`49.76253483530957 THRSub[5,1]+33.07387197721410608305205751520126933788444829983941032027962851508146914046914`49.14000379431111 THRSub[6,1])/(1+2.08691127064813066664586998494109112041325193368642711752714160700961808302802`50. z),((109.63272051868169732212587449048216323653543864979437636468788329879645283260292`48.318206598849855+ 173.73984190179452186737983912106000986644940171594505849122083534885922028523928`48.31820659884985 w+5.51552008267077562924641161694208228731214138624023454566981933198692117716321`48.31820659884985 w^2-18.70555266641182466939346358645167634158626792817625914351334235237579179702944`48.318206598849855 w^3)/(1+0.91435123623435620027961342644958576894795746625954933447851207933569582195675`49.69897000433602 w+0.02571002191348312726266196930816404853161685421203891675234657459999596322026`48.318206598849855 w^2+0.03941298084448725229054735966699136801783620223665670860417670811245197769001`49.69897000433602 w^3-0.04013640322065474464403111719742385769210920089189009256113307596943645904143`49.69897000433602 w^4)+118.16195578368114013379191707212651482283136726650141264595856865993008134560417`50.0512781006759 THRSub[2,1]-65.6151646543349485974152900482494750348026456346798875954212466049933278005096`49.21862733648455 THRSub[4,1]+112.83635609027294874010824054999101993252356992009870647611994641885176912826743`49.64379277409763 THRSub[5,1]+112.95147719222952242607762826773658023346197196228998143390884637750273614625394`49.050563280348264 THRSub[6,1])/(1+7.97923191612211442051340691020218992856816871258098319252560904860487048308817`50. z),((79.01831914546661856910211724205241983945920042601276066496001685526436391610827`48.506004326265135+ 127.20647161557633569588554167383424449495988762505876108581916749760848465400052`48.506004326265135 w+6.27678409016545316198864030790791958548370695456393335155728256191902283178223`48.506004326265135 w^2-12.83946972793370955972046293212447384104735289347445137387995894935318093745192`48.506004326265135 w^3)/(1+0.92898656555208989268806800934528141270188197158291299367372209039742181473682`49.69897000433602 w+0.0454310310806751499291091565587424747138560254704605515024056268147988798485`48.50600432626512 w^2+0.04434335382989360570289322396733478214026321445292233928557661484081942452531`49.69897000433602 w^3-0.03699926064897523226927035486423730133803323470327065277800655066549245447779`49.69897000433602 w^4)+87.68911155384707979617225149756221158197577223378185735064494872507575686267836`50.07061665217674 THRSub[2,1]-45.29993516777890837233551299853993954089891561286685073187883331509044481189332`49.215583184881055 THRSub[4,1]+83.73693335478836259115277004138799488268876798090937698749107509979435391106406`49.66313132559847 THRSub[5,1]+81.55989730618514518136586207762742063469076714606874015136123415034491420241951`49.06509768891903 THRSub[6,1])/(1+5.66357343138558711607658515287388320532248007061352678390426523899412097670764`50. z),((53.56389276453913429127499789081193255146617845191607630883425489533243537414037`48.64515000978546+ 88.07508417540426328520132402062336810522220725221568227087778502965908025757931`48.64515000978546 w+6.05057541559166994278084616530113843087594698563810896494868727635391413726916`48.64515000978546 w^2-8.27622812308927516003350477597147910742423438755148873826093928234582831882333`48.64515000978546 w^3)/(1+0.94565793471933860888504720064083228010849454893220632286715427516409122810053`49.69897000433602 w+0.06800169946935912809871451622585673280525686577837182802296658117366510350023`48.64515000978546 w^2+0.04921012350933695738228688042901823227292534810750327304532077959625758470586`49.69897000433602 w^3-0.03306504126933942524957663744983634163814393469377981153476460272413509558778`49.69897000433602 w^4)+62.35238324060218176166220956122130790488279175286370170394196021676308128986419`50.102950537607555 THRSub[2,1]-28.40878295894897634932881837431267042283692862558808030074350764288199443001685`49.20792191846793 THRSub[4,1]+59.54214003781253230702948034381141602544141602073773201345998657504460889492605`49.69546521102929 THRSub[5,1]+55.45928375999235680558340284003223539262755202818599651055798262949071037123668`49.0894155854929 THRSub[6,1])/(1+3.73821295464385818759180773925914385524448548403775315460207208127051448637502`50. z),((12.80217575686432090112521976064861692632675222966073365526989026221770723732626`48.79144449561134+ 23.72207757598288452769110067187029742376921580568801321460074392983015670063804`48.79144449561134 w+2.37412920376728480802354161961955904670632692129848736235302998106476795022433`48.79144449561134 w^2-2.10091757371410398874250371579498815585624704151006811514761956131421237024646`48.79144449561134 w^3)/(1+0.97846485441391122969318622547596127802964515216048262293693198486240000687933`49.69897000433602 w+0.11571249871569962265145982147565755329720768544082681260482320488610988775383`48.79144449561134 w^2+0.04621455914222420672429362479981965065886199536317676074267910459283442210365`49.69897000433602 w^3-0.01739929414682726079791965921435419419709659463952710308696813762459169173866`49.69897000433602 w^4)+21.77914328817236374031233255114804416800476526090574753881411762358734503589464`50.402550114857185 THRSub[2,1]-1.35995632399576433509556703426382793158491096428277752399161258076483692737092`48.75218843942577 THRSub[4,1]+20.79754986371584086293943988483242270867688695882581054038103797144345091555234`49.995064788278924 THRSub[5,1]+13.66278804741332469037241767607601211333909367057041025805599755592405357353272`49.319042887711184 THRSub[6,1])/(1+0.6550164325052751243172336581851493092242129208558080095321823061589573556215`50. z),((14.30620670779665408421414539290203642446831006378914268402376464584001379898587`48.79656128719227+ 26.16302358802848065889769454705167445130910652365510300598079353052264972039635`48.79656128719227 w+2.6414104469944754524407715630817781907501082791392786404101091539088554090815`48.79656128719227 w^2-2.29352390545317398119203526108547295255920713033122949630373609211632705212351`48.79656128719227 w^3)/(1+0.9785767542920566600801382273518883925529100057199469276214732655067802727272`49.69897000433602 w+0.11506036379370116572465521506289024161666179181424525218356465749769751421077`48.79656128719227 w^2+0.0479178830607014228264964411398927416315291856566571427746429886106450460927`49.69897000433602 w^3-0.01871098279555831526962681690156561776932543432761421138315405152011149641558`49.69897000433602 w^4)+23.27621978906090504452087912976779963987379304873370094836215801574913301761285`50.36187154923678 THRSub[2,1]-2.35800732458812520456793142001033157949759615616807979702363950887269558184965`48.90973169451561 THRSub[4,1]+22.227152615534618393011329919058765574941030803550632026489414218564111962955`49.95438622265851 THRSub[5,1]+15.20500039289409127712936528836392392446426631498279033684230785690626489314082`49.28715024063248 THRSub[6,1])/(1+0.76878060481014237882862326251620674682177192371643575609876896197319496042627`50. z),((119.83635329090782520997423380537922427509009761368534119555881020170636606175606`48.23547357914319+ 189.16177210589809446563239280520578954768631426671280155674216843809669641426108`48.23547357914319 w+5.09185828804261408245284640757540346735802392343245775386231146210137940832362`48.23547357914319 w^2-20.72311416532338691676229855595532004666214926743428077938896018689709392341148`48.23547357914319 w^3)/(1+0.91040534991147319572626240633358944411503060903752053694942714792818321946424`49.69897000433602 w+0.02040421216222401883960791452421301912874889788856774661831690321390616337747`48.23547357914319 w^2+0.03801456866928077433446344844938008977493676904497569046547565741037483394188`49.69897000433602 w^3-0.0409494358700669324823297400447044405093322870583612314355875652576651429321`49.69897000433602 w^4)+128.31840824067794613028295599831084139120349089488554046240279462431537289339317`50.04699132116079 THRSub[2,1]-72.38613295899948592840931599903902608038406138693597280638406391458352216570228`49.219158146229844 THRSub[4,1]+122.53505376712615204996833336360056891382485040866071857808126371261229814792546`49.63950599458253 THRSub[5,1]+123.41413982581733902244122780976433280936942384109494281736077487997508474620093`49.04734185392624 THRSub[6,1])/(1+8.75102975453464895635516313185148620944807145037799661958921040773802367083712`50. z),((7.06920483461414999571035221192164448641413764470499751494881286949496832834917`48.68170326330327+ 14.3079889542844838883071082995913956386100964284035436287480910056995452587279`48.68170326330326 w+1.1265853823300918441576653020384717343109518249864055255281199659317956894502`48.68170326330326 w^2-1.36396900372537475246571501893787932967053067571334749816065186662117637032716`48.68170326330326 w^3)/(1+0.96206334159386700170249910545555977295000411527885449829508198083615011960641`49.69897000433602 w+0.10506936676828794799201636474957874285421630693193129784810800199838277724241`48.68170326330327 w^2+0.03384044927333493522096388425359539578356313407205928971855892579738266356006`49.69897000433602 w^3-0.01010828483785191192682334785708991942103802828834122153263886630163962808691`49.69897000433602 w^4)+16.07268090276884847105163083915038637920037403775790720846381773145960683320962`50.74171677380974 THRSub[2,1]+2.44435193293991251107823410706794392761801651781578269624192068065365520775255`49.55041956941728 THRSub[4,1]+15.34827968648621417311157156448001881088213671494507859375887044491776405581612`50.33423144723146 THRSub[5,1]+7.78427967822335476901148625819606598163580269801848888476377846572622550477891`49.597847746975226 THRSub[6,1])/(1+0.22137729003060330113587648797225464828153330828628718863914296974652614105788`50. z),((61.49458929612360851550320512080580128291978826485531048184808922403042417558233`48.60307453385383+ 100.32401209567007240057437731842590331689270850339668766681890552937277192959277`48.60307453385382 w+6.23221277362871290322981368542003633084848016296900528288656363722167352277152`48.60307453385382 w^2-9.65754944531099805161955025811107042654967248771715502890109566427291359793679`48.60307453385382 w^3)/(1+0.93991007670408188217420996962156334709895380504765453261393994538834800427559`49.69897000433602 w+0.06020368421765056934610291784859500153118386291514453764087288859874419914317`48.60307453385382 w^2+0.04765443165966075755437749771119950252948465991840616169538733454718495472395`49.69897000433602 w^3-0.03448114008191413697256624346373842590288065475619443379725277285980824056213`49.69897000433602 w^4)+70.24640922840084587081037323313088649606583220776994355235054064336948459758855`50.09008739017313 THRSub[2,1]-33.67146695081475242209426082225238948362562226219224153301589459395292996850014`49.21137728090858 THRSub[4,1]+67.08037957893676780993752631348633851609260729986423215277131709261124659208354`49.68260206359487 THRSub[5,1]+63.59130929556349329615536016220759738555367186854298313380267472972322737615351`49.07973791128286 THRSub[6,1])/(1+4.33808699723420964315270487740250301204781221785121371828609462683979671519302`50. z),((81.9294492792399286949973567862926125330225162057985196148562369605282570618193`48.96859688568419+ 136.16172067149356095787703395970495701291358187615343794899244939226660966593562`48.96859688568419 w+22.46949290754176836790751109255433001416959152479354365356946298808052611843939`48.96859688568419 w^2)/(1+0.98242043358786672121063492439811870472609417229892472791481882742883980354495`48.96859688568419 w+0.20388958408720614013946950582687705458561218938269462720730356799678216651924`48.96859688568419 w^2+0.13088720536706955384958753224821463480895887548519568782676919560669379425614`49.69897000433602 w^3-0.01804985323834993360640642035406253665019580970505280199850777410556072271842`49.69897000433602 w^4+0.0047560564449948391846250601915455062902067729727877091888151071635671897644`49.69897000433602 w^5)+90.58678098784306566038374211618581898675454914841018734291903598578547860197549`50.06817066475 THRSub[2,1]-47.2317147904428989484765067442890111440847668892857373933948914888969259714261`49.21602867978794 THRSub[4,1]+86.50400383798889677934283815190434469251611312361384013248636696735276139121592`49.66068533817173 THRSub[5,1]+84.54492951501251660268511314862152016958611156479781636563042555931085656223429`49.0632590806899 THRSub[6,1])/(1+5.88376990402810928979699619854301081193218489690483278331789289302185067988814`50. z),((133.3477857698529540362893701915541371367514172378142379779991039701025113384962`48.99961579668906+ 221.86315404678955245653829538327428541605117748272345202715470330677811852893169`48.99961579668906 w+39.34142351421169658472655031812822095246344868845361330901944317753345631625788`48.99961579668906 w^2)/(1+0.99819948973391118383881960385841618727240228993783408486189583309816787917893`48.99961579668906 w+0.21436372411576229133798232850586854159855001079288166142877306877323455642892`48.99961579668908 w^2+0.13273856549589497548349579853605428927616178231920391574309117163513806347671`49.69897000433602 w^3-0.01759471377297930974815844006368371970994052511145201360669373018676499191995`49.69897000433602 w^4+0.00432770335658482563901379084252087108156257381491669055537189153844173631993`49.69897000433602 w^5)+141.76736555437687886195884346316592476834424646147717214592158674857548106613155`50.04230864574241 THRSub[2,1]-81.35210450146544108285990764227574833181123176466372726206325866409026094753215`49.21968049449544 THRSub[4,1]+135.37786198256865128689508489913886505208669126953166727968773771179358924312596`49.634823319164134 THRSub[5,1]+137.26857411205461805627628780803797249477298606138321216094325655825307761047352`49.04382297083791 THRSub[6,1])/(1+9.7730279598690873858572071265461173252188657396772497264624176998534892919763`50. z),((8.71714838057890295990508946302010525493076471097875461405883556210604244711627`47.45644930315154+ 14.69221657885678912103110754654118376512744132866379229074753058910515605437176`47.45644930315154 w-1.77419650486581822131047778581394002149840917858077368461842779763822473044085`47.45644930315154 w^2)/(1+0.70263257184146245455390798321861786225430536154914434493266535401562855513327`47.45644930315154 w-0.00331780735151221905858979374709826530436103733372630034210093373640434248111`47.45644930315154 w^2+0.09375451991876201554112434854635000868324523917301541837761579881264315158674`49.69897000433602 w^3-0.02551725541287369066522369944868881638963479972195808910233047830725369477409`49.69897000433602 w^4+0.00785691713899584971596471693744362596948221619066256853045149970899276457688`49.69897000433602 w^5)+17.71300456494178395309412779323349591376554088140815892227647521619215790711686`50.589943838747054 THRSub[2,1]+1.35080282482462218971656947101253757124123862204894822036681569083195449181424`49.07185313245136 THRSub[4,1]+16.91467340111875155206464010976580382969327378496741466755241287328383111822166`50.182458512168786 THRSub[5,1]+9.47405799007708142125415843130589217038720113336680021108243883479560129732078`49.4700878932802 THRSub[6,1])/(1+0.34602694128652531555841205925659658532896319595661837508886303751931347511382`50. z),((94.46677543074671288845557789741555696654375496268860590707705191683281680845566`48.97975530079173+ 157.06388954810938691732681986533172976199829769396767435205260285762251939435989`48.97975530079173 w+26.59813441147201611268069584703627171350778906735916293192619229913914078597826`48.97975530079173 w^2)/(1+0.98791064669155788122020105745101331815475327419877958930848695883496175949294`48.97975530079173 w+0.20756130440969155690343249817966986835737481763587620317738982707077805849315`48.97975530079173 w^2+0.13152964621282320484320817797282820722551699180804432324342372658106716395318`49.69897000433602 w^3-0.01788544812632480258228444898522829296567383850535904561415365659715462685608`49.69897000433602 w^4+0.00461075227145213706442620606078648741265440077776884649073676760792448961653`49.69897000433602 w^5)+103.06613611930579350114509718303780182996706093789209008148187562028471991310415`50.059324113544115 THRSub[2,1]-55.5512848780847175089840767888569997062264414156070058857701179118964201788439`49.21749212856482 THRSub[4,1]+98.42091017261791169597761712280038943022728966517641394380257106688986343413729`49.65183878696585 THRSub[5,1]+97.4005287685963133076074910398159997419745243184158505754601437553260686382725`49.05660998738711 THRSub[6,1])/(1+6.83208717878777324187211080641402166397785392443998663723356890903629223130568`50. z),((88.22682430295278910136901875069343668778192734151374610632326621124030926742895`48.97466236481547+ 146.66128039902214654132351992047571963206653720766302779458821935662598481294442`48.97466236481547 w+24.54496210013235530919822595197402596690672106690323799829573371852796547364454`48.97466236481547 w^2)/(1+0.98538003220043164784291260457817335225268928785949962572738941904886380962296`48.97466236481547 w+0.20587228762963784977615681334573820209550702877461503159552180534547617496968`48.97466236481547 w^2+0.13123335387725417454779685088891315851388520430845611173627469119653895421713`49.69897000433602 w^3-0.01796051207460464797231387240906387955498323683944491657061093226936212339755`49.69897000433602 w^4+0.00467820703358885945203686315573976268376828427183610646470653560949305197235`49.69897000433602 w^5)+96.85503774109594260925285165865921795881585612617054943430468755992412832136902`50.063419768137116 THRSub[2,1]-51.41055262594481691438924643927127712545897154112597878765199253832269245101903`49.216843101625706 THRSub[4,1]+92.489748119084998305796978269001133309519676880932669953926233827997360895566`49.65593444155885 THRSub[5,1]+91.0021699725123499671086096308545951757251044564558537769711055656920941029242`49.059688168724264 THRSub[6,1])/(1+6.36010029923835328804850803296938246417410114009140168269012406073996552617328`50. z),((5.65339501216682383455617627284901927553913226439985994849887679954949580287374`48.812169395980405+ 10.15676066058465915142194094402134890242922984244429693637576772362949269020954`48.812169395980405 w-2.2480572208406774479181581297667346159171791913861183578577930256595827282596`48.812169395980405 w^2)/(1+0.62984033047550180373233741628650611563636957110055047451224470017885546423311`48.812169395980405 w-0.06371353036709376351580212899591587598785571207771382189193803692251563612788`48.812169395980405 w^2+0.07984527896021512149313211825950111277052873200379209301184326547493412711397`49.69897000433602 w^3-0.02385831654085671806662461803922986009978659710784739724259189081499238567533`49.69897000433602 w^4+0.00666293939319623727540920286169059741870259452316264621817682108810424842034`49.69897000433602 w^5)+14.66341760695757074737604499349945151056679336885585877036626673516653360475313`50.98900322821584 THRSub[2,1]+3.3838607968140976601952913375019005067070702970838149883069546781823706933902`50.00874654068286 THRSub[4,1]+14.00253236860816956136697909197492940418063041976463578483982959709804845342004`50.581517901637575 THRSub[5,1]+6.33252804659790028349010171926977687685888165381388449440644505733401875420033`49.81609933253851 THRSub[6,1])/(1+0.11428612113412781475080378468249007269563493528609752963295815183519027318186`50. z),((5.75094976395096349206394525921211464809968816138390534506835791705069021222404`48.793750302273104+ 10.29541794022732466156929189834665379968131300679420072244853778241266250808416`48.793750302273104 w-2.2403604097230636793461876802976382779704402268562505965355491460603611871908`48.793750302273104 w^2)/(1+0.63235225869468347166322867112821470419094589177982353937583017506758836418749`48.793750302273104 w-0.06153941755443680009657140528966791409027231785301341888535479014817062776818`48.793750302273104 w^2+0.08039777811631832993757064000370722902234455085866749547475226570026683179822`49.69897000433602 w^3-0.023989993395588921833576866258428428823087919777641337140837622822017288037`49.69897000433602 w^4+0.00673364492537103767879868555342545000840562293394512044501223189300151004367`49.69897000433602 w^5)+14.76052127783317141623055349312106181487208760650773779416933606162812417230392`50.964697141185496 THRSub[2,1]+3.31912501623036388095895233775416030383687413864922897243824179387464364835629`49.97086578082698 THRSub[4,1]+14.09525954388149171525781316142104876544821199060521341532110040137971416437266`50.55721181460723 THRSub[5,1]+6.43255932751572284392554975216706412996981176637124379855143943838550145427837`49.79414144516627 THRSub[6,1])/(1+0.12166511528597671061569128464795487994061067014636271639480934612559721962644`50. z),((13.34854747921025789341498135898353337490002632777376861803727833400265914429636`48.14776625275142+ 22.00675553032935607177012459683083092579599237625100421107236223415968478688741`48.14776625275142 w-0.52093260804801545484348464939735605466529653628892425112875136289023629083927`48.14776625275142 w^2)/(1+0.78357721943915802196362866225433622040667888725358063160441022513798325938141`48.14776625275142 w+0.05992681500065857301919085898420418637343018262653733371568080880529509220577`48.147766252751424 w^2+0.10613115963048710328946315089458183351061477156571528089797975427901134314244`49.69897000433602 w^3-0.02446178769055917969930319120315154776977045843953509863696441766688594367406`49.69897000433602 w^4+0.00788483735329952403779831041682457074188535056705028561905254785153126756023`49.69897000433602 w^5)+22.32298865635913935231943040308187579766759003120755074056409863739706191468037`50.38669019031426 THRSub[2,1]-1.72251990278694807643363226888638235136012747781731299182493325663798151322797`48.82369998970737 THRSub[4,1]+21.31688393546318369453137429506841724094065747533314300941942612872361247213882`49.979204863735994 THRSub[5,1]+14.2230299858529302772048585675603208363272016844125288657172690467754516580615`49.3065739159545 THRSub[6,1])/(1+0.69634372482259044314869193854640234136552178193125544428637002234209150314059`50. z),((6.08859236887290462746347166397324414269603769390404985378973235403977476484011`48.72725158922722+ 10.77867164369526549481082395388329715140477460551180426488234182508955692484999`48.72725158922722 w-2.20925587458417064148137329615757034266564222381306715755756514500008242620493`48.72725158922722 w^2)/(1+0.64097544979819442820323232494567998655390598604319007571535987482971273992039`48.72725158922722 w-0.054139068471409404417290767966444713806149611314467952907406068657250321958`48.72725158922722 w^2+0.0822440938695202900803613186353861594160457701844352668615479427582699452796`49.69897000433602 w^3-0.02438838367232323961158326472811446994795769919669730903590613395059029930552`49.69897000433602 w^4+0.00695593418889359110806300594553887093759574324708303533844216234210475541866`49.69897000433602 w^5)+15.096602665795361940639594724101965698072897178321873105254589163343036661018`50.89172042841618 THRSub[2,1]+3.09507075758890353135292485043355771503633442410647209838140639273136865588026`49.85005118448089 THRSub[4,1]+14.41619362893369750161732748393087201661659687678144951450866601230004277265422`50.48423510183791 THRSub[5,1]+6.77877334215958096984084968017398628153920740546481394643713612681834505509448`49.728845046291134 THRSub[6,1])/(1+0.14720423830734336534462659956927244394007573096509073235102196292252673282411`50. z),((7.1645003115181969504972289437114660251439976189203081191388679542483217475292`48.468689380409934+ 12.35068928883754758207230576471358212176352955620726210781352681123600357568988`48.468689380409934 w-2.06837504005414439224826884034498891992495642443403909002336917802116484276569`48.468689380409934 w^2)/(1+0.66751471777024522294812017178526225286750734405226662678138911815138412697655`48.468689380409934 w-0.03187723271277690361615702158765492513018521365334892532904832471572244665095`48.468689380409934 w^2+0.08751224796281420986858956674980081665045276225066611697384260596045726092474`49.69897000433602 w^3-0.02518485306834876786804633169029604214037969831732181142435756089165192054214`49.69897000433602 w^4+0.00747200837380419650124268547713309252327822601511720542582780577288291014577`49.69897000433602 w^5)+16.16753574536738615467456380920741383467751011436769911278536782407559824687909`50.73035687166124 THRSub[2,1]+2.38111537120755405532961212702992562396659246674258809336088728557632759863957`49.52335837644503 THRSub[4,1]+15.43885938894077990029311458232104777517980669856122711079728067701888615526047`50.32287154508296 THRSub[5,1]+7.88199433021159733993323990666214099622117237584759934804067876840479398994307`49.58811466559349 THRSub[6,1])/(1+0.22858539372532191142099645394417090939896678063829809048734036380439209931529`50. z),((6.22543776101236970707264000841716237019882738315554700088019253823493181351709`48.698861201764906+ 10.97597263559801351527875122135538474559390184257613571217129740971505269431324`48.698861201764906 w-2.19474984059887205126860912597496659846403904537086744260655874096507578319527`48.698861201764906 w^2)/(1+0.64443531907710956635924747710489485082742193514850489262696779444644115273993`48.698861201764906 w-0.05119536564644462791241682669312505888717084583272137100567993104327340205897`48.698861201764906 w^2+0.08296442596580372457316007981113521301260830292633632184671886365870984437187`49.69897000433602 w^3-0.02452667359899831321731845140538283970674962684589171695870434583786762559107`49.69897000433602 w^4+0.00703682449194944818238990563226584086685943262569341556325435297243927781965`49.69897000433602 w^5)+15.23281530204455290025974297948395259918113894259017353801433249555411491362378`50.866109070233264 THRSub[2,1]+3.00426233342277622493949268017889978096417324792760514320824417125731648747646`49.80461626121622 THRSub[4,1]+14.54626711515751966312859285390069529171064898364666770147894517349057232959434`50.458623743655 THRSub[5,1]+6.91909269732232898943054197972464933860671097025426726865328144298854732879047`49.706163207046515 THRSub[6,1])/(1+0.15755515745620178936894142353461157295946758344961209701016478491043955370414`50. z),((102.91093028169442981732166952531011632301222145823639189193400790120499887199944`48.98552742999656+ 171.13947569646001236756094038182449742386663523631456625179843245348345944679928`48.98552742999656 w+29.37214600010949469899741172815262360849172270767681540510064021272981246404463`48.98552742999656 w^2)/(1+0.99083054173491587790474466930764278684606836148819792157026559596837212501937`48.98552742999656 w+0.20950262505732268707316028207106835079493038832136832611617378364239189166054`48.98552742999656 w^2+0.13187195693501761319773876828827355889534046375528059320831858689782816115293`49.69897000433602 w^3-0.01780047141810178345883825285909455380708061474559672025411506963202691201632`49.69897000433602 w^4+0.00453188079451862144192123753098959337202877152686057226029588810524189956356`49.69897000433602 w^5)+111.47124625974635226465169533820797571758835614822947263044362118688692575120317`50.05455732496863 THRSub[2,1]-61.15469163837842335132180889230378229797397155583192758507794828963122407090647`49.21818677684864 THRSub[4,1]+106.44719912911548895652328524887273943583146937898641820377224385448590580108623`49.64707199839036 THRSub[5,1]+106.05904729855757996979073673467348157888555595995199739520132043216861061330205`49.053027611189954 THRSub[6,1])/(1+7.47079895984301319545994606008166993841172007686419868850601275540427133672943`50. z),((7.83827130038982378977462130852368383581600139371513362818075570468370114524428`48.22910186955563+ 13.35730002131548362102731728905281138748731559506536298125052374005265985034658`48.22910186955563 w-1.95222997962257465873954809195897310325490493226939616159062860491479254572063`48.22910186955563 w^2)/(1+0.68325158731626893757841036723952742799232750830183281804932435772312150272567`48.22910186955563 w-0.01897161160484453141838214165088899108299008458915367293506661242321087900879`48.22910186955563 w^2+0.09039667118653879804162894545671573754422809442962022370793865782917186290289`49.69897000433602 w^3-0.0254174463532775120734771310913343629941332806747589198075262291359150434825`49.69897000433602 w^4+0.00768045429900581025264879047550169106006167151596749705163295606279196910513`49.69897000433602 w^5)+16.8381913018869331635145044977002385802353669271234752312487111036658915006149`50.660598851418364 THRSub[2,1]+1.93401166686118938276965166803470912692802125823873734771865843251613209614895`49.333915990546366 THRSub[4,1]+16.07928827053357130106935036861797519456833502661739458979486445495350322313187`50.25311352484009 THRSub[5,1]+8.57286969844818919940051711869357126149167021896081588002515080066348449810681`49.52894846917254 THRSub[6,1])/(1+0.27954910482747535727674256911097838654222545702089530628872291696946293555525`50. z),((37.46129123729003530817648221901177109879760331118809127197146741241045314839341`48.842709403077+ 61.9739943206439433046469923657624923982688604086652249306974386603151773977051`48.842709403077 w+7.62866615197970364298130127395006957911200835050741174270925064537928619321776`48.842709403077 w^2)/(1+0.93196343033544005848775207928934065934589210426789566490553787246084628778759`48.842709403076995 w+0.16910404400369526107649285727320406832229777836931520414750321806162346730068`48.842709403076995 w^2+0.12498285235461003545415040046254320906358299074453296151737051719742318164243`49.69897000433602 w^3-0.01973583467128499278580181755009001878320588765335169786277896254597158240644`49.69897000433602 w^4+0.00592794856012468394811883395605005903005672200767867543127139462901589426288`49.69897000433602 w^5)+46.32423811854003886807368384027317577629810467175886755935138854773684549820865`50.14513135338162 THRSub[2,1]-17.72335287757421442026980122701391567044713723818485753768312653019783723558045`49.192340188559854 THRSub[4,1]+44.23638888918989127244207676424539722081673974234353008576742977603452760359885`49.737646026803354 THRSub[5,1]+38.94790089630401517037852460909712128983192138310092958096072295010818678267628`49.12120025979799 THRSub[6,1])/(1+2.5202199781249841359083701512200726769592234715715415904780281261018614823645`50. z),((46.65515483343399421335985672592222601596321779486086267592879225652236750401513`48.89439088251719+ 77.31839351017404607754903215394655723450065323394471571969140599174793344735991`48.89439088251719 w+10.73752640555163040858248627748323995926629314136359354277444179522145018795068`48.89439088251719 w^2)/(1+0.9504107013381535883495030089609173892627571560755256349359858495485264023592`48.89439088251719 w+0.18201100804230786731514503071312582818661638197584116911267758475176482574885`48.89439088251719 w^2+0.12714951624025731025127959268005484859998151381856840102621523696299303759862`49.69897000433602 w^3-0.01909450258837564361694372460298612939699496586247145951961872000782173454609`49.69897000433602 w^4+0.00553166897810092690522511847594997714085063410596321643914479869186919321946`49.69897000433602 w^5)+55.47559044518573030153731474533106179884458092937731059557062808522288702098256`50.11759611468243 THRSub[2,1]-23.82425442867134204257888849705250635214478807659715289516261955518853158409651`49.20328340442635 THRSub[4,1]+52.97528664175696524895180032451410564941812253192989852488847688318685196779315`49.71011078810416 THRSub[5,1]+48.37516030998168148702874664122628019666453318497190599704846021535980225709924`49.10044178419882 THRSub[6,1])/(1+3.21563936537283648872351182969149577801223592209777359335520208644655011407653`50. z),((7.5427139298035914656885905409792494916991612362600104473459077009988226584186`48.346724337049324+ 12.91381352787174870978448331170130715672615851596630676546315451330507801561408`48.346724337049324 w-2.00555043093534083873643030836263114907628847074387896641223700093069479624305`48.346724337049324 w^2)/(1+0.67643934006365066716141135685698142510293756585564580397335228479109651443074`48.346724337049324 w-0.02453486924274013973492918994053366365858093000023965672558233265882787862968`48.346724337049324 w^2+0.0891670500668574391448508604395451739118872532732492019862073534112408910334`49.69897000433602 w^3-0.02533529584661326151567835355199249827288515612293062460548151141333404470087`49.69897000433602 w^4+0.0075980117493773232218263195584537717693047013473324328291678627602868191251`49.69897000433602 w^5)+16.54400055142746238690081710493996318714783345393941925866276602734462000146108`50.68914242241318 THRSub[2,1]+2.13013883383416990051210992987489272231971024036144132944262181673031309558481`49.41704510311378 THRSub[4,1]+15.79835679764833698273520969471677102959287043876583339824115319685856065871665`50.28165709583491 THRSub[5,1]+8.26980929571288098281049480779216428885807635858944928635799548232142641923086`49.55303223666846 THRSub[6,1])/(1+0.25719328853758945452426772597731704959820160222585521396680893676032833815109`50. z),((7.27475643477384565956560317569065219261379005001476689052999374655802772539991`48.43563126258377+ 12.51432382652218634888950226712139088295417798977917020254146420466705935898113`48.43563126258377 w-2.05071432468381785073370457149808170429166199427734004045394129931429168230243`48.43563126258377 w^2)/(1+0.6701398798208410191638500041056186884794688730190051847185407500379293470828`48.43563126258378 w-0.029710823310559465453996127854704719852053561523995039342130413596219388083`48.43563126258377 w^2+0.08800442580833842454684517957952408607268349419027247100577846882621535161022`49.69897000433602 w^3-0.02523443917515034129441796888893403427120161251710322890716411146335720289394`49.69897000433602 w^4+0.00751128864547134443153548210731733394694240500835820518136441547106407031059`49.69897000433602 w^5)+16.27728205816951443867634658505311078767972499680680592879250625719255483734724`50.71773230987599 THRSub[2,1]+2.30795116267280186599509027646612765529844921178318354935612833016502320499414`49.492237094285244 THRSub[4,1]+15.54365939795218832979315503209892892265013025882933969745781706077301674785687`50.31024698329772 THRSub[5,1]+7.99504942016457036769903925760449944851488209103330518110610003208939276139552`49.57733003134706 THRSub[6,1])/(1+0.23692511346044232490273839297566504341611915401889179322014127112823868124992`50. z),((10.3157550572085358428522425295878080935210187460663021229719824893966997112248`48.254968419407646+ 17.17233641772556674866534787828499508938964746947558046050676341733356542522877`48.254968419407646 w-1.38990728371840778650698639321557525462025778710288301793894033494689234640682`48.254968419407646 w^2)/(1+0.73446081211387039165892600287775902092697356963569232789765204756743583436538`48.254968419407646 w+0.02191587462058720670940101094882096834398333820084414234085260977790321981676`48.254968419407646 w^2+0.09889327011971153958155177357831814373460463791798381027373193335146622957339`49.69897000433602 w^3-0.02533599036621808871366058737423701144368558976844354608932573581193615141381`49.69897000433602 w^4+0.00798831870137487507006347815267168359670082488777303850220241185867813805888`49.69897000433602 w^5)+19.30421948526121500098340929985294073358702086087985349289680410551760565157577`50.497148244054685 THRSub[2,1]+0.28999287794500149112371513326624102469358530240115183995326309794832266217514`48.2528354314657 THRSub[4,1]+18.43417172166123446967940375729695271153176508401405335432066010765392316090327`50.08966291747641 THRSub[5,1]+11.11324696470418548848813087533533709745694163629100776405069778865620849557214`49.394400828578384 THRSub[6,1])/(1+0.46694477565361001865739097968869539127765820435002710576048915981526852171549`50. z),((9.40796869286036904853707061854399160019618469149943293146048957511410924307642`47.83294516455873+ 15.75656686227990490862684540560343897437926319297994298701821089819407456831595`47.83294516455873 w-1.61654312706298293749881711000722524328348518668848573882132412604600117939455`47.83294516455873 w^2)/(1+0.71692672572483637578487677941335385585902013639158638936172116760306171375252`47.83294516455873 w+0.0080813101127730185782338896980325855323302211121068808493716886449726941258`47.83294516455873 w^2+0.096114325810711884921243442118244043718232165944798292267222701078863714798`49.69897000433602 w^3-0.02548247927514096333750260551113901201475437809285529411239174404702790504494`49.69897000433602 w^4+0.00793816266462179755966198406069182984321033495486674400301311276760509141706`49.69897000433602 w^5)+18.40063061094301156602523728882179812319581185264434718957843504861370561901646`50.545405448583786 THRSub[2,1]+0.892385460823803781095829807287002764954391307891489375498842469217589350548`48.82124760761051 THRSub[4,1]+17.57130790643773386234537722161213500642420054484568933790654502918998653240519`50.13792012200552 THRSub[5,1]+10.18241549658246964573180741795653686248721141108049758623288181660050147623389`49.43353471840404 THRSub[6,1])/(1+0.39828025494963405293564295920965566634375573496669838843062053020045542379439`50. z),((118.54116124491693033502030231663109706704769932857050810434763008323237332619621`48.993778690264016+ 197.18950903546139807254398348396421850982927336457796953503496510899769039724664`48.993778690264016 w+34.49642903306733765998063869395640660709525196272731694589026745361724715519426`48.993778690264016 w^2)/(1+0.99510354205544401764445833670217096150500252269598703994873626420148196745451`48.993778690264016 w+0.21232833145349444477313981755284049687001848524560029847947085552119041422627`48.993778690264016 w^2+0.13237393446947234719623201511115014625837695284020056336111089478687823097111`49.69897000433602 w^3-0.01767954664727457381281923217476783189884701198183107974909073562462351877082`49.69897000433602 w^4+0.00441439840162285882626780921117148714991661805123479870069633963927749473211`49.69897000433602 w^5)+127.02920499988775321578556764328236359476896336422691318573280778268979891552525`50.0474952798228 THRSub[2,1]-71.52666413180602398541105709568670754942770969983022128860407268683313951378926`49.219098370546995 THRSub[4,1]+121.30395535659505089225283176710102680812995327384079739166908253224479841466319`49.64000995324453 THRSub[5,1]+122.08606797872041230007403991263244626133741428057849899120235354077609239332242`49.047720565139436 THRSub[6,1])/(1+8.65306205580034885321329347455872560797811476387597980314365704586838825333709`50. z)} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};

(* Sample Pades for the 2-loop triangle form factor with LME to z^6 and THR to (1-z)^3 *)
(* Mean and weighted standard deviation *)
Ftri2Loop63[z_] := Module[{const},
const = Ftri2LoopPade63[z];
{Mean[const],(StandardDeviation[Re[const]] + I*StandardDeviation[Im[const]])*80/Length[const]}
];
(* from 20 each of [6/3], [5/4], [4/5] and [3/6] Pades *)
Ftri2LoopPade63[z_] = {((71.57432334074678820898178701954545657168977606038509604977540074348754887857195`48.11973652163982+ 167.72132213862967615582091717394004147818829539154421592892443978327926405954628`48.119736521639815 w+77.87816583240400772603014775220316787391120985411819065972119786506768254140148`48.11973652163982 w^2-29.67590344143509591226243929738174949269025537864255919121831674193068226701168`48.11973652163982 w^3-10.40630193580600513681590938362222744398573604977344127656317641346174085663746`48.11973652163982 w^4+7.13261155321090402173320683660415353062808770413591786935545295862121414064878`48.11973652163982 w^5-1.25159200993410039149204980722933133309032123455662367992637925212762969356012`48.11973652163982 w^6)/(1+1.65857418323405445230642450708344577286194437572185371055778882326181968472786`49.69897000433602 w+0.55464232165347423028416846998677225044587443780854010166368796246886205768719`49.69897000433602 w^2-0.11653563877312235952279923010326058225449540182641302626617571203928432381693`49.69897000433602 w^3)+80.27953584993569981053742983953723226579815752399787916612414728305308520455769`50.077752495377844 THRSub[2,1]-40.36021803183798838191229855985661999678050580634419860886496568707533037314745`49.214179700893084 THRSub[4,1]+76.66130975784172655586706772474439151625923345914022023980960158839826859646871`49.670267168799576 THRSub[5,1]+73.92692790310904130028466572272640499510367953039020039786300094731935120624214`49.07046220121487 THRSub[6,1])/(1+5.10051319592973029684994008490701904761680156167008594112225060916712216191952`50. z),((93.67736124100611874610650676775351414634433414556642460952046619944061793599945`48.13319803124992+ 219.78171854425114903833316971037760936891002265292902119556552053454683242426552`48.13319803124992 w+103.23043902860836933999027778892848270186194029172782729287660567129618891830957`48.13319803124992 w^2-38.68359602112097893313369715366657849489978729515504939971754190187394636136151`48.13319803124992 w^3-14.00432183414167715173178080608416161401725703746002251100046725244726299596366`48.13319803124992 w^4+9.55980195930346646278257736819205936415245486660398370245578790935418153486372`48.13319803124992 w^5-1.67956149673462075327766920596169412339261073630982332590651988366738707096035`48.13319803124992 w^6)/(1+1.67116659326673314841280559306799582857555856545271475971668721894602280709708`49.69897000433602 w+0.56678316637149720329098555455124287177197998545966281449962755501862126484172`49.69897000433602 w^2-0.11882757311987830481430378301439397430375037470235015977952913026478415579695`49.69897000433602 w^3)+102.28037208154046838348396300453685154255713098154422545385538352724416788200886`50.05981273783185 THRSub[2,1]-55.0274421862411674305433206698563661812864881113750961340191231832027188247796`49.21741724954138 THRSub[4,1]+97.67056078833272239659731002052534590897526530936497927643088963843193190359915`49.65232741125357 THRSub[5,1]+96.59107447620893956206189732382162382399799150730792508293030348576129847672182`49.0569772142065 THRSub[6,1])/(1+6.77237627201029923822213811800227482828853362630318880601429262469561398497526`50. z),((85.57937151161148171847185900097318529920617450285102000390822477502749223971214`48.129091351575994+ 200.72084327999458589403955147219301540599683866038268122675558167060503703547933`48.129091351576 w+93.96297152630739963576994318851594207114949783784120457589346133750126492942455`48.129091351575994 w^2-35.38619442228804175571634563285852151178739716785981355557107779782077589698319`48.129091351575994 w^3-12.69035953904953301448777924812898337435922046721093479981176715075115917617973`48.129091351575994 w^4+8.67222303446884897583401122098004809405451217306067495181569493249576510374375`48.129091351575994 w^5-1.52298957552128051582031484528253403991375604313351113209758652155693170749953`48.129091351575994 w^6)/(1+1.66745677645179628187883867869883325671143948371694643400504729420567453913772`49.69897000433602 w+0.56318098204410988225520581764007470715208533388652950737807258966908422813608`49.69897000433602 w^2-0.11814915273750342599282633340249805556904660495888751921966707201879119853296`49.69897000433602 w^3)+94.21982643864771109078753752713510608573510365772443480726019845241247761743858`50.065333804384366 THRSub[2,1]-49.65374509097932923541237035158853587673846989549523570295566646664825864840015`49.216523007684216 THRSub[4,1]+89.97330668982739225440144872619158525320318960601328654031672068201208610962201`49.65784847780609 THRSub[5,1]+88.28750883049721288971391594599238133266916539949504824050691972546824062005798`49.061126775918595 THRSub[6,1])/(1+6.15984825300456226129317401263648941598248180491706815150389331138620985018899`50. z),((54.72648645558695875871876804907299888457883823205429706210535400101545486817146`48.10186873780563+ 127.91747727321358591613263566145451184061115960770774031668954584099493469245643`48.10186873780563 w+58.3530344904272300584878258927703036286925811093670201224015075210285346197652`48.10186873780563 w^2-22.78249537940548363742936755779109476053745918390516632166980615469444308418786`48.10186873780563 w^3-7.62326743323177266212001914680151145745630109986242966632232785552294514668006`48.10186873780563 w^4+5.26656497420776174192879808215074319929646083325183432016545164723101150142596`48.10186873780563 w^5-0.92325119023911859766854203112989507530413110724732980808677506687684181362504`48.10186873780563 w^6)/(1+1.63992791141258276491017871692328456925491175261360999625892484933549231093339`49.69897000433602 w+0.53705116586402333943960724951984496363713408371092071985711846981679177415556`49.69897000433602 w^2-0.11318763418400078626256999200768632456201937843290507124378392671899345597511`49.69897000433602 w^3)+63.5096012445734817908756843577669995142470458520059692757481967649670966405966`50.10083880088272 THRSub[2,1]-29.18026162826317636880446823867646482907976469168292534861433200835133799717219`49.20852783720546 THRSub[4,1]+60.64720183121434610793813432330419983468778813072053217110292166503221831237507`49.693353474304445 THRSub[5,1]+56.65139110459225738910566660062925635589686659397379477617364032662616367406281`49.08782642213802 THRSub[6,1])/(1+3.82615097806480492565693509507163775182559194952871937151425569781278978349514`50. z),((79.39300067325517902097889481857727806031899732274819169506222381126581077380401`48.125376381926955+ 186.15065203940128303496267915753796117629304387753804818414001834226183627535597`48.12537638192696 w+86.86864009605941640987100227622079117958168431048074249408289754587820740206929`48.125376381926955 w^2-32.8652559576445857758213942726429176071646677587619126861611144958298303019363`48.125376381926955 w^3-11.68360998198599888226266063987706220893748025251592242343110113763762057747017`48.125376381926955 w^4+7.99299688171426084501441126986052044480368581809906343171013572408140358683033`48.125376381926955 w^5-1.4032213632190228971089497866015192730257399485869712528777459100804561342536`48.125376381926955 w^6)/(1+1.66400140546017254473732675115741874868492681040636803160261318497395003168016`49.69897000433602 w+0.55984556775308302429136942214312087935966077561384565466339731228472031307995`49.69897000433602 w^2-0.11751977539491448775719111963812628349695679637177119821229523139177359012586`49.69897000433602 w^3)+88.06206060135275649923960020833214969298494296164889305944602102132231583454942`50.07029201959323 THRSub[2,1]-45.54856786611602617438041213905323161490502943144487453774621484592148412647597`49.21564334571684 THRSub[4,1]+84.09307346138001786594275815006484608665681040066381669130455301214013244285111`49.66280669301495 THRSub[5,1]+81.94409051538799885950438930474943383100566920229702493835485009539984280046305`49.06485366229488 THRSub[6,1])/(1+5.69191416058425533318201320764016589900302548367130216431396619426852977239195`50. z),((82.80295793706696042266460187534899995344637358306599828204583996665879209925258`48.12749434931583+ 194.18289498625659664205989465574725266023126803742398474172348276267364410545793`48.12749434931583 w+90.78085422897047644279428654806608239692913001834571763919423088310620255541895`48.127494349315825 w^2-34.25504665948135253555980609538552194431689649591471955308731978849464517096897`48.12749434931583 w^3-12.23889793664404585185983247596281007378903979789377484693463110842117360255402`48.12749434931583 w^4+8.36753279262193965593822332096111180831030221511094748166794514584501419633396`48.127494349315825 w^5-1.46925735049457109970283445082581368965061398373966787228596538481887300806118`48.12749434931583 w^6)/(1+1.66598297254002513275954148940726442276497389351907517701899872889285566735832`49.69897000433602 w+0.56175609232798955210495461860489960283984221467200699737591564412901113096589`49.69897000433602 w^2-0.11788042386737671523443211396696379266937815050754821389876330963686652999476`49.69897000433602 w^3)+91.45625065144600107021818608420835078553819210217310780637886516974342400460851`50.067469501665556 THRSub[2,1]-47.81136123284485588836613605630403234327386219179435103570144427820222290651478`49.21615308283916 THRSub[4,1]+87.33428620697402417811803454826440937413257043217302835344588772470778309520987`49.65998417508729 THRSub[5,1]+85.44061310127788398227125375475802606297484720992694915173331159417218745200485`49.062732045603845 THRSub[6,1])/(1+5.94984167562112528783733478710888487033664014109737580156481821822618103374828`50. z),((115.73930533545981138534610208834007597217515951500772805594633734158994612476401`48.14142838289322+ 271.66636217120326767039833302080213716897746017166690826579599306051037203644997`48.14142838289322 w+128.40579461529979782466476263086933703857000209848755944273322514103589842500936`48.14142838289322 w^2-47.65748421792231677134713153348295817859113804018555973450099021751532295200247`48.14142838289321 w^3-17.56918227143968521123236390789711895487625026186285218631359505095370040478139`48.14142838289321 w^4+11.97202021612943150357490363205964100597520297589987909606834246654472493774972`48.14142838289322 w^5-2.10533190352293642717593730030652273668075364001197520685915673416157308088463`48.14142838289322 w^6)/(1+1.6782571410744990667711356067514064253143277995472865344847880458152588533424`49.69897000433602 w+0.57373489115496455956782952238825883913023466357456724698609373996033348744235`49.69897000433602 w^2-0.12013304851937562518547215289737610891449088754734780300530740487935787029928`49.69897000433602 w^3)+124.24030451993169860171015992081238790616010665644869149534295565777028108570254`50.048623383286 THRSub[2,1]-69.66739714516865424269411861404005709035513856131140682834417127022012762724474`49.21896203552807 THRSub[4,1]+118.64075157353685812841510436003954518479714907869509943123258361582416127176255`49.64113805670773 THRSub[5,1]+119.21308403437775663284651195721535839957699740064881981086277668996094811151813`49.04856830689046 THRSub[6,1])/(1+8.44113103253297533277494344326194945326797453568417605037178546833169199246297`50. z),((45.90139842564425154091285672936856541503866052863898605254008143775250003047391`48.08694390407005+ 106.9746219705777267774214391770174282354057861930675912602055153919378025643896`48.08694390407004 w+47.97043104075907627892484079040186567903401369502651101915101453801047140782275`48.086943904070054 w^2-19.14959031143765863477014447018265582656940593495358208086164155362462953087844`48.08694390407005 w^3-6.13455237038476794288581098471158367600015712729020910379395703797277354998426`48.08694390407005 w^4+4.27696680023903652528981561193442797062640863951489717357566840034765241546894`48.08694390407005 w^5-0.74965649793801947072399121367710228618742174855081816715012362250295456755102`48.08694390407005 w^6)/(1+1.62266862080308638446843372138634865825029471837690223002780365516986479771868`49.69897000433602 w+0.52109225201781834377240728147991423313186595154654064995257078685945989774019`49.69897000433602 w^2-0.11012264904816732741985199695956290198035860452290735353174467221115367681485`49.69897000433602 w^3)+54.72531931227009334335525206121674632580132303384755939807790324644281197169728`50.119451671921674 THRSub[2,1]-23.32407367339425073712418004097629603678261614624398543016746966266848155123968`49.20263963474755 THRSub[4,1]+52.25883048498088499956094324041952122347568421191548720081157576815152904966919`49.711966345343406 THRSub[5,1]+47.60226900953471661379069969414490611436872634159530270255257739248758924835767`49.10183943633664 THRSub[6,1])/(1+3.15862559594306894125058704741235733435809867782865727252199943341202744891832`50. z),((11.4641235635118786044856044852062162849523750199546529084419811377434787633818`47.59336336068108+ 18.33935069085885977714615058231401380249337540853272640650259109178465801747143`47.59336336068108 w-4.58875050467961097591522133179927050457339379224935941235196694112114870413096`47.59336336068108 w^2-2.64109215265128632936353534165193489850136179234812628207707030594850048589406`47.59336336068108 w^3+1.88024318418084618232280321289926572254850600812095141119091894084760260077532`47.59336336068108 w^4-0.44522177683269054915671376847671878714219428275536299364416466515723968643655`47.59336336068108 w^5+0.03444292355292432763301584084647922821756669014305163153363917712649322364584`47.59336336068108 w^6)/(1+0.69823602067017597038277377767921388337402070517075437792992825270873410124125`49.69897000433602 w-0.21766913239578325959078479480155442535155793177832567081055460521626488605141`49.69897000433602 w^2+0.05594632344298992769331685759332446536671840913662721605803403069197940849985`49.69897000433602 w^3)+20.44727807995402881052775099388568399636971587421847771909345264375718838199831`50.44803872719004 THRSub[2,1]-0.47204618518354104857251266275558781716154470649126431084450259421139915810651`48.37796374410618 THRSub[4,1]+19.52571227519545429606208635399525126489319646131379555332622677598831070287975`50.04055340061177 THRSub[5,1]+12.2907680034065345263882196199443483194012398138157058783316060679283334117548`49.35506297245071 THRSub[6,1])/(1+0.55380681299372736400228403891309367737383101750329809144077957742830615879935`50. z),((37.6418497051722118470364902270022289168885014471493807205288138362483688397996`48.06600454796189+ 87.2523069962879499280397166228800280659250284680626284011803842787310420389828`48.06600454796189 w+38.04926569820991444628679152690424322255719941899858166541703827679555609685179`48.0660045479619 w^2-15.71917430052810851203641058651632711497275152542761004245822344714619553301752`48.06600454796189 w^3-4.70110866401398000045621080369560261934185860842009258416491823940660883788948`48.06600454796189 w^4+3.33508502311044934173637353704185731252946080066718019844292262472862310564405`48.06600454796189 w^5-0.58512765730212576512802544772551192542683015300414862065739647772601317331848`48.06600454796189 w^6)/(1+1.59595487704599900123951087866536960134006748606741818598928127351556555824885`49.69897000433602 w+0.49686729316574009418138926674830977077590128381769532335183668827560422941294`49.69897000433602 w^2-0.10542077832483527603709541888032124331723588675094473565699205823682875767467`49.69897000433602 w^3)+46.50396170676492390559948107797603397249896011142617700103170119998757939896298`50.14446588379432 THRSub[2,1]-17.84316860305747111195366605214915446791437419796306383213666829836499316941668`49.19264137244396 THRSub[4,1]+44.40801227392710812532898997506882684777420121198879781666029408008508818624677`49.73698055721605 THRSub[5,1]+39.13304302923443856884260534948698093211219918836408511868414909723812973836065`49.120698064786744 THRSub[6,1])/(1+2.53387733314052923929140761177893206077810193791366136771588433784653784039636`50. z),((92.21837585440214766926755637412728221549687330131640039129123483048124116030623`48.13251244055904+ 216.34841308173246837129258803025106396462895744688707232806095982786848421700954`48.13251244055904 w+101.56210592918040012267580404190266884662511016643172040219651961194132288190053`48.13251244055904 w^2-38.08969284368056579099270227184215401098037784188756432260766889021027520720457`48.13251244055904 w^3-13.76786598983070098809098461836152693851605102634754778645043714690768284062019`48.13251244055904 w^4+9.39999914141426670604774604794069808368473930813166503779142662182253820734684`48.13251244055904 w^5-1.65136713612107474604771915413361653044387358401194215956103442767690794888638`48.13251244055904 w^6)/(1+1.67055525391168408542839320453817223642688335123777486861283700472064034643541`49.69897000433602 w+0.56618799291073145365564557520082449885831021148367779222256801435184571045711`49.69897000433602 w^2-0.11871557322142665366643805903213892056918758340044527937914225454482076986584`49.69897000433602 w^3)+100.8281328599535603029149532318718201063607015133988201617118985743080580651424`50.060737354876856 THRSub[2,1]-54.05928270518322871016398082141301189048886846594482593925679988124531228020048`49.21727367196397 THRSub[4,1]+96.28377448432782598063528122678161672694175012394362783107170326352298255026898`49.65325202829859 THRSub[5,1]+95.09505122369416842375674107433610010689557322722521153219110033563337494152345`49.05767211935736 THRSub[6,1])/(1+6.66201932436303966129735799148501657833887622988941266925724282566791822785466`50. z),((102.68697832112464235867666028859176354814654978644181443572298964744204909248017`48.136993004582116+ 240.97670027348041301445884597735037061373042601755597733351710170867279755638366`48.136993004582116 w+113.52203442931876490191289701060060204559066671897659754565977451328284008765879`48.136993004582116 w^2-42.34969642532002351944310833544350268407011142846718970324642815695794145726184`48.136993004582116 w^3-15.46229098856534747582719939842201586498343317390541871009028734684787985748538`48.136993004582116 w^4+10.54575326473807270853396617691456744767805654944886944456676499076995167761524`48.136993004582116 w^5-1.85355176378809642725295095266570392688471619122437812250543083113171215207333`48.136993004582116 w^6)/(1+1.67449283639903202880367622625787346669112593198123010051723885441291503048364`49.69897000433602 w+0.57003282520258313961110146501410441531573470664278848635745955528810431564645`49.69897000433602 w^2-0.11943845007920870140099933720948203349544494967879848178480670882670652009802`49.69897000433602 w^3)+111.24832982488900202715590668142956398497049739331469126638406121758911632531098`50.054673824478755 THRSub[2,1]-61.00608068180685652632461645445150780956206571922207334237157497676601778697926`49.218170569366706 THRSub[4,1]+106.23432961409167033166750078258880062600087096074603275794090867666139552044469`49.64718849790049 THRSub[5,1]+105.82941008386379346420184544691025576100340624890563186807271032846918780066292`49.05311516164297 THRSub[6,1])/(1+7.45385934206820558924027905044123844150906057504834979182919104637700564929377`50. z),((75.37372336844658923371930902965428343658027032479489064305996139818246320156145`48.12262735283225+ 176.67921093400388440996532856348198484058030947752215477452569653972764867917149`48.12262735283225 w+82.25088147985708129645213366863951245960740227388071848767301419510001405599189`48.122627352832254 w^2-31.22625899662932416050168367852062645706239431204279900739690839046474288488328`48.12262735283225 w^3-11.02778417942946782988932039017449872732965678904386967821516719175795385790109`48.122627352832254 w^4+7.55101719884094789767792044070431477402119903024705217370139715205558856774766`48.122627352832254 w^5-1.32531615079924552694959728460980158348312065358770760738401033238194532454174`48.122627352832254 w^6)/(1+1.66138341460081236931220143516389714293275202388299150128693037048447191062223`49.69897000433602 w+0.55733038409386030100739597226745599860894764167372562880142610079861676218203`49.69897000433602 w^2-0.11704440760434361751328848879711376291469848352836303288025062136339132327568`49.69897000433602 w^3)+84.06136792953400693576855039392425793606519255165696640334981003767787759543307`50.0739386078196 THRSub[2,1]-42.88143941823685979873304559611463711029186249145025676701540752349185863372927`49.21494921373675 THRSub[4,1]+80.27269337431116312900031912976466104581184308038617803069178915747741485875479`49.66645328124133 THRSub[5,1]+77.82277966367711192719717581608794041678942535746201631049261011293173558342564`49.06759491340097 THRSub[6,1])/(1+5.38789797291082847138236137287345128717453738581649999268070844281902838843807`50. z),((67.90681057473682008432708065786301155201579919840870219081890040743109698033607`48.11662924500613+ 159.06935639425124996485473144082138280410547181492408903409610708737410305838379`48.11662924500613 w+73.64892700581103270324310581234968275426512634893513068062062930796765494988878`48.11662924500613 w^2-28.17823527427304989302192905240727876701557457479686036229694884922433062038197`48.11662924500613 w^3-9.80471381394541204964896956922754175739887147397535870567061578305281665912529`48.11662924500613 w^4+6.72806827075784843489183759939059350171035977961508899543475327245329401741835`48.11662924500613 w^5-1.18033877876866983465317091784155312416667327194813965673382012452928752703843`48.11662924500613 w^6)/(1+1.65549023418739788063630924815679047656436415256407423991864217310771141327038`49.69897000433602 w+0.551703722375632933709563218523002463582329268064069181214349427768234228313`49.69897000433602 w^2-0.11597859107487869410848971459229137971508890059616554195701070434355460865683`49.69897000433602 w^3)+76.62898120190885874955614788760742052475879093656667717331713920881928507693221`50.08182791521252 THRSub[2,1]-37.92651493315342767459144392523674550275426141472339728032696030425279695473031`49.21330740275 THRSub[4,1]+73.17528685427833117594533993921128925366075918230260601184713251584168863877457`49.67434258863426 THRSub[5,1]+70.16631149994078245045259144758181897324624727928895107335710478029478959904531`49.07352645566829 THRSub[6,1])/(1+4.82310430751289232995049845908801919232836687795240988073493901442916918997793`50. z),((81.44709848961144428535181748491004980131858875003497899295988032215396050223757`48.12667395653825+ 190.98946934137725735666947140596954378403481053276340996316690756986374810473989`48.12667395653825 w+89.22584294479220134574701723126596221992111393870459648660663930648278638362581`48.12667395653825 w^2-33.70251514166411563919718036194407880419263402347937076628450892313221324149242`48.12667395653825 w^3-12.01821822490320248401364923788407208388312074261490718881920093802902100635001`48.12667395653825 w^4+8.21865512277833177827126288447640420402002428360566367039274251618511814311576`48.12667395653825 w^5-1.44300622055774544413480870703568649044307703236443413469989066833447764232062`48.12667395653825 w^6)/(1+1.66521906908880941681042276026493090494703794510436690786681669219849369806122`49.69897000433602 w+0.56101886903999091828382896012979410132853333219790376453159419199710429503124`49.69897000433602 w^2-0.11774130361631174478512493600500049060869591155607983585436071720801224895059`49.69897000433602 w^3)+90.10666052762899619388657809497789368495605752760462069961752856118393274851192`50.06856414113563 THRSub[2,1]-46.91163448363351930414506406348372760955243914208202629786055320582922873578303`49.2159582250701 THRSub[4,1]+86.04552257085314783150716138521096314822657341468669621096214587186339966993278`49.661078814557364 THRSub[5,1]+84.05033374744781541310607924550657305443829524250733425506952543824373134323474`49.063554843842475 THRSub[6,1])/(1+5.84728512403826419627585617288406070235585046993881631456091549196465272533494`50. z),((12.45094861902223412824228105253110846019149603245859517623725668779755826882286`46.48234805005194+ 21.89263906847317430887092152105795354155511042573003541487080504868041371539143`46.48234805005194 w-1.27529599760450228320645090335100573788959798679460299429359499564359394553644`46.48234805005194 w^2-3.53286231137835189951342603857168762293364658285206371112777151320442971100498`46.48234805005194 w^3+1.3352927758072110611455122770742256292312108989998278184937532757421690951184`46.48234805005194 w^4-0.18527201440972961692677656411816320144717220504581378400353174262957555754512`46.482348050051954 w^5-0.00282496516778328677754829125299756237501798779667095425834452601774631457539`46.48234805005194 w^6)/(1+0.87728435716842201173006092521484976559623153991144846534994498071463157774257`49.69897000433602 w-0.08308653463019178300384403824205200645038602211270849029743127201054305541193`49.69897000433602 w^2+0.02229686898223834520649964700229460371266425834147177697584028383223683765821`49.69897000433602 w^3)+21.42954018046252435200278183257756421305301020116035339841253264504811825620406`50.413503790452296 THRSub[2,1]-1.12688758552253807622253322188350796161707425778584809705722259507201907424377`48.691603674618214 THRSub[4,1]+20.46370348744198540281302585984884575664663704109368796540202045429517413040512`50.00601846387403 THRSub[5,1]+13.30264464231107762112788591076203800108086067700156372194889476258584668767228`49.32768117865854 THRSub[6,1])/(1+0.6284497819966246528224490310010112094810542025907091054844336641923629082615`50. z),((109.09669516898919794923313545611202285640821794816565392831647019114368741394802`48.13930560922604+ 256.04970630234147256694663830379103601803441201082996518295380411872198858198264`48.13930560922604 w+120.83436012752299825227823674886326847685566242314163349594492637530801324452443`48.13930560922604 w^2-44.95665160380520015986970619844945537063433106297337708829878156677053343130038`48.13930560922604 w^3-16.49760335855862966666812404153067993569046373201288339996416543365203321745451`48.13930560922604 w^4+11.24642494574862805817935652047138982837136958184737096291834572102376829653106`48.13930560922604 w^5-1.97723095560784599568397683402218312007686796980026355726075257437089119531005`48.13930560922604 w^6)/(1+1.67647205081684379243160605760927474878206474144841807643557802291531338103669`49.69897000433602 w+0.5719759608080313993241656562860794039221982235536179735324478665484327125757`49.69897000433602 w^2-0.11980320516616138146556803371869241427206182279801597425947164056073506176536`49.69897000433602 w^3)+117.62840894782130607856662489495840988274482832523861955932136111899919317062601`50.05152504953146 THRSub[2,1]-65.25946676376172589393176193013740507474495300717135887099644157770606901718997`49.21859520707169 THRSub[4,1]+112.32685639248415247603660940245334727433814806132888660672159662018663239886545`49.64403972295318 THRSub[5,1]+112.40184427990549308220720856542559340727670379757260426867546657216503310536561`49.05074885974258 THRSub[6,1])/(1+7.93868721841865754988871709009718878046624419166906957088840030426456558998993`50. z),((11.56494922719234107407410725916926750024125322599770933449204508557960152098701`47.53649481088552+ 18.71885426713428868066851469583490293022868585205913326368235823216880192986837`47.53649481088552 w-4.22050009669448959704946600264379646641270960725286840650891363083019823617276`47.53649481088552 w^2-2.74043749365565522643600888108452239769983381301003693585280708759043057836392`47.53649481088552 w^3+1.81954261208222736995150687617064383398786001991175882673840891346869609475495`47.53649481088552 w^4-0.41659286517492466065125137864239988892822451624303798033167447944778904806882`47.53649481088552 w^5+0.03039636143849407398370428473853481701964142808381155774597000442244625345896`47.53649481088552 w^6)/(1+0.71935427591100013294329759462260361059846462276828139127636828803869538721511`49.69897000433602 w-0.20193448705610661988562367688839868815640865847747492909714865686778968498395`49.69897000433602 w^2+0.05192629829949618195361988649211060967967407774814151312692557286005468844933`49.69897000433602 w^3)+20.54763753844053348363533484354812587898219771798039633506924376721431501865098`50.4442253099426 THRSub[2,1]-0.53895249084121083064423522919721573890319926899921005482836334318281691587518`48.42858464536981 THRSub[4,1]+19.62154849862037279797931738503223978530273689402474457286143143630073527042812`50.036739983364335 THRSub[5,1]+12.39415323173106567189792502407044206481765956074248762587720117923544749498265`49.35202824875874 THRSub[6,1])/(1+0.56143321733639489944365251125222651841300249967060010515192332371479151337948`50. z),((10.68375149083109476354586804386080901957527509763294647160695299522458182783204`47.911362070316784+ 15.22964048246329888815991591257731154660489612568299449304375435229685197138365`47.911362070316784 w-7.74863867319814772000575886647776501895036443803382619317854073843753159027001`47.911362070316784 w^2-1.78184084399089425962605793558834037219528824254869502035110422518541475077338`47.911362070316784 w^3+2.4027572493063946488666237849353021649749319842833203630938040577478659418803`47.911362070316784 w^4-0.68909224967495069757102355264276662053520462146113484618321950987240081278752`47.911362070316784 w^5+0.06835654249754566673676624951408815791011461498397000015615585956603472289139`47.911362070316784 w^6)/(1+0.50516436129653626249690565729694791843097483013635093892043463015833435392616`49.69897000433602 w-0.35989848230681155398784971981189916267193450641222768365007859599055980958591`49.69897000433602 w^2+0.09342330269254888369532940540025981879880072420171929052258969321246471026285`49.69897000433602 w^3)+19.6705143496359235162963917251282110554325622867964715734088773590315140971412`50.48016523165321 THRSub[2,1]+0.04579630169519581424839351641606081012989101845673978627854759560571703179823`47.42197018739528 THRSub[4,1]+18.78395755142769599336970729782401579275417356341396506754869378550116936528687`50.07267990507494 THRSub[5,1]+11.49058537165239271072867459918563145006050434573515474819094885679423781314326`49.380742514182806 THRSub[6,1])/(1+0.49477984756902630535149598383600958503347774555161285786210556606373257400705`50. z),((25.52807597048197854774047263223305416856983787182599454571099906286143252017449`48.005185141840606+ 57.79158018909770432540878562035553593540652424594584937554460408900586342808538`48.005185141840606 w+22.58978403538010118892954979944967518651758776793946477008245337523631126572521`48.00518514184061 w^2-10.54272493206853661629308931561724679530671114236755921198610623673948395193198`48.005185141840606 w^3-2.42373418169283232329853801417437537875171607647546854942388868685458292525802`48.005185141840606 w^4+1.88551983229133947028157679972024731279619666794659284902431012391475877940023`48.0051851418406 w^5-0.33502033876594785769764472760361398444025320540465824609260057749776172418575`48.005185141840606 w^6)/(1+1.50454155297403228629975638809929315359956062666423297316987940247629657524823`49.69897000433602 w+0.4169294743681718816132104860780312261702768502152793730822604603907039675834`49.69897000433602 w^2-0.08950265183820736940637813367223351994440719977877580705208298660901411220333`49.69897000433602 w^3)+34.44620053898860885402192038773471225417780926174582434412870233411488674781033`50.209032414733834 THRSub[2,1]-9.80466115787326107756862559198827332236694029817616206086800238778319806864781`49.15332314432482 THRSub[4,1]+32.89369851908847890582290281711996424450305282632389524432737356612001229784076`49.80154708815556 THRSub[5,1]+26.71174851237682660195421951678809391395374949850018286354693008703242512526111`49.169576299568824 THRSub[6,1])/(1+1.61759735794374437115250841912097427419746757708046997604916801282521687590311`50. z),((6.16582773864250601846944085527207825752721834612828083623017264432762188848829`48.33701587265642+ 13.72476171836847489587288068986661505305085713305080891131280720299679797776966`48.33701587265642 w+3.45199390483587502126307846575224390621723862667533067223183720478200104210537`48.33701587265642 w^2+0.73139596167186722554416943176800582959067780771306090014348216168834851240302`48.33701587265642 w^3+0.67196747033658663727835186913110762815871032504423227994588730924269796169852`48.33701587265642 w^4-0.34949179296193941665384508974112719487839115276785240102617477722566582797604`48.33701587265642 w^5)/(1+1.10269615596341024493266502152987059164723660070651064376248340926432944748056`49.69897000433602 w+0.34795667875361701601570363169665123034521080391551305694809337255732722139225`49.69897000433602 w^2+0.22353096563524153904009840770707811599311278226735555940185515858736748241494`48.33701587265642 w^3+0.04480716477345548734024896912857114429973532816236096418980366610573764681046`49.69897000433602 w^4)+15.1734809089244885958467869875455963298786577257083179596332726383673506395715`50.877023950593326 THRSub[2,1]+3.04381859550281909454813000813780396049916072584884219546228407604849267017798`49.82420028048155 THRSub[4,1]+14.48960694339502378010705336201905096639387723460002609763603098979017367417623`50.46953862401506 THRSub[5,1]+6.85796941235522031610961178678879074339160861944407041277352470469183368629737`49.71581429855302 THRSub[6,1])/(1+0.15304628424998326571450893788104249610409963160043542332864001841931846285637`50. z),((31.03848736340316339686467212856249761126899003348028865191497808726817593001713`48.24529073336672+ 44.6974830117219412155925960373296969382956724550558124891189483051120766392045`48.24529073336672 w-15.82624279156121658521203155424664789721572047666527750533675013011568197410411`48.24529073336672 w^2-13.93773163730791439416681376177718752476640278570039122347793230127794037180217`48.24529073336672 w^3+3.28383344951592018979785903442072596943253631802213441092847883360787936688209`48.24529073336672 w^4-0.3024313647460491759062014679347725082963670754222738491302679411587905902126`48.24529073336672 w^5)/(1+0.70133951876079970055855175079151171282254462806168833872845765213139629902864`49.69897000433602 w-0.37347262742751570579248758571267654042797510473953754155447361825198189772193`49.69897000433602 w^2-0.07396956657785342043847084487299072626661026275837385178138786905873171536737`48.24529073336672 w^3-0.03945534105940917343380516836962413530071923374565154759303391265327841078061`49.69897000433602 w^4)+39.93113248234856182426684542515134499038852927186779531377267029325147664271167`50.17363632736861 THRSub[2,1]-13.46128245344656305773190895026602847984075363825747604063064769387425799858203`49.177548753205784 THRSub[4,1]+38.13142270693871214222220736876159761867273483968757155237592359566250738705986`49.76615100079036 THRSub[5,1]+32.36204744643330820079018446758299230253860410144018475946899098906861350180585`49.14273954828688 THRSub[6,1])/(1+2.03440220546791816424407743877334762280389751302486618964154953884753151185142`50. z),((9.41270005139795826609009704307694546935034066750056474459971452640338236905291`48.4335091408609+ 17.74556811890322436304144295445942218091213231808630839913182101092778074836916`48.4335091408609 w+0.46800181178040642207739852941646130272909197233475113541560765217884479909939`48.4335091408609 w^2-1.70746220513809781317537215855370968773521950320820962362842943438421933670169`48.4335091408609 w^3+1.09066868833574060247423404539678808929218989535358376627705772897422814934606`48.4335091408609 w^4-0.23832071717342993820455101351934947980935914863296704229482464283871751145598`48.4335091408609 w^5)/(1+0.92755332810368993802023889847668743891358491564773872547441896440509352264643`49.69897000433602 w+0.02786633957106937498578914401077661141017048125573431450418391276765030196526`49.69897000433602 w^2+0.07827653880808125634196098611044650847996631216036288616358349536726266669555`48.4335091408609 w^3+0.01564833810320584620818581834948800259652686596891888210177890045453489117828`49.69897000433602 w^4)+18.40534009227350704952451794282731829286470592658036199812648375988027529423685`50.54512652496032 THRSub[2,1]+0.88924580660347345876297603794998931850846192526747950313347666170654290040099`48.8192650340993 THRSub[4,1]+17.57580512983661797558286897119410670055600198485002342676028290427350135178133`50.13764119838205 THRSub[5,1]+10.18726696559182928118336152972926070518451690105069761421877539602688419239569`49.433307129374874 THRSub[6,1])/(1+0.39863813261669452351573629977539924883728284508857261036659910120079541934464`50. z),((6.74386234602756643380653182501525280582240701748814766877303217845295067483037`47.814182555902335+ 14.35655976220585699364012983608889330148565646083599254340903936673888396442033`47.814182555902335 w+2.69101779490616530276982084350579647735629798553823479592564441517954716379329`47.814182555902335 w^2+0.21000967328434305321027718413381109792803471572983348594856945754804974707683`47.814182555902335 w^3+0.77805853543216264619508890352414339740128448182214139355010220369385164344321`47.814182555902335 w^4-0.31995250815706480209227834361660715480276986539107982232229419115636714601647`47.814182555902335 w^5)/(1+1.04671786537830618137166184133849421629947273590629960140048236024838379368411`49.69897000433602 w+0.25324834516333581806337283675697291033846271763163501168734508824588018591124`49.69897000433602 w^2+0.18328382212260175389193305355520772191613370021160579204902929958677441611904`47.814182555902335 w^3+0.03812903567769885649756785704080463758926453257032483907163677781632391511246`49.69897000433602 w^4)+15.74884275695034144123346281006236361281503095115070195693556114399931941415281`50.78405449754607 THRSub[2,1]+2.66024403015225053095701279312662577187491190888725286392742507229384682045704`49.644588966849675 THRSub[4,1]+15.03903703647383783418812589636342137544226735485770301650760435056784262070543`50.376569170967805 THRSub[5,1]+7.4506780311983140390635007956084629239634471154806569530525311525583980669798`49.63436015515704 THRSub[6,1])/(1+0.19676854184844996979944828446178324540949307892888291878367281993872954733875`50. z),((10.36806828002289963195328024167720398222728345566156797778522725942008351949166`48.01066152826896+ 18.99968178571550011087076298014064176008769865335313106472453813610104642125866`48.01066152826896 w-0.18231224612842552819458053064766673956665069792789855735040114894734207917277`48.01066152826896 w^2-2.29649601889650087975424719004585175270146290352814115807993994587806061240957`48.01066152826896 w^3+1.18365948074568844064705226874493437527688730108317605130495075748786275733242`48.01066152826896 w^4-0.22315661539228932749944784638831448218199663465071404323582638961688443344496`48.01066152826896 w^5)/(1+0.9037560584209051050147194777287845844848995096789724197484703611373223934106`49.69897000433602 w-0.01850474742638641617010982120089551413362529202024137183694540278145549315761`49.69897000433602 w^2+0.05692745199469004855065392955542825384356516547222411698370950803207552523332`48.01066152826896 w^3+0.00984922299928486580520595395679096037595966967320150998046930158911088073418`49.69897000433602 w^4)+19.35629081830963565924993578154358077156693623452000864274401751479777037023138`50.49465337752017 THRSub[2,1]+0.25527865591272105227936414547248099937364171997438174005512082509487951640459`48.19319413717953 THRSub[4,1]+18.48389618194947758212450070408823622480335048552049290947712251379196733383869`50.087168050941905 THRSub[5,1]+11.16688821324776526817804632520625358566027418274809322615465140135497471251351`49.392390704561926 THRSub[6,1])/(1+0.470901722477335289710119291055553950298579239048376822281547098135050049793`50. z),((105.91452472123724469995351213044990766252110042733251267263247790218657087668838`48.32724550531374+ 128.9533579242780648537124407345862615240943119831366232024656534101136288197218`48.32724550531374 w-88.27856310417553332576509924256265627221658744734243400462741504414497810574153`48.32724550531374 w^2-59.22280464375390250760602280262509643061021116336438200579485062550083077576912`48.32724550531374 w^3+11.73181061472865260810279222951437161025204553312768379255955429688523217775751`48.32724550531374 w^4-1.30425027595159769664772575544227572007220481485239963813853740085385928002842`48.32724550531374 w^5)/(1+0.54618233079431907573261336867454090610431116304051833277697357679953871203054`49.69897000433602 w-0.61087032297754275155876071757437333919715985936824248161237266125215920878182`49.69897000433602 w^2-0.1385877433272678128976225817384459167804077073585275606209744511880651497222`48.32724550531374 w^3-0.07041598393658782720204446095637383642422165769260896881582576349636019824738`49.69897000433602 w^4)+114.46095245618575022427232168194026243573175049922548764535604160006119468743744`50.05304156540337 THRSub[2,1]-63.1478291026713553244022264547919734434029011231626042616862285650807366950626`49.21839416525238 THRSub[4,1]+109.30215824645028439646237277940342602625703989867324526265776014911560572477804`49.6455562388251 THRSub[5,1]+109.1388911160061986468246642999067213117366552801979983163110621925855709446498`49.05188851246903 THRSub[6,1])/(1+7.69798938776756674888698728203884310600498390114793690007990828698330496206888`50. z),((10.20560469928494979926384541992463232270273387548392266892924854272183248849978`47.62009154785723+ 18.78641517282899671274346774548153499821982357644079111757600030295891606462266`47.620091547857214 w-0.07304084844148122481781984930506242977363359636091790859649948819229383728755`47.62009154785722 w^2-2.19823839712047955576243807735225813282725430389428219929681868428902128828898`47.62009154785722 w^3+1.1680018924908287538383137603854991564895760893425357416167675057993411470017`47.62009154785723 w^4-0.22538363999511604838996277640009115979027544952711688328178007557194581432084`47.62009154785723 w^5)/(1+0.90748841963986272153060873108505952498112964692871899361516151048740166972982`49.69897000433602 w-0.01126967809851425466808522997718022918681058029002065683886446683711400526897`49.69897000433602 w^2+0.06021343239394917927164659958524569181954196946454547429610355371889975254543`47.62009154785722 w^3+0.01077584445778010865375583151002385737321833534439876558801231616649045271282`49.69897000433602 w^4)+19.19457844874554979628745070059672296750747698005309326173353325553419237155972`50.50249368237074 THRSub[2,1]+0.3630869022887782942543541994370528687466145562856586607287769979372648488524`48.35956245221722 THRSub[4,1]+18.32947224409811178492865902106941390321587393023003205323857607382823353979607`50.09500835579247 THRSub[5,1]+11.00030032504655365941605299158055778792534405825555707765730347914266516456762`49.398711950120614 THRSub[6,1])/(1+0.45861305595695503693789017029120391524040665636145255993937638820853352845188`50. z),((105.56976951152256094949481174279739652307336424157149389033806227384937771116191`48.32699230093832+ 128.57715006143729189905459845280072578878742717735703652742590284244720442400542`48.32699230093832 w-87.92273898573335578895703228701804599512125299422915575629689654016162759070079`48.326992300938315 w^2-59.00779398120586887183053539111915907425131863855207087685571431223123449582877`48.32699230093832 w^3+11.69180654670621605355357945891523268194818849773503677431814131635137017734021`48.32699230093832 w^4-1.29917645110556160024045761453266555857114389834744440544761723267535240478911`48.32699230093832 w^5)/(1+0.5465035324374067262576526202279191474756275319183937925040198880358311006135`49.69897000433602 w-0.61039889826056148218271320050603936496684086935182762776875386920307521955888`49.69897000433602 w^2-0.138465962989218804021888208807177609333459622642321640921520498629929156897`48.32699230093832 w^3-0.07035865259084967805693524200179403542160301680606931387537166308263905411502`49.69897000433602 w^4)+114.1177913512212456666285503197530631237478471399293756001206734041897032477696`50.053211247703054 THRSub[2,1]-62.91905503269501895263971221333384056874696555029852956486264976783307573528661`49.21837127017186 THRSub[4,1]+108.97446352965841852731095903910853046052070570226114489885546570298668167219664`49.6457259211248 THRSub[5,1]+108.78538393567775559285087261920587844855091912208422208815152557891487140310104`49.05201602856962 THRSub[6,1])/(1+7.67191227076630466323812903273333993401702844756878745172516619838990734535754`50. z),((7.09071343623314877202293310150761748403522507088028178481843729808708709023902`47.38746778679724+ 14.76840522786975117454550349869684819593034241959039205932597852453260149090853`47.38746778679724 w+2.31951307558849951547242820134735114134222988371252106222808750054997596304394`47.38746778679724 w^2-0.0772831532635652536656469330895345724530297160004274287846508841460735322069`47.38746778679724 w^3+0.82989010231164996092145730684067320855564490618824168289861914768099130999466`47.38746778679724 w^4-0.30473917011085815547393494226796452707754357478451887655344093722456751385414`47.38746778679724 w^5)/(1+1.02212568369493087110146375475943983584622195631778857007190872239322816112325`49.69897000433602 w+0.20911110974443621770718958243321555140903508986069515317526056111257351800518`49.69897000433602 w^2+0.16342527253042767534547573463929431646627069180201461465493406769685190142983`47.38746778679724 w^3+0.03450104713131023533702338208518763767865140008990389780665189770059535592946`49.69897000433602 w^4)+16.09409005131783002150886917649256652535199062020512675876374677322467924505272`50.73911492152032 THRSub[2,1]+2.4300791672405914774400752155064904968502721295176363293753013194769402665238`49.54429605619819 THRSub[4,1]+15.36872391739996872670461933475285228580986961771306465194797432955352908749379`50.33162959494205 THRSub[5,1]+7.80633429813013611707877901387225095684992292498383606116664718972988411282592`49.59561609816861 THRSub[6,1])/(1+0.22300419023442138781460050351649604024751857258335233164589419415382686754981`50. z),((71.30818138182665079962422998714162553381378866131588813125015236990209722553562`48.294496517203875+ 90.81064854467214748688948709168152287531166492001880603113645251585559413547517`48.294496517203875 w-53.28332863204335307943172996858494902647453570804943878584288286672362980896899`48.294496517203875 w^2-37.85836816613902533802355244575832527455373419374548203030954301680339357912311`48.294496517203875 w^3+7.75263713399373209113664988827738788185161368076106644008687778710101877707849`48.294496517203875 w^4-0.80749359798427424486603802105677183277140409798528256848540789397503835147856`48.294496517203875 w^5)/(1+0.58859850316138496364651630977237782277794689217924712927536128132072939373787`49.69897000433602 w-0.54794119380284264722060905031319679762555030857426388595162085111295180152054`49.69897000433602 w^2-0.12219223534439056781577971348889457905667406252857909627495656467071439599748`48.294496517203875 w^3-0.06259932479811333320009998984109304771841646953085147444591552811654071492774`49.69897000433602 w^4)+80.01462449797662239155532863616496288697078670564495005410709548745106988085347`50.0780344911672 THRSub[2,1]-40.1836104638652701025908977576084404108955919274422458675202644900073201573446`49.21412101679882 THRSub[4,1]+76.40833805096906242033935693671057167000890768240043020648441968641534544438713`49.670549164588934 THRSub[5,1]+73.65402965294827243528318576207388610787050753483500254211190849703379585432282`49.0706742181652 THRSub[6,1])/(1+5.08038234712414105250436598667010173726187741097209080117648623098264521834732`50. z),((7.88312405198392824933285978908617996088408304086097274285669702526170430128211`48.34210791739667+ 15.75791067438089417541327169250923294498122960217911996620130654035668898139331`48.34210791739667 w+1.60469837114485103483508663281598644901708716904338673960201285538002817378718`48.34210791739667 w^2-0.68002911901839981443087427190615265070896979120730408898536440664310882319398`48.34210791739667 w^3+0.92988682826236408793369500098145328324693293082583834339071748252691169491718`48.34210791739667 w^4-0.2759829061873765166246924213466063222786982226039824948130662045483202214672`48.34210791739667 w^5)/(1+0.9802285673879188358141781026249736078733226546717033901184541844175861971308`49.69897000433602 w+0.13050757158375825424090351462507942359219582281339429892932577025046424995859`49.69897000433602 w^2+0.1267974511242085119077364358100685943487295580824220053067634402155282300827`48.34210791739666 w^3+0.02711875879293231278945173150134629706904426336304762314812434487433867189478`49.69897000433602 w^4)+16.88283665999615325536998965720199278361624447683351166485005686066862989731479`50.65650990874211 THRSub[2,1]+1.90424809478837598819932822836687299134076955843204639198442792784763983168245`49.32120551558774 THRSub[4,1]+16.12192144710871257107545042474458874621199484467328672844672926721593822943694`50.24902458216384 THRSub[5,1]+8.61886108392754435244586268787366830659731090720430720057642971418822400454201`49.52551275784607 THRSub[6,1])/(1+0.28294174522329702433726015961812015644643978348330202069533953287379973625604`50. z),((128.59788321327468989304872929162791238403482911215951407782018600643608088681793`48.34167109998583+ 153.58405833228578699815137213716627561978426884045589700803374823266291543952911`48.34167109998583 w-111.92329659451598273782345985294559813194181490461884804372331538319820826310945`48.34167109998583 w^2-73.44078099273857608418669103141990109912370847897535524490378925191971263124595`48.34167109998583 w^3+14.37582095444862938177849044106365766777180627132564938144182981918662631819675`48.34167109998583 w^4-1.64178485569757437627552246514861675489434494346787740363435294685252445312108`48.34167109998583 w^5)/(1+0.52788361558604634442153011020733367235688213452179703087145667997898525076496`49.69897000433602 w-0.63760048098445035913381874852974888092875519484422396886092717021531994711017`49.69897000433602 w^2-0.14547369589675193096643911800675633224026773732430957900214178830348638855996`48.34167109998583 w^3-0.07363473055967671650558049770111214585480707981822718494380919510319455379477`49.69897000433602 w^4)+137.0394259501049659126802864979679315163224919151094496098124868656930176255438`50.043844497358194 THRSub[2,1]-78.20014476528416578334086966547708616379672873375191223799052540883528532046711`49.219515721907996 THRSub[4,1]+130.86301223060976453065731594465681319541133821301421905122384252839631265703178`49.636359170779926 THRSub[5,1]+132.39809032444057945750836181431786437120526554805005271464736466224210411938494`49.044977112792196 THRSub[6,1])/(1+9.41374763219835018888980688382766456474071549879112348508118926222646984273291`50. z),((5.79555734195438846981935560597871672803460752257444380776976581386582572964189`48.49551337020916+ 13.38012042315640745268267717762517487998545227487968817739204988040201539733843`48.49551337020916 w+4.09083289265659057783031940868637110604700917757928357051602533852569488440913`48.49551337020916 w^2+1.10017524067639534188903434046611846404740939512822851445054510247528201853335`48.49551337020916 w^3+0.58315064531130839661959577340055523593386339385847980959601986194988729533988`48.49551337020916 w^4-0.3714532723196144489824038372519090416147737486702944376552279636041061789307`48.49551337020916 w^5)/(1+1.15478587173187276708034524969640858877957364187482716036452535162469801488509`49.69897000433602 w+0.42971605912516846003935759746847620874927444495611751811268577578715632751686`49.69897000433602 w^2+0.25543075103065679066890899006875565985543319661437421932057230994971492821297`48.49551337020916 w^3+0.04956114780291243678146064493577762978015572296050106076861726617618205048567`49.69897000433602 w^4)+14.80492259600357429719802255503050159976585592954241263264636374142944988736896`50.95412143496804 THRSub[2,1]+3.28952413745009529364730629648120044724102858995944574678689000734042650497969`49.95404877610626 THRSub[4,1]+14.13765967948118536835339437650599371382250629235157415295664748229695252641747`50.54663610838977 THRSub[5,1]+6.4782993154170578380501351188987577190099607497581105656272147272014062283141`49.784619428601275 THRSub[6,1])/(1+0.12503921087020565505242581055530725659012485379844655691521590746029312586361`50. z),((6.03553789428642000496611923177408241997967559566064037148943656372181787644864`48.40030232992723+ 13.59649734435693883644267187314661582769025361004618274068927492830061876640597`48.40030232992724 w+3.65936824998199832759276129809725371767709533641380713693036172931224554204612`48.400302329927236 w^2+0.85769393813093395924425011237464674337292902580634295195790268318125521564441`48.400302329927236 w^3+0.64309367935962665690197364770538570109983544432408747746418594025478382343563`48.400302329927236 w^4-0.35693604602178001000724665322987117476924701800819889027264731376090687526268`48.400302329927236 w^5)/(1+1.11913795594540170189507697202368409417215121946517327690028403315489589757729`49.69897000433602 w+0.37436668743236756365578165211805056120772780277748036659361754550594208519921`49.69897000433602 w^2+0.23412656318281965280381409751882317600376929086543101391738741134672921588645`48.400302329927236 w^3+0.0464338545631389933798051086956200156982065332318906475633246347527694532354`49.69897000433602 w^4)+15.04379350842983119261045169990651832647167562301881704318427323655283121426794`50.90220248153828 THRSub[2,1]+3.13027686249925736337235353323052262943714879430850947309495034392483895371356`49.868146649583515 THRSub[4,1]+14.3657645983222455519267101466107518994536186483243548581100770215360192567254`50.494717154960014 THRSub[5,1]+6.72437202439444321129206045620665988625288884177062899836410028871723181467444`49.73816393817992 THRSub[6,1])/(1+0.14319122355877082389423271729478303358601704814431223934004804596270397635006`50. z),((6.03311489425627284506508265916879088812475219799058025365043400127757038394774`48.401390831688055+ 13.59417679709881016418609675769918633699210320815560147852693467310329945420243`48.401390831688055 w+3.6633868516977202645953915229932658501135819069566578113021251898040953074676`48.401390831688055 w^2+0.86007699963820456557839217541328263711102616171013735904162301622430538587237`48.401390831688055 w^3+0.64253446129997477632276200793931313882267878333986349817349319059421055602236`48.401390831688055 w^4-0.35707736117791272345686480303115894830074990849357262148444331384904853223612`48.401390831688055 w^5)/(1+1.11946118842891622801372949738029084748679994292453074456741920441090928565706`49.69897000433602 w+0.37488002680093431830538596099144719166778358163094405083846261762107376532047`49.69897000433602 w^2+0.23432974571569268883322597662931225755264295859403995663455405762216313044039`48.401390831688055 w^3+0.04646456465791616093569778014512766613297247111092844355682688443630240153179`49.69897000433602 w^4)+15.04138171204722554048732790406399288137190439080928650951450538549743487650972`50.90268907255932 THRSub[2,1]+3.1318847267543277981211027304588729261703296157815298288747955779617698455524`49.868980026315484 THRSub[4,1]+14.36346150242610850236559421243182341747375507847490278017721276333496584747507`50.49520374598105 THRSub[5,1]+6.72188751398109245669610182888470824142381716350034037056045288040205207785319`49.73859703299355 THRSub[6,1])/(1+0.14300794901062838898734720032678347647375990339380693903049653428456353818465`50. z),((5.63716210498324684317779780693906932965315830444662152825213860851751274679848`48.546842027780784+ 13.2550374786021363822752829294815534605332856433937216553991979238193124025807`48.54684202778077 w+4.41944451366911024843638666944471777154441052183455581722254566188590764906735`48.54684202778077 w^2+1.26783587017825201974782339847542839992572127065743346892624856616158278831885`48.54684202778077 w^3+0.5376824108776197305461164929145006319968275196178777310015397676896106874405`48.546842027780784 w^4-0.38162535648567369557438403062879402896219673075358419926887166045555820364876`48.54684202778077 w^5)/(1+1.18312321683477162299283726565304655514635006618317694118318386735368912828801`49.69897000433602 w+0.47205781862126231358934812128729729224673274368348369243321173520965423743201`49.69897000433602 w^2+0.27092260411415222140926317030813429422468107547360853881977328595205082396273`48.54684202778077 w^3+0.05172670873809794850389256611350446964223959598625950809175060233150947286838`49.69897000433602 w^4)+14.6472597586961547105904782354206157047158627288169992232873280953281188190588`50.993215558563165 THRSub[2,1]+3.39463269565504168471900250955445771060769072377638801969291377140798055051968`50.015208118408054 THRSub[4,1]+13.98710276008497066541590939962240850501503144240185132232527418836123775678781`50.58573023198489 THRSub[5,1]+6.31588305013287596054997575979997671455439674773970056470648898632582255452683`49.81991496427177 THRSub[6,1])/(1+0.11305827190090784299141517420292583104970677247331990340518540450619319524544`50. z),((47.53456446906303377213652920380710190243440837522923204711376761965689316732039`48.261131506437756+ 63.94221389653875340502431871734471581381987406134589871758861174608222096864252`48.261131506437756 w-30.5045566319940125920000204104176857478163278923809942773902334922251017079999`48.261131506437756 w^2-23.55366092832409377696243757219061190648339815077991868779550187011886181811277`48.261131506437756 w^3+5.08165416809364330775824687343040834947233939112043969475411299956405003979003`48.261131506437756 w^4-0.49166592761490494028005751586763203704402529735767455126144509647595292564427`48.261131506437756 w^5)/(1+0.63952538584991428816688597681808766158852009046568149809101733765508301458834`49.69897000433602 w-0.47051487677324462568839435448958019252474076455436450467738878060993477851531`49.69897000433602 w^2-0.1014508823475446736680905349442741163431197087033714341908663463921137226494`48.261131506437756 w^3-0.0525683206474068053653228247385744889483360720874564542894462829785996352553`49.69897000433602 w^4)+56.35093380121113520970852372683801378161546722225311815646553293048817109091675`50.115503219735054 THRSub[2,1]-24.40781666602161198135969448472380767399204560518102460242588945203205429738603`49.20399407061206 THRSub[4,1]+53.81117797384151722691335120089693267855701899807311131212522156664366901948767`49.708017893156786 THRSub[5,1]+49.27689467652588760503479301253396850926907250253453569846326827017152559614266`49.09886555216145 THRSub[6,1])/(1+3.28215748406729921665412048541431212910822878244687912920704422646456998332153`50. z),((100.93724827271698258319923640124566042850569870201900473731275095388961641827868`48.32347310742042+ 123.5158270239993406520326957041642071947390337880283996120311338698649704687255`48.32347310742042 w-83.15324894132208109345366540225426642197652623503204350581152130418088386804845`48.32347310742042 w^2-56.12224881834379143347360552274863309264199008526183335961173151532234403238669`48.32347310742042 w^3+11.15486478415637749969415162766000142836403480463818888976147418727159997713296`48.32347310742042 w^4-1.23119204860532642081622674278710943898450186077605121929615007925701300383559`48.32347310742042 w^5)/(1+0.55097127654490444448160600897171471189645411350205614254075570415196256478648`49.69897000433602 w-0.60383363061779735896691333895008684809906028903199640442074895743411581751905`49.69897000433602 w^2-0.13676863208778230319965429887515550390116513649177127532157278400012473577392`48.32347310742042 w^3-0.06955824010328990626813832836478289048012070460992699202448358340754279228887`49.69897000433602 w^4)+109.50669030826476701739109958014501684566812640515906283267594654229315031523104`50.05560147518113 THRSub[2,1]-59.84498767072403318648141172026180971669381839378498771989949852656870711359352`49.21804014498182 THRSub[4,1]+104.57118638516211299026992392899481371848291588736553871395772936241837819111356`49.64811614860285 THRSub[5,1]+104.03526131302885299507612215799738053938937620374291560252100086860071614403851`49.053812303269574 THRSub[6,1])/(1+7.32151060909122821167048401411714680449270973266677953708093341620073378719208`50. z),((9.7104132366878311450524296484655070717487402989519138968118915538570562780856`48.1850223213746+ 18.13623928575274552521036314396510446604508827773587675094649768566729275433141`48.1850223213746 w+0.26294176987520670449497386869217530352750131423115681157265320717785557624464`48.1850223213746 w^2-1.89415659608206145026318742798977053435972248046495158982617287566131833870471`48.1850223213746 w^3+1.11993296346230898000251346301924226330265348620329891435665526911793729297045`48.1850223213746 w^4-0.23303340491807203575023284136880002280567432022372941714763606434982347123611`48.1850223213746 w^5)/(1+0.9196211864403043025207765453005807046412093877978347423210979198628655832927`49.69897000433602 w+0.01235588991685787504700495752196730854979504250695362093749970340068048236839`49.69897000433602 w^2+0.07106514325330020623181304909068666528064172756929481381279824472795038718597`48.1850223213746 w^3+0.01374672472398875677483783715714864811542890476471266690750780852812031467302`49.69897000433602 w^4)+18.70167668922043849021204120779623368114319749412207516649561377848501186817369`50.52819802517713 THRSub[2,1]+0.69168807530551916497129386130404572632280088023967072422072331597005185110983`48.68247617719692 THRSub[4,1]+17.85878573517542676685033268657535551211129158788669580476633454244216518043902`50.120712698598865 THRSub[5,1]+10.49253791063576649367448251045119190142340212338711256586031725908654478009471`49.419524859419354 THRSub[6,1])/(1+0.42115701368609862681861825004783678065244533181592295099119886087911411807148`50. z),((102.42425214969951573197965698853423933090119722583782717145590734152439713523851`48.324626981615296+ 125.14174741897043175899225784947347638193638033312665098496166047079802443746737`48.324626981615296 w-84.68178820454510691438267324884005518651462684094748053054698437791193642683777`48.324626981615296 w^2-57.04774731600119270937561823773512646674016219271773678304716732390419140551872`48.324626981615296 w^3+11.3270955106933173769695788116799240225497256959473749574350801387063675857796`48.324626981615296 w^4-1.25297440035739315930365520348004523610796322973007983994254068270729341194922`48.324626981615296 w^5)/(1+0.54950556490864238769843692510455627081096257412390518782556024381380992877358`49.69897000433602 w-0.60598911359606964195903280606997002070861087834017596346554152589660023999602`49.69897000433602 w^2-0.1373261785097616289532095669648310090450957221439061368080507132934763118238`48.324626981615296 w^3-0.0698214368236127367607499270558465482795250674130583984622391591905763780713`49.69897000433602 w^4)+110.98681846625296071434309092271715830342129471987593304853207346959200852556506`50.054811130924215 THRSub[2,1]-60.83173977604949565111607261530990402186259727026290119713691647810127925382036`49.218151418006805 THRSub[4,1]+105.98460466168205000969387162945947919584461418620543124051084243617141144226929`49.64732580434595 THRSub[5,1]+105.56001433452661400318214698893360993041070063318482391623496421564769378796733`49.05321834882571 THRSub[6,1])/(1+7.43398686177351589256682646379286801254451362529251659268054991341861069824855`50. z),((6.7257116790378792693192979707996807081497289591471511486856683468202803818996`47.768839049559524+ 17.45572265919430626563967664741068296352372823656066722260371208720293953282446`47.768839049559524 w+8.06430399135090715075986240698755225742805375635954766430350734053827236581696`47.768839049559524 w^2-1.68116875572387405037333451708421593601804625016706422071696592537332169977085`47.768839049559524 w^3-0.49634949260299882874699477158232061316250948943060476593479206553567366628983`47.768839049559524 w^4)/(1+1.51207230459778350596761156629994524578490880994383891942421604793979135533076`49.69897000433602 w+0.54903078177687470405194698456780709650934133811255482251272586039325301791292`49.69897000433602 w^2+0.041593760457393536208268890052312091404975452037011490939956054168909855526`47.768839049559524 w^3+0.01182133817145715270257670697031566373285724781611885655536135228086018521271`47.768839049559524 w^4-0.0076621028363054136639429312413451132692373232884118267567165610675642278458`49.69897000433602 w^5)+15.73077601636307507423152308083589512545189087959252323851031161587653753725962`50.78659680951024 THRSub[2,1]+2.6722885238770947756249726126109380967836719565927053428775914243757014050525`49.64994972300553 THRSub[4,1]+15.02178457005370334803696412724964614892816466854974858947457225657391711263296`50.37911148293198 THRSub[5,1]+7.432066590594080659879491210979464335644321299564169565431251884962356425685`49.636564478801475 THRSub[6,1])/(1+0.19539563419280430010432723875899981425821252238267031658123441436237116345739`50. z),((8.72395576361645532744466676315890531634777016810198743287034029157382456094522`46.76935670352289+ 19.27724421510045493536518698441434979270660822372054971254440391602732211140497`46.76935670352289 w+4.88849839734722797084137456637352518625357403422148247522929387580318813894743`46.76935670352289 w^2-2.759128126081517868200590503259884067413451844158379936075583522126953991433`46.76935670352289 w^3-0.066143317936743611841770751666851736067246833140327972218969340842608439135`46.76935670352289 w^4)/(1+1.22714974670135268439916729652454097634482395202998373560938256982585252799022`49.69897000433602 w+0.24513518921919687009009524677099987887412874396363190961130270546649080873419`49.69897000433602 w^2+0.00046449067716519728266604413488655404492255207212379358683550352747837817082`46.76935670352289 w^3-0.00090963153493822577003401354757457053613689735621365512077888048557058062261`46.76935670352289 w^4-0.00664569979616003902460358038346773723214926159296240645623241877363971155169`49.69897000433602 w^5)+17.7197804714959339893279925931028609147754627777598210548105147008422759607046`50.589464167583486 THRSub[2,1]+1.34628555378852216556065960443296090390129069114784013201078936773187578942263`49.06965444777243 THRSub[4,1]+16.92114391525088204989372541763282605335689545346467597950366048193461344260047`50.18197884100522 THRSub[5,1]+9.48103818563384290556351122227682996577766585202163044185327046426457464765654`49.46969196579227 THRSub[6,1])/(1+0.34654184844076258251807162702374732358835874125880109694036490729084557996648`50. z),((5.49062812779008916191569972273433246529923286751682745122460005584053651058615`47.956404745526825+ 17.14556186649999835459515884992220764521504994761596121618231091762048022818225`47.956404745526825 w+11.97408897354215336283575584293237439004747660178595792017033026592165244986131`47.956404745526825 w^2-1.05690066284697919263827420239945129025900865705034707549095420158946116618044`47.956404745526825 w^3-0.977560591930299882054107778497115458432767212625948221138813926132093137924`47.956404745526825 w^4)/(1+1.94044514745034315911500086274453657980104987829695274011321384787451884220934`49.69897000433602 w+0.97053816779877266361984760009284565214111562456054757667791386213922429373107`49.69897000433602 w^2+0.08434161426737469042631281858097168773248400348197937483271145709498151416326`47.956404745526825 w^3+0.02429135407147320205131932865455769910219721033773896564571872418284211291043`47.956404745526825 w^4-0.00879270931201065312057370551831851167617040633615460872147210418593548386222`49.69897000433602 w^5)+14.50140333619259716481567478601413200179575333318428355595792383577532520712438`51.033679910615284 THRSub[2,1]+3.49187031065741338190220480915878017922109698753153179791251661110984295847603`50.07586143880672 THRSub[4,1]+13.84782013634612380492578143021941342118926973374801021984764132045532808428665`50.62619458403701 THRSub[5,1]+6.16562915507865638256479682990043722455653884698922345828656168287708493952144`49.85671854641877 THRSub[6,1])/(1+0.1019745128734848217702713233508255902318691974267924808784130497181651006663`50. z),((23.40408967818196460652330644672036932918872906241405840440977813601793719507151`48.24371993107274+ 37.67647906384075439398918547115273854629092257961666628896067176360240362558363`48.24371993107274 w-6.99673309202725406124921572895809960715537317305960499248337308603865743007791`48.24371993107274 w^2-11.98494793747237448582953099656889403093932440065447152888638679358188500651927`48.24371993107274 w^3+1.05918234699870371910157144685449254100626109498711790919538524604527989498954`48.24371993107274 w^4)/(1+0.84000435005640818859832796160216887705450946448677900927544424689370016592364`49.69897000433602 w-0.26099358043341182479150583212595244579644043829518347466055910669839082612653`49.69897000433602 w^2-0.11830872671491631707941110507552282421011367577171306931123369024601297511964`48.24371993107274 w^3-0.04752268338157970271480429250850948680470885737239346619616865180280966819168`48.24371993107274 w^4-0.00696153913279444199192447546252701098344881606644971932792669403426615589381`49.69897000433602 w^5)+32.33203529229563025718873548979052289104947956670006536822263078513622511031895`50.226952876165214 THRSub[2,1]-8.39521766007794201301316899335881374694805383481232274359728802179742364365374`49.13810883871674 THRSub[4,1]+30.87481942194277567205313223004039615708962655401655851163156883864202365371288`49.819467549586946 THRSub[5,1]+24.5338426125105587942376484174091405950557859604686712546191610618415294465927`49.18320871186572 THRSub[6,1])/(1+1.45694006403592365446524401242343732572255064650950163755046177198356205804826`50. z),((5.52790338460620616291606114929030609653472365449891069237555476659639842876596`47.95233813662853+ 17.13245400386091220183634100346434675528681886172387979981135458280328758917045`47.95233813662853 w+11.80241343961263284607846925628809656865778217635867626331383384775378372631077`47.95233813662853 w^2-1.07443246445723643775684643246136513239874646046582044432884878146663090137545`47.95233813662853 w^3-0.95758319040573221333711852127079064309666153318469946276856815173485083183163`47.95233813662853 w^4)/(1+1.92065073363549591223988448057963327071844877353908614207622699524248703493828`49.69897000433602 w+0.95164019308899741413710249334733490062544705917166958555416709835277391447291`49.69897000433602 w^2+0.08267299313383705890473211219600432401310850936081572990808541784576550155867`47.95233813662853 w^3+0.02379026480472466677191993039184757987148503284983565346260206239052155552223`47.95233813662853 w^4-0.00874596695861975248657324897077631314115813398852825610322166384508243364154`49.69897000433602 w^5)+14.5385062369071083410845049723881305932482989538266673374932866193857954463754`51.022944907098974 THRSub[2,1]+3.46713504351440593105631801824278111825273324043660927688894142203619613230866`50.060009720781586 THRSub[4,1]+13.88325079665669741923231052718088198825380794815249578292570848955504494785501`50.61545958052069 THRSub[5,1]+6.20385068317097824133257732570178452097731962106151217019312395332934894639914`49.846928627837066 THRSub[6,1])/(1+0.10479399523620363092427784771181074329113799754081387028570029772303439445444`50. z),((7.1691271602071590598727736878589271571044382455252590323317030569402053507563`47.65860217226104+ 17.78079771071839079810832269109263906102032556220712255922316340395272689034332`47.65860217226104 w+7.17131061515821130048488568976584291091772296777468303252010051763769892136251`47.65860217226104 w^2-1.91632840079385800702320958949480580655430905659332201928733001972030582073786`47.65860217226104 w^3-0.37818820494777571634024012891646454998607405792190595682494846931595722963435`47.658602172261055 w^4)/(1+1.42409817140672277660206786919539908701390711316289917275993349666833768395384`49.69897000433602 w+0.45802338441056894245092826847165847799890379500834939028643743216720985316`49.69897000433602 w^2+0.03044455011452950839596218789137882011434778784091983023457025492010353804483`47.65860217226104 w^3+0.00852608392937483453536441593072497261548974043660294662676202141707347508274`47.65860217226104 w^4-0.00737887455003274081692600421983231003591878039817778996985604769355888866992`49.69897000433602 w^5)+16.17214120008965653830213306698736375794777808958663640033894238798874107172897`50.72981615414221 THRSub[2,1]+2.3780450680593737995778992885099590084530804832632965683251709096342323820729`49.522048740069195 THRSub[4,1]+15.44325727424619136156254666236177897071033416230839647840329997765569314917595`50.322330827563945 THRSub[5,1]+7.8867386362808079440027793570259336183174174183073375758152548149705473406335`49.58765206163244 THRSub[6,1])/(1+0.22893536631807563334934495219014763009951104558698812322716815652969539684007`50. z),((53.18387746810151624074505617351922024616510083365059119319838885171961068396567`47.76413811733678+ 73.68342474448918512172952017902415378498483597089319495255042417769806605859565`47.76413811733678 w-36.22920364286982660571509362471200312429356411889271891371258349522516221255837`47.76413811733678 w^2-38.52238269336593466617408322198720057758228329892127875275693508138052483267132`47.76413811733678 w^3+0.8956183590746133627413983156237481167375903917494998922192510274430351664722`47.76413811733678 w^4)/(1+0.686410373513159447079739025812145393432210402792793431272296891645261380791`49.69897000433602 w-0.54493254506052104484995627656297989928244330029155335496833789147169372436677`49.69897000433602 w^2-0.25181149646975823509903454769426738342195194236453315860327647492380569181787`47.76413811733678 w^3-0.09755797696758636650220435693305104651498489585470201505975142740008133547495`47.76413811733678 w^4-0.01493461643861055005940002164091553167932202391124535117152411731484977531135`49.69897000433602 w^5)+61.97412508712316701247926376596835913212724286245526840839380925668500558102493`50.10366020189502 THRSub[2,1]-28.15661085662963318320685451081070457433322936531579143704474033616327729079101`49.20771481415069 THRSub[4,1]+59.18093010846654428228762196560163496986165853719497160176891301579969936091365`49.69617487531675 THRSub[5,1]+55.06962137885961976398571608575797116348703258770637807500010685190340853911854`49.08994967188996 THRSub[6,1])/(1+3.70946878176921405804341903416876645627513007874935705186682335418733353088229`50. z),((39.19121286037107168303629997444928893954503009207469452408111204317896638765363`48.06062744914901+ 57.37833501591273121162463563029129104773641889558045518979909524015248893745811`48.06062744914901 w-20.80823501770796702240966930929868419779707295003924300233429000169350646840516`48.06062744914901 w^2-24.71883381595317583571135326694170526986854307598172394805078155234659411004642`48.06062744914901 w^3+1.24026198028857219836360676470503904338607723288424298051118617197497233252507`48.06062744914901 w^4)/(1+0.74516323263314010507551840841057383640880274752011976997945843517464531144416`49.69897000433602 w-0.43131362333616137417143810734173162188092033662870482920328226984821368647604`49.69897000433602 w^2-0.19282874346787107179694602866475977746698963475766461976249185796606949262159`48.06062744914901 w^3-0.07644192403039746194291474160382627768063639865300755497929800764046649440213`48.06062744914901 w^4-0.01093559253929643579931632783057694796535500463659634608438665602513883016663`49.69897000433602 w^5)+48.04616080150622271658818988670029434613919840914681886007504569915676028862986`50.13899894588053 THRSub[2,1]-18.871301332885003652612805257965328050341199729776825071498897964477780429194`49.19504421426864 THRSub[4,1]+45.88070392888665161918456573807717460509702893538311244603980488896515211571207`49.73151361930226 THRSub[5,1]+40.72173838427319040267530834074906638300516704466401233883862497463673608162164`49.11657347238266 THRSub[6,1])/(1+2.65107041140902689238498029855957900019759923201589617211901730728743464190494`50. z),((6.33651815624398718450768076089618166083000002845716069256698610803778441355432`47.842335089880336+ 17.23718986089757204806569552730045377427052197298252112344737554988527119735706`47.842335089880336 w+9.00763632453763795304220467828199749188848185209872357143760039332307540698067`47.842335089880336 w^2-1.47794248582379150010209905513406662289955093387000280308717999818441951610004`47.842335089880336 w^3-0.61782145915096519278569664336625125062985628611638340358180796682317331054892`47.842335089880336 w^4)/(1+1.60997555176377690608992347323454887902778607629426594815912965110942766772659`49.69897000433602 w+0.64814196476593956860537091688700722542355626096178148808822926623073046033056`49.69897000433602 w^2+0.05283860712361623978267637127591291495559626955919332641790349764363041183244`47.842335089880336 w^3+0.01508529185756927389166407912374238576439921788937932612136079103211501003648`47.842335089880336 w^4-0.00795073735706379724720773651102717338772014681429589786451291870668627437509`49.69897000433602 w^5)+15.34338207549265317364550180676157917134911184534191337189607361452374854858167`50.84668645424566 THRSub[2,1]+2.93055115112404270934898679532714873285219131275977858728708342527756073083793`49.76889095228951 THRSub[4,1]+14.65185060637344096256793369255804486214642367549250077122021277681488930959272`50.43920112766739 THRSub[5,1]+7.03299298425518122456463157488730201730890632773324327583815221304092718817256`49.68904644862945 THRSub[6,1])/(1+0.16595722472415858210978757371251286648837676660036449556451507211025637205968`50. z),((15.4520268806433123498472245732591604154493653205104779976466674449246797417177`48.22641343902554+ 27.48428055046680544901638008010136195805431647823970065545958334370991131162654`48.22641343902554 w-0.97952894307289871443627321077153705224692305659429834753553251241659038082418`48.22641343902554 w^2-6.68107132502666514868598886977051982799657207216632661624155503871049021915259`48.22641343902554 w^3+0.64774817242278978604898651692095213764673948072511383316318226587260626494644`48.22641343902554 w^4)/(1+0.94380820871718125306280566242297253628741465980496653525749224014333637986184`49.69897000433602 w-0.10377411594221821019654874434022590375202943017279541700272971364152807296786`49.69897000433602 w^2-0.06916536033462864295795951435071204791806391508780437108937878830273405561676`48.22641343902554 w^3-0.0272535638114907307115451493173193764312313187338432921535406582001352472603`48.22641343902554 w^4-0.00584484561279017947614244062399334739247945587961158164511686817999089259544`49.69897000433602 w^5)+24.41674183347058437707191947616216980564274589469735246486351258690050759336644`50.33625465578749 THRSub[2,1]-3.11835535419457809293529165093991169001023138681051414135787588964027863235189`48.97679832060189 THRSub[4,1]+23.31627094197306622727101059191963775741483022214830195122917513953695085881408`49.92876932920923 THRSub[5,1]+16.3799084060367839159094088061659645363043436554695187764278908573028377880859`49.267210236712835 THRSub[6,1])/(1+0.85544988744246810501371268395953673121953130218475075878717312354533291412966`50. z),((12.52776663357156998867470926266380366446233903663320179185443230715968920842539`48.12147348379938+ 23.7856406871195561797467133106727416626202511566277503727623236013673100273555`48.12147348379938 w+1.28371909148598423452386016871101579933863828391546208733925111343536547171953`48.12147348379938 w^2-4.91718322201173403145590043447918995004102011312321835464443940675936900343341`48.12147348379938 w^3+0.40544114738746865734611793141181131967067658974400384502190579587179735679132`48.12147348379938 w^4)/(1+1.01906422871710852366528102572810891416311452409022874862884467798524723612489`49.69897000433602 w-0.00302831804895154100734575524943025349739938543034208947879747451880712889452`49.69897000433602 w^2-0.04506556384411680840076956049092009605176197068862724356672624084274172475817`48.12147348379938 w^3-0.01751801773414938400167563006458428199198066105573908691102722038254202154619`48.12147348379938 w^4-0.00586895064779825340756061385868341106023902935857362522066503981199525156897`49.69897000433602 w^5)+21.50600299816945781894665859148765267180521969800858543726567198378796064108881`50.41105371919286 THRSub[2,1]-1.1778627973271603875184510611569002674518805890180027896259821542319139975003`48.70613723456907 THRSub[4,1]+20.53672009984674318047257800925356006513656990879079187388884975858659805947507`50.003568392614596 THRSub[5,1]+13.38141276228884056419871796250344203369671334954936254431320950206570937346046`49.32574709149468 THRSub[6,1])/(1+0.6342602593926457543953762085262098226794469521033050451182795415271873958939`50. z),((63.66358067001917965480166340074953042631952893798729962235877577410116454063619`47.29205245699876+ 84.71207383902611086821268055782626565231462907384188805840788499429898519643765`47.29205245699876 w-50.68965995876296628482713150691892887123090514566310473021414596668966903044386`47.29205245699876 w^2-50.74131366048344811884027083726445225115184652406336504536954504661100755258666`47.29205245699876 w^3+0.37548784969394841542098232653501830891274807297859482941794810689141217708911`47.29205245699876 w^4)/(1+0.64074156185166669063985259439042760688404958400337171865011666704807884592395`49.69897000433602 w-0.63100908688177083108320302444051420710629259191149984920989705619191210999558`49.69897000433602 w^2-0.29734755444932759523163703359046790532992928834078895174433508196375969416026`47.29205245699876 w^3-0.11306403120832038065461283765745910547806049644612356758908504039159856460789`47.29205245699876 w^4-0.01809080556322506160059705715736188369714015424437746165569317526075942378422`49.69897000433602 w^5)+72.40537145884972014591557694860184073248415199652283440049598111061002638014969`50.08711249261637 THRSub[2,1]-35.11077510444733527216439663256635897457116878802750209844618823877995782354146`49.21209785976286 THRSub[4,1]+69.14203664448461986242536145118328370620154890344590639818008239661450043851523`49.6796271660381 THRSub[5,1]+65.81536277796655173639289634515042605888528782988973325531226001793992728555265`49.077500459021756 THRSub[6,1])/(1+4.50214845370534580588517781528716734484774177972426602204489454098474449867714`50. z),((8.31786708266133591597847078304898895518492677869382205714195952675063761716402`46.91325904727703+ 18.85004807468628485690032646119306361101030233591998750401622420624698846089727`46.91325904727703 w+5.39862817296999427540172968352018288397519837028836821156868263992034962397562`46.91325904727703 w^2-2.53677640378074453940552418188297252930059211087256886294880100403332890288467`46.91325904727703 w^3-0.13652665146983634878752017716948449930270709191427931752158872737830943220148`46.91325904727703 w^4)/(1+1.26711380146212701164680832638520897474406529656937726719410345151874840907368`49.69897000433602 w+0.28960151177998145736647897743608174206827617058639207600889979547537723037637`49.69897000433602 w^2+0.00725829240639034847627236045770082480224138026187456945956104242691288808848`46.91325904727703 w^3+0.0013216643741761010226197471019096620914610170861481004187365200664675029`46.91325904727703 w^4-0.00680541974692265177276713708752827663615316064942467528625559450093708855172`49.69897000433602 w^5)+17.31556949355171410203522067385660133313906511818535453686980426483362996201674`50.61975110889381 THRSub[2,1]+1.61575953908466875708917421726380062499222246419748447730459632507097312188107`49.19523208973709 THRSub[4,1]+16.53515086409989198860652244826698554799534852968019276384892133955131415141805`50.21226578231554 THRSub[5,1]+9.06464051992040525637795549166881088418756492579427339006145339377679062089484`49.494788252530995 THRSub[6,1])/(1+0.31582549739586114819921790088018641630929489084681164280214749093588444877422`50. z),((32.52236737929627648324723876319031059363044669138992238827782762948507926554513`48.155473159283055+ 49.18736502137297387598039550000524377511904649128225523202250673146218036820316`48.155473159283055 w-14.58092479650211011732498033274990762682540364601240205566539863966969659017119`48.155473159283055 w^2-18.98423251809562423065529367789794789702350569095130305614677041438992482778802`48.155473159283055 w^3+1.24741402447643500437852673276040553850901261838152436908670345145914723465345`48.155473159283055 w^4)/(1+0.77803872730521515696496158969281476682413484878964968167981773337918900224124`49.69897000433602 w-0.36940253280843865004212843081414431984118893424578267307619881729841038901858`49.69897000433602 w^2-0.16321119063672307813857074750859908924780165076997624245705250702223565171243`48.155473159283055 w^3-0.06528334430056910031800704609395342823723097409867831540037506332960373591784`48.155473159283055 w^4-0.00913152984228990220542801276614827171545349133125978496176842556504184757476`49.69897000433602 w^5)+41.40815122358830906056834860420801575158048325247317747684035477327384616150583`50.166087701884514 THRSub[2,1]-14.44596161427306121526624440297047565396872295866106414934243734722250434444495`49.18184045694436 THRSub[4,1]+39.5418717091847612655690106800125067710675238295463060546038905028573482208894`49.75860237530626 THRSub[5,1]+33.88359730436938571995292314926665175979158840672477099703471133013802230461693`49.137029887967756 THRSub[6,1])/(1+2.14664217081116341666795155064470298700872297998682207739758123392447144315531`50. z),((7.24121725773813023546594800276049236966185083330863346429535471351320546903358`47.63694903759281+ 17.83953575955400566552929210098619534014630832713008281000728256678577117921129`47.63694903759281 w+7.04017482652059876608277829694932345469964937510033529642146661443623236905549`47.63694903759281 w^2-1.95483658403811924024138190613638288163623542785545767647203042230759843246009`47.63694903759281 w^3-0.36059611802444412331530609754716044021609194181870639629444872383819840446928`47.63694903759281 w^4)/(1+1.41162670671376783029021725699959688819255520410231732811070402122944542175348`49.69897000433602 w+0.44494921839468604021394719071114159203493628826489072085959809971771709097951`49.69897000433602 w^2+0.02877067595848042075884961161837931510854535525268519786958929255743218077855`47.63694903759281 w^3+0.00802379933834745104651120719676002931526760021954922190646082899027758422936`47.63694903759281 w^4-0.00733662397284395533546340707911707364530171253610898835103728289816268382134`49.69897000433602 w^5)+16.2438979620721667972374941270187690050356919661656331625041260672888745485185`50.721515978065064 THRSub[2,1]+2.33020722673770029362099191515568884372780456554396539354838179010081006421324`49.5016863438713 THRSub[4,1]+15.51177993446490195552560636504212625524403680539749866307174612261420065830171`50.3140306514868 THRSub[5,1]+7.96065881613499115771253718115522571401757185364161106661436965510550380621201`49.58055871577245 THRSub[6,1])/(1+0.23438822636188271584147617981576275402127933985099192490722837291683568820682`50. z),((6.2787937902891061549484755448079748342139762651801029405654256417182186722684`47.85186622718746+ 17.21170169726141407248146756564078545242494296132748450405724710830846541332362`47.85186622718744 w+9.16409937833187345421333820547659869039850000800813242193113190960307997588334`47.85186622718745 w^2-1.44814296602972206087378289385232764542313312085483475850880243795880442193333`47.85186622718745 w^3-0.63762569768275348085550396254105198748364935278259395422451263083216672462214`47.85186622718745 w^4)/(1+1.62663271661071007771983245152701162184876991237029524657905783225388988062243`49.69897000433602 w+0.66480790792231542019325942505287826733228366749379955017733596426319129435453`49.69897000433602 w^2+0.05464688775125047832654789749116476097571869562943369327987862033252030004479`47.85186622718745 w^3+0.01560747314107838773570403299252573166831062736845209093869619474805166247577`47.85186622718745 w^4-0.00799749292876521662286015868583602812325406028501337018943302353446985605186`49.69897000433602 w^5)+15.28592461974935650780646834144577480827277505216744400414592462534566825867076`50.85663611233026 THRSub[2,1]+2.96885612161957381990834243887101830823641584154275816578718275139628092411178`49.78733721350069 THRSub[4,1]+14.596982777779264108537989026969208941934547457756844326747690237309240597522`50.44915078575198 THRSub[5,1]+6.97380322505808318174386657211148384234245399565962106312439431709331260206067`49.69780570978581 THRSub[6,1])/(1+0.1615909816554175396764742701460919360021546669531476022732198651012032307632`50. z),((6.41770163495671813995234939388480848494056659036928391289107248196213102654209`47.828385249032955+ 17.27636551184699526541170533367146576446586775699043619586078389987474048314804`47.828385249032955 w+8.79554508223156089118939827259050973778985023099034954332430759806396650811166`47.828385249032955 w^2-1.52002031487319805724619435179542149115331423283491671591393404425019103826386`47.828385249032955 w^3-0.59081995857279019140679357532952781558666568829920019377118319657949098302188`47.828385249032955 w^4)/(1+1.58757473376480862198698543838140632576505814477879692902072540984399557537658`49.69897000433602 w+0.62564370689283182365994553265743668024997307758782559234221848283483379309634`49.69897000433602 w^2+0.05036121810340886733534188463690641455839302669651166405799041134978588543698`47.828385249032955 w^3+0.01436916531563117216774217566303990858123761800608995179431726708730256020602`47.828385249032955 w^4-0.00788685360110122810709494091307794518730832392032063745611352994355880595837`49.69897000433602 w^5)+15.42419017200547730697414026755472670130303766919268633596402994026901839710952`50.83318830889738 THRSub[2,1]+2.87667908678215995379656115479838371288290743019259661124177920811404749848596`49.74334871081665 THRSub[4,1]+14.72901665438461842779293885284530846382348064978737771223297806273915482640768`50.42570298231911 THRSub[5,1]+7.11623739025775528734536169430597156355940488696668091130107233088626622094783`49.67719433285618 THRSub[6,1])/(1+0.1720979037140812884761451420979859956887874458013089602271268363154789535954`50. z),((5.75527561041971141875534222553911967617035557715497022300462327346425140863618`47.925890981562965+ 17.09503041557681000371439300279529700242955566941312257993292170352791061209969`47.925890981562965 w+10.85677352623486086777040707513657216484460904208852140810725784458551295819714`47.925890981562965 w^2-1.18402429139253030294437814149208335520611209679423554493948389703590951060515`47.925890981562965 w^3-0.84579979414252614111738314805504880495675670487300538605501148134107737831649`47.925890981562965 w^4)/(1+1.81285067397128778194093600887699831084004284229725152563642852741211669514331`49.69897000433602 w+0.8479032945921190076480533998054372639667101888193887758228075866245438312969`49.69897000433602 w^2+0.07315331043068820424375613214439743075043667493814310693244102364592436487481`47.925890981562965 w^3+0.02097224008598332816329363655826961397490159726124154859254946623509754120436`47.925890981562965 w^4-0.00848506736417132450558136976307741111287206315947522000317329651013119970712`49.69897000433602 w^5)+14.76482712213165458056694581162057434820743157694165197085241905559556476182547`50.963657392891065 THRSub[2,1]+3.31625445336470843806802412542115194827997815835995285464951979789634992200866`49.96922174330789 THRSub[4,1]+14.09937132230721761534178793996321520744637338768044185426423362847269438420852`50.55617206631279 THRSub[5,1]+6.43699499010938284557191642651997831312369226966105770754114869534952838335678`49.79320442222314 THRSub[6,1])/(1+0.1219923202166531549259553021323726580199248012846884290269158452311523324254`50. z),((22.5865347798881219616978880251145275471415595700317628018159515525584083552013`48.24823554601606+ 36.6312514123629851286695974871949959072691736418525374699449326610738695102159`48.24823554601606 w-6.36080171549936685059222512513421941634409477882594656818151083366791459715441`48.24823554601607 w^2-11.40507298911496092657382669688953556366117279877006737787390119545994225756531`48.24823554601607 w^3+1.02922333726722263601805061801412448693282734400171189155253162647424934988805`48.24823554601607 w^4)/(1+0.84742214975867151536716896148302218672478796880132717854757167448129532176463`49.69897000433602 w-0.24881838864767930998778290230588036799785383379443203843415109022150499306923`49.69897000433602 w^2-0.11386443236572290611836211176258539286282785800510696280070798228291132867207`48.24823554601607 w^3-0.04571159406224343436593132709486398086298279157861541837037239470732339104116`48.24823554601606 w^4-0.006798738599603591694191504785351736657629077655858424561047658974402597224`49.69897000433602 w^5)+31.51826066507580866685163704771274201416334167773090301758179726502801167520195`50.23471823305362 THRSub[2,1]-7.85270124193139428612177003197362649569062857549954784317006567505861468690926`49.13080656376997 THRSub[4,1]+30.09772189503398139432012838044611717735558369138801184714985960825342290867824`49.82723290647535 THRSub[5,1]+23.69553323032965820334599481187949680929289432917506405153620437242810683282106`49.18912652624272 THRSub[6,1])/(1+1.39510060769991277564935639617522584322673535896006208344891395492370660706908`50. z),((7.14702472840778440119931896181042189637195351681983671266277146671334908758686`47.664992518409626+ 17.76308234649980182494246636721496246199790714212404507138437181927677365867555`47.664992518409626 w+7.21221558333423453036240036000465423965770872657018946001425127379905230827995`47.664992518409626 w^2-1.90453586679063077237701992884629483452787154567518093338265256961907017632569`47.664992518409626 w^3-0.38366379864051508101559862928531489666630850181301356455841826857689004666696`47.664992518409626 w^4)/(1+1.42801330031897907111985302305475590377630906864153749371887113612523038974969`49.69897000433602 w+0.46211827864764389712895582279298587803399461374202842120590826034684348743078`49.69897000433602 w^2+0.03096490265948211787832512082579195809206303787618453373637774588110341669282`47.664992518409626 w^3+0.00868177076963472259551526014673996709419339753154169761911204171681111831843`47.664992518409626 w^4-0.00739202529964557171023522330090383701338127861021758221288324032629376892482`49.69897000433602 w^5)+16.15014096715640214445246649189165171899929514433139188471439458184119282041429`50.732408050839815 THRSub[2,1]+2.39271189001487672881101033857376703441873578010012624540820278039926454961603`49.52830816423406 THRSub[4,1]+15.42224859932318809366231685405662164525949920310111441084500010488826149998215`50.32492272426156 THRSub[5,1]+7.86407511119509590057814161848246936225954498996168765598617792017222667841372`49.58987008735069 THRSub[6,1])/(1+0.22726354908717227648555319300226606681455803637669756601760690111547036065975`50. z),((6.43845228755615619017399183199878807575066066328473031512003698606288256639873`47.868556749500215+ 15.43096255869445918839235528587005883297840747537871762635607092067221781360636`47.868556749500215 w+4.58820464463656004576168825287304452671826865110987683471507473552495700248357`47.868556749500215 w^2-2.33311447322796804744941970690842394489036510388474521961885018952560190031247`47.86855674950021 w^3)/(1+1.29376230941380931311659899024403100640508153381518154319157039562213721912595`49.69897000433602 w+0.29272988017376925826306796695459844437124170338414496616288297375547018180466`47.86855674950022 w^2-0.00414585235087417232722618427858307074712519029741724720825983722725955834027`47.868556749500215 w^3+0.01394289484088669713678580213128199538771753518773023675255507588180334342502`47.86855674950021 w^4-0.00795226024020516239518317119492357164245590265528575935216017146244509995893`49.69897000433602 w^5+0.0012114190017383448318716531304619775159369551365144689636589004180801660564`49.69897000433602 w^6)+15.4448448761958820084285376334624938597970903741511005495909432871053648115924`50.829826583672286 THRSub[2,1]+2.86290928398855681949362957752653894055353896022032046882383697688981655549737`49.73689011861892 THRSub[4,1]+14.74874044400464118209508389515766087081699549077702050209020659479099220722541`50.42234125709402 THRSub[5,1]+7.13751481981849555529492921708020995587538164175570933315148482119793532795908`49.674248160162755 THRSub[6,1])/(1+0.17366747302134690717085899924407808358554286961046565168367463763251930898519`50. z),((8.3665026157833755977353250197537082407765278081870881679880226111757523544834`47.613449330983556+ 18.50540569480228885996610171288836750897514396107667486716386873381145901914079`47.61344933098356 w+4.4750322692766878407583628462324100786093801973759145734009879013414909879423`47.61344933098356 w^2-2.75184734390377134159582839281540646634716869693378846054609836515262183864717`47.61344933098356 w^3)/(1+1.21481458069956145623092556136217445291257175016671789962701485379445490672989`49.69897000433602 w+0.2281990109677648552714620306449916794207557789295345022769943277248481964003`47.61344933098356 w^2-0.00321126439183928511269124365143839581534191811080944704532333134761356564533`47.613449330983556 w^3+0.00122733533840337011118263201935511927330466993094630911104539386136928608719`47.61344933098356 w^4-0.00669219074412033461981996670682422396296797017473805772866812263458169273409`49.69897000433602 w^5+0.00027918582744237745327089989324264473112907192409754390863678772843052118378`49.69897000433602 w^6)+17.36398014208262170444631466719015564338480053429109938145714004261047970352643`50.61593413790196 THRSub[2,1]+1.58348577339739702214844488837476441816173218679365458091303913988640662754134`49.18069861201288 THRSub[4,1]+16.58137962817176206461577145237102651280787490182025001408205897701412256673359`50.20844881132368 THRSub[5,1]+9.11451071678261257242930821407708188664656138354889125517322945649137748232532`49.49161457083233 THRSub[6,1])/(1+0.31950426555339471702282925264417159190925563443833567581012122161476295898446`50. z),((11.91681646214050276479500796589233673896139013561165488132183580290192872404829`48.510055420713734+ 24.04078972534447288898082540171459868324539947825108114935038805233511392940644`48.510055420713734 w+3.91365280223880262041612376323919954946713461145060801585481237215393785375695`48.510055420713734 w^2-4.08462606730790652285835427161246026447800005015195702223887705230474596920025`48.510055420713734 w^3)/(1+1.12570646787385422419232249779300554650766217953064376059790254696224427942451`49.69897000433602 w+0.12720626415345298785040464440843773585306931286163282852868078760462841502005`48.510055420713734 w^2-0.02259291183500970461718329563658873563051117082566832747186120265735462999995`48.510055420713734 w^3-0.01648491647793453534158168981077185331773978614134522941166172057044743310565`48.510055420713734 w^4-0.00655994459090322498098414004867521380267031104405007834568050931368244730804`49.69897000433602 w^5-0.00070074164082951597338744841480959596235747119360194526474849831166988662878`49.69897000433602 w^6)+20.89787778352789658256589640518597969357555122408467647991745283351208883722566`50.43145071564198 THRSub[2,1]-0.77244598756611956326460960362245161529876827306873015139383605404799946159149`48.561372195372854 THRSub[4,1]+19.9560032962725972916953749466558951752588655347934604658478222079648151920163`50.02396538906371 THRSub[5,1]+12.7549529834721125054255551128611295138845370212396728999532155735561697991941`49.34188257633925 THRSub[6,1])/(1+0.58804828447997047896882663437573127599837963607724459009999186672805484987005`50. z),((6.91588864662272981352808411444659919896718090069807584860077964170810902731347`47.63697015614693+ 16.18919843165457229207933394740323058785393809363505875371515744373274854890397`47.63697015614693 w+4.55625366135567080645766158447197538348494953306798103860054286260724097174807`47.63697015614693 w^2-2.4102097509364105318946410640239317833208184191917401028639518823189417639119`47.63697015614693 w^3)/(1+1.26966720081395706643500578599987707296609715213908991505841313477226181895125`49.69897000433602 w+0.27506175355081453801137917010347570389553158688764673532434699497730290294943`47.63697015614693 w^2-0.00250062793564457172932378751768818648015526400147715269788435696527822602127`47.63697015614693 w^3+0.01041452451786882331407425072984926970679734973424468993945909546407658600509`47.63697015614693 w^4-0.00749701105008957357462633812700955962425202973612033042800918977372531352224`49.69897000433602 w^5+0.00094284088658808730682571221254776381694859602472746133461272859674432997555`49.69897000433602 w^6)+15.92007362955716070810433424376931296621297491901670707638058102117232958403248`50.7609414161203 THRSub[2,1]+2.54609011508103768637643183732199286960961593030991611763074515417850670720399`49.59439263286374 THRSub[4,1]+15.20255047518572123636215359000943164641432938771862429226116685468351375205347`50.353456089542036 THRSub[5,1]+7.62707139887521518189309583630532289852137721873169308387723248234773298470239`49.61438101437429 THRSub[6,1])/(1+0.20978052786492492912385167221435730413323174353122327605493999264493198642155`50. z),((8.27442636038473337107240003919886979405820412279053766527168983845446432712826`47.68451950388787+ 18.35871124818084082471619879061178818794064285698261978608715354802325147958337`47.68451950388787 w+4.48142244143557606245003576324222976201218456406741206834787153040272388235249`47.68451950388787 w^2-2.726024941041155773340807008835109181612037284488533592872369823932936871724`47.68451950388787 w^3)/(1+1.21776386294412255733260299719796741836250278557480289513578647504886134898928`49.69897000433602 w+0.23099956440758476891541090903170802831363090118057010928932368209358140012693`47.68451950388787 w^2-0.00297581806306353428631137255370262216695492820896285258409326458957296712979`47.68451950388787 w^3+0.00176146872956883819799325580852277055649357669623992918412918090976868500611`47.68451950388787 w^4-0.00672392581469757086148610354906705731645372932374180709324872515834781608927`49.69897000433602 w^5+0.00031555014776305990683858610488269405555803579659120064212651224087751931344`49.69897000433602 w^6)+17.27232963571393949270801110077417430152941786783843549067315359349123468754785`50.62320729731069 THRSub[2,1]+1.64458611097651849664064726598541864606532063109543050810236343929923663819371`49.208120872945045 THRSub[4,1]+16.49385984141905601391300001254534528755513840460369139309363289010780673991623`50.215721970732424 THRSub[5,1]+9.02009700959566865144258380369170908181185656127927049236170469106374834702369`49.497664664851 THRSub[6,1])/(1+0.31253966221337384363012138957351011768061828349519034136116879963982502624841`50. z),((5.80020039663141188815339822379867518751228633945439773568963051452091594863148`48.20459954650968+ 14.43347349739617335904226286495531484591751948117363670851762333780665313796749`48.20459954650968 w+4.66388656966389438359779162050012272903170675031963788450766690685510047449084`48.20459954650968 w^2-2.26674132925980203372464435836618555634562417065136614706367992438993516513586`48.20459954650968 w^3)/(1+1.33495274458781358275308707454030269049352025846506577148572465852540323912294`49.69897000433602 w+0.32020543220076808214273988207565485612666123282692980852798132348942308717999`48.20459954650968 w^2-0.00862073469920055759746481196814794600973460848056209176444840227709912475706`48.20459954650968 w^3+0.01933250682880791247178246800781723686722959974820593210923739387495706930016`48.20459954650968 w^4-0.00879205535230707842527295466418501342427652152600875600139781939098451452755`49.69897000433602 w^5+0.00162223138388420731034311011868130498860517591049261662208357162611652749021`49.69897000433602 w^6)+14.80954418177945446616559165543485257809457279070246088821497916840812258600706`50.953038889794 THRSub[2,1]+3.28644308026617518100226022954496646168855068251941357640781305602131137255414`49.95231531456285 THRSub[4,1]+14.14207296880811249581453258251392221115225144315308977593604531597995923308341`50.545553563215734 THRSub[5,1]+6.48306023888024120022176183581496961563392944736500449412843274831109865300619`49.783645849938495 THRSub[6,1])/(1+0.12539040927604323307281300320404855314521643999363908448952456811957473096641`50. z),((5.93951768245647096588507061205632263748919975815735851704477229833632684598101`48.132529660296065+ 14.64877497123924925163517666609698765404278305706506951953929999160710850552583`48.132529660296065 w+4.6422342409710975733061051663325347047301260311826990660365937644219344033751`48.132529660296065 w^2-2.27703722947283876602895436795672896406268722223116323072396911891296021998777`48.132529660296065 w^3)/(1+1.32479733973742471524655477406951342689410876235293050520357791699845223239037`49.69897000433602 w+0.31368338389460639386105532217079754244968212050645451344329910034303725673797`48.132529660296065 w^2-0.00737272475718262047268508885049719017954729956731314584510436685942386188105`48.132529660296065 w^3+0.01807196493018657777968221153509457148796523599676903383194650329630668334762`48.132529660296065 w^4-0.00858110106801314420326323018191367306218451610943406312014215727405244042452`49.69897000433602 w^5+0.00152673322043699004796834449768081267319699863055603440887358357304050717445`49.69897000433602 w^6)+14.94821728198858160301258794098646908901988907923424704610345074259759327305679`50.92204103054619 THRSub[2,1]+3.19399434679342375643759603917722212107167315683155613781549867322833091452103`49.90166854715034 THRSub[4,1]+14.2744960250410744677173327645958359999849146273706499644817981970277310436914`50.51455570396792 THRSub[5,1]+6.6259142393282314434144261462622540305587071690890133939224591828412254102766`49.755856973871175 THRSub[6,1])/(1+0.13592830126544919236052679360584601137864418442551814974188631713139628936426`50. z),((6.12590265065027519253537103382564016868314762269541321545305220651192189500619`48.0345052687137+ 14.93923167666261304136734288407233336624042926589292894187030398485962642357898`48.0345052687137 w+4.61841049802893556970162171692763354879875528658422957834324570692458684552275`48.03450526871371 w^2-2.29468393234965826370485257863449065555934266536939987394378969923019951824604`48.03450526871369 w^3)/(1+1.31232783723992065800789685711092129636323496039755066288250421427971534994116`49.69897000433602 w+0.30546825294086262408140869449328697562435996846897953695820152736322013531744`48.03450526871371 w^2-0.00595645130715344444173469421708241203095997495464600182517386105010616293742`48.0345052687137 w^3+0.01646534838376019476107318737346931516520992856989898468891695023643269119843`48.03450526871369 w^4-0.00832472855946351065435375700285001894333161902379906796040163281264342854485`49.69897000433602 w^5+0.00140432024845163809225856959847813197619139155052973003103757637810614565843`49.69897000433602 w^6)+15.13374042952010886936829996059476087279035214883370960043931706819170425554122`50.884540197633534 THRSub[2,1]+3.07031224843907224553378802610502759855803111043191443492492112283225692619819`49.837493294214134 THRSub[4,1]+14.45165758096673161600792689224775497408572595420957754560729582897957738378351`50.477054871055266 THRSub[5,1]+6.81703078435833245235027068149438050794310076121518789371933010943595635343076`49.72247351823403 THRSub[6,1])/(1+0.15002636994115899053095589280831308801936338810131832740432446021604846651632`50. z),((6.16594817632230548840681110647914060930753352223588653753373167393309762977093`48.01326439422143+ 15.00194281919728430633368328435434571671493591958007296453157064477491747295728`48.01326439422143 w+4.61393534637035828751744126885535339380797490711476497287406774576070415718825`48.01326439422143 w^2-2.29901385233271718578388917059402020471732507446903417199977335237449915744565`48.01326439422143 w^3)/(1+1.30979663227703852573165928792534474230277906257519732642559878300582369980291`49.69897000433602 w+0.30376953445765831896229389866771970603631973431256142072366259599837084221289`48.01326439422143 w^2-0.00568692079421991199102803119689734508529561558103583370451452284662831191008`48.01326439422143 w^3+0.01613088260293200229482184039925591055582850390471440692988196933103986522532`48.01326439422143 w^4-0.00827318749419898608923714915517832229383610964506932992016485065275409526813`49.69897000433602 w^5+0.00137876947913027786096121122558704057183839458033824821570924757668764296196`49.69897000433602 w^6)+15.17360078971559702095546777012461885035939418098817877697449655397372124472909`50.87700153185033 THRSub[2,1]+3.0437386749754134778090094864184556135120030889956016505681347989775789334062`49.82416040019641 THRSub[4,1]+14.48972142111794381685031140340145821231973015664281389655723799494871278277526`50.469516205272065 THRSub[5,1]+6.85809290747115038621858918345503301752709447159463064878325123298658739525967`49.71579445217712 THRSub[6,1])/(1+0.15305539409772157981961740449487436956788538353504057635906901668804867231555`50. z),((33.32929180227193176481824397897215922366834827149626122685074001060003428570337`48.9563494778868+ 52.79190062715084507271806848699074184981359861585138507571785518959155373280834`48.9563494778868 w-10.63475951553638256506225323042581363539441458828860404050415300407029911063531`48.9563494778868 w^2-19.46892899409081594554833307019353964790197576047751443643945629773185500471404`48.9563494778868 w^3)/(1+0.85177376247461751958741045693406257492149508313851600662849204668534318521023`49.69897000433602 w-0.29455387890945424436096869371956234416648772890042141768834504445148741961697`48.9563494778868 w^2-0.17151880148658450020384378194411056321618250654063723175916594890478278803435`48.9563494778868 w^3-0.07491042554581123707319521611777996801805728175770167388605917591185732872144`48.9563494778868 w^4-0.01288296855068348974746713739830011002605489010639445194495716841984210857185`49.69897000433602 w^5-0.00107349144393948250679145117907204875244577589493557343391214182148112551131`49.69897000433602 w^6)+42.2113445294714463070589279198055615542863532143801442528294994420171241668934`50.16225506371305 THRSub[2,1]-14.98142381819515271292663061336883952243930293326570866666853379305135634803641`49.18391273755067 THRSub[4,1]+40.30886481852249321551602524523954729094146274482751474776401998994562334822413`49.754769737134765 THRSub[5,1]+34.71100634552746734403692912339032999685364373104786875328469469545766468632987`49.1341325773947 THRSub[6,1])/(1+2.20767754314542470944700505575362562705422564753767493930717985262797595725178`50. z),((5.63196700584117557599205290090797295807366194887210473235039777177912527643198`48.2900473737391+ 14.17605155845218900879877315922648974456921784614861446351066215620867325104455`48.2900473737391 w+4.69555713811100130806050662996836898867272316669930311167990104489213199772974`48.2900473737391 w^2-2.25797534944084987088472902504737899166616553712309993919010445760117390719446`48.2900473737391 w^3)/(1+1.34834135169746510657759072391566441114605435270736654685536107025804263766598`49.69897000433602 w+0.32860770447141381733761568084723450313137564358034764624741723323496327781193`48.2900473737391 w^2-0.01037136962698227360824175628834170980578682203036646916683835630596355617886`48.2900473737391 w^3+0.02093359600579332578694767390683651110220960973310130919139753063320899111489`48.2900473737391 w^4-0.00907169845135800544790470511742878882747696655558562519612570921195743274367`49.69897000433602 w^5+0.00174254932548686275417876894324592088261043672016179571537936914834641670189`49.69897000433602 w^6)+14.64208868103943498131595831208511555954295527576210110574169083542759076949322`50.99457430742284 THRSub[2,1]+3.39808008075952150423534912511145780738962902581298676472333861134166591689683`50.01728614785064 THRSub[4,1]+13.98216474466389666543263210808436410996002953514923866734735550041514284776483`50.58708898084457 THRSub[5,1]+6.31055606798006033865120149212028203697997668557126042068825367217122878152012`49.821146390468606 THRSub[6,1])/(1+0.11266531711924387596577916447455983734814104694682895271781462339828573179112`50. z),((8.04602589999708007082963758786375143953737682050635040696854394019244733218134`47.61041892491501+ 17.99442325798083987952574983109777771876449310672609471140793315407452089335723`47.61041892491501 w+4.49608246456631890360721523464190994529527760713071196838855898160643536442799`47.61041892491501 w^2-2.664217629809726248455713937415114256992321877034780742028209723907210853932`47.61041892491501 w^3)/(1+1.22532091585282107024712690001455823596013864281996236575258537444401809041003`49.69897000433602 w+0.23801876972689675680196979653023670407709398837388683750969825666595667277863`47.61041892491501 w^2-0.00248517350353396680132938107859461963797444543526190915446973103108044847776`47.61041892491501 w^3+0.00311021642418587654343033382192929490961398489881247642848739663596352161205`47.61041892491501 w^4-0.00681219162454534226983131949572760881077363920138506659841503420337243526964`49.69897000433602 w^5+0.00040882255632554139182129015693809692409152595883209915083494575540093617896`49.69897000433602 w^6)+17.04498527034265561515773789086455989505254215005989729885406006838878075369301`50.642148293476694 THRSub[2,1]+1.79614902122404108167416273925849491704990444294778930264842578936753926076354`49.274681102013744 THRSub[4,1]+16.27676196422147753695725620318505488882629727466259921789008557775921631271451`50.234662966898426 THRSub[5,1]+8.7858983652758968093572176532727506962630528169226584588188244115770028397994`49.51347404827611 THRSub[6,1])/(1+0.29526356206799790135127059573859219093996403388892557506987203408438912879881`50. z),((10.41312697505077506896696826488937186680851525463621062109017475253018477882058`48.274663870504135+ 21.72889997269281190499439012818148649985191309231545919533548421510471287041046`48.274663870504135 w+4.23401237420298745678684120447319185164458158677195363309826138610321517041766`48.27466387050413 w^2-3.44633289592397276012642499537519378537614131509006694327411511814540578985374`48.274663870504135 w^3)/(1+1.1591553303663220501156712395922300878717634438463774356870485296606947177665`49.69897000433602 w+0.16871339397789587851892372806317699323619632061508532466094048299545531804314`48.27466387050414 w^2-0.01256564869458837672151641821667261424756795901568092297150716589323122194604`48.274663870504135 w^3-0.00954991436376041635876787811624279221863459056249571003550334360500183383967`48.27466387050413 w^4-0.00641632571448721774216414633195372761021222924493336561293244317963708783871`49.69897000433602 w^5-0.00037281899596707027402063240506352776754238567258495812256787356665926848763`49.69897000433602 w^6)+19.40114116759607833811472036893594967702285272246761651899130739315688663854902`50.49252656725858 THRSub[2,1]+0.22537842305509259970284108721090172906969739467597648922359423952213533752634`48.13544329635982 THRSub[4,1]+18.52672511067949006093162947605355383803266236541526960942366158005896301813768`50.08504124068031 THRSub[5,1]+11.21309077024977786377025776967768106379795162294482444578896945779595519754598`49.39067812603659 THRSub[6,1])/(1+0.47430994033469127833017097950210735950005999332017780904500766716566369626087`50. z),((5.75537102992732038641602413929290404529455125292181902936066435332625196752829`48.22754086999612+ 14.36458084811181580030198865555429699738791234226456638684978970724901621659815`48.22754086999612 w+4.67168417621884918685207272514945086612383832257906648715484947333940932352646`48.22754086999612 w^2-2.26399692625249894221918920396183217098734723353818948185674007165823315321454`48.22754086999612 w^3)/(1+1.33839230662305798980790288932313790851983478415477373492705255348755505596508`49.69897000433602 w+0.32238396813356776553578194424583013299506514621847169310456823382189351974733`48.22754086999612 w^2-0.00905995992203400155518915977261367882380298617384900173362324490758766826261`48.22754086999612 w^3+0.01975022589655292698110206097757593360123125125848738990744131831553979609959`48.22754086999612 w^4-0.00886378232046238683130906896869023264512160425482229772105660069543615496323`49.69897000433602 w^5+0.00165373867176747356674166676735263895859168084372833981981619487412411412836`49.69897000433602 w^6)+14.76492210043145565143402256282792718345076332778541301235431774293756398013469`50.96363449299026 THRSub[2,1]+3.31619113449817439082330629128291672478442365779744549364825400633501710980249`49.96918551168655 THRSub[4,1]+14.09946201990261644178942516813307491043087753586745626229248811548365223075216`50.556149166412006 THRSub[5,1]+6.43709283194072483004633052570436829750834746559421077553761837569489523283147`49.793183786915684 THRSub[6,1])/(1+0.12199953770197029091171690266114445087460863614846739644720768010905100764341`50. z),((7.72464097491567977295201577538375332146418014022375283009338211652428537278515`47.5313113483194+ 17.48109456793951668113571154822426976683785939392088325252174701637906119395359`47.5313113483194 w+4.51435837432650615529013412315618817276756185023053610968844094666802684549021`47.5313113483194 w^2-2.58287761189605154251424515619620023832926559680119642049383225141739450081098`47.5313113483194 w^3)/(1+1.23661622698463194632965807764281479364218242508213697603146522410323530382083`49.69897000433602 w+0.24810178087190603166622871230214108127101757678318738958610848110172033680348`47.5313113483194 w^2-0.00204200041083773803991360118192903080809720589578268231290308540008084616403`47.5313113483194 w^3+0.00507108904762444174163080615528360763819598016993619988442060630222144995882`47.5313113483194 w^4-0.0069615688162467014121484143901353048741879555927380592419908259795492888038`49.69897000433602 w^5+0.00054784898402119426965791098505208305899414452723954580646724794445119691175`49.69897000433602 w^6)+16.72508638875319336972223651380090175627898746330285832896173902133297434643659`50.671234061167084 THRSub[2,1]+2.00941494228368257863116365730093367623227423411914861590997315407141019893449`49.36597665788904 THRSub[4,1]+15.97128103445428656770509668319125657726271177825163910808716429963406447643977`50.26374873458881 THRSub[5,1]+8.45635474863376430957756101553445373849633431320895362090487902813479309292326`49.53790150485619 THRSub[6,1])/(1+0.27095416207161962405457608869966480632106182939244508263050136085983602637782`50. z),((40.61034023188568168311564975159581490152185469919399267349904660854239754737654`49.12872716121869+ 61.38700693240337203781818427691466430352906335760214329849848405119977799519625`49.1287271612187 w-18.29620221393704259019369862563816376472456032384846120203281137531691603541874`49.1287271612187 w^2-26.18740180367212848918719457942129903268596107195197865809544492544842484703234`49.1287271612187 w^3)/(1+0.79535030766661822560741103501091306842910929767879215732037186360346055875151`49.69897000433602 w-0.38743752166009824840121750661587143217242120165660213260129032121201832347041`49.12872716121869 w^2-0.2077636708117384096211848878833726797307986961831881091661973025912949034524`49.128727161218706 w^3-0.08647906098259754593987580569090794161559970776041341997326682382687609040382`49.1287271612187 w^4-0.01459921299456608053420916503757006882823076015989388799435958895878804070875`49.69897000433602 w^5-0.00082988459274637749709621999477292305889956834047290218727744469269525375509`49.69897000433602 w^6)+49.45872630645494975558759921163994696640883994971678127499064166938552533757236`50.13434523089082 THRSub[2,1]-19.81301166951748834527907814125842979718762742349013334810929527796362379515627`49.19699118734915 THRSub[4,1]+47.22960462420878592630846101010930049499607898784777509034809492247628914101455`49.72685990431256 THRSub[5,1]+42.17689178440954671311390658308057644103163038232111699745423350694885859124665`49.1130638067486 THRSub[6,1])/(1+2.75841251810933305968705847559031386915889829013739734921431191984215402246938`50. z),((10.2136323054535644121723828240980072642986238266689394451039006924761707376666`48.234881633045454+ 21.41837967414253935280695416801655246203759946076607564378221846190067171429784`48.234881633045454 w+4.26700543758291266690835498952151668177797746301161476384241215440352418500571`48.234881633045454 w^2-3.36926680355912086846480342820752246404370248504113144249773329550950417448907`48.234881633045454 w^3)/(1+1.16396079372129269347046763940676882061444968906724345803846089507588811406997`49.69897000433602 w+0.17434035683965205182605844125346713572031838737717708147626616957130581299274`48.234881633045454 w^2-0.01138668187497192858845567260915730907511520475824216048562414089909415066972`48.234881633045454 w^3-0.00857567777645479867358333134085973787530455054936839780828979944365614424235`48.234881633045454 w^4-0.00641466177561181348272743343101418245070035063783874961603474935867242483533`49.69897000433602 w^5-0.00032082263044498227779257025009921808674941907405437972209596523923871952891`49.69897000433602 w^6)+19.2025689362723995845357318804430591506477296677886426388817057991429814716178`50.50209981056752 THRSub[2,1]+0.35775991060421176875550007953949541331977943112862574262999530219807211548039`48.35247466744264 THRSub[4,1]+18.33710259762378545024338422066739378083706887550234865425897265289885289458873`50.094614483989254 THRSub[5,1]+11.00853172037137766612150020236422696633906772843928638117423704844236356393031`49.39839409102992 THRSub[6,1])/(1+0.45922026019752985450741178714727259732083100105948695019617286679164307031358`50. z),((32.80110331283153118952227300221984762253224924636852291081777718882075418621983`48.940044708490824+ 52.14947720493601503071653472613634931123102228574580810123494646997339786764477`48.940044708490824 w-10.12124059078314906487289503767720198498596697536771037881088329857279885507076`48.940044708490824 w^2-19.00305595766248760776983912005116911714621442741894314635651290898874023414292`48.940044708490824 w^3)/(1+0.8562648837944312059313593472294324654779229437966066759071365178691806133115`49.69897000433602 w-0.28716513585363037331647967786429481579884290582739783303558153824842494269208`48.940044708490824 w^2-0.16865370933479595216978125405976302547559975783647691153768800710148795311656`48.940044708490824 w^3-0.07397879476474444146562350165726238210786176031085181072567667529374830372204`48.940044708490824 w^4-0.01274709725529570171700927985377734295002699961281718860709486641326375026637`49.69897000433602 w^5-0.00109065419787440609881353013757733792833234738057883486700872924963071678794`49.69897000433602 w^6)+41.68559831720708532329059740374489875984748868482350513035799917105744909447779`50.164743246503285 THRSub[2,1]-14.63092634335224539041441026932839765948005991356128258502086694574490629975986`49.18257543720162 THRSub[4,1]+39.80681416756020982746607610973285345734672107372795064561735161486953708909774`49.75725791992502 THRSub[5,1]+34.16940924032768782277344730267237025895410349770279767106908965195611626118255`49.13601341456711 THRSub[6,1])/(1+2.16772562175384909898795393873374897396772319076280811882733618093537636626359`50. z),((7.71300053154697484580622538873301955668031684998827760863886363674825584472403`47.529375216482556+ 17.46249117826879825746609550105625110826399041944935682444938366157706428624144`47.529375216482556 w+4.51498031175086385284021121189104834927103222975407787044067189413346239355477`47.529375216482556 w^2-2.58005939866672336622271069290555649268979817472299570154386004632982849818997`47.529375216482556 w^3)/(1+1.23704160122887262287842313412565090431448962075592297539817606503815312146489`49.69897000433602 w+0.24847222911503879851209086595328857476345155910639836529648745872849399897884`47.529375216482556 w^2-0.00203182906790813969765029934865513974632484581857198026876270170580312850203`47.529375216482556 w^3+0.0051436156805101719028852668705011352857706926661584064206521824594237364104`47.529375216482556 w^4-0.00696757658153427454708925884697649509808447173591205915875060414447512202006`49.69897000433602 w^5+0.00055306290645833289180675232855435187032162312845203259780091916791974647304`49.69897000433602 w^6)+16.71349976933129290495473339992376015442072736439107132678170123934280743063425`50.67234664822071 THRSub[2,1]+2.01713935523161622180949906655236141080444763339367328402999834206485480946939`49.36925179495851 THRSub[4,1]+15.96021662792596646148141300658857494217910056601323814230111734769349183493901`50.26486132164244 THRSub[5,1]+8.4444188004679648085854643504244052185126508938367675304086225256756997486275`49.5388395199213 THRSub[6,1])/(1+0.27007368457593943318218222545998010364339846274682169087797129210193039000819`50. z),((14.88453174310501749247719980885666643777548359771412240142959457866316164864582`48.3091080699806+ 28.45652981201563917557299516126246423453178588997781054381990742253042558915308`48.3091080699806 w+2.91964650319466830877985973949011576847498105393956556072589108217980144198838`48.3091080699806 w^2-5.60190036457098493327747444569276540365619698088824777620098843940812862174701`48.3091080699806 w^3)/(1+1.06964260424785589312218292500592172783741008127398330794595239588220753507391`49.69897000433602 w+0.04997175484014630172712786615427021797964816237292628645488719432166771454175`48.3091080699806 w^2-0.04549165976724501689715752458956847777977837895048235812927161568304211371021`48.3091080699806 w^3-0.02846276167963776439420435974611242176204916417404542230375011050758590100561`48.3091080699806 w^4-0.00725968586169584921691903623723439732545827734708037226963959821294023522412`49.69897000433602 w^5-0.00109642658098952324913331698790180875157512032804733730256290485326960899611`49.69897000433602 w^6)+23.85187072210785353074990258363564791754648650629387430946090923212360084143006`50.34844732318009 THRSub[2,1]-2.74177461328609086205394705592223043127939179454152870442280698645567413106118`48.947073072633266 THRSub[4,1]+22.77685876447391962357775234149354497705586693200843463256274727959937972384311`49.94096199660182 THRSub[5,1]+15.7980068124762672426370122530446786213232755780090878133019831364659309031077`49.27668756906225 THRSub[6,1])/(1+0.81252483023599209329943622859160909149642259355682490215379427994283407652621`50. z)} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};


(* Pade approximants for the timelike region at three loops *)
(* In the construction Pade approximants with poles w0 in the region *)
(* Re[z[w0]]\[GreaterEqual]-2 && Abs[w0]\[LessEqual]1.2 were excluded. For Ftri3LoopConstNH0Pade61 *)
(* this region was relaxed to Re[z[w0]]\[GreaterEqual]-1 && Abs[w0]\[LessEqual]1.2 to obtain a *)
(* sufficient number of Pade approximants, while for Ftri3LoopConstNl1CFPade71 *)
(* (Ftri3LoopConstNl1CAPade71) we enhance it to Re[z[w0]]\[GreaterEqual]-100 && Abs[w0]\[LessEqual]1.2 *)
(* (Re[z[w0]]\[GreaterEqual]-10000 && Abs[w0]\[LessEqual]1.2) to remove Pades with unphysical behaviour. *)

(* Sample Pades for the 3-loop triangle form factor with LME to z^4 and THR to (1-z) *)
(* Mean and weighted standard deviation *)
Ftri3Loop41[z_] := Module[{const,ls},
const = Ftri3LoopConstPade41[z];
ls = Ftri3LoopLsPade41[z];
{Mean[const] + Mean[ls]*(Log[4*z]-I*Pi),
  Sqrt[(StandardDeviation[Re[const]]*80/Length[const])^2 + (StandardDeviation[Re[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2] + 
I*Sqrt[(StandardDeviation[Im[const]]*80/Length[const])^2 + (StandardDeviation[Im[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2]}
];
(* from 20 each of [4/1], [3/2] and [2/3] Pades for the non-logarithmic part *)
Ftri3LoopConstPade41[z_] = {((21.12490074539452469961598302830056228632753382239680288903087167373817184263944`49.69897000433602+ 80.4475377983364950047645772047970846665030599578549768227143`49.69897000433602 w+155.4365083552787158311904322321254755358503086675342695389368`49.69897000433602 w^2+7.5789819429386128083698857226270631787121964715044524864694`48.58452166385333 w^3-34.7863882707753169728562412457290470950996905008345403570016`49.22848399662938 w^4)/(1+0.97835230916003314853163745911867979088188899242508803050981465793358473231965`49.52287874528033 w)+32.86195898015769169465638538544323634109914477462254180913019774584461530552216`50.153683771925266 THRSub[2,1]-17.38960916809752841563145103134613362597581548243636836475194562242085248052226`50.561002958045805 THRSub[2,2])/(1+0.37890626573074888172812510079431802116052282320130117829199958170605165154739`50. z),((30.92997244633249933085646724535597676856718595194349823288671863937608065317091`49.69897000433602+ 109.2198741777403946918337346688153544911218221585830496631839`49.69897000433602 w+317.3081673490027579894639497548256689439419863260815652419408`49.69897000433602 w^2-73.0641739464468149084738755078126691103685952041284538474652`49.20170458775709 w^3-30.5715358050616650804439864309998334169421998870473906003671`48.843064687135396 w^4)/(1+0.76694224760839528571570455126796734589901477260942401623027485163393978935038`49.52287874528033 w)+56.7599665527750904476326014821238372231100964833823347453157`49.82915674015012 THRSub[2,1]-30.03575153091224477391699747297157230137514337889485628427538825076135905982538`50.236475926270664 THRSub[2,2])/(1+1.3816800930689292787116433992923774952802026929004012801839058923079045247052`50. z),((49.24381441541395729093275197352247117148083944231280533798157731837162629394301`49.69897000433602+ 169.2131417473276704671784865476975212305016744554791115864207`49.69897000433602 w+637.5911926277440356721780110984287871472909469057234939125719`49.69897000433602 w^2-208.3503014034285115239187718591640698346595489131438482541039`49.32225989558335 w^3-31.6980069052659549438809707513692571635013211607362769022051`48.546108702418785 w^4)/(1+0.72451889839200401479584555154382673256843403565975886317998610530930705757525`49.52287874528033 w)+101.3964921601257319286332921186861261862130825755539553782189`49.70904024246402 THRSub[2,1]-53.65612472297567410491531554593145158017533948638930346082245988873445576920149`50.116359428584566 THRSub[2,2])/(1+3.25465379124653768996797586599042173868306379047629940598661290822713442866712`50. z),((18.52900673258953186550361877235173716925046840766637418689004682853575036573736`49.69897000433602+ 88.5268243730365367032771763952716558473966372209605591499556`49.69897000433602 w+157.6187980277373064275316735076609410829097040950448587419478`49.640204444433884 w^2+67.4846402320587309005225708095779607496871695772850799100082`49.37850274901734 w^3-58.5546979007597472152069932748542820318507918694610522206505`49.44171212061106 w^4)/(1+1.91892852140924339048391098024574261889381518921090041168557716231367575953648`49.52287874528033 w)+26.53495835559404680486900618043513241970205647999115580757436476601014422917661`50.58464412253707 THRSub[2,1]-14.041541326679305544067935170342894261116407276005930658169222247999744732742`50.99196330865762 THRSub[2,2])/(1+0.11342176403804709259458038695577809155331329630119007784918043575877061728855`50. z),((36.48680696317077638855367304890735459101685578995580729478492871007239213807398`49.69897000433602+ 127.2678155007722590039239635679903621137839082688175082644404`49.69897000433602 w+414.0434722159213171591404788089774589736562993374819728158381`49.69897000433602 w^2-114.494066761849354846639782628113207277403626987343711296992`49.266043472178666 w^3-30.6898940726580091197535290463542716392377763325143684458327`48.72470200708757 w^4)/(1+0.74531109835078857411823423971057769653581083036798849276505279417554556654356`49.52287874528033 w)+70.3036995731546570080752709899672992884244326540990255755027`49.77246952145873 THRSub[2,1]-37.20270782964253948376323385904411213584119629351917501469542515939850586049924`50.17978870757927 THRSub[2,2])/(1+1.94998274156478617907000799999011278380371002573180130810296318202825292514729`50. z),((19.10251019419940650278149513648042012942496338568237588076638850920530489281565`49.69897000433602+ 81.2441596625183991242071298464344113924197245681281392460117`49.69897000433602 w+141.3624702870474333496575173725655768883387487931551443726494`49.68193072698438 w^2+40.7392853585043990634229670401943567273764900297567676405222`49.26174499383014 w^3-45.3612653858630537207347947242112193485227899948260555569014`49.385857490370526 w^4)/(1+1.40132846143896050911389514893543102451649672285861688849949247514793742200325`49.52287874528033 w)+27.93276456104626893941578507497290392833833992780493129008594124897612152515148`50.42591951947124 THRSub[2,1]-14.78122040729140538285061879547720424679232202036719096716096886493982141660193`50.83323870559179 THRSub[2,2])/(1+0.17207449792220771764087968932310506433801082409015854523464119396657783145686`50. z),((18.82298538411852230323993388241062815143483521071971084544109532717327394655319`49.69897000433602+ 83.5703547300748740728151854364885827843231222792528913040406`49.69897000433602 w+145.7756952102097113276867698849083398844779915837848090321514`49.66385660901177 w^2+50.7675196882003566794264118840065603061052278914901121164767`49.32021538733436 w^3-50.0230934133488942284115289545218574932510054960779272187486`49.41240000501218 w^4)/(1+1.58467275241876653085650633775279752316438765319545253764011511074826238716729`49.52287874528033 w)+27.25147571056204666249270560947327442174370693582054927786077122800341044774644`50.49409886816744 THRSub[2,1]-14.4207018256798654617385550093077391669910771103803756833952084986017453467121`50.90141805428799 THRSub[2,2])/(1+0.14348723490260408617849766992633482633588089172468498752612061117042136049198`50. z),((18.53003673240949152568852945722171574889620007497739624028362122167668438545448`49.69897000433602+ 88.5016750414241658978847344099189049215411027893744356865173`49.69897000433602 w+157.5549712913192327323196071846980122308169817394686269163235`49.64029817095059 w^2+67.4069308662228577640264761963106654879228544958132090359195`49.378303314174914 w^3-58.5135484052944701735241177564298774920712136326955856387772`49.44160706145552 w^4)/(1+1.91731883823188380120282725067409263243069153884321364699626102870094691153254`49.52287874528033 w)+26.53746878532347303609567202630082643004521269049904358805619848287962094336942`50.584282050122695 THRSub[2,1]-14.04286977431887123325234288344033090274827131707273222096546743836633788002615`50.99160123624325 THRSub[2,2])/(1+0.1135271030802409176359609968013178332361313935661646136084414137294392463249`50. z),((18.70653785796752350210819190730558442263737605691643970182337753226694455831905`49.69897000433602+ 85.0986733175439042920684730272144060143811362422241455595331`49.69897000433602 w+149.2188005972156465663307054161431386865363560742451505131112`49.655166474431496 w^2+56.3198629363422615901321843549666658289281453951526185843501`49.34365016132562 w^3-52.7735115884669972183881700358161694074307652353029335463258`49.42384437591183 w^4)/(1+1.69256489330077083770842299733606648692642893633779458374094629224431081595552`49.52287874528033 w)+26.96765689243928708379688858769267131793465485670997223909201729804780816104323`50.527181918198764 THRSub[2,1]-14.27051302151617462775530619719603878116462589977611038818208561122515869866133`50.93450110431931 THRSub[2,2])/(1+0.1315780378009317553637244452920296355657836004947069862290995232998179042568`50. z),((41.2845296871850070444962060929762045639144056008034767616124582778958589570129`49.69897000433602+ 142.9959459549123022549038439907033623151848196425807187875656`49.69897000433602 w+497.9819388487805862541315790751681102028265186656812198390931`49.69897000433602 w^2-149.9069921327926879997577334564393375526764571946116520324018`49.2949408387364 w^3-31.0016094855568015557489277712330132846135745667201710202852`48.64645261254682 w^4)/(1+0.73484814169708031819631640789126535244548370180939104838026949897015556532297`49.52287874528033 w)+81.9972411898714845956354925112026992013842409713210383845829`49.741815789522775 THRSub[2,1]-43.39059573457148541884940150383432958528314871691789968097397144237635793331316`50.149134975643314 THRSub[2,2])/(1+2.44065031903970427810853878929789490420137408858977925101870914820515653816194`50. z),((20.30122584316461699988359585516036632824467871279546848988103873638536967503801`49.69897000433602+ 79.3390539657674661576078425722040822922625958922392855248822`49.69897000433602 w+145.5930340681794496317578766409935139944776541160988044183549`49.69897000433602 w^2+17.5650776630636946587920829313725993970284271733865044710723`48.949762688831896 w^3-37.0257674211521069177949331458638732470071261762833894496215`49.28607004340696 w^4)/(1+1.06986583094736428217361813156563580638128814964876695041921650000955277536176`49.52287874528033 w)+30.85440720988535425533476718948538663490311063484467481776867127963650250139697`50.23550595022517 THRSub[2,1]-16.32727016722306684396399816836069164862212183707510655081181694168232618456422`50.642825136345714 THRSub[2,2])/(1+0.2946682652975166621262952816556847765895257772065389936135139180126526148407`50. z),((18.64801572881163180389662077730636937054378235653367238211832322979959561463617`49.69897000433602+ 86.0536835285618542303532525020516716165735802288992400416736`49.69897000433602 w+151.4855296222315021941338351816244692408457787938085764085216`49.65048331809157 w^2+59.5698345337506427805967190540000657388511454658350871444749`49.35524949818658 w^3-54.4260582844658985943809088734269705482015174085725972398495`49.42967966937033 w^4)/(1+1.75732055632329400695931601771089947428640087025302662505498746197487768329326`49.52287874528033 w)+26.82502027249499807560526131624006233079917107653988992605655814045508410328237`50.54509699323013 THRSub[2,1]-14.19503380022607038019263214219545952837214122138954938774740035220400102971966`50.95241617935068 THRSub[2,2])/(1+0.12559292507278934404619228322545473180856493455672145091201874742432405946235`50. z),((85.4860544941139526717836451576644617635610554618279137476123`49.69897000433602+ 289.1362906559614023527240952677088812962365487616591492005358`49.69897000433602 w+1274.8574605445565487580316452778359859190415183235748796101198`49.69897000433602 w^2-473.1345589156849416595388868211988762236180754500425131023609`49.36333997499649 w^3-35.6515988087334172008449068417632715975239651179777244729833`48.29150674192856 w^4)/(1+0.70817211007614493803360971009270467920300269447093425400454900085911871001209`49.52287874528033 w)+189.7300968768087929048544241640158733028814069113401842226908`49.65097538179328 THRSub[2,1]-100.39974287914938605493896503652905561370354538297377720645378996715226952398875`50.058294567913826 THRSub[2,2])/(1+6.96118148461879133131069367686314815972439277325187287073726128264821845024461`50. z),((27.67488362093645194661171578026836081118282015051368177503861143639578812630372`49.69897000433602+ 98.8470898879708716084041394563792432871148315160920136850687`49.69897000433602 w+261.2144745481982126484101210241771910545270397841044085134413`49.69897000433602 w^2-48.3063888269774029120009610218768852317847628737461905171485`49.12147260329101 w^3-30.7889680994354653992337274189881750653256235340476162058425`48.934740297113656 w^4)/(1+0.79085157760880768333325596555765754590122796847337252082647293896344751474157`49.52287874528033 w)+48.82630326386559280761257527094820195654883096756184223650670154545179187201133`49.88349192019115 THRSub[2,1]-25.8374837420466231501741080610308343077353954649422476068425059253466618557844`50.29081110631169 THRSub[2,2])/(1+1.04877912310907841981136550614324496314420389331716756097625634713191808268106`50. z),((23.09053949296684857886246790087942163747772151389367759350187213955070601768378`49.69897000433602+ 85.1137079210270483794127334271913307949502903304990385172893`49.69897000433602 w+184.7256090734367224930982719272472846779992592214438393094599`49.69897000433602 w^2-11.2914003358153126819651541597631133239189515747699972609003`48.68174203676149 w^3-32.3547706879811433899636496575900632036487993860202395727306`49.11627511374768 w^4)/(1+0.87386221611938268854565678197834928828380647718540572018404995482463352820614`49.52287874528033 w)+37.65283161294219837035622934598610735470722106633227664146809261901752441220336`50.027941200493345 THRSub[2,1]-19.92480199420266349119247381178365657725600198632032789784204483960680492192541`50.43526038661389 THRSub[2,2])/(1+0.57993397365447245607453231062955845357247892199032414157165957194754426380906`50. z),((18.97214492032809007254390274884591876787736293929455176068604746976831768326133`49.69897000433602+ 82.1443895176206153192184924460902253210640246736028455540531`49.69897000433602 w+142.8908742071372540733927943864700058416294037978153186747027`49.67393594244154 w^2+44.9623983370166478083539730045371519846438838663161414740399`49.289435812570126 w^3-47.2686004247374192968409219054216495195444389466380294279634`49.39807227094553 w^4)/(1+1.47643113970938709426961615054023669442597225209551144891226299844675312673377`49.52287874528033 w)+27.61502386549530948552356722078737242395811231325251818207359458480280424732613`50.45597590435105 THRSub[2,1]-14.61308111542000715778517019244905494262403472176435355200500431280541848081338`50.863295090471595 THRSub[2,2])/(1+0.15874191978109892368044343346043426570495867596877766462487209162519991384338`50. z),((70.571299977622804817686268692224136532460307124223628528814`49.69897000433602+ 239.7361944047067051305623233318100884648225239595897480241563`49.69897000433602 w+1012.4653110548236690181634253342636768447804880156025979680564`49.69897000433602 w^2-364.2861056649029843284004611761778385766704650334412153835398`49.35348483488155 w^3-33.9553321374827709405505099035224961822407581316930835435784`48.37164105688418 w^4)/(1+0.71218367649001207229375481006212736297506667669169315727463229371843219381724`49.52287874528033 w)+153.3782039737984204476062078006811358982489236258382727939862`49.66601944168068 THRSub[2,1]-81.16336045637346813373695813863437729641689999282047072232659650591132675494644`50.07333862780123 THRSub[2,2])/(1+5.43583563030132572487793943573761526778022354740218715313097263956016309460501`50. z),((20.22801263824260616741424904740508434778620240695206347144278837977807650809272`49.69897000433602+ 79.2926185654479947721430159930166555632907995873652023235668`49.69897000433602 w+144.8675559067184321904594949820292471705709816645321392913608`49.69897000433602 w^2+18.5806086891846693770103593995944349154381608602106921134571`48.97334617670377 w^3-37.2999332448513724086959509376199237103276278624579755988099`49.291577038840344 w^4)/(1+1.08093607801941146176595327369809479448970098612006791564708113146215716126362`49.52287874528033 w)+30.67596387168167452488569789613443198822499988383076294458992051353685986673714`50.24416510394717 THRSub[2,1]-16.2328430543450339526772277348395230469306992772401955924056438148908540635595`50.65148429006771 THRSub[2,2])/(1+0.28718068254946637025043689565227048960506795734941381663212458171180707692135`50. z),((19.86059697084356447442180682408478675603500251256216381362606241496019382474291`49.69897000433602+ 79.264769300125567300914011270531743047713715247572198194921`49.69897000433602 w+141.8155152117872925365932613556147186332178381698075172291512`49.69897000433602 w^2+24.1808660626246465765250079436734656373892009387878857708881`49.08035545299864 w^3-38.9717921719028013640685222239734607336931702279897499457279`49.32029130566606 w^4)/(1+1.14805513898729284891595565626962912779382827730105044663337291350271288145686`49.52287874528033 w)+29.78045768165956465992738080190894085145113652228588310408200598230901129557624`50.292200650011424 THRSub[2,1]-15.75896678112896158638817117059107508744799216634955629363868254409461736869516`50.69951983613197 THRSub[2,2])/(1+0.24960473958247066030314692889834219164365252246867491021891156613014215528945`50. z),((19.27239059344888011014916238389603734274030145403822641163112868057663039554623`49.69897000433602+ 80.412673861250187222712427628152779799626907356418043369117`49.69897000433602 w+140.3509550281782224336369637571529905329859277320124308851587`49.69139654833324 w^2+36.0756001165814599925102217571016458767115136779550382288799`49.22439564235471 w^3-43.36930067740583143334577234546378351649797947733151165419`49.3703675861477 w^4)/(1+1.32271156256810199431402499253401651336854232729214852336753254282048199412254`49.52287874528033 w)+28.34681590014201646775210831829552082997340953101330669264339248490248741416018`50.390535623528606 THRSub[2,1]-15.00032453820307749394376821870991629084513746900063936349132933053944887538575`50.79785480964915 THRSub[2,2])/(1+0.18944832478864833622454501771147537432137930034005346771990148807702612089709`50. z),((25.2236488664669285210383476835768421465829414083105894947536244499923670098301`49.69897000433602+ 81.3741816610585963248266850050708736767413650818171348566976`49.69897000433602 w+186.9303169574799943294724149248760066945055726810046437730764`49.69897000433602 w^2-106.652034690121530544568348934235714127257986104883540761398`49.5416466287128 w^3)/(1+0.42988774149033411249274933693969712111257650268133213025587516404455577122403`49.52287874528033 w-0.19999102028824020450549677031574818573973717625636425817504917717064628486505`49.27496132596763 w^2)+42.85188221817637407695918890374579670742308958787928696960745312094447975129759`49.94544065531943 THRSub[2,1]-22.67599093351006038018410636643647712325620694648198199939265381831457828504902`50.352759841439976 THRSub[2,2])/(1+0.79808905867960280649629246952941638176686260189124993459111159078432622409596`50. z),((19.63292391847546804936815052114517063832420414312337544777514786733177477309733`49.69897000433602+ 58.8951947283367702799912915769624225427301581317556591459265262176535175650335`49.69897000433602 w+75.9641050642469633095449947714501955347649584596041942931642`49.69897000433602 w^2-65.9560242497582081671408947048465507506753283542705248928196`49.69897000433602 w^3)/(1+0.15426463801424998614095253637086193762082844598340237102655129277102719888683`49.52287874528033 w-0.30826218222707272411752310846509988077906662622258272827457723292677693181665`49.69897000433602 w^2)+29.22554768247483718323592446534721921023733551751931100624850317628132849418326`50.326561058178676 THRSub[2,1]-15.46532427445069952366824054141989886223550702496360362443907893215426136621249`50.733880244299215 THRSub[2,2])/(1+0.2263204041825488104529368216738539003100126172256111365160392992579510788013`50. z),((18.77381344901215514117011972435367316724889037104866823672730779151394641405466`49.69897000433602+ 54.54248691939151384269945362920426787547221722895798848562863431855806958997113`49.69897000433602 w+56.55318713138506819441299022106878633474468844159415551841888580567978426348275`49.69897000433602 w^2-58.37743955821768848707391334978306156166016969199929909889359860165312607933404`49.69897000433602 w^3)/(1+0.04950410643273469218724657259490195510536696722746605753774416710969085683703`49.52287874528033 w-0.31622361056027434173829028326887477659691574199358921234590420891129883582886`49.69897000433602 w^2)+27.13162841995836856417104699924747751493362811696268976580937214059327938601863`50.50767873926252 THRSub[2,1]-14.35728206592933556012537805458219011612215809588447609770187816006118748350271`50.91499792538306 THRSub[2,2])/(1+0.13845837524015822227694628950509282078260875275344035913622138782060240919598`50. z),((49.93739134999302297920661496357354999126491634926127557445406245480702918596576`49.69897000433602+ 165.5006201251556974115311225890582169513290151990805795519299`49.69897000433602 w+629.7117049640863522588557432551303996289790859634643763199019`49.69897000433602 w^2-290.0207907269493907122861696153811416808984310109937689014238`49.40638588689514 w^3)/(1+0.60368230714086891945427107319929574692656180971703776923840810376121380325858`49.52287874528033 w-0.07591053745876243876718690961463524323722362936209821066412230038069958456465`48.72896834636432 w^2)+103.0869547431966607182284319753402039435988871782849456533107`49.70685756497425 THRSub[2,1]-54.55066919157068026842284794687398461772128844553429472955163357677300433426171`50.114176751094796 THRSub[2,2])/(1+3.32558655119512626867604218116362179044890580584322992151044075438531824128234`50. z),((81.0157132667800956157773199589312211289957652556741616310562`49.69897000433602+ 268.5950249205040112062621853410715966025455233389114142827708`49.69897000433602 w+1177.1040020639052969859876550452443821115634394484673540749441`49.69897000433602 w^2-524.3136998498184148287904853623371875047300864562443769783814`49.38338588869972 w^3)/(1+0.63843360695984716913518258384352099126477323591486274752904244794048296435381`49.52287874528033 w-0.04635572031063213633075189514912121524772314062950499036400396588998510467181`48.49248501329977 w^2)+178.8344857317328761678461078053727861841999373731503535789435`49.65479314654582 THRSub[2,1]-94.63409696696133009615453527012889913973738781506182560282392351629772557964876`50.062112332666366 THRSub[2,2])/(1+6.50399551813448690961915944358115019797356251122697803933860952706098822817799`50. z),((18.98998647814741248923905406625543120638354200226753642543438959589013435555539`49.69897000433602+ 55.68754075536472920260397544271318616504301350749254510188962214645895121525925`49.69897000433602 w+61.54645174477159635863580078824164698343906212689156024928552529420666197709392`49.69897000433602 w^2-60.43486426652523335745820707870348118308198772112535798075547751140589599824687`49.69897000433602 w^3)/(1+0.07937967091663179480802906954593798855301792222269797547541918048552240182394`49.52287874528033 w-0.31610072905481981173536242210748964801058343095806579760312431497059892422939`49.69897000433602 w^2)+27.6585092878234980753802073007791876247480173765413079652502907969438505305195`50.45169568781814 THRSub[2,1]-14.63609235766680861701943968173466796601739228695328235497302162385801716395275`50.85901487393868 THRSub[2,2])/(1+0.16056659253881530862899764395613014840216501843398635039822192141300932114494`50. z),((19.48553444216990767508834095318230683508423781455980488404982312415068438316535`49.69897000433602+ 58.18300482205454532884052022419898053360411245765382518493483150857997944684345`49.69897000433602 w+72.7127213564210956346252404784550575470374124772261963074071`49.69897000433602 w^2-64.7489323245788459484077557691064828043453140185245599454159`49.69897000433602 w^3)/(1+0.1387221111629037311030814201948609025462436955259612604996613619276422570709`49.52287874528033 w-0.31073356697985466912582318643049195965488334156625776541866723507402554436415`49.69897000433602 w^2)+28.8663137137382860634965153741903580756259019949212518763724588574367088775606`50.35112341104872 THRSub[2,1]-15.2752279287031699698648703550274788894978917214334956700608276094811847780234`50.75844259716926 THRSub[2,2])/(1+0.21124674498124402860483104025238218446101341664788478729156735576509209916548`50. z),((104.5030790681056496227022988150924315752824574349953555871362`49.69897000433602+ 346.2738647602038276766687639926428651937673773991968655196512`49.69897000433602 w+1589.940970232097682749748911795295095748935468043263599068224`49.69897000433602 w^2-701.8077779222482212701454751050882099436560580706880364430299`49.37690255617288 w^3)/(1+0.64873963509855272409220537772879969381037181802013059649075472555726770485625`49.52287874528033 w-0.03729561401661238840170428857627103085094885723931795754337661302153031934749`48.39157898592476 w^2)+236.0804970716823536688056385510485782589753164374215212280065`49.6388961005513 THRSub[2,1]-124.92704950321404147888640545874642391111815098271499845348588050958380208384437`50.04621528667185 THRSub[2,2])/(1+8.90607032360827339150000076809400254001305702551717009445533218825771136519095`50. z),((69.7013916848411765195876813615766569748179308501203821207051`49.69897000433602+ 231.1294457970725581739213509559288562094680638804401557380677`49.69897000433602 w+978.0635699806644296230227521985696012915456503490820782857616`49.69897000433602 w^2-438.8980122440058052424651367722270145393929772440097089538433`49.38859751834137 w^3)/(1+0.6303277934445510886287530998201612324118420592129196129826260641746397398875`49.52287874528033 w-0.05338704457616309863928485442530562117654550007846553396630371554018854437699`48.55894554428063 w^2)+151.2579670594279423747413812899146003130203969138265971008142`49.66714080071575 THRSub[2,1]-80.04139169891326529598332127576341101401612711612422287447922332952246377166974`50.07445998683629 THRSub[2,2])/(1+5.34686929789781992973531276080048075397056602699111659970862840302216373110428`50. z),((105.5126162633072969272416447427473010843661730482132958296596`49.69897000433602+ 349.6109109147012379159129806248942014645138287134904838769471`49.69897000433602 w+1607.6791416625684441857136372031033091907507274853193457267148`49.69897000433602 w^2-709.4402149174294957533092666335505923734182989846739166681976`49.37670171506698 w^3)/(1+0.64906311770394238250277190787740196706957964470063568703476640950310384518214`49.52287874528033 w-0.0370090644362068100142004862494529759686604210339484462454167294777270732642`48.3880276149282 w^2)+238.5410530239106231769436966596891121193973408477972091968918`49.6383933912446 THRSub[2,1]-126.22910536577906547660002639742743947827487431328905004586348659274066130598032`50.045712577365144 THRSub[2,2])/(1+9.00931663408408206648649657242986704011344152233958092910520958565460216140257`50. z),((101.9394434361610244239574528981684423037330726006359884075655`49.69897000433602+ 337.799219378975374548077490495176618765052823017126260004761`49.69897000433602 w+1544.8945435823996730703432304825314353125657119656443847270876`49.69897000433602 w^2-682.4267956976144593538780070981788175088162918267400976988517`49.377434253244914 w^3)/(1+0.64788453256800025228665088288171659559173370943710389930923436763116549066914`49.52287874528033 w-0.03805245044547597208825580071417144111512275664605231885394197821618672330736`48.40083738431169 w^2)+229.8321201485657563178405766518179953910370336916026554569115`49.64022385693067 THRSub[2,1]-121.62058707674807048808641774329774920947013292746939902874642969034113925094831`50.04754304305121 THRSub[2,2])/(1+8.6438849166112268203960444489193666136057915368779012457753585398471435656372`50. z),((93.79545455567233197312760911143399408779371973157416230569`49.69897000433602+ 310.8721183130337053783103199862654555369936196006162531256452`49.69897000433602 w+1401.774171117716263868669191127900426850008108618242190476579`49.69897000433602 w^2-620.868969645004219761943489337384400271080545521235300510082`49.37936141998883 w^3)/(1+0.6448003611163766546998268644489369987243617502943158879979514098974642365254`49.52287874528033 w-0.04077452175345628106837797236822287808634612743264717629426371833448842102898`48.432771704145225 w^2)+209.9826877452705922661016145075108893271610169506550965258829`49.64499943045885 THRSub[2,1]-111.11683494467668575824935653963571071357431930943647302207892717890634366838844`50.0523186165794 THRSub[2,2])/(1+7.8109915784925472466308518758362660025883241509233775587436116708763996264116`50. z),((19.30603921860506161529783088743776638908828787614642338672917523824172978805078`49.69897000433602+ 57.29809907857916652154174218311888371762892733695560437980569356892129478736465`49.69897000433602 w+68.7112802107014416252563867469259859170737240886418221779137`49.69897000433602 w^2-63.23787105526041647440925502150407710605821391175718998741205900232203963290644`49.69897000433602 w^3)/(1+0.11856288406484687834287286227083798023832365421786511376780313973554100149104`49.52287874528033 w-0.313292812311646812052242282543418779118332923044527392822522949586729909086`49.69897000433602 w^2)+28.42882805908560324308570232903472581110970194956404808935095104762200141458268`50.38397225166484 THRSub[2,1]-15.04372302798641617175467463713724687191304251597325726160732664669040836494043`50.79129143778538 THRSub[2,2])/(1+0.19288960106501703184474063822336453030448616736359684329231896637878702545162`50. z),((19.25203636496210732462125797423834200105502980076409947246848961138535375133759`49.69897000433602+ 57.02783501688345249469266011355658908891541706432687569061214931782333679162907`49.69897000433602 w+67.4980525188982149627777400970527689881713652282760284330427`49.69897000433602 w^2-62.77300800509756918630375815672192383581778145114584531118214309490248422009901`49.69897000433602 w^3)/(1+0.11221481010082144319010734099524439726883253818094750692592222909591325313508`49.52287874528033 w-0.31394456498057154076415636354796421006247059880812892266512880570966785898703`49.69897000433602 w^2)+28.29720631835128379248888092452403744220260896283334271456911441484362753166161`50.394573312176384 THRSub[2,1]-14.97407256585856483540171510044584692335709828595431242332811134482250160361037`50.80189249829693 THRSub[2,2])/(1+0.18736667885838507919814254433954682070952375598430468397543646448016899886392`50. z),((18.42772259517786577299893033030520110950565534916170797708782780256186640083854`49.69897000433602+ 52.62441450646999597963865652377584780502069527158639712456834264382536439635992`49.69897000433602 w+48.39749014858337885804256961279002230642543106853103326212116903071460900297572`49.69897000433602 w^2-54.73835948714918244695926088351260092953497691572394577934259052796258100388376`49.69897000433602 w^3)/(1-0.00439039116268793814607580120937832543415185833441355483630761710758129406911`49.52287874528033 w-0.31167615750873303098491299792531153583267350868557698836530655763449439635029`49.69897000433602 w^2)+26.28809742926155826492263017214921465669478414518611062798539418239851411656554`50.62217704918114 THRSub[2,1]-13.91090958222400613134942174776609497757788375020372771147169338057213941816017`51.029496235301686 THRSub[2,2])/(1+0.10306334084454544245877206727026242808812797850235357311180621453866923263685`50. z),((18.96016853610118533398866348218228344080197163601574146566244451843938803985427`49.69897000433602+ 55.53181929106829029537433071780946149577238707674382912576317366031572451940927`49.69897000433602 w+60.86227796378383389960982871476978490575465868600950857130049592747739171304033`49.69897000433602 w^2-60.15883842426741038084650024516192137371975082026678983831984068797722927686071`49.69897000433602 w^3)/(1+0.07541647319779907153147891660648168988043574200941084160313124450539603702608`49.52287874528033 w-0.31621998744764506958868745606700454020567843948502772407561694730019833575265`49.69897000433602 w^2)+27.58583369435971591584106420150518441566690748785491217103935240670581078464928`50.45888056050586 THRSub[2,1]-14.59763451140274969419949203735744210672386984349551544822120206025669091784778`50.86619974662641 THRSub[2,2])/(1+0.15751708379670351998982481539858714176443676545664527788413186302968331942795`50. z),((83.2849401932754271288646734091323139507307429119530850410814`49.69897000433602+ 276.1044774791451725175634191522625578406837933095443669742374`49.69897000433602 w+1217.0067431845931951319888737165965129145806764691671660471106`49.69897000433602 w^2-541.453669562755751854588343141762605430822128551680944852158`49.38255676950892 w^3)/(1+0.63973735980552719206619095577009740490543166084911150995791030475973115434179`49.52287874528033 w-0.04521700910380578274874628183726825967221776935653821667986773589042592683189`48.48086258665363 w^2)+184.3652971247984645633066626763224492925736624115683704506197`49.65279460080214 THRSub[2,1]-97.5608442301401637252498793518183469528386444816099755786786942445431600574925`50.06011378692268 THRSub[2,2])/(1+6.73607147225146679711733332929846752244181254927490421199676617756848460260774`50. z),((59.05528766376064068906575710091831023474308528394722191744708380324361782434131`49.69897000433602+ 195.8210748149040352465530627932235525354234582870521369936307`49.69897000433602 w+790.5765324510024355275140717332465879514893223365051023978636`49.69897000433602 w^2-358.6278084443392879374412222680121398143531643788669506562961`49.39608998535581 w^3)/(1+0.61892488189235391234289488607763006131880056772732106596199688235941504630487`49.52287874528033 w-0.06313695365140644424344956755600749206586016109633893594992954861605143423768`48.639078346076595 w^2)+125.3101022936540474871450228777970030431897633691739263848965`49.68429414190625 THRSub[2,1]-66.31052351494685388702458683662946007244833388463984166470260494154016045398375`50.091613328026796 THRSub[2,2])/(1+4.25808231080846833412736151525077700836325806387037416184047573542140233236595`50. z),((18.43721113063458160200379820941652594153222569506015906446686220675304837718579`49.69897000433602+ 52.67851496385436141831866867795048558018988300013126562636653135046350935874319`49.69897000433602 w+48.62369802346960287326790737298744617392759582238228577929899247961666620101441`49.69897000433602 w^2-54.84530301315168835679201713435067308049327098246498648993500315686548891928446`49.69897000433602 w^3)/(1-0.00280371126467465623718647359235982513712116740084026618306743727366799804942`49.52287874528033 w-0.3119028588511491387132411648101850022990841664353935566354382928023261289877`49.69897000433602 w^2)+26.3112239396139457431038939438566294661790482698812502541938182267187140762603`50.618488939825305 THRSub[2,1]-13.9231474703149993567286767623614433993933882190857013298646578813847433020381`51.02580812594585 THRSub[2,2])/(1+0.10403374221497649698361026748792377587367925130809652730619205928549855726292`50. z),((19.95644219518604934247553375651265317905153122646114947274465047645584155509824`49.69897000433602+ 60.41755429818580395281092959581597439392291263571023383374896777896035887387285`49.69897000433602 w+83.0000800740866404302896387478809624003576283842385319256574`49.69897000433602 w^2-68.5227295912961794652121019896375559286673416249791739067809`49.69897000433602 w^3)/(1+0.18552635941151259237787797921465426451437302453479324009340031283439837226056`49.52287874528033 w-0.3020161085959700917767534867066283922749867504172199981585117245488861987756`49.69202576191616 w^2)+30.01406228619466475789364792278371225773292129478230822024651962734569419811894`50.27886533181887 THRSub[2,1]-15.88258365908764379193034912816629256667288512300667327748016296175595493544463`50.68618451793942 THRSub[2,2])/(1+0.25940692006390517028460025119903801475881416779534925166617642114785638778262`50. z),((95.4036131117899920260452511779821883391117807731471573286737`49.69897000433602+ 353.9944815263155889152105141778032556096830147522753557503659`49.69897000433602 w+1567.2548379989857202683262847873561189906628929363430143273619`49.62402121102801 w^2)/(1+1.0417168486924321981126912534694609244872917979831951179278578558616362757085`49.52287874528033 w+0.34055612919145431697376579842836221278009515684286955036381969090584698943675`48.291723154249766 w^2+0.34608174843318015960375257874373392461044565753581059841277806686475274852061`47.67236493192881 w^3)+213.9022700312821094695244532575035418982480729312643877483073`49.64398179175588 THRSub[2,1]-113.19096582948163889103302118559587917690872048412836469632952399236700850380561`50.051300977876416 THRSub[2,2])/(1+7.97545945384020852255394683971858250584549119169060683020565742065433915735346`50. z),((19.82813050008010526535680081071787627075233766075095916779357527731654343960373`49.69897000433602+ 71.597358099941632824349703436668574556628578349210707472198`49.69897000433602 w+119.6315661593926889196138788604251326936848645444292058285175`49.69897000433602 w^2)/(1+0.76753619618944349162767993021033389078648998387639355047514851535564696313803`49.52287874528033 w-0.0060798712413864724023508926440620695502560553371957319085118173511679567508`47.071801440429816 w^2+0.26527936588584280256698804431134178946350125800260553770902253601083407814373`48.470428140979756 w^3)+29.70132680043540320901462757352725660524407253770658383887337923908460368480848`50.296861120766714 THRSub[2,1]-15.71709298113894311583088791866913528147160858492890345266713506498553633079937`50.70418030688727 THRSub[2,2])/(1+0.2462843633383558214365635955456639459621251618070193928659087411066101606221`50. z),((89.8875171808940679389918575149588559742189097292611533015429`49.69897000433602+ 333.6055888505904343796306408991911011514559613225014090068701`49.69897000433602 w+1462.5112554995490494426837660744914857196116247933265099109408`49.61889365388507 w^2)/(1+1.03977979394199818493911222604330160438203576086466184024068540301356020107923`49.52287874528033 w+0.33778239076682589891013135181299393414715817239818361023291815607571460556588`48.28210724690851 w^2+0.34477725196274164791974333198893891521673570896706121338365069340223829878599`47.66872512349677 w^3)+200.4578296081463694955632116436209352676702200170434320881355`49.647649382022934 THRSub[2,1]-106.07655233443502088163216490654676814415261345854687049789575838020743515588327`50.05496856814348 THRSub[2,2])/(1+7.41132317852261718537125512815517816038667542851187250001851491346404063681809`50. z),((62.34086489216612468069090676508085961734861507799627171909572922878646711857005`49.69897000433602+ 231.7107855020030359606024426505978002078172691101454621036294`49.69897000433602 w+939.1130962440052042081939631779044616563464159990767233759462`49.572148903195114 w^2)/(1+1.02376700155311311841778990391711689966697414522530641033940919686634112924713`49.52287874528033 w+0.31502560565949250110229683859243034906462078478726306033875289571537747890136`48.195532216459945 w^2+0.3345546095849383656175982285679984913925262682384522553802827018510946430387`47.63168601558288 w^3)+133.3180752978027336896392986591162691582214360390069559651189`49.678210572199646 THRSub[2,1]-70.54811388060049842625053532530043860590144939687534676618638459174580872079775`50.08552975832019 THRSub[2,2])/(1+4.59410135817842900044709316742284570227885212227166396261202926242371099226348`50. z),((20.33628005576654874366326770877437544110537278540623961232275942355858031642698`49.69897000433602+ 73.7305752911135306697329605813991491340254392053571903867094`49.69897000433602 w+130.2802786935877360913395496445811506004280724015250625865042`49.69897000433602 w^2)/(1+0.78771353053593364840085592451455123697741473474528928379859660411648218359619`49.52287874528033 w+0.01568173378007201167664741836855427809400183328930866586426615833448796774948`47.400925314150115 w^2+0.26649651686474088353176086699113327023284849958663001688495130259430911613451`48.370510875130634 w^3)+30.93984522235118521642648465096678437955730569594868766453835348214154591156987`50.23145500010713 THRSub[2,1]-16.37248152074514209873551602047125732607886095421296979951685430773081896436842`50.638774186227685 THRSub[2,2])/(1+0.29825329231285227720840572855326521244078808460920030781986132501708380035234`50. z),((31.74283434929029815258256007450866307755864033839332052468716614825149311108404`49.69897000433602+ 117.8972465403514218890143617096027430977552799383698263348478`49.69897000433602 w+355.0655988563186702924264106327510636290934672873784442780636`49.04180360047678 w^2)/(1+0.95349900225108473755435096004595375189896168183639353841209801500423888690057`49.52287874528033 w+0.21869921961130742855111933261126473285658950396366912352814831006105767406742`47.4085906706521 w^2+0.3001884197616496217895984574720086083055209540732921232336`47.07730513714605 w^3)+58.7411636826766854268877464759862758886329040855806216439273`49.818682695815355 THRSub[2,1]-31.08414440958231495232325602263826286848433632802353761231381968632786539334911`50.22600188193591 THRSub[2,2])/(1+1.4648122379820983136738508825060316649525044009607051541892761801495041597182`50. z),((45.31586110771155673149367475876634358476553802957168750170723226708261359258712`49.69897000433602+ 168.5772995489556473588484701575016344509180494978367306724562`49.69897000433602 w+614.9575455178177242711391513719095585308547313703648282225484`49.484179463524455 w^2)/(1+1.00064619065543017678531174502233570392563565332627766727276761174448684772306`49.52287874528033 w+0.28270122505215966543376760143840195568127801279648766769080651387231716131681`48.04011912951758 w^2+0.3214635093047532894332698026998718458110927412089362739873`47.5490754815222 w^3)+91.8228489726537123688396266390144241572756248328700944673029`49.723180487211565 THRSub[2,1]-48.59002645885572434798839654566750151660432573263452897499671794059494320983334`50.13049967333211 THRSub[2,2])/(1+2.85293834314903905610134856749104661896682462405308901093282986879350264093807`50. z),((46.16223824643901241918610251901410110678861331168156900887729074084916974857092`49.69897000433602+ 171.7224517169581663944317558796485731121959204444541298988465`49.69897000433602 w+631.100276039456369338631463404936191261303395163413688369152`49.491805090915946 w^2)/(1+1.00234031372008611880743674459306488559388699673250372211401527782904576305562`49.52287874528033 w+0.28504856732257442743244514569718942791402881763642585182748294688410242151605`48.05314210033045 w^2+0.3223591850736733169530353755346944398381849154164122559947`47.5566819612294 w^3)+93.8857331501007829122537323427584928506319208053142053096224`49.71984852458287 THRSub[2,1]-49.68164578765219548520836927157521932592827083930446317528990577062410565803581`50.12716771070341 THRSub[2,2])/(1+2.93949812248161425079300472159014412455434306009667509054274352726560770238904`50. z),((39.21561443851986797667565976881912462575805832119302900993855835499416391648363`49.69897000433602+ 145.8708961903272289524487032918496343734485980001292913836344`49.69897000433602 w+498.4499348776747649286392498456094453428262839500052968979001`49.40188582052502 w^2)/(1+0.98530949018639002427725310409777286752567413581779013920046648302162150928211`49.52287874528033 w+0.26160174443513646619557512919392102522874953481071452850528375445946610002168`47.9051592332688 w^2+0.313788100514769438100850985406179488718499457239864917495`47.46397014193115 w^3)+76.954651621151321035941139156790518607249106144233452819625`49.7536351443254 THRSub[2,1]-40.72220150256248622719559405325395324743220301917959427089330615725271532149808`50.16095433044594 THRSub[2,2])/(1+2.22906042703067401536063160629638810540283815840152066698768600617730315582211`50. z),((19.11125177615969347205616403809695712764161099096837032228145399868795383695934`49.69897000433602+ 68.5034384785389070945739720864839259689660503987683075183662`49.69897000433602 w+104.309000517682036621380257180695379158242710571175169505801`49.69897000433602 w^2)/(1+0.73282698981651970859474069061990127880685114189017286370734443093127346832907`49.52287874528033 w-0.04141394200295635012720103251704052675567032850860470234453016125388922533979`48.02830634110661 w^2+0.26398877008889935524120222036811679621731033158907274824635190456520278379493`48.628280054691515 w^3)+27.95407051354262949064809154121192854206551197244929032081130638515698569852842`50.42400012761007 THRSub[2,1]-14.79249490821478228766155429195408812753668393503996422492380421945051429186551`50.83131931373062 THRSub[2,2])/(1+0.17296850766192933532159936956486387161232314363663272354723963244300666236002`50. z),((19.06652778262519562499250270985292232220980142538381236958089168170285131536214`49.69897000433602+ 68.3061753387272092531810651906413158680381443517664900126336`49.69897000433602 w+103.3384349704230500495305593050687196322223712491543122075428`49.69897000433602 w^2)/(1+0.73035257995617142994470129209225264266498025329711333428561250144174018512294`49.52287874528033 w-0.04381950739632176064445812268282494981870121410176887057250681073302015535181`48.061018722067544 w^2+0.26392703296177867121099687574692741779303970121289837966186133668960388614256`48.638961304567864 w^3)+27.84506423916088519293272898438281471400263826726810301614014306748145512691787`50.43394231988825 THRSub[2,1]-14.73481190430398380701730743441962084855034415649720071961923673126252109269507`50.84126150600879 THRSub[2,2])/(1+0.16839454313231287389189874686573514351149332405718653525438137883983405223883`50. z),((76.9224151898943850547640633024157590849443154742684002381957`49.69897000433602+ 285.6679196535169851122110540038034341856361933653432563998099`49.69897000433602 w+1216.2547959529613332293406650630308937621090702916529291389049`49.60278876273404 w^2)/(1+1.03393341341053209122090727370077176083023384864854432003873426400521639587922`49.52287874528033 w+0.3294381862788573078945966399422604276050132749278040622638790871286911647251`48.252038840064564 w^2+0.34093011226927421274185818810416498811812446596827811236551978553837440960234`47.65670398540085 w^3)+168.8578459455049884850443481253353662437330739908948158474585`49.65875635781201 THRSub[2,1]-89.35474442446227876270645584574966949766734526502935205265618780049723126532859`50.066075543932556 THRSub[2,2])/(1+6.0853701062874692714728152636321393653569504841993210764903735677370707522301`50. z),((61.26640279498082139658168982794638434660834836287275418909524267165528693404526`49.69897000433602+ 227.7320411986889424965663113713380647109531274184443838460687`49.69897000433602 w+918.6794183297072403685955522196558020797048092769069366954652`49.56896769465002 w^2)/(1+1.02278014106155363847332951993332169668140242212635748326377285520187728937169`49.52287874528033 w+0.31363310125469756159535232153230697848516206921074152679728804534572189103898`48.18972651229465 w^2+0.3339564976791793032295332992033011973113985658971452503233638102166056893457`47.62894842619503 w^3)+130.6992771779921072024348956552256262154881814406592266569163`49.68010885699854 THRSub[2,1]-69.16232078709828896193090101527900832561543361209579486274934743291954212215771`50.08742804311908 THRSub[2,2])/(1+4.48421511742597799952442230708232224063736288220490285306445266874037909195797`50. z),((84.5667807897244232655099691229985161030577520012745773562107`49.69897000433602+ 313.9354899603775650248785460784537601009367258881877696908771`49.69897000433602 w+1361.4631303811411374805521411372447955590126983650862101472656`49.61309304779509 w^2)/(1+1.03763283087811470569436160324213313208060426081354369972398310206439531833341`49.52287874528033 w+0.33471337341331005681317986892891458520650438214040428644486629936301750066014`48.27125258372986 w^2+0.34334883660696325134572641309532345720012379128580904116013291775526682772676`47.66449537072407 w^3)+187.4895411094595916381542745730909171984173189243850898149614`49.651721578128054 THRSub[2,1]-99.21410482461175915705095380358561011927555692804047804002496362444661679021891`50.0590407642486 THRSub[2,2])/(1+6.86716650553058621574751922289740708078788449436323037926340023866045949980975`50. z),((109.7947160305649895973972900403293187073235878689869805941233`49.69897000433602+ 407.1754826708288076540056620615902344111111480168740811601449`49.69897000433602 w+1840.4711620114526643841510679061977837548513661412760368775702`49.6343789453055 w^2)/(1+1.04574332431216827969217020671009137346227574418590500461222808573335220076602`49.52287874528033 w+0.34633634688524082845048273999357207029618918479928101243742454474459553733446`48.31119916499927 w^2+0.34884165051838469285391988775892888344924466508319058477245677785275996492578`47.6794172672643 w^3)+248.9778612172497987432557897034264261119652344966947091383765`49.6363773888676 THRSub[2,1]-131.7519658730955230938232624685502782336580291180376712084889`50.04369657498815 THRSub[2,2])/(1+9.44725097088716293280852939832784485808264752356642319435876329336732538915713`50. z),((20.54718671787924255542023789235214697526893407970044681011207009243497706286872`49.69897000433602+ 74.6048607456833381372040535587459016796771829416370878026538`49.69897000433602 w+134.6594716264446119005408064276205611869370914510728749272528`49.69897000433602 w^2)/(1+0.79525466700039743798656753345835916549579494561347966474600891517765524450391`49.52287874528033 w+0.02401944758106386356164772720115535725802616687923949958682373881838959556`47.55320113808688 w^2+0.26706012595992277389493205612510364293109347886103140464861826104942948658873`48.331250754641964 w^3)+31.45389031676925606877839549855184929819933094141288937573309628800749199400657`50.20828690267106 THRSub[2,1]-16.64449948814950496390689412553024006665227363388967515407460773938196020332132`50.61560608879161 THRSub[2,2])/(1+0.3198229133445510683841285404403718781724117987229717270491062572615631891639`50. z),((21.42979006395510142915077223807807092279582483177886824840353620241395548328692`49.69897000433602+ 78.2086030834181179688350476486459785558816250552921792490551`49.69897000433602 w+152.7805269926880475419080414918629502835333881426841932874056`49.69897000433602 w^2)/(1+0.82263729557838926322759850196511099876298948403450761229896232724305174864159`49.52287874528033 w+0.05514387399801955095776938364177403594833079984238700850203324539023823191326`47.7841551739303 w^2+0.26968534845544256008304502501475112881130898613289273372083170012108949466858`48.177395302524815 w^3)+33.60506902218561513559789473968183603167309879460286498726029169087879217639463`50.129050284368475 THRSub[2,1]-17.78284175680463377677173327574512037978822009354717763375579705129735339958783`50.53636947048902 THRSub[2,2])/(1+0.4100875806882184907255553558349726474993020401425515211543516217341694525217`50. z),((19.35223188837717976009826018056796899047895651517537301386741024685240757750284`49.69897000433602+ 69.5568306443728057595898647025001786390991156916999200450969`49.69897000433602 w+109.5061893443466147494074864261542936552843573260356137117758`49.69897000433602 w^2)/(1+0.74547211174253338265405571355681896360747636788481141444033266654122788756232`49.52287874528033 w-0.02887471330547146072756153703644087582055296849277023927868956292780045098298`47.82865215141554 w^2+0.26436023925619826975170240575887253851946207753127214544789994745053819646726`48.5725708155119 w^3)+28.54141395398608536014977641883366359140909887426293711595138657309781837601592`50.37518039394101 THRSub[2,1]-15.1033002647342935120557015621687022645186849018454235203244609755178080533603`50.782499580061554 THRSub[2,2])/(1+0.1976137684831833300235655079615545451062599353467096994159428277093699035185`50. z),((29.89788263053124464949396038124144644376086887859097825190772056044272072874376`49.69897000433602+ 110.9400140091655696424330573713219896675119293303718693642574`49.69897000433602 w+319.4545271349460834875516047716638012711927394080331551120528`48.56672205427498 w^2)/(1+0.94149761461477053054373271031124923953960185291707042828661944543637251356431`49.52287874528033 w+0.2028151496251310296212210346754504650191539681837204271448`46.8692402902436 w^2+0.2958038993291134630112146679851489767259597049641557363405`46.58254550047068 w^3)+54.2444428538224164785442417991061436525566365801565217794577`49.8439833613265 THRSub[2,1]-28.70460830830987403535996274123522306199057222976297318466502083958304769741826`50.25130254744703 THRSub[2,2])/(1+1.27612730505119597295269389881031299488052962164582272900360852329425328967695`50. z),((42.90940821709495603998685691902006697395047400627701070148400685828950635901265`49.69897000433602+ 159.6287475108652910156147310570690845047725268253114455640843`49.69897000433602 w+569.0340267542357443592838757827768823959138077459423427255195`49.458557491513425 w^2)/(1+0.99532135842795883564082386840391816471128739665264923249641610928093575042052`49.52287874528033 w+0.27534485809359880554346374216426776162703661066992949433044041544429320848207`47.99701037382911 w^2+0.3187111365196692547346673095107188110422911378381076034202`47.52310001976049 w^3)+85.9575752493008199947321902209348927668941870496661088911832`49.73369386176235 THRSub[2,1]-45.48629129277496045180403529397687741040188145068557643159741865194885489899679`50.14101304788289 THRSub[2,2])/(1+2.6068281617006166899155528377742905987426412153918865267593002424753424799745`50. z)} /. {w->w[z],pi1->pi1full[z]};
(* and 20 each of [4/1], [3/2] and [1/4] Pades for the Ls part *)
Ftri3LoopLsPade41[z_] = {((84.7809686136295789367199789139176886837314681269452904460314`49.69897000433602+ 141.6425327657502199757311203255133526071249531881775181860466`49.522643279681816 w+1.17705192833227765261194607009760919364771926081643206839367162100205864153539`49.69897000433602 w^2-54.23735519566425550863266950989351467482974086412327198868598980896517381602797`49.69897000433602 w^3+37.6968278218023252313844619552194019612477987320573900951662`49.220795129393345 w^4)/(1+1.67204692102515609031237399194277387623654529753102681212607130265492823539103`49.52287874528033 w)+197.362252258956354165158764658803628310821027068867210983087`50.05938247081775 THRSub[2,1])/(1+6.82490404551112977795186434626802691548783672647707419801029053950578092879581`50. z),((16.29030560515407871302778042397982212621155796030264474127859973715117153421017`49.69897000433602+ 8.02196929485700909076321721791370991725137449049450630276570646768892333592764`49.32571589132854 w-3.75270740521187267149564379803002723099457489883025325953286932676311903340222`49.358691836482194 w^2+0.45465699585269485758946726792406662975685033374490725031998379598247204729324`48.94192874759632 w^3+2.32013954090994960232905313198655601589537356942758650703017862477279764022799`49.59951177935076 w^4)/(1+0.91685094507164038444165765246542919768320601890213602108857875160264900886175`49.52287874528033 w)+30.42921666743131697920778824472186542596436724407913104410291750342734383984896`50.76671201021393 THRSub[2,1])/(1+0.20643992393389758507386690470324633218560786758491982921888086901286865177314`50. z),((91.2696247554392574783901338983549186125569029086615426451817`49.69897000433602+ 153.4034958267841775587407892417237196924471071791991355067256`49.52387804774883 w+2.14028987580093923157545046931551012264602510606902037129010528564139173840991`49.69897000433602 w^2-59.60011329273150858062641924012178958780430737750834571209796741820375595823266`49.69897000433602 w^3+41.0045900177925310658322417434054099215614096131348902327875`49.218904185303984 w^4)/(1+1.67497825908609740945924497609907470483404058165126293142021578313759060340427`49.52287874528033 w)+213.1771242295758186895647188025881700729878973504269850431056`50.054687173705965 THRSub[2,1])/(1+7.4519229118127278236673392910791006983767208669690336357903004499103115035056`50. z),((94.9757919548158438646002890291441101982774397949653491823343`49.69897000433602+ 160.1183532056265560360008563837928535844356865154371087605246`49.5245032926607 w+2.69197608729453294528704261893537295969137633809383332905201169189168206685663`49.67429859298346 w^2-62.66374504523895852181909180638981987394729098911654728802994238356686822156297`49.69897000433602 w^3+42.8937721972261783154216817439379045229052555736587429139606`49.21795650424031 w^4)/(1+1.67644413426484605272072112481680119704849473889970622716056086653476137916088`49.52287874528033 w)+222.2102057304092166599915354879438993649620072942632611972363`50.0523244877144 THRSub[2,1])/(1+7.8100612851353062271067882691206331302418151657648312323297589408265268441665`50. z),((98.6494675944534509060480031591993859180468064060423947656563`49.69897000433602+ 166.77270256131450134856371719999451562741005344570702493562`49.52507417486799 w+3.23973205394477680364008552221761153770832343652214250976361739174160648364384`49.63704735437658 w^2-65.7008495184046271695871437921167221660070114636937800893919`49.69897000433602 w^3+44.7663118603867549698629885022874081288659334834199654427238`49.21709694906293 w^4)/(1+1.67777183882994834295704715600440358207734082167363204224273465093300890806079`49.52287874528033 w)+231.1640952003863793968493871077221479807176387662715314548956`50.05017593260089 THRSub[2,1])/(1+8.16505989877473034338666414409548678874020703473024051705719498359621499060426`50. z),((87.6234807014168313546952297873552753789735215980940623196785`49.69897000433602+ 146.7955276981627766732501864696918308916473535784139045250966`49.52320811461033 w+1.598567228016801763555119957604446771819955665144427742124320855853618445534`49.69897000433602 w^2-56.58647450050371538731343134198791574352366863493987337059417169796585066603695`49.69897000433602 w^3+39.1459129413094298305169477758170266851245203638153283957609`49.21992692116327 w^4)/(1+1.67339387844872849275398236520249923773726349301952575880370080304773685710853`49.52287874528033 w)+204.2903377917421962060028097468324218577346001099324717325711`50.05722980607034 THRSub[2,1])/(1+7.09958476025091066510774423581415638272424406747220741723986743652178662039351`50. z),((61.77177771200532928773143388500238566744081829768867420850934290423092713605496`49.69897000433602+ 99.8550078690924119498870888647970369856744758974538690907456`49.5159774299936 w-2.19310620403492433553371876140438003503373340088414028809117478429962236908336`49.335188232477805 w^2-35.2373168495605033697404422087373902200409138842135358531357873706128381112797`49.69897000433602 w^3+25.9632578751490916231067205037892263063511880439768368953889`49.23145947277495 w^4)/(1+1.65535455704210474673915199561502587096174759769312154127418675744027692773198`49.52287874528033 w)+141.2817017868763246707096346704502135474313854387294394061764`50.08540567343719 THRSub[2,1])/(1+4.60145492471525517639928622775274909220100166211757329655535611519702785567781`50. z),((90.5374538730397482645787670234883051271569947371417789560796`49.69897000433602+ 152.0767268390001135052486832304954436413186152552920136705292`49.52374811050768 w+2.031421664742450861477771075844306576144815812310002513879969154483602361062`49.69897000433602 w^2-58.99492219291747336232677112352788869168123648831707272046735644257741855798916`49.69897000433602 w^3+40.6313625030452507849178049557539475071933373909236644781749`49.21910195720483 w^4)/(1+1.67467207412803465786990517048318573192998010181154896335342331343571919527396`49.52287874528033 w)+211.3925961990098012999011330073187902248695324955563000484889`50.055179434974605 THRSub[2,1])/(1+7.38117098004321003245995773596539958081885593363947771207449321376811667175264`50. z),((15.21024615972495079257848743850598772866830957097434499560411830286822426666905`49.69897000433602+ 0.78266688868842620194670663127081915663277466373725741186294918353595722544373`48.67899678551484 w-0.9967571688057928440815745897469197754027534093143611735378050317718532874032`49.0847174819357 w^2+0.28137595831376266965651253017781398683861554097504690077517449259169841721264`48.97875679235741 w^3+1.51522451949450769605038052107323334209809740950639553496411183907212605734996`49.69897000433602 w^4)/(1+0.51305478766738283567686563397115529241311323672329008634443806124662960927618`49.52287874528033 w)+27.79677607005423867712717219954021924850095642439192555096410048165555682729015`51.033309340744786 THRSub[2,1])/(1+0.10207044677087607738463909632434584493626692434256306843733591220512100336379`50. z),((42.78168131504325672277682222301397789895274325954345561952271758802428290060102`49.69897000433602+ 65.1117418881615937962715121117311304871266059182821532514271`49.50423436733842 w-4.83368306924051894286832222587745178476007948923158785674072101410878514454673`49.41168385229666 w^2-19.60757803942624175799708311858045920416460325012594659106404323962698978358259`49.69897000433602 w^3+16.266756900829373179836567843066726297726689244065500566988`49.25220684098408 w^4)/(1+1.62209476989950695060139188984098346793563198950679091601195008775788399673304`49.52287874528033 w)+94.99693392985799692857358211880678673710408032733316822172493585188255639741647`50.13401216096681 THRSub[2,1])/(1+2.76638330841284917164691190357597957162467521688855751838966699112347613678383`50. z),((15.70480657454868813691343862628496964295313758669641331444927252735464218133168`49.69897000433602+ 4.64365619813676409215634613014957794547167516161531532986303009037177874893785`49.22164781615607 w-2.55995111403955412992720227761106190005058746475157646694017048824071685278604`49.298548221409405 w^2+0.47083652544930699023347841546514935930961297205335439007733329276180349526942`49.03820430492139 w^3+1.90971256581136024962555659388728534299049377450895253077138149326275874563825`49.67306941847635 w^4)/(1+0.73961989422922180104875686058838775179128233548856033128670773437190491115527`49.52287874528033 w)+29.00217353159894567240073027716423775577047635762885406134539708441387783213616`50.8849558463835 THRSub[2,1])/(1+0.14986134581733744058985906131518330722598585640266325539368615200889478654381`50. z),((81.908244736054615893660994068613374592386632138255782388654`49.69897000433602+ 136.4332899896465451716070983737235692876073378638383696921548`49.52202991568238 w+0.75187405632590999376398880444970025094941716978859783363927072432639581691816`49.55608161998544 w^2-51.86356694002118380283532338109827079446434031787372297897888275831764381719984`49.69897000433602 w^3+36.2322686289086733026825683844031996473349815873748491455682`49.22174409728022 w^4)/(1+1.67057260669702311220277388423966175440285506601362871455003693634464086080659`49.52287874528033 w)+190.3605312033359401690929049430174111223798662765587403172408`50.06172933827841 THRSub[2,1])/(1+6.54730387229371884762445183934506231148592985535370313276982477404868804235583`50. z),((32.9741393497685794314479440210189721771329764701938435442554439415640660552288`49.69897000433602+ 46.8429887653035755463278241208271501272464489263990114365572`49.49153991850441 w-6.01756338163583089883651584465435787663971025265023108688174696940948091872674`49.42468856323171 w^2-11.60124698254481303640342002927200979887403149250296788865897340112610774112073`49.69897000433602 w^3+11.24302844696871890478503738818365787999567479634007582475770549746847269435594`49.27755223288622 w^4)/(1+1.58004773915782463959028706070204884020429465557975057400338908136456273028736`49.52287874528033 w)+71.09290555518779528718598054049766417704619706283343978891606067690536989193671`50.190292002363364 THRSub[2,1])/(1+1.81865026325308780561049193946485030714871949188379037399743080769287706327389`50. z),((15.47525476266824990803009911702537012174667004016632208384409991234163427542417`49.69897000433602+ 3.00613038807417307863971939845295990808214812382049482912885255703536828526778`49.1161322385015 w-1.91961465131618984922472719748939654996477027704576996424222217567189733332666`49.24339342835959 w^2+0.41405176081499326512005794267916613586133668827637078975633566313534484162908`49.04008578568495 w^3+1.73389851081785361916616974042990105678923715492225968608088547163863397521029`49.69897000433602 w^4)/(1+0.64624768510647704683384475593038083236557066046425411615335921044551074616419`49.52287874528033 w)+28.44268441148348840819659690008265163870417307851434372687788685375044272911625`50.94606588203758 THRSub[2,1])/(1+0.12767904586229509318053317289388849665340965791108812294139373948570817226157`50. z),((15.40008901612270535880777996151059990377079806578967129808154132342997615337254`49.69897000433602+ 2.4166151233306152704178805096957192137141408516762100877146391094203447821919`49.055762683545545 w-1.68053710266766938248511249890404989602083583032759000403431839768604603705304`49.21490682050967 w^2+0.384710045362032238694323531944328828150490526782939344459019931757464639098`49.03276235054387 w^3+1.67380804076478156398287672649137765228520977466575125491427323184208407012641`49.69897000433602 w^4)/(1+0.61160643090991228224377556006823485300496347949792950323716834354546475957891`49.52287874528033 w)+28.25948212240945495479253598962030355335977826737831702853312850835764451690674`50.968696561029525 THRSub[2,1])/(1+0.12041554781991678241925657369316374997997240057803126801661216364075816804603`50. z),((17.7918117329583533849692843710916852361771114722555175162226409398045221343714`49.69897000433602+ 14.03893120607738347355208275979284320129225075995578554719968907641379502887725`49.40189750937297 w-5.35038425081493178900180882465593707778920424552070079331002967739190611117035`49.402658561232876 w^2-0.12090117770461746528373408055594863050336843155398332491600475796616188658567`48.296630386011664 w^3+3.24554755302924796881532219348186330436990207368819549409522290200674642500296`49.48897168624904 w^4)/(1+1.1692850803856120338583576265146468614258386392269093040329431265286665272305`49.52287874528033 w)+34.08885383348746494532749518278614672201523090129729996971700650937760464375067`50.58485863912764 THRSub[2,1])/(1+0.35153509455549305642134256449176014543652097869489305029949499499239086820397`50. z),((106.2487733493523488062299129198260175396300889725865984777949`49.69897000433602+ 180.5334336463067278315163369640616120449527904799917030619521`49.52612356050177 w+4.37521454669580471585493788050523214403029201072079564811186597789346657728296`49.593770073734966 w^2-71.9842328877037753329902775127785041334240045212244191557489`49.69897000433602 w^3+48.6396041419706013819444046112668650304834723747507053010034`49.21553109407754 w^4)/(1+1.68018598510249320755413399910752384698815799512526330334386697416799342207115`49.52287874528033 w)+249.6859655157085810214089840040984834794670722834223042431066`50.04624812452134 THRSub[2,1])/(1+8.89940426453842288967942822356219071929882487553229376160335448580416446831419`50. z),((102.0154922624287492178377925252318368314971141863818165762676`49.69897000433602+ 172.8685253359893407675322916052482722259411289075816797881273`49.52555927405848 w+3.74231278018205107967213714066289462509282511765616387056136229337327436257473`49.61411094325401 w^2-68.4838670315191924294886200257576829850046640316477882847618`49.69897000433602 w^3+46.4819745193875382734108656878479284200978671620355844187352`49.21637082899741 w^4)/(1+1.67889205793503402041844910861355588233625209694489403304310346396695167382434`49.52287874528033 w)+239.3681436212862954172833487044103615146355688675878379653805`50.04835674750451 THRSub[2,1])/(1+8.49032924964349922849996696061691530357388603418252245097886536365906833199941`50. z),((45.84044968228980614301870153333012495190588332436297703083190299230971445746022`49.69897000433602+ 70.7419912156124409587317474793469924790969250711763005464761`49.50688535339296 w-4.42720396158696648653026409317330780324259131841620366056692647956107380924599`49.40547189488129 w^2-22.11820084935935878754794698945088252559049458613276576940947420703965603861303`49.69897000433602 w^3+17.83025729020445663814925828745335863037818374286403523518`49.24729832892751 w^4)/(1+1.63005748980934464428252668651545260088656315818252784285198050701890264886678`49.52287874528033 w)+102.45210323742642959279284339606160186026046782018115936573422868077913751587644`50.122736075818445 THRSub[2,1])/(1+3.0619615347811861980727244721364874191330048970652760906458641449955163050103`50. z),((60.32940485868844533068162377585681293116222312897587211985510330698179499045253`49.69897000433602+ 97.228395695395628071404330665437248511820405343577133098479`49.51537325875354 w-2.40045413323899913959692728101467972773111473345079528636453466607869072928336`49.34649203777966 w^2-34.04769640696664444882661968127804064703748541346912422302933179210594349487146`49.69897000433602 w^3+25.2273709917691257904228583191812963493550664743371828391577`49.23246496324544 w^4)/(1+1.65376661737227913133318563258510265438188130381147415627896634501578159445258`49.52287874528033 w)+137.7661907919075477271551505902745535478346546007046590445509`50.08782081147919 THRSub[2,1])/(1+4.46207398488651599232063941312296084660886275994477701856365698581812086919855`50. z),((15.68887911919060562824367911309990815645402279425640919205289380677747417746344`49.69897000433602+ 7.39212369467637093929477425340645167180954500987270482080453746729999861486854`49.31098065992882 w-13.67419029721947724768212559290934779284675120379300991407302554689643549174599`49.69897000433602 w^2+5.33499391994312172954691066626226637057627073331861514598352381222863937553934`49.69897000433602 w^3)/(1+0.91565724815706401535822362991242898718819001992538220425404174259542258504578`49.52287874528033 w-0.63011219800123055642019775035701459635077523852967064491638939998390743287087`49.5836596694589 w^2)+28.96335337195405811591919808671063097814024697117048008745313767142666649449757`50.888857534406185 THRSub[2,1])/(1+0.14832222665561393199756655268423025530951519313532901907847928840127978750026`50. z),((16.93839915802954009107998921671914888561742527774426682896909553513617742176062`49.69897000433602+ 13.44349540216282561382526058319500431329085539897149616623603106240654862319373`49.39588166933874 w-21.25324167037567697848634364738850666745175794260583252123454270021202508063272`49.691963510953684 w^2+6.96848997522606197508403229689436100545958506921051189558133923770168185781348`49.63069280112796 w^3)/(1+1.19804571278648558592870587416120417405958934584357147184027103319569587868059`49.52287874528033 w-0.92228121275227860895788898214210457348605069057700142262555910560503988295071`49.46151481197732 w^2)+32.00882211110192886300564684878366743369602659676844435197640194895316846752893`50.67362385527908 THRSub[2,1])/(1+0.26906720389760534549275081375772263223954175867915860449411421687645494581077`50. z),((19.79112003281723542405109398131544532652187348844373014181482563065956778448512`49.69897000433602+ 20.59112870921300897521544696553792385230971556119489744112319391206655956941505`49.439163494254316 w-39.1569497978824563685845733013770667121725023047897769752308`49.504865940279736 w^2+9.59510411383237246316760282707365003067925157382500735489493697192359794628312`49.42237609065227 w^3)/(1+1.37220329874176466755011358834309351757764205926999234015292328237082295573477`49.52287874528033 w-1.65077485254279917327940633519523481920678761207080579223332907204251412870822`49.387118613230925 w^2)+38.96178963113733728585515951983743053812683500972990521933570629876590513312426`50.45266900317095 THRSub[2,1])/(1+0.54473442522849478050546759177875923157932738243312035174528708219540458517203`50. z),((16.94464832875881876496979454724672057987188302753145529888419532353029613779926`49.69897000433602+ 13.46648673761674186731896290548402951087564835854179097472698521114161933033646`49.39607966687864 w-21.28862393849740964147373818946475822868384152354296424929719598702070326557334`49.691206427730684 w^2+6.97485915976698356198397668858389129097522581169849833667903243599235447436309`49.62990540558777 w^3)/(1+1.19892411590173425450918707507103683533945366544995516909082558397973745873673`49.52287874528033 w-0.92371145074319123690190737928491962589822660193574049360627343547634939521391`49.4611221505339 w^2)+32.02405328267985769022553451884556888848265079635061461268463902217387030996492`50.67285685239228 THRSub[2,1])/(1+0.26967108054946697768597298846008209208995264144624043182501378707791238739476`50. z),((17.51168941385723889319128758643172794295898325908941518258095551016945837977743`49.69897000433602+ 15.37182683978797990403680234268017863082177966205288484863136050708015313697035`49.41074657173088 w-24.49672739093904229175221992575012450453694989386772512084410254146625338688285`49.63122939092115 w^2+7.51745788014832560904689533170101904711463526847549569209590651626205159333616`49.56633226635364 w^3)/(1+1.26569178457658863725057972561044487904317954425869781664410791170043978448436`49.52287874528033 w-1.0543789099918601259527319700067731101841080342943755200999433729503146119399`49.431107129917784 w^2)+33.40610866778947378391492375660415345058631996750591685541511335636923655821965`50.61087160871798 THRSub[2,1])/(1+0.32446601043238695030970952419256755970534183402388430330556737117835974672634`50. z),((15.65185207979795332414022698765892201275339035876345108722541984571571775194322`49.69897000433602+ 7.14586484437159252049285281656580223591039521799493439620470090877355025582106`49.30515006386789 w-13.41660238655174582382407795912223564453235875994634737497548036472834866805083`49.69897000433602 w^2+5.26863831404129811636770249473525165375411010851540430130829560170540661852498`49.69897000433602 w^3)/(1+0.90232468166043849036887307781869681498906703289075075516512453441340117034543`49.52287874528033 w-0.6209158001879170333088425328583110906042324696835851358355165047121234857836`49.58925459911275 w^2)+28.873106967359937845028673051007927553154893488191925315983130252206437473983`50.898107308843436 THRSub[2,1])/(1+0.14474418957750635913285067258793135568627009166735847005776158681147580117077`50. z),((15.67683810394754343711198411153320189961601264630335821609207055129673427720177`49.69897000433602+ 7.31268094087644222765066199271085571452276714212798993925493290659846604012224`49.309133932164464 w-13.59079507536730761370251865085594803320640617787895940222762087443645361176473`49.69897000433602 w^2+5.31359418134582545097819642848975311090480224942649832450384892628945147514968`49.69897000433602 w^3)/(1+0.91136926079057015730264287939723701813393393854626949418465230193528344976847`49.52287874528033 w-0.62712810628559482280927111219780692562651694324252998072998485370575828694669`49.5854603179646 w^2)+28.93400567494199298470295788817535660089769095220968878243869591850586175904616`50.891837647485985 THRSub[2,1])/(1+0.14715866619535513860745445616486004570785700147867861223253220418860456339833`50. z),((16.46270059629310512617768916357442110967059859949770691111479231564324648012115`49.69897000433602+ 11.52938078845949502448881403713393384977695546091681200580066821492171766983393`49.37712626761308 w-18.52514347222365401063211001314387620553059442031880652086058051393507687917578`49.69897000433602 w^2+6.44633003082852624105134427270505854228530738859783611075341519597441738168707`49.69739100674003 w^3)/(1+1.1192623611816604146240463212547012223549463106074410400892909290052974385236`49.52287874528033 w-0.81329868225760924746088469729382772179834469258074418078370552435648590852015`49.49640614267643 w^2)+30.84939684860507058146059877515396281020746958929283256029193913295458956954747`50.73896401304262 THRSub[2,1])/(1+0.22309898392068844604765845708453777690215620082632985734983922237392239623102`50. z),((15.2084404551687197353937141417312870772604295111244316353809814542530878701705`49.69897000433602+ 3.63469441768207607550133395403541678917656934369158079737682443901579224779539`49.16345850449859 w-9.98914162111906368710667553481255365669578460138976722390768348489485809726872`49.69897000433602 w^2+4.31495769814318676194936469657190845686752901706514300933692064875610207985259`49.69897000433602 w^3)/(1+0.70065674477836370485969631557997641083588268539800358862648166570037413231257`49.52287874528033 w-0.50466274683613542705239467193627866611923768749971824663710362418286324951715`49.67301120903722 w^2)+27.79237500676016899088467213387458206361942616384385520842463441837410665437131`51.03398364104867 THRSub[2,1])/(1+0.10189595596739086520440318257185952801204309565346105677674946213278232245555`50. z),((15.23144942095911688005916805704953349412210750489412327331928656019107354191281`49.69897000433602+ 3.84840024742346561276652089368976976216253878976754774464502292166179010190198`49.17732813844847 w-10.18690964592425292118352613058496623548506970081994401928415984123694797989472`49.69897000433602 w^2+4.37343534168934517152669922391208163403330186219306263238634466483656530862185`49.69897000433602 w^3)/(1+0.71347893251117244104865196323750187860049665695090784655196436374467592361504`49.52287874528033 w-0.51105412475504733745813021213299522136263585160827947067085741152948992783698`49.667706649066055 w^2)+27.84845500856621432718491251104118569245411559747266765982603103089281228130435`51.025484446929894 THRSub[2,1])/(1+0.10411938333499419479893074146197109188958329415002874259115602279351730117841`50. z),((17.81715586441092580377821926822994569179205425026050482132442905243051151399459`49.69897000433602+ 16.2739511748638940805643678498296243779673821271409201923726098461442543324974`49.416681908084904 w-26.24817846604268950606559992985283490743350664648570929158517527612111645078404`49.604959973976236 w^2+7.7898601509652858444216252342173648649486460930287606808647008367404108997815`49.53768137030681 w^3)/(1+1.29292264277149990941871611796947796400385083168304379830685318424684950319562`49.52287874528033 w-1.12611784595916710919876539010605401761124434888016214235370003119962842292948`49.41884079839472 w^2)+34.15062535988201913650564547572757379123673496449268660409935985197487384186999`50.582629740230644 THRSub[2,1])/(1+0.35398417618711093729511159153494570643112507269881774741367488121649282561719`50. z),((15.38900814904522649190788461573704228979444508446917614113010159218119105877666`49.69897000433602+ 5.20753821081541562848511092724978285137967457947189681498143607679819105907019`49.24491296217461 w-11.47419821142502962745679426160236258242669132909518642099886388315649064728522`49.69897000433602 w^2+4.74401497268371377276077959775859977291768284241805224608399567130694009332238`49.69897000433602 w^3)/(1+0.79347651051124415804724481663697541982865114314007121627158180852601718179536`49.52287874528033 w-0.55360932598419616059240812039035245149730326837466566919085627189570586093531`49.63459570682993 w^2)+28.23247460493220647948431700651761449153162496085692268197092414957647244700198`50.97216048439796 THRSub[2,1])/(1+0.11934476943981576253987909396504557651910796216569875866866292201888404013297`50. z),((15.99349751752601826355249883468627600266037326692020858643347160562181750943629`49.69897000433602+ 9.22237221551835272157334794257031597544377135266017732900969259488974484031832`49.34623329801603 w-15.68382477525653085913888624085711763959610233021243305178868822454099132786688`49.69897000433602 w^2+5.8266760140012050609677256967166814998060397228352664248795050362806987970348`49.69897000433602 w^3)/(1+1.01076372137536040148831892941001253997017818898401761083732471961699896373796`49.52287874528033 w-0.70386822268595389363151119194719286063313697581859701946014334133922810336697`49.54337412030125 w^2)+29.70580309717961412754810892419562410048638381364596760534212719360736667147711`50.821225989676705 THRSub[2,1])/(1+0.17775844250748506284859115197326288519875558212948418460405816798698591870107`50. z),((15.58149247314990449348420559323158816163169174724292219960800745946103613121574`49.69897000433602+ 6.66120051972430325312484450714424282108954919723050694620538892223456795448619`49.29268784894353 w-12.9173230475116427967824067266228033483327683991501763006573878682017657894777`49.69897000433602 w^2+5.13786158883033039800646398316060849177907457621489448177206098053386730644804`49.69897000433602 w^3)/(1+0.87574231089413471426315616057627384244194566889793870147378942621400363122523`49.52287874528033 w-0.60326740575017820664572243434900945802895488124155576172681016965571408576017`49.60037826151932 w^2)+28.7016187351708146572708444075148321220074704546974872157042899308589183676069`50.91641496626567 THRSub[2,1])/(1+0.13794512366467131173780300602675341593710276825823101665243395138542494262194`50. z),((15.29049359392052605374560214305946654303582350210500868979285676711563420344774`49.69897000433602+ 4.37816881688164222847519943749520003098707962565966142663700910534621197649452`49.207352812790475 w-10.68237274391324852055971076640043111423896996090813775797899796454982288047782`49.69897000433602 w^2+4.51815493070438936162023306848455088441921705051143623057867276513993603397702`49.69897000433602 w^3)/(1+0.74498745719196301742038505960155333397963840859721203355942698222338571855516`49.52287874528033 w-0.52723739218583512530810264120933611042620220104697531074670872023447978687189`49.65467274445302 w^2)+27.99236401153818697490259612468653298908539488548150721274895637460364033360276`51.00455327744638 THRSub[2,1])/(1+0.10982500397243683631767549871293095305847234000988159252535913335255100589949`50. z),((17.16677166258314140672154248719772615777145203172453166060435936281855792749757`49.69897000433602+ 14.25334503348736924872172540602572737044151562989146616283893753930268808984263`49.40253252613359 w-22.54381064058176992487060700203062644065547793183364757368184384735613205956627`49.66575354989327 w^2+7.19497175847084363929056874234706431866842801328244487819160712551300054490154`49.60322062681612 w^3)/(1+1.22796281098528543644364067738677354515864998842852202595155186861860640299903`49.52287874528033 w-0.97463869918889389269274800807485472853087396829401886809221252140397531787013`49.44810297634965 w^2)+32.56543689268251384496966440053026278692393648921588361078151522631364172128987`50.646876606798784 THRSub[2,1])/(1+0.29113554374643558927624661627348122600946295481537653646089975397995175588216`50. z),((18.27115802865556194405119965520797825358346455212092295602322805074336556921908`49.69897000433602+ 17.486191840559767002550694924815626271698171104331738812217911478281094586815`49.42385628464092 w-28.9237072389604744185378462470436439913020403218927834480839977866414811882506`49.572152252916986 w^2+8.18340132038902579990238384651949305217671074695511986738940095575696479856644`49.501099209594926 w^3)/(1+1.32467680823109306356861394818888325667004624302128366317277036433003875420155`49.52287874528033 w-1.2356441616058210799475543939520162092125020611266219097144805194030264267173`49.40469195607578 w^2)+35.25716975751912075375917325022767220251424721113035916018420641751415776236661`50.545736674184596 THRSub[2,1])/(1+0.39785580632156742539943326466683671087782948813575745418238959057286297534523`50. z),((17.30968676470683020204676281917845148204309182243480463885050021375367571349896`49.69897000433602+ 14.73088647878394590910871096525775733514299057108488449501299287718021409771256`49.406166483575696 w-23.3512530937131701730821868964989982516064208630438286241458053747606184071244`49.65076352851105 w^2+7.33101686980718823142632617826265099432381407579309651695921623880047441061702`49.587305649545485 w^3)/(1+1.24459285393495502761850443926028191657070179649456977233682946158478135639739`49.52287874528033 w-1.00755317570514968399368335466694428178407502714485832670361990355724942279191`49.44061899531387 w^2)+32.91376542071016512613867725432447034546043530387471252044051451409163841907324`50.63136974013127 THRSub[2,1])/(1+0.30494587108580053251485817804627400986338997064620742356881539501132855375268`50. z),((16.14756923584919087870752865670840578728097130811069735029230671541544008422689`49.69897000433602+ 10.03776869599469228339517399629519110543360008201329916774880971644561871807261`49.35848794282076 w-16.64273635601741961212314276475922833715442258619699338044465889151184463613377`49.69897000433602 w^2+6.04533059072738070536479121293181978214243779868156621347884210366922714678259`49.69897000433602 w^3)/(1+1.05066896953923209752794239145060198625186686915858135479164039718809603405868`49.52287874528033 w-0.74020336545218671755005255045552583103519077747566024312863852690592655544705`49.52623870617578 w^2)+30.08132376684092064559741911606719005991313122505768139819135545582197654647883`50.791749919066156 THRSub[2,1])/(1+0.19264686809836428295039612814692839593422959750963477621612149132205967700851`50. z),((16.11907023411255672464981972899159973034865561732605444819791571505706448044101`49.69897000433602+ 9.89170320337638305166579255006356540260351085503939865977905541837032116676623`49.35641527184388 w-16.46765558596764283015701629597049040661995194018414275218721285445988628388401`49.69897000433602 w^2+6.00615644020441077708361028805787978422368296993402995519687214692897542487351`49.69897000433602 w^3)/(1+1.04364042645033651950799102401593301391382065752358097618580664948432024901486`49.52287874528033 w-0.73351946528977959637311281357998715606957964323076662116550543028744534820228`49.52926796779501 w^2)+30.01186284089491590345990052526933699775237692900191832113121336274774663341684`50.79699910459523 THRSub[2,1])/(1+0.18989292161559568561369546426761349462144352399664505624615528039387660056736`50. z),((77.3940989963727217669080554945786181946218990065279185398188`49.69897000433602+ 127.4028870223754101200748294946956230446155920282681842086577`49.52095482666131 w)/(1+1.65712058438593855182360407722649979433579594044430707097031954345082464679933`49.52287874528033 w-0.00122624322312947963476275778448941542206926287610015447439994745385390592457`48.5138498916038 w^2+0.62213291251801676107328357091399796534393855817955974514868658230854153174734`49.69897000433602 w^3-0.43868212608651236744177143432573364746429431227114536660354317499084550831709`49.226220612744555 w^4)+179.3581548453439303038595913873668981918209902013164084174385`50.06581751506356 THRSub[2,1])/(1+6.11108803928363125239607270089446085152165487483548799322997607876444084829532`50. z),((82.6215668736848704974096659898950951995704277873957496778102`49.69897000433602+ 137.3797588950497336159722322038737195534539655633601823793702`49.522184719746 w)/(1+1.66674801200620561326599044798679741296605993487630929987181931993461699294926`49.52287874528033 w-0.0103938002107635457298962447602992969646278260590995225440684606261360808309`49.64219179901006 w^2+0.63488822883148127855442391734405946138618641089043795902936177661085876895918`49.69897000433602 w^3-0.44301214589916612655769798565064526271388975784475106398488258674250448512175`49.222550088233554 w^4)+192.099118983899819535988636312337305903157322986622756576452`50.06112941865356 THRSub[2,1])/(1+6.61623439169091603825711114881144278903590162473641746799444788657442687940705`50. z),((18.51828480577663303079471426670045937699247385858879389655162758991776517165165`49.69897000433602+ 8.97838487074226866918958644996189953724084153248616614868262466967052045967154`49.34767264896719 w)/(1+0.84624693656621022752699420444189963993664525392983853985832844515688821746894`49.52287874528033 w+0.16831930738545133110070749830858985359364381632540361273330872908032812151346`49.334039225968425 w^2+0.14388010513459045300700087297448724621582859749597672209653374865504313620473`49.69897000433602 w^3-0.24765018244743651901044585400294478386458271499229147147499351846159619234931`49.69762836434177 w^4)+35.85949453098007602637531473858074596639001933069124521510261261863338258213138`50.52777797476902 THRSub[2,1])/(1+0.42173642940232840395670025191206719059219425277190253769833431836678320261922`50. z),((16.21518055132118171234324976426477923349279071987024019616759746322552485451964`49.69897000433602+ 1.09496428829206121796408058004531231197648888318595073850652915396308173873264`48.805707684675895 w)/(1+0.49436601678017598054841251763879969074750605785296429528057652576299269716674`49.52287874528033 w+0.05143808922613426015101102496924423320674564675562934629146955107691889528575`49.03599475590691 w^2+0.05756591939951247411129395507207510297162141539960031545272934394340218228835`49.69897000433602 w^3-0.1698148762916542053872155611968596206404681362019389250015800763942533115965`49.69897000433602 w^4)+30.24611355914704852361487489097828845184656142562945098267161354186574857057355`50.779637997461215 THRSub[2,1])/(1+0.1991803581539158892229890082382057345196506408782349321362891938152880484301`50. z),((88.3774273490348119981513950445862545292838800671227517314528`49.69897000433602+ 148.360672389783027283344924948401557042659775496949420246395`49.52335082305541 w)/(1+1.67598114529719087858669745828394076418793597183484066555851998595095432328556`49.52287874528033 w-0.0193605596077133721957873556960543070816422757633401187901697211322502436361`49.69897000433602 w^2+0.64735246550012382951738917148700800232560300244828863361177958549369922198115`49.69897000433602 w^3-0.44726376403629720608622773453769857775641847408682445405852013281359582610052`49.21915729423583 w^4)+206.1279401309887698464784172178731451401480247593624988679369`50.05668480982797 THRSub[2,1])/(1+7.17244095141123779780651736313671521100847674561680911203220451032567041247189`50. z),((15.27590996952638730011818911144603807124186884875390058650318752891481570105843`49.69897000433602- 2.92041883593379458711325819055685031017450747246474135334537631162366635628185`49.419786177797164 w)/(1+0.26800929772862477826471622739740081956056806728677007057472591533575709298373`49.52287874528033 w-0.04741408935669683701143745600210599560958208468807174196435898245193477249714`49.20822969056904 w^2+0.00505055506268586055527542469842988525567455228099431293509182677722664290718`49.27697517886235 w^3-0.11284054410209253884473217616988155675491522357919601195794720826279186088404`49.69897000433602 w^4)+27.95681918567281409719199319890798154255518197955774202317917731317468508020968`51.009610333780735 THRSub[2,1])/(1+0.10841574334368191168957580358485707236682428297210950897456297926065500354825`50. z),((115.6117865694088253425150096168916742137934745731906165686185`49.69897000433602+ 200.2842456660033524792049447582352532108627561182357848835177`49.52715721896833 w)/(1+1.70691170078262913943302245474207420162377560652262337472534082359651190300771`49.52287874528033 w-0.05059335122123193791929499883551479825169207774509578028494064524906694520712`49.565606764354975 w^2+0.69072791532099732173419152322465172172910220911205877625544320776339869318574`49.69897000433602 w^3-0.46221780948950020042040510622070610263510565169049869498890521122403577187617`49.20871496451565 w^4)+272.506539159654639270995027384384991986410639025863961792076`50.04218053031332 THRSub[2,1])/(1+9.80418112527823882220220599293664243131699933243053716083214873029377330200187`50. z),((80.1174699070489107740990074553755806960189919690877350112967`49.69897000433602+ 132.6011265018388480761908697001486769587380935172159793575729`49.52161823427641 w)/(1+1.66229992347678722320834540252868907634286312219945060493838019886145830005056`49.52287874528033 w-0.00613482985920027287269585082719891470503195457665482802711705359571107730043`49.30886747392273 w^2+0.62896426169920398154838350503952308028252934725731627815884302630000356692696`49.69897000433602 w^3-0.44099853267774096210105701332019125766494909961166515516626843125263895259549`49.22422919561008 w^4)+185.9958562953149193755942476088909552681036611329396412685391`50.06328871088065 THRSub[2,1])/(1+6.37425577442187910317048998342640486842495296201814797552180505350123830354992`50. z),((74.733979319749571886853436307148447019843748083992374797861`49.69897000433602+ 122.3240091563665217036823298971208558643196450599185649127545`49.52025346625128 w)/(1+1.65167878451691045873105804207498703910184810439065815662959117205070833791686`49.52287874528033 w+0.00387184713895865702718442101076412912898897249875795596000943900051371067001`48.86325813099955 w^2+0.6150327575769070075803975005189600815471671548597763473806902079164080259152`49.69897000433602 w^3-0.43628092998223808750302679490644794615801719387337697746993877782579918969752`49.22835468286771 w^4)+172.8746163139605048127392184542005122023970963390625209730797`50.06849103058528 THRSub[2,1])/(1+5.85403246607866356117658471207730883847641733208256809885244973277444252755012`50. z),((103.1877673468745629942486764256903003409977567326354431714612`49.69897000433602+ 176.6020215783969044293828169021928159644576151878353683079219`49.52569440444604 w)/(1+1.69487272526892387114872495175709680717340575932654764951540590795328716976368`49.52287874528033 w-0.03822362031508381784035693006308227177630134122872943747089849294785629128196`49.60708557501791 w^2+0.67355182118161453132404393579215595784548720453408926056232531030782761838291`49.69897000433602 w^3-0.45626674393248648357557333013394419955103756431272139415108922466890814194101`49.21260924202518 w^4)+242.2253423955284846162670309300058284347283731201609498234349`50.04775380049243 THRSub[2,1])/(1+8.60360980857258171034030820709547043326979913283290297238874045351302736521655`50. z),((50.43132976455691625345045416909875574811199606524239627604857015692130151316809`49.69897000433602+ 75.7886280562014560972366417878935704512856240355650482667811`49.50961748093645 w)/(1+1.57270294211802971611062274283189138615427470209197855482447362896190349014747`49.52287874528033 w+0.07066547992419876608671200699694964615502475355648775624520689662611330630061`49.38604315388513 w^2+0.52099156766869790803614825060521669822570876946046439473373678285335069480597`49.69897000433602 w^3-0.40504532438501124629184891210707815280468719543317587751897069430376477602176`49.263848425619955 w^4)+113.64150504062817557832715376572444340480763420853405378382687257714734154118737`50.10899048066643 THRSub[2,1])/(1+3.50559244410948991897738349539673819464125730800128930778436153805439514762148`50. z),((113.1098070013095425785222092407570716734813187925477229960476`49.69897000433602+ 195.5154818396737770041605876576029963063944711938499245659136`49.52689075476453 w)/(1+1.70470365482221454482802473639658394853260184952636711541162495366114217868469`49.52287874528033 w-0.04830486876983404811789328281281399655383726172495226254916045574224740230235`49.57141119581034 w^2+0.68755007679799740949499571275866490230655070734012774969287998492582397499566`49.69897000433602 w^3-0.46111386506949140059018573213752337149484343206357498122137581075099938455212`49.209412899147736 w^4)+266.4084372294820324457165375453532592166692682991201914974279`50.04319567316856 THRSub[2,1])/(1+9.56240711876387281809950828956944661319828756624698413708373360697583724151428`50. z),((41.76840973740186915668748288342863845653395774315811410218019542611859162107708`49.69897000433602+ 59.0421582085397870945771612174312676414800918356353855387628`49.501892098354034 w)/(1+1.51853849822685221934790701756353558068365016461907079497931683394799327937865`49.52287874528033 w+0.10832983642131454182674800727323250348081693372371791921780368256408845728772`49.4041602960054 w^2+0.46605585013310736204089266980863486947621918659068257072862046399007463091141`49.69897000433602 w^3-0.38716855010454522611698324903739338379615214310283346726032925108901576714491`49.2924183147431 w^4)+92.5272761268176191416008733908178844841022866891484386069034309008086576060687`50.13822274706187 THRSub[2,1])/(1+2.66846774901457616850810909623800072041533075222192411897097815214508101074291`50. z),((15.42110610146031408497925551922147727591928321971642845283286519189893743114658`49.69897000433602- 2.25571248316471615852497473637108632031353438648600548438087334613850943114565`49.283450253862945 w)/(1+0.30765495175212278108479267575180353296103715512733653682445259231415558905672`49.52287874528033 w-0.02905458906829855054444018143376423730944624680809903129383388778361979728185`48.9741541760186 w^2+0.01424488947111609143044994452948557419439083836901328550168835745421480091885`49.58285008549005 w^3-0.12317203953834251528293575455514350724586309478913569833867253873500225597095`49.69897000433602 w^4)+28.31070729239005504839257027564725426878991275415134099794162695903047346149333`50.96221929438605 THRSub[2,1])/(1+0.12244649363263109331255000974449323093122447868150530222791781935856795637665`50. z),((20.83169241190976116318149017350366742920759364313125062954354972426000133178362`49.69897000433602+ 15.36038620952917738435713088868128523964475285467110909988922001225095691174628`49.415497121362144 w)/(1+1.0476060675958729514489510391629249673004341187247782233251879894138759140746`49.52287874528033 w+0.20474259916727525623573348494019650787770879101119536294420290184498398702258`49.379353343807836 w^2+0.20334475544887620333628039331255105609006843720588530818081885783646750435754`49.69897000433602 w^3-0.2866375414650088870181152465333146465735209003626120687555072355341762440486`49.582387750626346 w^4)+41.49798797357585234399337091219764515565096993934238620728649656933967487822074`50.406488281831066 THRSub[2,1])/(1+0.64528814531842734463935661936428599627416964022305118791268407921502531345201`50. z),((16.25019028813626109470959279275863301071589533621270193460847171843726386218043`49.69897000433602+ 1.2330750934292704354190568185380919734948784132105377908683285697620252591418`48.84708834228731 w)/(1+0.50158611745270358340422140653608358858284391478285775604993762538437696733266`49.52287874528033 w+0.05433345033202226670896136072332906556090016294349216720289937999676911197487`49.05257080704666 w^2+0.05925081379210584552255925657641446443332914859694383543896028581364059444866`49.69897000433602 w^3-0.17154708193130489140476199674159136288931142696252521322464700816101680459378`49.69897000433602 w^4)+30.33144317029533540466571883419029242575920462166863937802900504619318671080719`50.773546902262744 THRSub[2,1])/(1+0.20256345705876648171305582528115634475237111613189967928665071261124038613539`50. z),((15.53004983339983596099419298206252443075303275740500119690918666135599176737822`49.69897000433602- 1.76866774123971824201185186267604617813375356201167547979128889241523061886266`49.16093456136252 w)/(1+0.3361618520812878210622328054535075138763584881201259411304497836982047789619`49.52287874528033 w-0.01611090902571991712000796897027980925675567497786741125692248111655598283178`48.70375257867091 w^2+0.02085018887343876044704917813181812794620787781891182237582610793421186243591`49.67096349860775 w^3-0.13051360879287939568266782360965884212022597791609371877215785253350069449864`49.69897000433602 w^4)+28.57623703151790187527164679906282919332179330691901078910327242421795032390413`50.9304530300285 THRSub[2,1])/(1+0.13297406263898202751388741833557533271725356311615102031707573121405177573223`50. z),((93.2577843151661682102927191934155157621859252050719725584952`49.69897000433602+ 157.6686245064599836626579484782432332731196709359351974848833`49.52421434775683 w)/(1+1.68288809721439744770304771206677140786295951561540659642019540315464120350092`49.52287874528033 w-0.02617774949497344505869365705916343943959101602393116924724817783044141934468`49.69870510050355 w^2+0.65682333658405650781601763711473817630328368906517297855748083639511979057644`49.69897000433602 w^3-0.45050789677098723093550321874249316168557937717250136811975519774597288739778`49.21670162190123 w^4)+218.0228870820167838618512235118842919187363076717691110501201`50.053393784677205 THRSub[2,1])/(1+7.64404490532292373081964372905619180681780745950396966238902319826132440124676`50. z),((98.8581561551114137871889831944020390942757578674199837035741`49.69897000433602+ 168.3475283371928160075103538833418251126937684266085113271089`49.52508939272904 w)/(1+1.68995069166255108748029257345308904731529708522568442202612857866835707959826`49.52287874528033 w-0.0332435417650615469622032676676207173875134785591039840581877132010471003352`49.63477445910842 w^2+0.66663646902932382398232135885760717749077463700406463875412044855104936791509`49.69897000433602 w^3-0.45388165967213909860364733200739379356721406951489453229472808177559604969845`49.214263995048086 w^4)+231.6727340920780670686329218736350976528214949358051781814526`50.05005917068991 THRSub[2,1])/(1+8.18522611838231981055948684367962440346328572181190053269996924197315961216257`50. z),((75.314749856254737517092437249000489270878739939922844115351`49.69897000433602+ 123.4329822461230988159279446989754302418652427527656745309804`49.5204114194615 w)/(1+1.65290135640212546320136873218650850592429111001813233704855175746454762931424`49.52287874528033 w+0.0027318160978030691599119547772703352290049162108642223353945129492039223166`48.74595948344379 w^2+0.61662098093710107662466796680735228426507419593581497161469822204204454106424`49.69897000433602 w^3-0.4368174897127875427165594113968368631841861112224456401191457156320271168245`49.22787152883185 w^4)+174.2901346398515635567387753914578349703715483262307105453888`50.067888927587845 THRSub[2,1])/(1+5.91015411521867757820259633543496244412388672006943383292559269918660599862641`50. z)} /. {w->w[z],pi1->pi1full[z]};

(* Sample Pades for the nl^0-part of the 3-loop triangle form factor with LME to z^4 and THR to (1-z) *)
(* Mean and weighted standard deviation *)
Ftri3LoopNl041[z_] := Module[{const,ls},
const = Ftri3LoopConstNl0Pade41[z];
ls = Ftri3LoopLsNl0Pade41[z];
{Mean[const] + Mean[ls]*(Log[4*z]-I*Pi),
  Sqrt[(StandardDeviation[Re[const]]*80/Length[const])^2 + (StandardDeviation[Re[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2] + 
I*Sqrt[(StandardDeviation[Im[const]]*80/Length[const])^2 + (StandardDeviation[Im[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2]}
];
(* from 20 each of [4/1], [3/2] and [2/3] Pades for the non-logarithmic part *)
Ftri3LoopConstNl0Pade41[z_] = {((187.4483150631075303705517079282051361182356890460270249873752`49.69897000433602+ 958.1580263872470371365942146932415806835824358156615769253609`49.69897000433602 w+1032.6255810812470717453374270086150436363893955507556344860114`49.50808886173876 w^2+90.2328462490312145942786691731124226062024521092857108756294`49.5201875395537 w^3-301.7874889092830359195880148985532555026646115943713141986392`49.51720831915926 w^4)/(1+1.69732390517030087124842602473869442060797219228569592756866313689862708126148`49.52287874528033 w)+358.2547292322099678783542349617076492884432135810081252910847`50.09029891801215 THRSub[2,1]-96.38520878023909530636388932574856334301270035325657706843920665394848859573251`50.09029891801215 THRSub[2,2])/(1+4.326834603215094018550378594095808990091461556769384105973957761213573529632`50. z),((73.8405250159121745762875497245514450430664710813856212144284`49.69897000433602+ 143.6399926710260169330125988918039875672033296770651341056529`49.69897000433602 w+104.4824830294024761077334327770073541676009266578379669432862`49.634046975632444 w^2+22.05336332973772644531521030488063808172991232951725380572293983296957981126751`49.42078755443135 w^3-35.32490507023697092893694776513260318487640218287073980052647374682574370673222`49.69897000433602 w^4)/(1+0.8707540713854154950337821311185604645979448208196492325455579610299130120459`49.52287874528033 w)+81.35723070637263728882919132783445547921736593411742507519536750647730853245505`50.76109948514419 THRSub[2,1]-21.88843029154569501483468455750904608630546313725542196441804536313220177004691`50.76109948514418 THRSub[2,2])/(1+0.20968818102484195527441055868448180491250494408853413937766816797104891414039`50. z),((74.0747471583499949224518878910538462413602888960708478405388`49.69897000433602+ 146.7985620004509169633664241527432701866702323608777987367678`49.69897000433602 w+107.2601099833416878481211506261677899870051887196281709946301`49.63014357157107 w^2+23.14037341419459463840575860031401430250978454213028801715913005762190525224695`49.42901460129577 w^3-36.3865852295871534045301250873236070000206628939369947948137010484194697556809`49.69897000433602 w^4)/(1+0.89503674796641666506333720666249333391504836937738768547213334100531369389136`49.52287874528033 w)+81.92810287379577178969646923400989257408274912233282506937027872256157519741304`50.7469024236945 THRSub[2,1]-22.04201830742989499168665260866241317005114289058032153152038329932616478414033`50.7469024236945 THRSub[2,2])/(1+0.21817639169538667336900593620259138499132452064342774769358563452747746940071`50. z),((223.9216815230130009454341535363429368487136395091936929780814`49.69897000433602+ 1203.1886988202260714319658859041208812409100085352709574305457`49.69897000433602 w+1321.0002342370926175891181612809253273840517355186195729496282`49.50521632082569 w^2+101.5804245072586544773842916035225837997958318237797656064676`49.42352248292215 w^3-381.6234638974942762556427589237503433666469744428669257045751`49.49848538453843 w^4)/(1+1.71129077626734226331815051178518860695566642986592521565779222192929582082102`49.52287874528033 w)+447.1516607838973782398051865155230755729124664333817683428218`50.07078904312882 THRSub[2,1]-120.30212768845612620184124071216779779345164980960082745247270910592625475638487`50.07078904312882 THRSub[2,2])/(1+5.64862943931965313621515582778364738981985499906042497178478803822680453192703`50. z),((172.8518000723371343783840210290327632040904870339217490048916`49.69897000433602+ 859.9234683941121239293049600190707357547998247283047190844581`49.69897000433602 w+917.1176357905216769517031945753770058218350707760196508671796`49.509751757919695 w^2+85.5800761429206735035333540510787584899190031291839444949573`49.57407205214947 w^3-269.776959119122567710384162553465811569275368943037733904787`49.52804415191823 w^4)/(1+1.6890755680004196447565657840282151103024953820882904033262581322145632050659`49.52287874528033 w)+322.6784849758946684093943717290010329601137615734353478156073`50.101508694113534 THRSub[2,1]-86.81374063071707804279146197298238233540256127838257361927390373087533789807263`50.101508694113534 THRSub[2,2])/(1+3.79785688570354463984040046259982803896569760115608066269896749405334200389548`50. z),((133.4707263158936970321411804101908460730448723672667799603252`49.69897000433602+ 593.7315447267874338387538155431198179366258055192376779774815`49.69897000433602 w+604.8057651841297856873551627338663950231653276812333019459522`49.51748042497034 w^2+72.2859425046555989156583068668374178079019156708061623259565`49.69897000433602 w^3-183.0115419566304827577761380154461802679627503941330388194857`49.578393177528184 w^4)/(1+1.6491513999403109015370324597123814592030750564862997300665451084233192044337`49.52287874528033 w)+226.6945669022247843678381838783715591877480631335668164065387`50.15284422231012 THRSub[2,1]-60.9901318177834820553198820611776545726688852924024126788588986061655005780415`50.152844222310115 THRSub[2,2])/(1+2.37068673433456083178605575832359942393969474849794409820448608780029640132207`50. z),((283.9013460374498183422614484295572030640377332177945457494709`49.69897000433602+ 1605.4720748583511919776662186911726063291694164258153951128435`49.69897000433602 w+1794.8392954867429781714750427888037053604683833393306794984252`49.50251223072613 w^2+119.8158813564708730924973170599960213197255947396409236749351`49.326049008181656 w^3-512.6813934483621107193597104261569885284550009881991048154006`49.48085238021907 w^4)/(1+1.72411591331111115379442236360817171640352572486171747267110546067672486398626`49.52287874528033 w)+593.3407474615542566563339222127217141747513721826823676809456`50.05224740076105 THRSub[2,1]-159.6329850117251535764443412411998635598308533380602562379709`50.05224740076104 THRSub[2,2])/(1+7.82229253986230396686605598111512019161363646804834801809946019277882016060263`50. z),((71.0846269535056721293926043804885335643660700989757360704036`49.69897000433602+ 96.3394075827740767706981937359776740221878403783700057302024`49.69897000433602 w+65.8518133322183275710918189806968427357087785628144836699047`49.69897000433602 w^2+2.78734092197651477274745340121027458864323645844882323941180544908010365578836`48.89968292570472 w^3-19.33538592593233675207186286649362845743509302273836866459979914135372605542788`49.69897000433602 w^4)/(1+0.43042654189813876615162041661020730161061466429862496905503415212174398193995`49.52287874528033 w)+74.64025047679901214225251382816932761801134178667428852354084279233266659238351`51.00459094651076 THRSub[2,1]-20.08128724785804124919861427463976066851293344871076813626213458197810983818573`51.00459094651076 THRSub[2,2])/(1+0.1098144325535055930609806244598493217151415970888620087921372526550184628793`50. z),((76.0499341024406084654421574656440820135079821092748126999725`49.69897000433602+ 170.6154187163391564967019331267275908946860582733981686972808`49.69897000433602 w+129.0340743374860563204902598883104402332954537142722131366053`49.60585646292885 w^2+30.50429308178547365416596254246371938273541429756628249270414602387762050969757`49.47724307938516 w^3-44.3646452632767820100592373421988907259213068102197143083806348838401126394824`49.69897000433602 w^4)/(1+1.056791574179035811787612515068090183904312245783197867130651062329860067437`49.52287874528033 w)+86.7422474294849418746355445531252360082208722146142201985508289247693395148342`50.6484737613219 THRSub[2,1]-23.33722054828459467673774211192087502478823913330000675412904113263898802063263`50.6484737613219 THRSub[2,2])/(1+0.28975716847699017745564070523773812733589463911583594803051427771479269422764`50. z),((338.2877789029657646517003572898989256966376339530523970995428`49.69897000433602+ 1969.9223780893372667754122486803900765140979752136716968951294`49.69897000433602 w+2224.3059254608889351809465910582548410785462785836939119698111`49.50106133448402 w^2+136.1463742087055708755208766732242265903406009627838419441811`49.26997207841357 w^3-631.4070445842502304939587817373148086112361367053834835717365`49.471386930150665 w^4)/(1+1.73086972626509594446634282441150332883139777926530422729619391605473547269326`49.52287874528033 w)+725.8973899941543079666898189793315466828014819867014130542556`50.042225366920434 THRSub[2,1]-195.2961559992903554956114600104335501849619161395453732210382`50.042225366920434 THRSub[2,2])/(1+9.79325691998913287024343737782793720877491028401865767069420301815986153470619`50. z),((71.5528738582962296368796683047366837434653246475489336312836`49.69897000433602+ 106.254681906636141842070079401857417078011916958419853109723`49.69897000433602 w+73.5202868784115799629586592879420744621605166921508253313482`49.69897000433602 w^2+7.26020854665569035142423018059081302210410510098158211434899825959754412412783`49.189147407355804 w^3-22.69922592357735184000161782613459024546588523472758587268250193563539778604756`49.69897000433602 w^4)/(1+0.53388751369433481054162754093989477268745115775519649009622774209618192465647`49.52287874528033 w)+75.78151373502372512006259194053681613780492047245666954894056637739754608167854`50.94877713144069 THRSub[2,1]-20.38833385029355467272542164595941014386153699143940161690226570755837353734033`50.94877713144069 THRSub[2,2])/(1+0.12678370084011897394568536983446490961746480238480757745468173564480102224206`50. z),((300.143653358375520708159253567978960460325041108530300272711`49.69897000433602+ 1714.3352846186557965446766210381152997507218077385762980366023`49.69897000433602 w+1923.1104221594779468800004786724986268174936838434170219998936`49.50201064322483 w^2+124.7066735858084629311458818771158265437005366078760545499071`49.3070140335252 w^3-548.14582538830169202000384459751133612887575502804739983936`49.477580481075094 w^4)/(1+1.7264607889441094467351264279977772563206411345066871989426295358006567528955`49.52287874528033 w)+632.9282992094042321157318263191672636289945112292395194830076`50.04878861353678 THRSub[2,1]-170.2836593196192058547225752462014651409562103621234648393959`50.04878861353678 THRSub[2,2])/(1+8.41091377302495597494218946024273042753732416032803178172177942638854095310972`50. z),((210.8132035534386169271757211032649410838249747232253088542456`49.69897000433602+ 1115.177866117565543601660598640664479187603490901706597576244`49.69897000433602 w+1217.3895591290869690925332874956223211752280366825321100140892`49.50609044907465 w^2+97.5359677586796622924631793629219179871355482481664958387599`49.45354152635743 w^3-352.9488726714919021049465603997880148893962715703529726392308`49.50418363928857 w^4)/(1+1.70707816534570932441162722983442217004988951971892982977759306042093417307147`49.52287874528033 w)+415.2022252940570323639578336860150200603445377087739705435625`50.07674593593053 THRSub[2,1]-111.70641977777832128067480641341765529621225356172159017005278492516722914765211`50.07674593593053 THRSub[2,2])/(1+5.17357818490855419633345870674257928475072397261344145883744697460993195366711`50. z),((89.0711400658239168281670667850337894396742770543175532605367`49.69897000433602+ 283.1414376833712319944128700481295736164615670546573900904567`49.69897000433602 w+246.591256141437536751581912828399778677686572329465549307044`49.55133063047594 w^2+50.589858496996067533832526843954649725358953714969469207884`49.63093744626258 w^3-81.5535745330618488381290798715783899011948489590511574347835`49.69897000433602 w^4)/(1+1.4441860130750103327731121399491815076684049284897138640474488721935314417098`49.52287874528033 w)+118.47897391234960975822736286762376218935004283252829074062604323199304810713864`50.36416557830429 THRSub[2,1]-31.87570101610148686806189363549663561027134373932722368844431086903310218005713`50.36416557830428 THRSub[2,2])/(1+0.76164568529854806441365230260703760951366262588561387503991097646848457324813`50. z),((299.0961186040449420179333525040878757067443814526174159918706`49.69897000433602+ 1707.3148822878712290070832251634928669291319128535825698275317`49.69897000433602 w+1914.838052508255536165344766080880974582446152643715907184578`49.5020409529869 w^2+124.3916583590278542126355993696564106549971802729600204223983`49.30817426123446 w^3-545.8587985734702662093737504847581260741672890533525436855581`49.47777820555108 w^4)/(1+1.72631939479342653614602910397148342273260147755074529190952246648769448635273`49.52287874528033 w)+630.3751313943053104687518365287982631423335404526240988297226`50.048997796353795 THRSub[2,1]-169.5967525104985093861027917506909704977369360709999702534621`50.048997796353795 THRSub[2,2])/(1+8.37295111250563396860872038408051045822308997171159186709422153661818215114617`50. z),((237.7800371736408418888826323065892466890116015189724593607032`49.69897000433602+ 1296.1885870682322426331886935867931724210004751801914191468395`49.69897000433602 w+1430.511429708511096879338325416576877920626504041276638635717`49.504431047378155 w^2+105.8270117469005680977435112756381887916709202644031068101251`49.39599961885163 w^3-411.9225522780372034315633596013365631118421835453979602034307`49.49336566443874 w^4)/(1+1.71504729133461876035333779804020119269537089072680036278387464153416726458064`49.52287874528033 w)+480.9287812766569751715624842044296384070197591076235428803588`50.065422470251036 THRSub[2,1]-129.3895577906830093742710093281636117866948158200812117604352`50.06542247025103 THRSub[2,2])/(1+6.15085626162400132027869346937126780226248755784518682482725765953428703433486`50. z),((81.2790102962980124408613605127059082575423509630443099231864`49.69897000433602+ 220.8396292995558338718150911853005677486780990205444060047002`49.69897000433602 w+179.181660548188361316693250423732265516080450904003245821217`49.57348610371895 w^2+41.793091467642804092298367140791259906895965080321432516388`49.54914271434978 w^3-61.04437015001585711598562052499779600034967443044308556927611623467748783814924`49.69897000433602 w^4)/(1+1.28923381045150207203068834931643079493968271603087353722341902162450975861474`49.52287874528033 w)+99.48713153539548072818539160306002695324233781800345305669249048796978477221781`50.48947400743789 THRSub[2,1]-26.7661168480230812041580044268472396857481196189024134932859055656741576015144`50.48947400743789 THRSub[2,2])/(1+0.47925889484590053378689536912049827251355073547747997492564695622188555615975`50. z),((82.1036239812734755750138416489148329867647983467625798977898`49.69897000433602+ 227.8836974598857514895938062042973374558035758606876214480836`49.69897000433602 w+186.5783662889317615001144831882137959032599175909700606604408`49.570243394770166 w^2+43.0126245853198301521508853335214081647735476165391416842588`49.558337350515245 w^3-63.37112247929619309226950352967572312383273722722203448860782618387076916993182`49.69897000433602 w^4)/(1+1.31251511684357020440357816697474047580853496174936950782731983723776269953849`49.52287874528033 w)+101.49697141103273662492407057464536851212280887218022213827988989054033873676067`50.47189067543673 THRSub[2,1]-27.30684616775408174167953864517138295545446450610127353214945974114100515831524`50.471890675436725 THRSub[2,2])/(1+0.50914289559422476056454641277372972764518997519915329309785072663537981082302`50. z),((72.9180746376773650685900518723500067480336020533272079739771`49.69897000433602+ 130.21728077077036630389643413346639118388386702371463011954`49.69897000433602 w+92.9672463014759081676502629015658184967566071823137323600577`49.65305837043701 w^2+17.14387101664348000764624981416228760864762371505837301970669387139886666853698`49.376470051571935 w^3-30.80391839440479215010402221165690634396350568640707689819086110526990151300062`49.69897000433602 w^4)/(1+0.76012043594160779689539724849105545475997956043137828180525108924276118381289`49.52287874528033 w)+79.10893239741581298076476129575516429865448002121630542544260297863844342169595`50.82435254066889 THRSub[2,1]-21.28354587767211898118560367404557159325698704346232815445449646218132329568142`50.82435254066888 THRSub[2,2])/(1+0.17625857841731153206070360077765836303275302457282949417695613409163239464269`50. z),((76.1959356430458860655017317730288284569761533351987828425941`49.69897000433602+ 172.2201343110264524388663780796021097035910829865184190670073`49.69897000433602 w+130.5524691744774758001063047036852744629505900867861531412559`49.60448794819591 w^2+30.9489860731755588213283965466391165434569400933765224614510138310603167540689`49.47993104752626 w^3-44.90046219018529071107995671212938900739053924656275242686721036961128328398191`49.69897000433602 w^4)/(1+1.0663708878274879654755177429048791466172955200591790062443334127835078027564`49.52287874528033 w)+87.09809856748987368747902601816167024620104641020547024778539429457104490249738`50.642392889852395 THRSub[2,1]-23.43295909248971411149851227156078030266328567380611222314170496881175914400659`50.642392889852395 THRSub[2,2])/(1+0.29504826445102125686232269397723427718829945630825362480860794199740484514324`50. z),((70.8196463656161619983765608033793866438235810068663198150251`49.69897000433602+ 45.05183283558701506045376822230718135219520642128615539391453504720896605340217`49.69897000433602 w+35.9508577510012810979629357222616029650052627587228916555497`49.624199225400794 w^2-9.75797654677738373499990290904579333564206886588736552140668513882708144128029`49.35249437518756 w^3)/(1-0.27369785545184030782754685022999210056145051693019439966884461137216003799028`49.52287874528033 w+0.22344741659936362545658771091783919390126802559207521870898048934787391320297`49.69897000433602 w^2)+73.99441041676412818492597462753900913207535925416116888123326064168195407004943`51.04055847629049 THRSub[2,1]-19.90752979556002502616570020152507060907847769321228186623245345692178232799798`51.04055847629049 THRSub[2,2])/(1+0.10021153578977174926911118723901491765137892643432266967437654429302477296367`50. z),((71.5955020537788815548370066137418000842395196971155124914072`49.69897000433602+ 46.69924218862085254429234906509646492459564723313899841121857584353245256420729`49.69897000433602 w+40.5303474870357971424672652195880129021603301047535310237836`49.62465552145771 w^2-0.88954349734281633490632864601636624139538232105487799836553299708849866548991`48.37943087054212 w^3)/(1-0.30120082030704863209039365531850444745696842720209978274308507025946571650536`49.52287874528033 w+0.3343438954926664247850004667986896186195500121478141038155011611381609170022`49.69897000433602 w^2)+75.88541189808906777161399577913333256460034481764107251379689643874062262505228`50.9441122999893 THRSub[2,1]-20.416286715452929704713856779515683336695146667960744137210340959091165573102`50.9441122999893 THRSub[2,2])/(1+0.12832854668601490643314463017990509441428352649191419585585859144916017551313`50. z),((70.9178155750087308341260896521511123987776342045019214533739`49.69897000433602+ 45.29887427577196975106346087034574520776147169911888985384033274762921672746301`49.69897000433602 w+36.5572811074689050305023382083457077947058609059492807461972`49.624957523783785 w^2-8.67298926362765331663772879669783365075375809793398468969060636851900482740471`49.30934329021103 w^3)/(1-0.27666685446770365579298501442903268571704046948508221331475056360683905366562`49.52287874528033 w+0.23736184366376027524200720344149346267906044494337371033691576183586439674236`49.69897000433602 w^2)+74.23367929526065615694049775589205992439340361785332929097286599817246689762793`51.02680984796034 THRSub[2,1]-19.97190293267932157298347168913730846728191884545201686176069652569192562349897`51.02680984796034 THRSub[2,2])/(1+0.10376918803397045964517575691307263209149597600526083128368811129099319764551`50. z),((71.8996842826999026847976253397066038016270866878638599303929`49.69897000433602+ 47.15520681224285354757778852887556097879166933766174355278005039274909776210193`49.69897000433602 w+42.1939130600680775027008658007855686674109749495937519655299`49.62184622951958 w^2+2.78684395836566553979933261859572143416937655462604428275196919270190800973296`48.83999187065406 w^3)/(1-0.31446311493691264993618294640658723947432941364313054215269473337948636087956`49.52287874528033 w+0.37854000670385810560172221999005800328891045158285917342573602742250968055609`49.69897000433602 w^2)+76.62679854287156336701466434815064487487100677030372901370720059748751211669025`50.912544409359676 THRSub[2,1]-20.61575011597073391740282757282177494632272741779533475783821905802820435294106`50.912544409359676 THRSub[2,2])/(1+0.13935211095899105819601068987541142671762658956350902057979617220909032218569`50. z),((71.9606283481129032402671226116848595159695467256010086173546`49.69897000433602+ 47.23366819796167344125362239776119324645487541717364261469296890463698317728046`49.69897000433602 w+42.5183140660545445019599591290646650595555145761330039615783`49.621111818969446 w^2+3.53818039906591435246583872022037644669138786386903692849669432613414533010037`48.9328466490052 w^3)/(1-0.31728594920942242791628983003254922917592371230731135669645079109461498562849`49.52287874528033 w+0.38745410365274993514620037687909828375516112322606048818191319477619902926252`49.69897000433602 w^2)+76.775338174316242243336254041680809302918511204670425453970460749834213012772`50.90655624323695 THRSub[2,1]-20.65571336619667936917024371140744286558578785945275138373587047177037661463102`50.90655624323694 THRSub[2,2])/(1+0.14156072394903890304491903056399539429439285921992366588675346207778413105056`50. z),((71.7002981953602954589121365137415425906600212821194225098014`49.69897000433602+ 46.86841621094927252740325164443169281013596278911005710297121993898972048734808`49.69897000433602 w+41.1118267174517138779707791646834663479287708309026044212738`49.623854374879514 w^2+0.36344576643676984918085366147718283780514672946267220834210908532407543277917`47.99194706529249 w^3)/(1-0.3056140554029708814058480107811078909643771720493996092258370403291630378244`49.52287874528033 w+0.34951683872154778182828606882260940332817895943962880941471825655593740744326`49.69897000433602 w^2)+76.14083267026497509685974217517719721024129780423958988138016629802562180533863`50.93290543487349 THRSub[2,1]-20.48500537411724437679298970281101515454953734939172670362207963325830622586555`50.932905434873476 THRSub[2,2])/(1+0.13212635895920517144534281695927561350190135668174896840947460330248388046398`50. z),((70.8557342125161290155834999027345552815518575300894620191815`49.69897000433602+ 45.14395629803120832044980173018426620870648046495020922347254615814476105222658`49.69897000433602 w+36.1747051518735254896986138971733194671321029152733722896545`49.62450448549156 w^2-9.36029275077529601496888108672181267589471618172300410534793485481596246228356`49.337367449845246 w^3)/(1-0.27477176857083881081173909864459004454914220355452150519904171998055282648685`49.52287874528033 w+0.22855926660035195484600130995866113299002333022198431536756996788520196013065`49.69897000433602 w^2)+74.08236771731220754051996053951934689007296468293096112278134445417846940060372`51.035443265728 THRSub[2,1]-19.93119391520819252552977745956796251437431959909083055801401037164883618694612`51.035443265728 THRSub[2,2])/(1+0.1015193593966478761940413443251385910047070421264481072761613055012515830765`50. z),((71.4095377955918871458654536572265889164861882638183178642716`49.69897000433602+ 46.36781846315787909918079834766190213460672265554560430281696937436646918137865`49.69897000433602 w+39.4768737211470578655489300107926562769674175933373540887934`49.625615700064195 w^2-3.07914548629090746497048641547481993258917033855832768753650578541906269132664`48.90174290444742 w^3)/(1-0.2937746787423095831969240025866845372586855360159521182828591644942324479919`49.52287874528033 w+0.3075462109601791437754784323004586631352031572424805605622770585535081971811`49.69897000433602 w^2)+75.43215919520839123951037236638784870968808351503610173649303486346950998552383`50.96493881202697 THRSub[2,1]-20.29434315732882975500086873530988607503969634072590652943233829217052046891318`50.96493881202696 THRSub[2,2])/(1+0.12158920178781925856994535564955043352203765310800429658331516465613352583839`50. z),((71.0284777910119198044117861664612184293210180308648398731553`49.69897000433602+ 45.56388303618645349930995758257197117613035345175831749988707216851124964416954`49.69897000433602 w+37.2314156834882892207343574359783716378064459980813887628698`49.62554669124973 w^2-7.43768584916337971245313812458546202571322108238734464274474587551765364551012`49.25180732190626 w^3)/(1-0.28019350655244750860626653966257660509487890982648548988212736699300527056382`49.52287874528033 w+0.25308198292672536316939398459489067231348557621995242771337673124090464676304`49.69897000433602 w^2)+74.50339751423031891373803369210474680822500504611136911040677833538523038239869`51.01191684361461 THRSub[2,1]-20.04446819065355703223692270222240475798875258292850815179722495675051423093457`51.0119168436146 THRSub[2,2])/(1+0.1077795868499310740143731541285085561041340835982809493725683039971325173523`50. z),((71.1884512625018845221023351856497842882316351043326178514997`49.69897000433602+ 45.92184423034594421072655041774795070992497755106874605835683161106634046192732`49.69897000433602 w+38.1883503380035785257553265584681264781544496078186971246652`49.62592989311621 w^2-5.62818677109192637549734145292134452405877463339417325124181414513803838799997`49.144306969653876 w^3)/(1-0.28562534813777772283785108879956687095981103710312837213438126853968943337923`49.52287874528033 w+0.2758797110500087767413635783875176643741181570203416458516663473967093768313`49.69897000433602 w^2)+74.89330259087747380366115944001571458989815708964899793808615018556848004974803`50.991429771289305 THRSub[2,1]-20.14936864039124136261733085398734757168098184006134630113822585189024173966799`50.991429771289305 THRSub[2,2])/(1+0.11357702561285965791037531963280064691967684813100363297065422058465360817718`50. z),((71.4508753108676092757225599325349005742022323830497735955744`49.69897000433602+ 46.44494028588892556029663245634708489896077988686610204660369794589922017412885`49.69897000433602 w+39.7134403061461364418474440701578722980764115300919115800042`49.625455118908256 w^2-2.59609605183501964884089168280156945467649483592052432352378592894598486372346`48.83134598483473 w^3)/(1-0.29538046603606069997398938771375329188950571446198022117658592282052258908741`49.52287874528033 w+0.31348955671405643995034081868436517026055108977339028929335197685831047044552`49.69897000433602 w^2)+75.5329115694106004580759580423205297686096334387835023582509979064752972412786`50.960200354587194 THRSub[2,1]-20.32144967632272224590388657003820544845265054786071463163648676806901764841212`50.96020035458719 THRSub[2,2])/(1+0.12308727338175636654553549979803080134999592206647063893652921258114608941636`50. z),((72.3207656382885287641985134953840521999728510435660339544188`49.69897000433602+ 47.60886404643375427975753434746364894137688488657135908879565196639573799020035`49.69506739066541 w+44.3743500497983915431708123765530694306408445722615034295198`49.61570496655157 w^2+8.08404675331693912996648628577243216335338132690567198769388224267796376062579`49.231061435986724 w^3)/(1-0.33509294051161378976627609729349001271524666969637922482931307404836537135922`49.52287874528033 w+0.4405786423964359207048888473287654686326057836606012965130646661722814779529`49.69897000433602 w^2)+77.65310469661262540640249854055892253709644678200879796238413878270170231676961`50.873192626246315 THRSub[2,1]-20.89186854464515059553263086260541390250255011595013299202935249665651680402813`50.87319262624631 THRSub[2,2])/(1+0.15461209969649341226456659380392376305043519822121624695949719391277544538433`50. z),((71.1162666030279217826457450741149033480007181103544694708133`49.69897000433602+ 45.76399427488375680508393895879639738500276856975224545414933275239736609920341`49.69897000433602 w+37.759120083840418866240628364363154221175253128216081539144`49.625823384268784 w^2-6.44822369125447124381043460492522587421039134436691148620371965058106231328631`49.197212937825164 w^3)/(1-0.28312572895512261254728033622350648820823414040609302251370352360165949984043`49.52287874528033 w+0.26558152195155061574960388800765405999863737529411272563155340317613940175274`49.69897000433602 w^2)+74.71736613764679055702239368445706490673570090227651073782396882769994391663498`51.00052826296962 THRSub[2,1]-20.10203452197489319574497949577624019409943881034713706303975403978472732952019`51.00052826296961 THRSub[2,2])/(1+0.11096105348307185339535396100635554665086851187002202508773496236683748201693`50. z),((71.4582797349047371827167564201978493697349633170921994617788`49.69897000433602+ 46.45854614712103886828743952692533120343567735584213772368605233720044618774927`49.69897000433602 w+39.7556698472602729747720266953791324889720662501935792034318`49.62542310138147 w^2-2.50935247021404586390663084707539854442565826441500756952171227168928813771672`48.81725511287116 w^3)/(1-0.29567081518308006901388975439225054250445377864275583341534723232913900674664`49.52287874528033 w+0.31455492642070260586413643389375894691510834434651478319810491715314780933443`49.69897000433602 w^2)+75.55095845240210632276309250065483068616066383195965653515489143850394696404998`50.95935835415186 THRSub[2,1]-20.32630502767759962332805855348518035618129407511252520311103144438613425380966`50.95935835415185 THRSub[2,2])/(1+0.12335560971608851432885743807314163565251959065042778685259936816376679805613`50. z),((72.3057477801055563888010494981284018706139141727452744151966`49.69897000433602+ 47.59625677805586979787800104808970042002967147117431315146372993881722185901254`49.69556583709676 w+44.2990449468622927482012781947375365783225424697889688519632`49.61596517422244 w^2+7.89075596162391461581087135726798608674569610182332397448583677573225241037554`49.22297613347613 w^3)/(1-0.33431190320724840100695216079014768398719085083081451681081571465341021550757`49.52287874528033 w+0.43834715543492346347677707743629477881499695421584430040923650163717277044962`49.69897000433602 w^2)+77.61650150802535223701684392350703287850119671326413262710309547309476518254683`50.8745193144403 THRSub[2,1]-20.88202078637112082913077118275955297295961505655565231282882178328454789076325`50.8745193144403 THRSub[2,2])/(1+0.15406785250128523705774384044572342994706075874026488350180997120563100419931`50. z),((71.2414793511157693592649214691521546627645530532315640855247`49.69897000433602+ 46.0339614143523848633266126883438170233368200388720299637384203738385391280641`49.69897000433602 w+38.5009899650466116662241347089044518940428971125657615733771`49.6259408609535 w^2-5.021995112646509062638467712967804726642990230460457073662660754833383272092`49.099391940696584 w^3)/(1-0.28751231452707630205631286394270744732247527790568035722295234212031213488131`49.52287874528033 w+0.28345728619330306309848543801165957282759302031915263096498601382381012046564`49.69897000433602 w^2)+75.02254852623711190707983314235485627820613269229361155725391269480409499015647`50.98489175808476 THRSub[2,1]-20.18414109542717054476308436982743376404454452204273970022882266465268343087981`50.98489175808475 THRSub[2,2])/(1+0.11549876359598164710017976277853649325577988083672787924518100740871369572251`50. z),((71.7292588850484104085969192787322266490959214086374511170416`49.69897000433602+ 46.91292928221165602240980830147912809095025201301724478523591391538650959179019`49.69897000433602 w+41.2709721082106823130458900148240408826669096197922512797608`49.62360136235778 w^2+0.71219989330355868729696047632942504884604181261864503973030072262374534446448`48.27866436683966 w^3)/(1-0.30686259951724517157338410052195592998077432611566313685355201447272720896433`49.52287874528033 w+0.35371954920490136051693539821794172153733009724487005591736621448265555372922`49.69897000433602 w^2)+76.2114188732611842537949306874037155607951123694080888151973307577092068154114`50.929871705267345 THRSub[2,1]-20.50399595639755296545721546240122329084938479219769919191596926123100723509129`50.92987170526733 THRSub[2,2])/(1+0.13317589438176775623200179291060925017592741744476543219453008871074974294182`50. z),((72.0275041403415212937136659878537557531420765134284123701219`49.69897000433602+ 47.31479655133238756561885612024819597618762909902970656931304850404904970478682`49.69897000433602 w+42.8708629046682220428419117708630771357674149435000637495083`49.62024362591145 w^2+4.36849558044061093326221932456161923474515004056611490809386626065085657047317`49.01272738467701 w^3)/(1-0.32044703256813428563112601500995744252035137536818948538243256018383881227171`49.52287874528033 w+0.3972600769270003640057887921250150649956028087106319702343198109281396197452`49.69897000433602 w^2)+76.93833526784605446167941447764433150607100378617965061040369280454922914050491`50.90010491772031 THRSub[2,1]-20.69956626640573712346522309028509179290053727343176980300424739795595852130015`50.900104917720306 THRSub[2,2])/(1+0.14398430272467402295698864983903774405394219671256941582825802215781189778586`50. z),((71.9549244186033755816101767238278996093512718091816222217831`49.69897000433602+ 47.22650783159439960860236724237709088762431365785308144885807764141495223847014`49.69897000433602 w+42.4880786791826000501062000162279441827913516502524668347855`49.62118287197022 w^2+3.46764613764082844264860740288460685377115816111577198991822603232427092462773`48.925106186699715 w^3)/(1-0.31701941081323635109884631878095709676079878084428465820311271230093408993068`49.52287874528033 w+0.38661892280047253524994776806809880944121243550070014419788598671507639160427`49.69897000433602 w^2)+76.76143592507523690988335073292406128862404246037597391580021593190496313990066`50.90711222619301 THRSub[2,1]-20.65197309122953248627587823630060620620121897850403194642139406078727298912091`50.90711222619301 THRSub[2,2])/(1+0.14135401353804665130131683117954788728616650780332334588406021905260988684498`50. z),((71.5914791646834171302169727554126624135950669215138186055071`49.69897000433602+ 46.69249512343569365535210032341051995877181492189217004185849522657391878279131`49.69897000433602 w+40.5078508556920936498614914494931586457643431487335985585319`49.624682634774295 w^2-0.93736482374592898471723129436557064457148743643036030207722450927945260871733`48.401798585804066 w^3)/(1-0.30103468048279968189874128833767591898083249555035972344136868919605022279999`49.52287874528033 w+0.33376250327687625967531531642608024063243854094333256420005507764903075727151`49.69897000433602 w^2)+75.87560686687669918622146153981887626343729988979111428368660651763518336741056`50.944549848887206 THRSub[2,1]-20.41364876010052918572260895558935366654700006855024731576781068132551174284834`50.9445498488872 THRSub[2,2])/(1+0.12818275718126898234065193968521373457690196490483726365361342200254553809813`50. z),((150.5223949826070572023382565041360693463801822283123999191216`49.69897000433602+ 680.0266104366549679390333097131408114872067648238204037549976`49.69897000433602 w+598.4780439614794489871535093947468413512391078381250923625057`49.4735454667638 w^2)/(1+1.47658102832932359143617115328680412396529384685222171469219910337086354979035`49.52287874528033 w-0.35038370845834047030849471820581346103590444006234377529686444222437314187007`49.66592974550873 w^2+0.5139286691280264579078705063027857196447885113312586287842816294538459814231`49.6094580191269 w^3)+268.2547838340291969272120849279508773055365078479902427806553`50.125351263786214 THRSub[2,1]-72.17153392937309111891212214991325164911648706457616831611014503465846018593813`50.12535126378621 THRSub[2,2])/(1+2.9886392234584848944080805848533066422252045914449337543304861771218610152127`50. z),((319.0977913625020695577193716039362756643810197954473104760567`49.69897000433602+ 1746.7604608255148592494333903561552762966759676041617362925753`49.69897000433602 w+1605.8875880113654057767415114100064405158814249717103152852664`49.467183575245336 w^2)/(1+1.43239082976485280238087485055309572696535126576945355537221526166727624832402`49.52287874528033 w-0.26511632868395994578239165178203156879736156748455251033938388810550300586173`49.510893152431414 w^2+0.51715898270893741341341421004111924501410678315625460183614663957448405395629`49.58588386432705 w^3)+679.1254252856694123616598021876820555906688812098057558439251`50.04529032376325 THRSub[2,1]-182.7125800806951268538516219318634152823100557308304152616452`50.04529032376325 THRSub[2,2])/(1+9.09781175279352211943402781219296426563132437378660297639800876892662733601787`50. z),((71.7616787707928936455232086566121912855464058293090399863233`49.69897000433602+ 44.9902917499686401638858048127327256966741162061980356030121827645465017718371`49.68380726713723 w+40.16576573139678121783298613824145273289574146518088805232823841710047057608191`49.69897000433602 w^2)/(1-0.33574544144081983728792375208763449560972962607610870648259738103029240614127`49.52287874528033 w+0.36700205387103514943632803705742836320301596406395983313538459877458684574138`49.4010111543079 w^2-0.00946311556944680596513464563439916621574272841309393408975587269191236219356`48.122951860807824 w^3)+76.29043621231347644568809459285553614548385012751553892382279765768569233769513`50.92650715029839 THRSub[2,1]-20.52525485991052681269482863157564638774421657577260220938514872330607814630303`50.92650715029839 THRSub[2,2])/(1+0.13435079107278926318984197274304608096792751310211605248664020097149870452959`50. z),((312.5852040041596337540685953464274207910476588357538943131592`49.69897000433602+ 1705.4578734634722306859174564652605642740717173245128761884008`49.69897000433602 w+1566.9883116077534816551800205124102314335552424324489393482966`49.46727804106998 w^2)/(1+1.43292061457533706594910242845422033762253270176190319735309268336971005463093`49.52287874528033 w-0.26626963995220234455723164598074977783236271835988562639593732589047328778414`49.513168250545434 w^2+0.51703680580528457321065790758609532043825944907970527352298491576694834468254`49.586125903294175 w^3)+663.252225501509627706122236069719259899191869019380404913301`50.04643426832534 THRSub[2,1]-178.4420386185194113932632572075593258186182912177021896463765`50.04643426832534 THRSub[2,2])/(1+8.86179558057098212124629770981188987850279059210203903001539025880881278268647`50. z),((70.8632839206340262052146681710284707232597632718012308936999`49.69897000433602+ 59.05540628976355349152962617908117345532026394062612299408036148749309679227946`49.69897000433602 w+45.63032310214437499874363707027353423748214917222415738508809457716964459395911`49.69897000433602 w^2)/(1-0.07895433167452117765527862838482937520599658077925975835221720948482827511746`49.52287874528033 w+0.18354834088395647080046795801288066672937141601874315822213000318452056012922`49.53022474341499 w^2+0.06857867251588748940527280775981383267753177259899005711052676486654151409064`49.34343837179043 w^3)+74.10076870276908068397205086982286849683558397267113377457521569962522363292883`51.03438224664754 THRSub[2,1]-19.93614453464264883392649584423517434453531894660355219064232533473292564441014`51.03438224664754 THRSub[2,2])/(1+0.10179296082620889836678521564253299816392445621962822033557568232098938806378`50. z),((330.9189356945511382515817011936711056641248356432450123385843`49.69897000433602+ 1821.7349765420536635025396460950937406493473135924315684152531`49.69897000433602 w+1676.4918890034382603072740335120934194827620138139822268672751`49.46702318820856 w^2)/(1+1.43149836788297574328577418891756957117874284784015919848853055058667765427314`49.52287874528033 w-0.26316574633842607192898756389214434005452118202382094084111405458498776886846`49.50703076335507 w^2+0.51737084540390466153446680187293059317361881556921847087873267058135254923859`49.585479569485244 w^3)+707.9372285422725379824386245840354589176124004489047763352133`50.04335187881708 THRSub[2,1]-190.4641362937126982820679960759785569489673875288785564113815`50.04335187881707 THRSub[2,2])/(1+9.52621003492428085397159903082592047262551377481512006287359994751829748302872`50. z),((71.8285227996161109881971214185462229078023770719585007332415`49.69897000433602+ 43.5853798880027932259941674411645833911198793361722985593004`49.660511110416785 w+39.55868450722732328318326911826126406321012053444723650288270589142518466427843`49.69897000433602 w^2)/(1-0.35958478147097693605707754271912137614903499534207060239529800603700225944949`49.52287874528033 w+0.38351800790925855359540360423363055796977601027269345051006241394598858596576`49.40003157687435 w^2-0.01663188932135376397777341932829677013134618761531129632509866228481339862682`48.34517659988889 w^3)+76.45335588855089643328712800455610050414271619644388030454714143828538884152337`50.91967276601024 THRSub[2,1]-20.5690869316942169023858656064454039600881364729677598175805717866970797197567`50.91967276601023 THRSub[2,2])/(1+0.13677321874258166062630139837151361734800541727686273171788098855581908766535`50. z),((134.3046923488970831273284646550684823256905680036271959510023`49.69897000433602+ 578.5111128828281998706206330488708684968705556371215681738015`49.69897000433602 w+501.6066040739281019974430728190643335609022154175679363976532`49.4755369923515 w^2)/(1+1.49493943412482725693257713099469289362899905043249724685832849456407914047115`49.52287874528033 w-0.38034172500050384302166343893035916685968124784302135538797445191452997640876`49.69897000433602 w^2+0.51535112859951319144407555055888436368044628331668046095729163616527997805448`49.62025098567124 w^3)+228.7272013571175571397039207606368104684614613840955654090012`50.15121927649992 THRSub[2,1]-61.53699381379571217708668812028542879459235948733679678186653294871355843524133`50.151219276499916 THRSub[2,2])/(1+2.40090966418454477044687090437895868806944961502699351570501586399451539956386`50. z),((83.7324418819845511121703351579751507498036394785358604864434`49.69897000433602+ 308.9289680847098436316825041517243031601445493017905519007826`49.66348085670688 w+222.4407369702722408561695605202680044987161718601233205983798`49.50103657207622 w^2)/(1+2.15889203201124659646637292023563316138567164603595865627998577933196545538858`49.52287874528033 w-0.97790699979277268396444451222842761295385390819609157445289190483587863256533`49.69897000433602 w^2+0.69115451577291290961120995188572568419810873344612032718982810853714136699723`49.69897000433602 w^3)+105.46690694163006603523258257970193383434656190136036528612216781333344770535393`50.44091422938721 THRSub[2,1]-28.37492157259457195841937920489524948245581318736796979974096683662982806410857`50.44091422938721 THRSub[2,2])/(1+0.56817125790570161711323743958028775279276056106691843295782129501748984079036`50. z),((71.1212348996829125562623318129741619191396435964057783575097`49.69897000433602+ 55.80098418664419943300713685451150268923676612030455143953693921044966821314629`49.69897000433602 w+44.50107524698846747757998943062948816687466866506432251970321390419253835309558`49.69897000433602 w^2)/(1-0.14232561442441589601732543693517908628604283791687935546469857216773063488521`49.52287874528033 w+0.23000080693930899189706099441380457188472748396272642192649595169217363315314`49.45289754356071 w^2+0.04913120800029864283399656356155198975197748461730469206705509562949651906267`49.0507264814381 w^3)+74.72947542095500144946216332497907951060434723538762567441399104266586795404591`50.99989450515293 THRSub[2,1]-20.10529241560365937974695774653005460670217287645906545466553706205561029170683`50.99989450515293 THRSub[2,2])/(1+0.11114110455869771924621523094841998992703032624230725117161344815649306982096`50. z),((99.5761698046381792578187280338704154533559988223587823729944`49.69897000433602+ 368.6063186812831443486798853042474838358616929129308592032863`49.69897000433602 w+296.874068661353294884985691342791112382613412383503825854079`49.48512034651742 w^2)/(1+1.62948476749378142938431186592393752440594319176316250127782010152218243614519`49.52287874528033 w-0.54821219504739008047431648215912443088997881247648799135272882497478669640191`49.69897000433602 w^2+0.54258758096116569619252328677612627812841974693098378687659026343648487004888`49.698732830130986 w^3)+144.0829968002942531594112332433758001679734236934762657854903`50.273091597476494 THRSub[2,1]-38.76423280731471340731478513902120107107705210354262437816919760708821269217132`50.273091597476494 THRSub[2,2])/(1+1.14234797328596476122764394880869648145453594661110752890322375012747956792777`50. z),((220.6938987453797215217454511221292823307964206839472109453342`49.69897000433602+ 1123.0783422729819667845622476755940340885395237984107606195464`49.69897000433602 w+1017.9713441628404872197010817859544390560419205923403326781878`49.46937010870679 w^2)/(1+1.44550375919282528497697934605440562208240942547003068079162369172093449661496`49.52287874528033 w-0.29266671110518401969071538988574182982202924315603059977607529383300343552434`49.56365317238122 w^2+0.51485452913203747204588026148794641195678841649590289969743147269631495949762`49.592263596786 w^3)+439.2845508212782386569526436650626974523311680110357274959092`50.072168156251614 THRSub[2,1]-118.18555259712591540254708164250780766595960426634195961397157954975895805690452`50.07216815625161 THRSub[2,2])/(1+5.53165458830794433853377418755295520472170877222736369187130608077046458327948`50. z),((144.1034495266093429910926929542033130868737819213630491894203`49.69897000433602+ 639.760624804981631542924748565524291019416852692721597343857`49.69897000433602 w+560.1198522817961653764035774668105296986415279379190674062145`49.47424711461977 w^2)/(1+1.48275440233702946787420434416441203184950515689585936878717869305151956337185`49.52287874528033 w-0.36075691553421053480939495281524583983721531224400009911630429375876745406613`49.68345426535514 w^2+0.51428204764617762837437481903543676038939885665941105942476861547712844896188`49.613059281786725 w^3)+252.6098184738088493962020880286081505210491736743333418412703`50.134445672494955 THRSub[2,1]-67.9623968836844544081557898223854732561572460822784379724769057232708416716858`50.13444567249495 THRSub[2,2])/(1+2.75601663386831102305140387209037767513848243878856491413877906837678863001612`50. z),((71.2267843284148151800913744781749041093218565709863854402648`49.69897000433602+ 54.30766384215255461067942306873985232848485597038330041291513833554082346968668`49.69897000433602 w+43.94816223985502843228003173878464702336704605995853581508743170817375007580647`49.69897000433602 w^2)/(1-0.1703934884243011982223346426041208334316431542100200705113580461381682734726`49.52287874528033 w+0.25028292200205325050487638366273943428062409705771642322886535257293597909422`49.435679024808586 w^2+0.04056643188136921718645464183043646378323574221918582095114364057349004129512`48.923210332835886 w^3)+74.9867321880706513051016827300690804099024813758319644211205065737476146741387`50.986691471175725 THRSub[2,1]-20.1745050321731936207209303305208345490893203128821591989396146336325141423392`50.986691471175725 THRSub[2,2])/(1+0.11496621595895689503034122605667635165625550376363547947466634932298190866006`50. z),((234.5140036067708451453320104841263919027336453948856296697224`49.69897000433602+ 1210.593624731024696844629883807796968860460630484871951537095`49.69897000433602 w+1100.5650269103413307363976764501452120612161429836972430477468`49.46892342885014 w^2)/(1+1.44267257996376775683667607396924181579860822580177581980366442724537110846218`49.52287874528033 w-0.28689194569394089109908782658653551170792338629610347690817705393976491499135`49.552850747858535 w^2+0.51523300343257605162468280264354566795212787906792952002026581224944304451181`49.590824249379985 w^3)+472.9684422506797149026843029728466164456156269161362547330863`50.06661245937436 THRSub[2,1]-127.24790025939334110111559874825065801084415870902179030262217501607813164708163`50.06661245937436 THRSub[2,2])/(1+6.03249520197302155793781379005300025135334729740195181634668350381050737759443`50. z),((71.4940281446498171819508934258429974499762271849039842978456`49.69897000433602+ 50.04821712247826149708930482529488840519006824379928701946217383471079716579734`49.69897000433602 w+42.27983855132750899513221058361687871569552992661888332971496382083371653404111`49.69897000433602 w^2)/(1-0.24778118835958232232427764443646665200615870261558587430687534407132177304398`49.52287874528033 w+0.30543469474611673840631355161073448032743410604470104222785099465026433269937`49.41071228859732 w^2+0.01707389088000797673253488578380626135865740481043579173706378896923372678346`48.458607412190084 w^3)+75.63808843909207879057331160807438347759292497510583669659043500572970304954495`50.9553215975109 THRSub[2,1]-20.34974656598228754541393875375968967086598745927345804105353874596398096974469`50.9553215975109 THRSub[2,2])/(1+0.1246511321201402489754407757008787141860080996974118574151601021791047374043`50. z),((71.3371159109598029925146922623579083242033894437777813109972`49.69897000433602+ 52.6361511454997493256897723956439034430360357023788478403323004199328306191098`49.69897000433602 w+43.30816343712896180176332856930483445049983994143355388195261923786827420890817`49.69897000433602 w^2)/(1-0.20119371445089959354325656263351588330175217623688533166657919240002610203387`49.52287874528033 w+0.27236000883209319145053849177168120595779315593694599770863343292919706642411`49.42277788660728 w^2+0.03119673586822678104845117783687464925409480571271569668201573147057900834441`48.769104977646165 w^3)+75.25564455052759768106808900250254632724559538763240971118204597424346723686557`50.973398492131885 THRSub[2,1]-20.24685348170950127613110745806651039726488935415631962226167827831397101552041`50.973398492131885 THRSub[2,2])/(1+0.11896463261806960499798886098019162850013655561353369304673164665872256640078`50. z),((138.9847214260333886864386471871063589379096225094835928070697`49.69897000433602+ 607.7255877306329997352885138730340757687464767453507024717935`49.69897000433602 w+529.544861195683051673352005441418905224055518771108040267544`49.474883195198665 w^2)/(1+1.48862341935623632732980059645444547399758559685516497495945835002712769730747`49.52287874528033 w-0.37033108375918075167861701064137579779855603625599963401535423260349923719376`49.69897000433602 w^2+0.51474012139758411405611016872959658934618438200070103547067174771633159680996`49.616512133082736 w^3)+240.1338869721522605279921380120118662814959382013703313837761`50.14271077040847 THRSub[2,1]-64.60585986017537794826611719006367808907783656055611467968458462796024375398277`50.14271077040846 THRSub[2,2])/(1+2.57051392250761886872240406972176456583583992723204519884386811845671175524753`50. z),((291.564432357638003790926599333524761090801251726746951921482`49.69897000433602+ 1572.1615756608790055987147115924349759231143486230566046745399`49.69897000433602 w+1441.424605904999347918641594128911918523969622836995048657721`49.467617329691 w^2)/(1+1.43484921495409473105931533010704685085990503987008133115045748584893113688545`49.52287874528033 w-0.27043919822782523974345815303392210206311239630149684371000693358957388249018`49.52134135935891 w^2+0.5166141547932444973281825415849225826389998174921564063404081781775368586942`49.587019429258014 w^3)+612.0180708402256432966279152968428354386243511206068062467116`50.05055635697104 THRSub[2,1]-164.6579506755906405978203589925247198055254375744590361393295`50.05055635697104 THRSub[2,2])/(1+8.10000279558500764540405724205544378155963265154263520106168307555470056824962`50. z),((86.1713453858351222828420993549778085468967854879492467335254`49.69897000433602+ 309.4127649522477591345751046059885559367520393837726360860693`49.679065785862335 w+229.0497367242063276294995483040954023350152592112846974931411`49.49690587048338 w^2)/(1+1.96372829572308158744278633907398359380529109318481970613230277132748809871711`49.52287874528033 w-0.83537160338813902558286077920714531199324015425957495399330497289677621080687`49.69897000433602 w^2+0.63509956900838708385703154962368385097295109171957742884061105385173078833452`49.69897000433602 w^3)+111.4112728964785545486503775697899912737748726121207550842767800226399645294897`50.40193389876825 THRSub[2,1]-29.97419970313628649726828196513895159100557056271871597284964650966994326311291`50.40193389876824 THRSub[2,2])/(1+0.65655712326558799795809322690588812313202080691242124018543377728294005676075`50. z)} /. {w->w[z],pi1->pi1full[z]};
(* and 20 each of [4/1], [3/2], [2/3] and [1/4] Pades for the Ls part *)
Ftri3LoopLsNl0Pade41[z_] = {((34.20853794224361630835138722791698771362448327696456227982278515651034254700195`49.69897000433602+ 11.63417234520417352301301152240424898271463568984554263466286231236714548340932`49.1171102389329 w+12.94934541025749538430956076771812563078390894227485943185465557275240456062256`49.24406139545613 w^2-11.7333963818764477536501206885120354927973657504294680097343`49.02939250692108 w^3+6.5182874274066817346415903657906552048773760884343345602886`48.65726069665172 w^4)/(1+1.12850839886882581262034729525715836384910843279244917504487348408491149961743`49.52287874528033 w)+79.51776494682281166732473936459322563390739377400240788010456158311672934098149`50.263683338868226 THRSub[2,1])/(1+1.19731838136507726245271260986248004834000815862038738208285003195144266053083`50. z),((149.677110530912876256505201519769454410675633985294508927027`49.69897000433602+ 39.2039966819085383126574429876441051053532158574831015038951`49.002461395713766 w+124.8595103638948217313797482906722612489771136451037519641877`49.44934220809216 w^2-106.2767352991828676734225686579728762670450367772484488586046`49.138712159595464 w^3+40.9820273537853892936799163513820407005392552226459497393058`48.583252239347665 w^4)/(1+1.17125570598875454109112237221137007280314830734265843933476139600869580740606`49.52287874528033 w)+360.9505689373701666475841025597553426178668184312262256728262`50.045882497379516 THRSub[2,1])/(1+8.97416514939352243080120952586030416346845317583879518531890057763338371531259`50. z),((105.6430466473103050331617947271447169333772741165656815288072`49.69897000433602+ 28.8936237235901848720689319087813030387234698688752234681197`49.02043587448748 w+82.0596246133884315251939211198720908406156189988829326285092`49.433026487544616 w^2-70.1604759768020735416845120646716981656025871054070395403552`49.13042676756872 w^3+27.8386222073293872582709754265529631575906006338628830521955`48.58936087727477 w^4)/(1+1.16790243936693362569481490718454467090952813907240877548632219998166336753212`49.52287874528033 w)+253.6258675746269750112978363116047149323648170628751385805287`50.06685946284422 THRSub[2,1])/(1+6.00845630135709648643523174021512367372801485873764517274822125754353101212857`50. z),((147.2308781202170216298945971985174327229759001821238049107207`49.69897000433602+ 38.6321479706108028719386009976425308768213404887038308361692`49.00320086936355 w+122.4812817407594036172506087691235361287171475665565830714227`49.44872130191572 w^2-104.270079850131849337732769592998871418482115268939713551175`49.1383982526246 w^3+40.2518665595153532500117708309646871520880531655500563441971`48.583485328647846 w^4)/(1+1.17112832543008336270294954059552134881152505452587572760666415288115144644942`49.52287874528033 w)+354.9883401584006840322474115101462359295682951207921372594587`50.046696060999444 THRSub[2,1])/(1+8.80941058293035927274511838116400669392548329940581534327060465240935241626155`50. z),((19.22831959178400997791808618698683785024428826197503269981342866362731318544747`49.69897000433602+ 4.82723586222930922707653945921316654672120798530778332646748814668616926558432`49.080496264834814 w+0.38131113739116040877857455063581547180773909156688234044590224093779672727354`48.20311614602877 w^2-0.45363634916053101145064856406089247352242311750823900196122016809735489340618`48.30037210698935 w^3+2.05753945642643082434074287088351246174772895731675011820351493364034387361051`48.94576234322765 w^4)/(1+0.91734768517680869774540300019803050833441469850387168826946344966710052086168`49.52287874528033 w)+43.00631633145990949266053512983586936464826221387325031973522892799483945074779`50.79989009894559 THRSub[2,1])/(1+0.18839569312735987378993762290404700598929103316516821879133097554045494756348`50. z),((18.59745554369668578105081764165144856638395485358850890700567132104166752733562`49.69897000433602+ 3.78496276900210629008473376637924760000276322465735677840819550408613049892331`49.02434849516339 w+0.30832274379110021250339445905975242422490954155167137382545880902434108352931`48.160057785126746 w^2-0.20928936789801800164671326124501907492987856769343328089887399399831337624767`48.04602998670034 w^3+1.87228139447567817688724818489352519189083009482518245087444548744784620203925`49.011156589278436 w^4)/(1+0.86036054202596442000203188070615582929498608354835462872195893956493736691567`49.52287874528033 w)+41.46870454662811681911274042438177314233796704495258082308987782798905359521383`50.89507379074944 THRSub[2,1])/(1+0.1459067896669331055419480839582322620929326578220627544300716398784448166817`50. z),((18.82438291358738872840238529445266395236765830396034783764444886478050719520287`49.69897000433602+ 4.20167703958858509711636252376683310433741169689448110844232972633778198990861`49.04979574099609 w+0.30933502146148170967682105409027486326822549159345452449492621317781768261273`48.14263677509608 w^2-0.28441768793103577273152163666099884505495665318952966175822275851736505514094`48.14781108488735 w^3+1.93876820825151113852520468151838068354371903864086116704486314169529407678066`48.98498242719901 w^4)/(1+0.88351968109138513656077489353173955643664281401231588902197293637548106496122`49.52287874528033 w)+42.02179708582529390379452183364795065319639314271822225298996539087887812241201`50.85756420915457 THRSub[2,1])/(1+0.16119042350380694595393005170509904113784394896407061444364998260000292721904`50. z),((18.7248524856215259234836458797427571541564388556875730607569703794306374784914`49.69897000433602+ 4.02565482082437282698066299663142940359408091905601184602169646090281762934415`49.03959227768005 w+0.30481546162307156141725482883830554884570434373231571842094331444296629142287`48.144328448448064 w^2-0.24940516050887271081616525472228789206412437746038162033659553908166056127685`48.10421964919697 w^3+1.9095822316622624018116490981120035168466254388793887335637954730659173801242`48.996039074140526 w^4)/(1+0.87379160288418625226390621900059855555417914517318085243271095418445148910662`49.52287874528033 w)+41.77921049454044896349018752853169315948126956688370245075705830525110302921639`50.87349706815201 THRSub[2,1])/(1+0.15448701607705953420358258003810698128049186306321504273660099252379533238967`50. z),((135.7820902756112278550238989362474239408909607224686039997412`49.69897000433602+ 35.9547140364978614454274337272159404428243516667099776564905`49.006985015287434 w+111.3514176966309489041767987614344834479024941852435119982411`49.44548055172617 w^2-94.8789182993745507858589249752033667322074896433405781967757`49.136758043527664 w^3+36.83459191131630602335049937699180768248276233302341382873`48.58470112371912 w^4)/(1+1.1704631737584032015153617022105054481798816277781684315501061514149519320569`49.52287874528033 w)+327.0840854060865522279958514373308057711829836414251796347552`50.050922356976706 THRSub[2,1])/(1+8.03833091379532382726463620884371508249348765398001412930685503432623510855895`50. z),((18.40583566082122443545073778143738313776053272228693846860288880976843046807192`49.69897000433602+ 3.38533871292296273124707970642333284166226196846371018718152451704862815888455`48.995259896566296 w+0.33630176352967095643386627728893098070238917023221498092926318107713522232005`48.214966896585956 w^2-0.16043369255983843400055544272218600194124718488189465513342686487665460519525`47.959370787882534 w^3+1.81631656868669843770845010537563311267980875417709557440541850240847111543593`49.03623064423314 w^4)/(1+0.83776594712619385368928395593876049686048329578432867592791869472568507571416`49.52287874528033 w)+41.00166732837057310484229050045335912477068757322410096920484026182388197948967`50.930375021340375 THRSub[2,1])/(1+0.13300112682360242178894935723095457385693166616289469984677111955004519725701`50. z),((125.421386852254175624815309242426541054034649823646268435889`49.69897000433602+ 33.5298617622991975546289351834645615546241327006085368235907`49.01094898104066 w+101.2804628041766052994917702157417386220488660834777744205553`49.44196756452069 w^2-86.3808593033502406511816277733949746720529973405923020315151`49.13497663514841 w^3+33.7420982375528876699595395679043628926406142299498716189579`48.586017546145804 w^4)/(1+1.16974158000385418859946328198152894320100261619543239303491500235215624355607`49.52287874528033 w)+301.8318306117290701861324337561417615355104302284796578349023`50.0554662018593 THRSub[2,1])/(1+7.34053409232199686164914638190400484371685695874343412730409030372814333315737`50. z),((125.8261224446077110822968400154611334690013322289569544546514`49.69897000433602+ 33.6246274151989504238721504430043006565123775186781056955538`49.010783031835636 w+101.6738553431022834516079669189886803982023229045734209989692`49.44211714744142 w^2-86.7128194279798099739105609357856045794087684719451784588751`49.13505255968062 w^3+33.8629048036130808932597932238444075167543459218597096310165`48.585961525002475 w^4)/(1+1.1697723173069421585419446621278799513718195394155518921672943372607508134655`49.52287874528033 w)+302.8182970595009205858891594143825637670568433348520845597017`50.05527351126864 THRSub[2,1])/(1+7.36779316907973220426777497886836347920380369502121366800685968548234831503679`50. z),((27.68301598216516756773480246345553719382699108570085871800747378234552889047648`49.69897000433602+ 9.68944896352077782816573313735672342678074408212963203125714107091306560917698`49.137039500797925 w+6.85839876872154251660496636884334885502811935676821625196200113938665906311326`49.11452630207552 w^2-6.50840002827987133804449354147906703285404095095862770127058447167525941207162`48.955566194632546 w^3+4.571819736292968613953185657329757350513130598695908229062`48.70032116019189 w^4)/(1+1.10147925847648078917761283409139873097287585154777290447189167427927041793327`49.52287874528033 w)+63.61303951760257762574334499132309001821245332917438350230844518830824467052556`50.365407586553296 THRSub[2,1])/(1+0.75782230700280923474488830338683357486140765904249209631778135183689309355996`50. z),((18.09196454493285338213454137203217922580816652558452728986277599483010297979478`49.69897000433602+ 2.60720895536287501274886559143252272004868867635393506843475868853341431183362`48.92067035000007 w+0.45674403974176322087057924323826234884498635207910937001420116908864893412794`48.37931384743756 w^2-0.11815165676893175520666960462212738454007293833161027000305154544983248025816`47.87928557272121 w^3+1.72511684834129930904516568513799828760206141027019120778315375912529696997729`49.08487356099863 w^4)/(1+0.79289320024907709208191199822206069221291939424639867999217926004356948339047`49.52287874528033 w)+40.23666585432641975113190206981467342541085829586972544162214952721514033048355`50.99736899642321 THRSub[2,1])/(1+0.11186180277679694341981528642012737025260101599696203344692267356795226594163`50. z),((92.7392161870523475065189529720561807325037956279692868196463`49.69897000433602+ 25.8608412861861588306007272656548033394031448905424648631033`49.02853203619684 w+69.5243498918201013851201626588155370921219250894184588606332`49.42473357236917 w^2-59.5803756835571752923541418099855399275496844503103836173164`49.12618648688695 w^3+23.987086971836474277555840694962746129505771349196826815141`48.59245248727902 w^4)/(1+1.16619345401020367851289407062515554230380428013296995051746831835978925979428`49.52287874528033 w)+222.1752216782266646604012008185758873570498051132023627550073`50.077213798343955 THRSub[2,1])/(1+5.13937902811910211864858801890511416795965142394582404778805492579094903857661`50. z),((120.3393903231181972334034110121515953363319324888014504143888`49.69897000433602+ 32.3396343485353278271113533859253791776152852700466981426693`49.01311835732802 w+96.3410854532093834745434710370470837716227134155754597898153`49.439991335491584 w^2-82.2127530686933855494758828306101082475049322032715120728682`49.133972949481596 w^3+32.2252112348008224666137116613574155635923883252101832368513`48.58675740551737 w^4)/(1+1.16933539326774400513065778955831632096497290314408717630734172185933888375025`49.52287874528033 w)+289.445425367421798609129725829506814532739358338747865852435`50.0580054447708 THRSub[2,1])/(1+6.99825993584194066732733616295810356616647993203409011901217673114290235238855`50. z),((53.2137217548412991217329233179622978705439610246018944512572566714249394269626`49.69897000433602+ 16.4562217990524372656394270258314157767872492266187818029821`49.07258089430942 w+31.1971865194693753046850501142392001927010054669208868427838`49.36419698339152 w^2-27.207728228968878657969688406954039853420091450976056245895`49.09466339123771 w^3+12.189867267333518173585409238604405947337989744668722525978`48.61473116945056 w^4)/(1+1.15364079639501922316695269537718162022418869421007946589636985874035326775196`49.52287874528033 w)+125.83930552556193498316890957641105808502805914748753539726450938422909958193973`50.147262356398706 THRSub[2,1])/(1+2.47732383215810301734509433654790420802166921534872718303610618021121478943611`50. z),((19.07497862924918885812343249152932429157266369361921372130041844819719221825137`49.69897000433602+ 4.6047971052792947282632350935176932457283328398672093158644909813630168490535`49.070499072435226 w+0.34490924416729616989727295616665657144947586849684618093044358394257108335874`48.17065280623789 w^2-0.38480729168575797513954268331629525746279422253789330006639452522341320651819`48.24719265570374 w^3+2.01239784345654736658242070606496144339678889154269453134833437287532898851239`48.95968568530925 w^4)/(1+0.90546285982119374035151383944777461939046750112547188712293965798958454169229`49.52287874528033 w)+42.63257674080510197107526087582947720274387625022027711239639074636634089352277`50.82058421286346 THRSub[2,1])/(1+0.17806812830031953783924448321552821586811454477534987819185390970233238468511`50. z),((18.47516074421711205299510992691753106391353637241912716101919401917230440584683`49.69897000433602+ 3.53560204691670231588851878690623462560503741741393398735898822744226979375704`49.00680003582832 w+0.32274585210152427442032519472736163771521420709571329821870024129751055928098`48.190730486599776 w^2-0.17637220761982479510232453813714944592873004243779711283028435997553326175013`47.989825259171106 w^3+1.83654244653332460181692655793950011286906992333979394247658746571942602149816`49.02680790950611 w^4)/(1+0.84630217075240669857794856456889396480353479766537282821083841223212879079393`49.52287874528033 w)+41.17063410581991785843599412103598859328622756762808789589877015436542230820791`50.91717645499271 THRSub[2,1])/(1+0.13767019424743853350271943243929047908286844193399261711004994939506695687638`50. z),((34.13132833862337756129051099051537842425760027390829054404746755841852945328977`49.69897000433602+ 11.61292106385104227484855179529979083722812855109873627128643127094348191905612`49.11734253038756 w+12.87621578567619114588728667699606371449392743694919117805406178417442995580898`49.243069269741135 w^2-11.6710379580635080163619655340568726210032851229539215519537`49.02883978857175 w^3+6.4952514502200447629432340296558374349737057742966342867818`48.65760185684345 w^4)/(1+1.12830053545673349676345490564619245468414927300730995159123426187299414426553`49.52287874528033 w)+79.32958114273918200162216603766765331432672458899296438057468694723913468793774`50.26454463465014 THRSub[2,1])/(1+1.19211828888178512954367909387340270429451132665179839811528258635720797125592`50. z),((18.66342909544025443268581441886271869964064563088798755542503870601886218697211`49.69897000433602- 2.57306714239071357642663828831363387957444524557586428857736077896651941267833`49.06836906496766 w-4.41227045518826023535458272427332195694979008190090757578091068436188110725107`49.69591042135995 w^2+1.87379624933567153275520714625675577182553211254191193442911719173691074498895`49.69897000433602 w^3)/(1+0.51999245246158602951307348980667562301224646129363299378458191037040519969155`49.52287874528033 w-0.48134706799146649352306913855175709307373966482312882344147303701453367498943`49.53469973603205 w^2)+41.62950259964076790795405354577721397079717008754502263420523928861396583168383`50.88372623715407 THRSub[2,1])/(1+0.15035013031928542880893927488460106541371310651490630789989354961300389341424`50. z),((18.01399322152307452554205388831917240163410746963844118156116490429728940010408`49.69897000433602- 3.10321390227396073658818406662871107940118023067393552646212119880144288176353`49.185923836533846 w-3.48279245720083613928880129525880810403889049799709359943406821708447387460836`49.69897000433602 w^2+1.84117203942713867414330562567545373562034584885417201814858185720924384903212`49.69897000433602 w^3)/(1+0.47523487442849774313157484517799735173992481662894796744661510770471559130799`49.52287874528033 w-0.41859136024345192766498162963001422501853588232482585012769579838018197545535`49.55309537905277 w^2)+40.04662550234045290272435583650488683373623460942966108841632382357791129743783`51.01619514437797 THRSub[2,1])/(1+0.10661040821233567342203966043834780864664304742853178407034666767931940705795`50. z),((58.73103661953309918481120087893106328382520397279633858674377024408123915662104`49.69897000433602+ 187.1418039767518290235522432782288050789351911241390320611896`49.45149560096847 w+136.0564046742338692308732803907570662787248075813539665708247`49.49121589947182 w^2+32.4508402640143433011392585990527237669358796142471248493982`49.2285755052669 w^3)/(1+4.04027980899454958169109607768781858081921439759074484077040895156552636411286`49.52287874528033 w+4.15664737556938003346949643754102283350683689135868985732554723429655852736681`49.40882300110914 w^2)+139.2867168692552040466427456902549601105032377409361567329821`50.1306587561051 THRSub[2,1])/(1+2.84891682332221261139388076873066751052370414783525252644842808167161487404101`50. z),((17.94552783896776517109063689064313203789021178668880317396146684639007037651729`49.69897000433602- 3.21505258858053223358548103507812201271866377927717554282016888554568133346959`49.206511962330836 w-3.3608286420576135395666596105745122367042198314405863596045595269325146008342`49.69897000433602 w^2+1.82216940148411194236415197335588486790334637549842190819561820961659095939463`49.69897000433602 w^3)/(1+0.46720992452519628181626534984600963587908158375390545863414710593856386078802`49.52287874528033 w-0.41233357719084452602809919748250781837784226766264117523316658671714231341912`49.557809282909034 w^2)+39.87975408307154445146430515736865971760960900129427732313623503152055048791889`51.033584351730326 THRSub[2,1])/(1+0.10199924192604405115715763980772757350535517299483974898202647810793219907662`50. z),((18.73138846199036426132250882939426599967326560336189576522452695590746435530418`49.69897000433602- 2.56088990379575533286383733219324583254761229164430585797391373571035703504113`49.0635391695502 w-4.4933552458439343027489459038218057978522951050861371125608998077408316192275`49.69098084102794 w^2+1.86542896223108210635176462235631523106035918143662927758666811445213323672316`49.69897000433602 w^3)/(1+0.52218508385167261264462278159386876046759657514374005486310049621635452102671`49.52287874528033 w-0.48827056044804516790910251118544046511598244173345650567363772192978309043861`49.534785093629296 w^2)+41.79514070061349632703059816830854637673229645539068214021842612024627704237442`50.87242689824654 THRSub[2,1])/(1+0.15492721625932885684627761794423687303786129202243254074801659608046389980319`50. z),((67.2859755771964941499602967864801156728136802985875524914543`49.69897000433602+ 173.3964035025544910056699384506590835414902694868174561071377`49.43513474717287 w+133.1916502030499119101861670563906111081427598653526584590619`49.4916221673747 w^2+26.2717373917776466798662533535319430000586713549807058904996`49.125615272908995 w^3)/(1+3.44247317641762322659390001180853295047833422793038162593641157056952743432919`49.52287874528033 w+3.28847731537846307031828043098049412694961152641162608118004955145750779186235`49.381884711066434 w^2)+160.1377623515602092462850082228718383761286838447365394688342`50.11124998250194 THRSub[2,1])/(1+3.42509480744422064258324615274796787929426948795915721266208094767314575852457`50. z),((19.44467853003060516563751589635579557102528597442298059739773096670644565101961`49.69897000433602- 2.78299446054334177742716370092400995036472281834361236798000265391272822317197`49.078096327722385 w-5.25723230084254203675578196093218511534017603738317860338201976060151369365077`49.658188443258425 w^2+1.68777345650792906623512412706931147631330165539263391083404671624267125334044`49.69897000433602 w^3)/(1+0.52627853459437689843550602300252582253605439464798504529630080787820464696371`49.52287874528033 w-0.56532666585413001477302222976831464202111243374121958065866602688773793986497`49.54994283877477 w^2)+43.53365031761790628087364702124958003582213513621965357251326954581437842418449`50.77282732153152 THRSub[2,1])/(1+0.2029675395780036184173825839286192693345744156831434912147203951386033989807`50. z),((19.36276395037172754446216480295347408507420773596670256418871414081942712635961`49.69897000433602- 2.72883429314658306637498555949966465619815321139186758205514321263356081855434`49.0714459706955 w-5.17463984602587293787811347036862161117097563188258699121019559917368657100463`49.66043882591698 w^2+1.71526009790648388288123404345537657354658446790850227903669966237847821742857`49.69897000433602 w^3)/(1+0.52730359798926198572579117980659485973817591799775329603772079968798452287416`49.52287874528033 w-0.55604644861246531888234939054357143956592912369340281329380998041500108092279`49.547112027111 w^2)+43.33399902441947299668997667892070672859988815322320153269276883951355225046938`50.782799211721894 THRSub[2,1])/(1+0.19745056539366125091582761838073564375638372501106003231037390429142153806812`50. z),((19.07778512301734180360866325930999083555617327116531920902476781334481721219824`49.69897000433602- 2.59510687258054757890841948084817994021553617002581178273474296531219343773705`49.057288907863665 w-4.87959076859098771573964502544454602990444953746993518957968915719284112887807`49.67112491311982 w^2+1.79765280130237285285595964490920625703065927786022791283057678609396198515739`49.69897000433602 w^3)/(1+0.52807143125131903205768516260504829682772818609893101205717150865056935079713`49.52287874528033 w-0.5246588570804680111617018195345304847122363029865156672061474989700709595784`49.539267112255416 w^2)+42.6394170384968982078848095038406002978425370684002885767885640905265549565338`50.820193132232816 THRSub[2,1])/(1+0.17825714658902828666211340687703097922398838827416090321023142100155816596632`50. z),((21.12897873975968256511663453031869608565659298222216344108689106692363405912758`49.69897000433602- 5.27297954992295676207622817988018728322115918063989036541516135509782135939897`49.34286857095931 w-7.05078437884432809885384850150522010966042629550788329381300381434297618090197`49.67787414953132 w^2+0.84045376727607927419663831426501357405645617818274657331865146396572167829008`49.69897000433602 w^3)/(1+0.44182244052380420909968336717540936978614144259541154656417532238152432833606`49.52287874528033 w-0.79018818791896097199959063208564334649400980373548200338926589724362432643123`49.65023658042704 w^2)+47.63881348157682212496216848039129861093218325543867985513727998021457044005528`50.619145435766974 THRSub[2,1])/(1+0.31640571889179680247321014159297204789760313045454532942447516062585291564183`50. z),((18.60247780559527241944581248780363337861748337952493792805325261575588494029245`49.69897000433602- 2.58985074625248649042170260358250426930462846468998760810281654507747403425681`49.07380836399972 w-4.33765742115053897707412702996969757592906363898992396575405252607117133455591`49.69897000433602 w^2+1.87974062587666717870476260595402707280258011401919843822668723408316431176162`49.69897000433602 w^3)/(1+0.51769717637991595619758427827027181469000406475947876808429352500971588290364`49.52287874528033 w-0.47519599908210468560477410640225613086014428818226771872840827533920818250911`49.5348801167376 w^2)+41.48094536000968645580160408150992546322724015032303099099399300113107753327971`50.89419632205194 THRSub[2,1])/(1+0.14624504067617826993495910048123140548892695710215146371451245131064550660407`50. z),((17.98810637588167707692846010488771635780275188499798888508806863432556374820043`49.69897000433602- 3.14392626690268312074641749345060425742379966875332555963931997080512485114994`49.19351375195706 w-3.43740961439414343946718652441773919607904559040172798983268797794995381448784`49.69897000433602 w^2+1.83443093034755613638974310981122553112515082669025973084265497855596753302764`49.69897000433602 w^3)/(1+0.47229531432521980959947215807101611031566941335098996398153447044785754498586`49.52287874528033 w-0.41621709041948222779161336365745376920808513944896959943483542801801514926543`49.55479573335756 w^2)+39.98353121276885159695804219959278454842778521966971529173085816967643784371443`51.02267145610422 THRSub[2,1])/(1+0.10486692054857193173326380418173921145955341132331283058562526592893070929175`50. z),((21.64289410220630218336485240809750381777125011646400785516894537384980896839924`49.69897000433602- 6.62573360318583908342211674342094443746101179858024529419830052342983112424857`49.449018151486946 w-7.76785737019915735364814034767810429731357402564282761404695639929461971246796`49.69897000433602 w^2+0.49221063408829695196631528696239885068777115346666100407633273591652863397119`49.69897000433602 w^3)/(1+0.39127080888391762887098376831512303737305065775238278512816111215754680708698`49.52287874528033 w-0.87943339068894343876910332161276116361071852148075895709546753116527853425535`49.69669118694058 w^2)+48.89138496682754706454921188223736635207134774707549480401269439241566780891925`50.585331665941226 THRSub[2,1])/(1+0.35101808947786347853593656739681081699512577003901502854865656610242118076795`50. z),((19.66930405379597986980746710999464992476095248998690176548877015104384051672351`49.69897000433602- 2.96506968375623701610118473579453842225380752844107511197394450325210241404653`49.10111186097987 w-5.48108570550749225504469359857263566926390678346009495239139692961824879429746`49.653733921804495 w^2+1.60459648602380791652200467158927490186056376305543180486633264988798336966701`49.69897000433602 w^3)/(1+0.52180532953222878413838762405762639243114917814534816460067584946735484866195`49.52287874528033 w-0.59140381934496570144888798101559695264714355493109300221749660853794959908257`49.55886354049555 w^2)+44.08113254229501391611183664623119475214893555530831908107261641345776593558855`50.74703358231918 THRSub[2,1])/(1+0.21809614331275585043326344449243346222752534785665801090769218382417500943558`50. z),((18.08403638551113195739874843662922275270376957595953140570967488255231939421158`49.69897000433602- 3.00215023679198161014200334463903869342631393276852353204960277894796336637588`49.16655998134431 w-3.60142620575559030477016170511946375228441319126337258053316671261113103998255`49.69897000433602 w^2+1.85685431561595785429504393916101038054462488385115984814897336201876501521795`49.69897000433602 w^3)/(1+0.48264352865793286482891983215842167476973225684999843050952517604021953371032`49.52287874528033 w-0.42506504364720658242344161013534576847551525296471819047534214821538877700487`49.54896286854732 w^2)+40.21734246540320649846885344490813178700866152927293766563120969754997049079826`50.999238416047305 THRSub[2,1])/(1+0.11132783860288388737469397730069321754629046756046619204356677397103931719348`50. z),((19.52129932845664309689995030402511848033969692579354581985979923790165054968751`49.69897000433602- 2.83966275676967201504552564641217966322802096949640014328931140110100998476959`49.08520690575104 w-5.33392351576812091800255405089560273545578757993663007107553106988144514556286`49.65639247542204 w^2+1.66065158386558802705875259080159389988143777288218440143121544731721479347616`49.69897000433602 w^3)/(1+0.52501972336199047807798982428667233458579999590183106019200790646443736802856`49.52287874528033 w-0.57411627460942578944330264082245871774813196272254223653324387382469281198996`49.552801047923865 w^2)+43.72039902041732387238664211086955475692112961619649138822910559166113447362894`50.7637824806362 THRSub[2,1])/(1+0.20812797583563311323356095451166956505613812443676109022109599588389577119022`50. z),((72.5695221334260051644723772442127266942931863132312976389834`49.69897000433602+ 171.8600462695871207425263461626157167010901882905475707213156`49.42761608039942 w+135.7985714434523348081088133708357424749867636345492475633937`49.4929218398813 w^2+24.0961395948477125739573300749193305756186716565405423481363`49.07063083306518 w^3)/(1+3.23948089346223270791478061288654994866818413158171343480144315698776396210242`49.52287874528033 w+2.99311724215057916340629343294705944339166722741646208863811767402877808861337`49.36954143376187 w^2)+173.0154076622998062283436154556617937231182189398185530569732`50.10191342554492 THRSub[2,1])/(1+3.78094342528340334117704758047219861050810539748204311806476449283710220659759`50. z),((77.9443384902042721289828626167845581131614869884153774856899`49.69897000433602+ 172.8456509014501312777217393104408718596023257498805534095742`49.42131632405881 w+140.0560749581668640785622270604477734559089684618858486766393`49.49455574079784 w^2+22.4833642630568702884995480458441007772767457984723183819983`49.01978841844775 w^3)/(1+3.09391580437810249778079460921714705150890316912542729309585759161394949414608`49.52287874528033 w+2.78105132697902750868988818076090397997246786422854796242296418396979201343819`49.3592447545951 w^2)+186.1155058475509474917506979343768947238280993659068232095528`50.09390283243155 THRSub[2,1])/(1+4.14293909454535424815488792014374934077002254384285464463394767377312526214588`50. z),((20.88383486661487993275894383251488197881872403123809604372816780425719262117044`49.69897000433602- 4.74362385043716413172196890265239062557208651006947605419935601104678918492887`49.29572801191976 w-6.75315922163709058099359201005014420812529427452666574807805592947431263156909`49.66764136429487 w^2+0.99257238267599910570536741878423365702018317407373137136871051850268348059369`49.69897000433602 w^3)/(1+0.46126172250103576394210945398511896348216733808768225391609201470345458181322`49.52287874528033 w-0.75224348928204415792757540256047018023027729264700298008255060005911550310464`49.631078164905745 w^2)+47.04132166147775848298162483903941583566945164135314975056266423631928026528567`50.63693882818652 THRSub[2,1])/(1+0.29989519750205538349790004193489920201024111407728788785510908044164381847533`50. z),((20.25991688877399132595173794683405772925299107265550802373349765479445557323495`49.69897000433602- 3.6639440260178956886019886274859545447634309123030063797055282711873169388905`49.185374116582395 w-6.07300988318458189913245352270794764409204405239494555520547101950908535963089`49.65287923859825 w^2+1.33815974050861084294816054066745648033074126683453329875598246362077898710125`49.69897000433602 w^3)/(1+0.4996513162035801379070645599163012444103706439286339483712976916680673805479`49.52287874528033 w-0.66489439312037018784045013796800500369866069384642854802325043284444654696436`49.58930051110487 w^2)+45.52063960897350916364887093989822631019206384573386408898062232822033284757641`50.688229430710756 THRSub[2,1])/(1+0.25787411418294897234098456792701663753006564042552390239629964554106497455848`50. z),((19.17477567935845071755045330971226075500027155281528319140119114348495124521658`49.69897000433602+ 4.45833885456142248119054570233641438223701882016703078741718493621248358568664`49.059252063638155 w-9.26124823444991830004295237559382089497172123250595267516923994875034125655384`49.67452303803491 w^2)/(1+0.89803137412473524796240853910015741450027546528781769887446252039638257014494`49.52287874528033 w-0.51232833176975994864674938751181042266388212156363807317033320473630399076011`49.35802793351764 w^2-0.30900628723048795086175086673169454749291813975903414249628294542444888435533`49.69897000433602 w^3)+42.8758131731310245153531112992502406851145647932426541799878267716475381261469`50.806963920555724 THRSub[2,1])/(1+0.18478949281710186373746124009425702978521784571344662813551168420596502445236`50. z),((18.95656267778046105043069519835423766023250552533552417718743941808477477868346`49.69897000433602+ 5.42092217925361372984534585947729880712285415153751455770653094586336718237765`49.117359321063596 w-9.63836489480975152649726256050733155883269739092661172287624486084406674497174`49.69716229910278 w^2)/(1+0.94826729015374644212755309765388025699571534569672200600456448222703301622353`49.52287874528033 w-0.49060418521076306706019582622176164362749430127148279981527082366613582391784`49.33674412514116 w^2-0.33942658647079282476270056884251463723906265443842668055768195325543371694204`49.69897000433602 w^3)+42.3439602583119003567024874567367697629705800880728194616683534223778751701294`50.83753443205666 THRSub[2,1])/(1+0.17009277458443792551404072427940126148461719585824025429713009473872264106651`50. z),((46.88177472089804300404722875511769154634113529037837284304590066666847340714934`49.69897000433602+ 147.5614777158396578027000254788597593724710061001966610134667`49.452484111113534 w+81.5073068117680183858350876687818266269613676560489548229348`49.584886673379444 w^2)/(1+3.97830723429075745906121633103179074093962828827344871916611514352080466949964`49.52287874528033 w+3.55431196746456139567195385888457621369428316766490468297011050785443308907893`49.43856255494335 w^2-0.79148783875910294281518796326139082040318329397739263214632029460607451497982`49.213781038844076 w^3)+110.40638236273462781428401528639457823256528503599642703760042981250561655744297`50.172485910669266 THRSub[2,1])/(1+2.05086509345294469234575293444944541179625717171896008101665097597953767246623`50. z),((18.40156842214811872925467792926071656989154963259954997755858256358723293334599`49.69897000433602+ 8.62432669694983698389712703789163218781253279338043743155493433402624154243949`49.23733057389605 w-11.19876170856278407409027032948385801435912827420543744655626439808334676287113`49.69897000433602 w^2)/(1+1.12244438367203888716254303498448146031348792457564513695360862050421259468114`49.52287874528033 w-0.44043754753295578445882862539837471681127980611060949377370908983480410791492`49.28860224890672 w^2-0.44061934516894045832179832487505942003463064565032936838355865312520148701222`49.69897000433602 w^3)+40.9912667412831486956533947621446035959733253890139969715064297430340280862486`50.93120431832985 THRSub[2,1])/(1+0.13271372687970977029071140155497619913626567647497044894216455124875848540387`50. z),((18.6247824172447832644388002183363967480653865169691060183441014347713503703302`49.69897000433602+ 7.14566050519984273730005083828604784729827658579357998055531358704723925861726`49.192042900519915 w-10.43001783646792680910496150826491761718061456498434032032350767268251153345431`49.69897000433602 w^2)/(1+1.04092721035228829547952567315652744246786478239174634279221663393608407689142`49.52287874528033 w-0.45974992896404257530598808090472648772150455897661491218221604280144152201366`49.30672825646273 w^2-0.39419685697092154320615512112787345410089369882481690947840335356955708702385`49.69897000433602 w^3)+41.53530863183087151182899280416823913763944075066139144150274602525913773060138`50.89032681964913 THRSub[2,1])/(1+0.14774726368915807462822296370724623330928185244553605718048656043104943648996`50. z),((56.79017542894158820564634198874851084136150669062362622708263576558394647229141`49.69897000433602+ 134.6758256942569488692467710085598582875463000295228711456515`49.429751365091086 w+86.2255699991207386637237728758776174748209936630848065191446`49.628844724901306 w^2)/(1+3.22220219753091631060906233878318361799998240845151266170351798752950352528164`49.52287874528033 w+2.6660693373566048566120697918175450360448103251125574508055493439189734428837`49.41731291423542 w^2-0.49414494596180585433205004240353947424380806156228421687490781400243917979967`49.05489239260036 w^3)+134.5562348447618923164225361173023537055857581636449428286259`50.1360513737782 THRSub[2,1])/(1+2.71819917661663135642241161398721954945976888187957908712304802850565728659956`50. z),((18.01817963282616178747817617820900843332199137786024501678915358186719793433738`49.69897000433602+ 12.55037278698783701279429815378165517658630911309642536298037807553847117833574`49.31341782153461 w-13.46215547856008505377666759581812348179026186298444306455160044305901805142966`49.69897000433602 w^2)/(1+1.34411032622758129866868154559269640949228673458296809521048831028310309675976`49.52287874528033 w-0.41006568865683028375674662655462564661358751687418171276524754282040324977574`49.26342384749539 w^2-0.55962062533385353689219228194721917448295129809325649365996723056680175313105`49.69897000433602 w^3)+40.05682908800252406874606453869816971774901632487129018270405990086037798386788`51.015158708039806 THRSub[2,1])/(1+0.10689236440597486539833614504013000257684143703437844899830100382690492375057`50. z),((18.24308719771656814171817682413207924148691076289462339866211492972874276187416`49.69897000433602+ 9.95095139529480912183585944476594153596913291479191748008786450719848202138208`49.26858561461262 w-11.9365494991919709418682499972629652539136550860218992824828887990834391975998`49.69897000433602 w^2)/(1+1.19670383816473216330246974379974564871416352349254408254350418280387794972233`49.52287874528033 w-0.42743806705211197157126044252198349757149916451106397510427682382308928438961`49.27709155533116 w^2-0.48152842857151261986910351128523596285243586191909116825596506412604333675461`49.69897000433602 w^3)+40.60499873457182971000768152447594720703547977594605485543282038042427192103546`50.96350625565725 THRSub[2,1])/(1+0.12203996370430323127425636592685566953473373486235924363659381504132330670566`50. z),((18.26608255154792236959352517436954827916091305316354248897823455476415133169825`49.69897000433602+ 9.73897270260521900744900299516455820768304120110797844728512952083684725636584`49.26406008515203 w-11.81628736346117901162483898660761576462993399554439378934688125145088848713504`49.69897000433602 w^2)/(1+1.18478211703100228097909429122890679616924330435846635217664041889780984348976`49.52287874528033 w-0.42928676913214808290929175413639167666593122771395141222115734310328186423602`49.27867867303103 w^2-0.47504184250740897676419300036011987245702242992616535064786136726583824326833`49.69897000433602 w^3)+40.66104555980250592743208545898555092539322675595841959824963609906529204146976`50.95862857242982 THRSub[2,1])/(1+0.12358870843296705538005172321834817955546060751628081719081929563526364153272`50. z),((19.57798253557408916297081098805514996149862825531645948988551069624501071935573`49.69897000433602+ 2.8600122777944735545799067397519771139810044416658942299240037735845107257782`48.913982643193954 w-8.75637565847950803490656123234045518306418255654760334635759135833237798458272`49.64765289811294 w^2)/(1+0.81736290279875025187171258420669523717833242151384527551861767093834699696035`49.52287874528033 w-0.55562460575623799821895004419325943938727439892506520844868197323770307245332`49.399910985241895 w^2-0.2597433706251794636819789815742891231471189036278938234342133795918271722862`49.69897000433602 w^3)+43.85855361573796604740021055044007829067832552803343831094267823012256621570125`50.75725870659359 THRSub[2,1])/(1+0.21194560868750101624221371122433521082155395400366925848803549501901564414389`50. z),((18.14326375212974058418841235732939775515643443845716792922687114466010349109583`49.69897000433602+ 10.97051026597549866833857430687411964039036160576557884711642225233437904645327`49.28830080218371 w-12.52502099201582177381402751805980657135821279962240266904057346702852983553424`49.69897000433602 w^2)/(1+1.25428274655104257246188589247185592257165075514902636822175962193611570053006`49.52287874528033 w-0.41956496604022508371563586257950904751274226999275100146819289748249268670701`49.27057841880279 w^2-0.51246658994481166206963437531486974627120806842899149691179432037681462744397`49.69897000433602 w^3)+40.36169796826223139492673207731873067000298818906067890432179266643536330610594`50.98550558924637 THRSub[2,1])/(1+0.11531682144332787193951890322368172242322992476305117805829158517107798404386`50. z),((18.0646863969399357736036612356195500101275724789870469266002672281449746677844`49.69897000433602+ 11.91507137889884601434431633906010405707915905026060680156614700422934097342453`49.30400077927888 w-13.08227346211546332879546568495058686247740413120653439714991184363386295094507`49.69897000433602 w^2)/(1+1.30791509398417930026748834092717004509569154569329177119888690664963399839285`49.52287874528033 w-0.4135479400976907741106442872324973011495392071528427867847503344335265632551`49.265937764228504 w^2-0.5407657945239196055180445359693437400048003576549099303548178799675967735296`49.69897000433602 w^3)+40.17018052844763382072678574170274813803001992990795684248860112217282283664062`51.003842768132756 THRSub[2,1])/(1+0.1100246104369191776567876053923366553384146652976302289262828356273156709928`50. z),((64.4881942186323595904389207789455441664318806006877739259688`49.69897000433602+ 136.5244324845501464666235467235435751289625471243461052866451`49.41857931045219 w+94.6945719557474994312108810446256973761627022332115132986935`49.65454275512685 w^2)/(1+2.97905468983952856787626765707829754225964257754386382924165539838029600394946`49.52287874528033 w+2.38406101548766304562212724142970940877534900686630083948808309316751200522029`49.408613104447724 w^2-0.38679085385303624743687533870538561359421052005959938613254502425604299016654`48.95747919701579 w^3)+153.3186995101230198049427697315656157552892289796584202084333`50.11692642719525 THRSub[2,1])/(1+3.23666330241897543804785414337133238149749084976916211783259123843484827331648`50. z),((54.68252151585125647342466248612742571064939189292519312725939311587990099341695`49.69897000433602+ 135.2841925832942969148342527667813827416363721346385433531362`49.43358567034241 w+84.3571123936869748437720077602390288192479650553758775357466`49.62062825702053 w^2)/(1+3.32109291674682955781676765294809262543622177086904859129856035035911048263397`49.52287874528033 w+2.78145542433527228151783511750856318384256153224278117721270484797927257373296`49.42058198154844 w^2-0.53553926554410560431804938505348083479299051963259235778030558110588667046997`49.08494441658169 w^3)+129.4192271091967298895300598491266037213077694109957848039259`50.14243996102856 THRSub[2,1])/(1+2.57624798457645657512255903107787262962522234755566629270006015335156260732674`50. z),((20.18782972164091671232274183963204247130207231223185799767881769118550587270162`49.69897000433602+ 0.60505224344933460575861043641920688090389025264289213183231089271954660226362`48.315628908615885 w-8.31083728956234018869818546457081755179786618448885444921706746157071990730108`49.633141986576476 w^2)/(1+0.70952435427604288256743720583662798544891549498042972484302345908136790901644`49.52287874528033 w-0.62973594976186173528067483005735490492629961861961051796248876072722838202454`49.46864638661837 w^2-0.19509082505760084672866655850847468194372493946799685778296601305942442885156`49.69897000433602 w^3)+45.3449407748823773133714008330984148741902314827546490015496552261187607385963`50.69480449475025 THRSub[2,1])/(1+0.25301901950076018877339974141645962320576595672736562046173180530687668321991`50. z),((19.71312407765497633094865640488554470616361302377926227828573085324096806539956`49.69897000433602+ 2.35279714368417907070205856890453340532289888975075896803645742086520268236688`48.84526511749137 w-8.62931501466077476604115721472227375414977304935063502522328585421586804144745`49.642048970429215 w^2)/(1+0.79250915142823548479275371307368636766445768919457814707225189399922024473785`49.52287874528033 w-0.5711061886054469237924065160552509775452427570658502154967970357726413787165`49.414605556677266 w^2-0.24462636132120030872896944156808387862511253566993092412378308281656869348317`49.69897000433602 w^3)+44.18793556158495893447671219130577410198238369401825908490700631456317230102172`50.74224705346601 THRSub[2,1])/(1+0.22104743649394657661322713591662620942288191928446847885982044891326218466385`50. z),((18.40482602711473339316689940992367005995750731134527355917835024950329157877694`49.69897000433602+ 8.5999469454030460254578152442393566028023965797578015063830108996375796466592`49.23668410147173 w-11.18557208412467869449432146943670805447396119752594666257203664237689811650358`49.69897000433602 w^2)/(1+1.12108836489736483026441663706763398414782006121011099871133646209652753024983`49.52287874528033 w-0.44071102307882343172706179116303051127628988499921324854769133293247926908161`49.28885193231188 w^2-0.43986061256408319126764358856358469797935013423168931310552062044661410566346`49.69897000433602 w^3)+40.99920653719033272567802124839252099635065932933502068977516448885250929187841`50.930571053043344 THRSub[2,1])/(1+0.13293312765767189981695026513621170304037535384060478202706160294468620612253`50. z),((22.01682048836566971224800676415235746346896955442719234128271308196083078176362`49.69897000433602- 7.384110521403847373558663304953060389030611869374013488996579787275415546013`49.497033385974284 w-8.65036120142984838423374431148289556555887219233019832570372293211447148890658`49.69897000433602 w^2)/(1+0.36623245578431861755528068114095712811878205662641828865950602466974748911339`49.52287874528033 w-0.95129822738276569167846906706823441945991926965367060425367312650104487514132`49.69897000433602 w^2-0.02466503586412438712735157613497325484377206074682316667601816252758125028288`49.69897000433602 w^3)+49.80275980227960973669624397176141928248436396645843653616431668046217470414961`50.56326095378416 THRSub[2,1])/(1+0.37620215595145724503222440235283338792210631976879679901405255634336856863251`50. z),((49.69760013629593241555236602796572833594414890964097159298336492588084830875435`49.69897000433602+ 140.4671204289149174125367009480158393549216997981710636306315`49.44460901789314 w+81.4549909216532742273196515424397315933008944047617005067383`49.59880169107425 w^2)/(1+3.66370081866911743098813070445018256607245940503222357373162126401963228402713`49.52287874528033 w+3.18330981450132484991779231632467449127676539209381296611183182102743363200059`49.43071519411076 w^2-0.67222185157857815383051574461554922332739267097151302086357073698168591213652`49.16358791684603 w^3)+117.26942417954356910246698670977079930312414024804883513594899835711772691220226`50.16026636740894 THRSub[2,1])/(1+2.24051187170729256568160336607418846608493020649745247288359227147551099358116`50. z),((20.73873693035429460818610223118268809410744450772508991546078400693300897390739`49.69897000433602- 1.47340489230817495032352662558052823203453669035135181902946756113711200034153`48.73687165475099 w-8.14916762326208101878244849824247798947600515810437476782968884035455995949895`49.64107966475068 w^2)/(1+0.61556268221599097476338481837512793203694700662488991738235826844792754968543`49.52287874528033 w-0.70733047808211810684367409763779305673283520125434715388308850921787671308419`49.53625386080919 w^2-0.14197820394135218244605729494688644108174151213633969876496998107237631119504`49.69897000433602 w^3)+46.68767288813988364021629234493729530021621523757028955124679268629990935605211`50.648049186494866 THRSub[2,1])/(1+0.29012280323616784639390877000482073361089495991607476034972319315109898638161`50. z),((19.38436817305079254205483753696146803716915615405551010418837653124202000784999`49.69897000433602- 1.91369486859520857009479973436768630105944807591079258453656743058396737054467`48.90157238233489 w)/(1+0.56982068064474694922958005766801167220520259655266045659051229620862117536375`49.52287874528033 w-0.26182269502287818629420960873707947916580315411642641986966709963012261539313`49.407824648171584 w^2+0.08272796604287693150819934482040573595605879892877440140094920366711255518375`49.432080897644454 w^3-0.10869736689754518160113770548685247191566443277025052027715782500344055396141`49.69897000433602 w^4)+43.38665523060870643930805165373053714001834408330063042841406329292291366558809`50.780137947393015 THRSub[2,1])/(1+0.19890561697653619393551150817118534729271201370163150852883695676310300168951`50. z),((19.55469432608771227555906573133142821978751092354158600905472416083668211549892`49.69897000433602- 1.98853223384453817004073788643154092179558729824484686408359959733164403119463`48.91378409903149 w)/(1+0.56926285660153233280459799441307759588616241873763910048111068343606554112155`49.52287874528033 w-0.27339655080311150184728093682151191695389476871571771535105369622036674499102`49.420890945476124 w^2+0.0906524307526475104378676732683011740435034406969050272075654807423991306474`49.44651279819996 w^3-0.10974036534722737006673976497014269121595918743285630767108450404352992931447`49.69897000433602 w^4)+43.8017930102438833075768680303817488179439192731454187750942407116328992031403`50.759922165917224 THRSub[2,1])/(1+0.21037714003306931345921645585186725537925863481724096075202405077944414632843`50. z),((22.60987543671713808054835403395320109720818703900313200427810200671871158585093`49.69897000433602- 8.01379430213998776360651654676997504015978150510324834826502143770407431481045`49.523590159334574 w)/(1+0.35356760156805394439662998369244114679806151385826855226783949421683610256494`49.52287874528033 w-0.59836145713405501111166196969846523374538467241521487531588210008999040488867`49.69897000433602 w^2+0.27897669966723549369936370022135890096663416423162882421823702691299430987906`49.69897000433602 w^3-0.12345025736203266017800393671457668774468408142367388599160614390144998511088`49.69897000433602 w^4)+51.24821905836294946952255664523762462509960695490616960747038055346042883561886`50.531863334239745 THRSub[2,1])/(1+0.41614460396958551928305156049075051735631636654039451482164958787689826343523`50. z),((22.11314743547155551523980070027237017603754965083941297949297808789896663141346`49.69897000433602- 6.46828546935811515365782557146180530631397806281575297995897438322315694616453`49.419702767891174 w)/(1+0.41016970698144476544849073363430518011315929655392822368331437526229799607415`49.52287874528033 w-0.53267396611150191145871850378728320987845562555088186776372520675470055906055`49.68148737354948 w^2+0.24056860495299651110516241882865888375880381366356045803998285006953004640364`49.6745809351358 w^3-0.11981239526578006955779834799601743168642773170357168226108012008120537490899`49.69897000433602 w^4)+50.03753851492924370788543125030892833945496366462819323788946356610759903412882`50.557877865696504 THRSub[2,1])/(1+0.38268980787682593963505309594406484278745137615132267032758994778150750902858`50. z),((19.08117337114193470938345018147216794548581282561338725771545204243367525061182`49.69897000433602- 1.86324865124651928472392552034595287816185309096446866244909268472040833277176`48.899531357362335 w)/(1+0.56650048330198266808912924183160473311651174902071890994638609006143721987248`49.52287874528033 w-0.24359686921562654034924821395345389566676791050317896373739130825537218760216`49.38837820140984 w^2+0.06893491464229638154527851517876189294965812288028159228551479400420251252058`49.4047466960777 w^3-0.10630653728475537774500249939414518435424663675462104605994910608947223033963`49.69897000433602 w^4)+42.6476752523895800907372872396881892446573748588918010821316230635442168521167`50.819721620668794 THRSub[2,1])/(1+0.17848534622713141196789866798717760830184382389801915458826965453507697981028`50. z),((18.11899112953386412681343923442550552308971110128635645999291626232414442238865`49.69897000433602- 2.53417671148642663145473534076597220759705503284608762269035561584927691915537`49.081773036836864 w)/(1+0.5093635871477082845965491190261452021939621966100646088838629135673496581454`49.52287874528033 w-0.21127695654719110895157595377269879925729873186227959620208181861648590954074`49.384006197796644 w^2+0.025441260516086221857618777865520063039359769945264420171881667282446151084`49.23477374683868 w^3-0.09089172240709394282700688501771999772225645716731391513013216833501190329431`49.69897000433602 w^4)+40.30253804202242131263566639582248399841233299147827952508933314283258939270929`50.9910693156936 THRSub[2,1])/(1+0.11368205223856124800877653380415682985332588625626020413934594997292975966224`50. z),((19.12152758853576546419489638298314228656164154982617145054373672963502883903669`49.69897000433602- 1.86358326835065498094290290303219584322446424344661730974135032481491234737042`48.89820699485663 w)/(1+0.56728209962478873335649916806178069508113257021789266015970562873650549364382`49.52287874528033 w-0.24583593264981382003171451965753056791089055833975442748437438902954556191976`49.390632996627524 w^2+0.07075266011658596369224280084016236000471952005350179360049745197922827005134`49.40857297959481 w^3-0.10667118415399665152223052258026992623807354106971253051732452850036969105864`49.69897000433602 w^4)+42.74603102400240377967143214837491093114705200289012527653663503977178807042179`50.81415871905913 THRSub[2,1])/(1+0.18120321619018597777144119209115952761487774296224074293917686042066760569485`50. z),((19.22458020680087140470390611302260839053602640096929071260682526841730230310674`49.69897000433602- 1.87347259464541952276046242388612950004938294938038414896562946301282634099131`48.89710999576835 w)/(1+0.5687932632941710978710742245954881698265222116599065401157917535713907634829`49.52287874528033 w-0.25182013576046704765083272828791472965265583564437711512021625243266276752184`49.39688446283601 w^2+0.07541704495741842794649831956173884174453359405080965788031328748495909974148`49.41804039999956 w^3-0.10753387602627908958271754822847246579391749811623704960260963761301150578335`49.69897000433602 w^4)+42.99720228789453417113474792890079493221805192707556925187224432109205183682959`50.80037900866952 THRSub[2,1])/(1+0.18814384430504760292213114896466015490583548099654771212729307770516584177924`50. z),((18.5397720155203114432114608792093659945266491557036491726575744360175456621935`49.69897000433602- 2.06750152799057613969345949837880400155122053175884741049724047406791659599046`48.96802668996405 w)/(1+0.54442593680289819496844789212577441823487017085569358766029499048792192006801`49.52287874528033 w-0.21990467278952433452534337189847422652344699100922700965612225724898365959394`49.37182738319325 w^2+0.04472794886633521524862804139047361358038381910781424512681911842034317381499`49.33983621552204 w^3-0.09954164700416853177859015615792984919679271095599291027795680056064692384784`49.69897000433602 w^4)+41.32811185794411559551829065373197716094014013305524860935433241607044846313416`50.90531942211411 THRSub[2,1])/(1+0.14202178485904536604777854591127381836750990710531808117355973954254072497409`50. z),((19.45328764819750554145094478102823280859936257839553028000703269427530573248657`49.69897000433602- 1.94008634425290742541134094619863688713841790746896654223253137779934970330407`48.90564527856898 w)/(1+0.5697937640198941574789343385465586264071578295602713123783792135526403214434`49.52287874528033 w-0.26639605270701060462128701712346024991293093504122197526441066988198433680017`49.412953085571175 w^2+0.08591651000972129960921251511210301914436967781324199305304218357143579613951`49.43796988649007 w^3-0.10914169829190395379385797381222708128474555490909791328606340395893077011055`49.69897000433602 w^4)+43.55463341467434714168404169877088231195974249916080169546501033941028897453131`50.7717976989998 THRSub[2,1])/(1+0.20354736654988742975958414129430725401597702509704013772483027148576986460399`50. z),((21.62870879902100314987333746820734490344489565952315390748246176040770650865845`49.69897000433602- 5.1722237074891768042123411599036407996935328132731005395302940638149423862828`49.315930261658295 w)/(1+0.45811034567557008268150981150155727815915927202571819081538355883218031002115`49.52287874528033 w-0.47313510958591417965652943708811615768088458208903555831681991243107689561672`49.62889307486264 w^2+0.20648974618698817980378995731579458448921582243248686856912154459396853694836`49.62717562763422 w^3-0.1172342150694193800296740416753469649811523275022312858949729895631526900942`49.69012617267212 w^4)+48.85681097356345696295624720230714348728893934957211897840981660185787706714202`50.58620809623757 THRSub[2,1])/(1+0.35006270459038352700089273968247916062558471321067448824214040826380012775322`50. z),((21.30921229844064448370565431313398550361112949099616523248539094770438795531009`49.69897000433602- 4.42921659636151371429536965289382893603644310931523398207684312887358516440895`49.24616979395044 w)/(1+0.48567579356347325418632906889110768680370551641400380901509670771702811930869`49.52287874528033 w-0.43632449904440346165764799125063541436567591747243671739219138952756385161864`49.594491983027176 w^2+0.18568395000917017344528574149507187630043984790770374783954240877271837134601`49.59715284853893 w^3-0.11593131648808499732553819596436886750644185148519672056425716679518500848127`49.68889127260963 w^4)+48.07809868841374631157121388711489789338588292833433602886633690670932459200311`50.606781895567096 THRSub[2,1])/(1+0.32854450901360216450678325889455611900706886538582780545322565450330921853984`50. z),((18.64141952740755524884314049434335103380031864142229717535378775815571601044269`49.69897000433602- 1.99769136978240286211021446509808782479742962224610675566846705977188490058727`48.94802707480741 w)/(1+0.55035591931693779685072809852985718786710516677806508931645864349260568428507`49.52287874528033 w-0.22337618766717901482183661289753375787999998730426631729650811096429285022478`49.37263357189604 w^2+0.0492803515584635212011128877393726382322100652465009997408436806132043671633`49.355026495315464 w^3-0.10112374378460054509710470412005024889570924111379483530182031595102229687575`49.69897000433602 w^4)+41.57585844082598167249543164903974820144936159260327635796926938365460729767217`50.887469341420484 THRSub[2,1])/(1+0.14886777859202769552906960646492081519220549608248852710342933261370468784315`50. z),((18.17898536506389605335877260038026957162640585827640296179224900429895095168964`49.69897000433602- 2.44880205082242222954764461362295314730868086167822657324471193127566546801988`49.06279674180951 w)/(1+0.51549812346678765730622062339506901768736730828731003158295619243842978604566`49.52287874528033 w-0.21188702450887605317395692091042555199386418349407598002128084960035090350128`49.38051559556913 w^2+0.02825777593128011177567825031340151417326339417050053445084363574536566750033`49.256867950467196 w^3-0.09236442779644011358095752511321463003083327022506280442003345868483147490564`49.69897000433602 w^4)+40.44876264279438097247137792902226006938214899172744167533146014472956635181978`50.97747390993436 THRSub[2,1])/(1+0.11772268395524577077776655817417004043936159189610962736197569194527766046782`50. z),((20.82449575216251510818500593253308818042486094839867807611834609645981474758927`49.69897000433602- 3.47182716383933850287216413472063451160395092174181158811154923802182570809024`49.13969078190819 w)/(1+0.5209550226566050524583310376665303923934718689604023166112410088374500095836`49.52287874528033 w-0.3843460066919997824093588294185450803269982924725924236659759783692335823918`49.54299821836313 w^2+0.15642829092415082588114470476342700729341378564852282792375996867652928331136`49.55340720747253 w^3-0.11434361946986564466573855752792486515533582557433239178581465570884813098377`49.69557917325473 w^4)+46.89669379441184321425780990087631411033615629960303158206594854895771317923671`50.64142801018791 THRSub[2,1])/(1+0.29589868840784123372753781640951785694103137762219436944839246091912322311619`50. z),((17.93196008708357407084864876690465810410068582520310530050055002892441681775153`49.69897000433602- 2.84503242255510090706742163828562745241344083072923153446821072321037136686629`49.14599079678894 w)/(1+0.48748297449874721439782404902484241591946973015788733731052440744386773775273`49.52287874528033 w-0.21088083173961939090198232717695383795141863414036353008308215877623806969549`49.39932096198879 w^2+0.01644200115840301867699074588530969901033117345256991629561375361254087468002`49.12925574479102 w^3-0.08568172168295625245714835160056791045222891762296310685480401017717182921245`49.69897000433602 w^4)+39.84668525428972379723187862998490027699613386523745736892206553065598100070755`51.03713237767277 THRSub[2,1])/(1+0.10108544932408772151225655497722614171188100208546450948360830141794257453467`50. z),((19.68512680469531448150579460494485372285350917426489963423822315121736870375278`49.69897000433602- 2.06725189417552687680909024672136854725410643775512829137782710961691598751614`48.92764964628477 w)/(1+0.56775455598461023248644884921537255591535864518780322461727053416714473841745`49.52287874528033 w-0.28285769316930947336991734316305105379166855446389726430997421235871939159418`49.43170647592401 w^2+0.09683012007769771530054832184734438446428525943221176607836227027205179468935`49.457361043761054 w^3-0.11042547904423771306945948954397197411610323766849887395372959444733570697712`49.69897000433602 w^4)+44.1196975046272898086460843152827282045734428820149768115233996348967207442821`50.74529647013992 THRSub[2,1])/(1+0.21916181084838176801715856125321492645604288507382791803427308420106103945796`50. z),((18.07245792181300913547147969064682637061080771806394447059935167671380015130707`49.69897000433602- 2.60506663319746911181712612574483053051856975370109890159858618748531637571448`49.09705382230593 w)/(1+0.50431896597638881095637722331152781199680589554012979744135833726598960097031`49.52287874528033 w-0.21096026041135577696690360717094007367135126118398904102836670019735601331205`49.38717134401393 w^2+0.02323532773775890252633463716447002493067593327591419685112991065158173116862`49.214665385401304 w^3-0.08968603209632613656308566190907171706904356844336277000598889786044958326569`49.69897000433602 w^4)+40.1891221502870462658019258909112136020307258507833782406048131152555855583768`51.00198635523736 THRSub[2,1])/(1+0.11054802522188503878036850466385221952838865728645744169964293842475959393627`50. z),((24.17680273039231295996627388356603959353732219031322470227567352438337141562338`49.69897000433602- 14.53335279104499266515819174641219668119515893377435645130320394332481022717565`49.69897000433602 w)/(1+0.1222473653891380689901792525701559801190125772981856182770610943831887691519`49.52287874528033 w-0.84046212865255625714428240734723839152711535215779745039424230403477228580059`49.69897000433602 w^2+0.42864953916986700998438629678551609646544241087793964603701539532579443955453`49.69897000433602 w^3-0.14489494169311920029815003448795939292826480856117474714726697385061124905147`49.69897000433602 w^4)+55.06730794135480025294662600868800934819012673789497552770994431340906278190242`50.46492041551238 THRSub[2,1])/(1+0.52167767834959314004207443284549546042948151115468805100897152663761548126639`50. z),((18.2008769502049368712046227758897339682847466771301297661419054723263414154225`49.69897000433602- 2.41929987727397480851408571418668318182160971068448971804635552271927755969241`49.05608248895205 w)/(1+0.51763582531270774174111468284299336114098676205302615317419344384753522897675`49.52287874528033 w-0.21216466442743745078725768292659542025573563028032992761369882462620079762491`49.379401658148225 w^2+0.02927843612186609709665266787471403098814386162119735003886217348170006452501`49.264051765695385 w^3-0.092879798666070265410629697367578901073964145529237725320799328972227376092`49.69897000433602 w^4)+40.50211924062804544787043831839945580902684998118465404304287725330305594896081`50.972640920976495 THRSub[2,1])/(1+0.11919708949550988350962398407461345739833521134773401619890681186455111879883`50. z)} /. {w->w[z],pi1->pi1full[z]};

(* Sample Pades for the nl^1-part of the 3-loop triangle form factor with LME to z^4 and THR to (1-z) *)
(* We split the non-logarithmic part into the ca and cf contributions *)
(* Mean and weighted standard deviation *)
Ftri3LoopNl141[z_] := Module[{constCA,constCF,ls},
constCA = 3*Ftri3LoopConstNl1CAPade41[z];
constCF = 4/3*Ftri3LoopConstNl1CFPade41[z][[;;20]];
ls = Ftri3LoopLsNl1Pade41[z];
{Mean[constCA] + Mean[constCF] + Mean[ls]*(Log[4*z]-I*Pi),
Sqrt[(80/Length[constCA]*StandardDeviation[Re[constCA]])^2 + (80/Length[constCF]*StandardDeviation[Re[constCF]])^2 + (80/Length[ls]*StandardDeviation[Re[ls*(Log[4*z]-I*Pi)]])^2] + 
I*Sqrt[(80/Length[constCA]*StandardDeviation[Im[constCA]])^2 + (80/Length[constCF]*StandardDeviation[Im[constCF]])^2 + (80/Length[ls]*StandardDeviation[Im[ls*(Log[4*z]-I*Pi)]])^2]}
];
(* from 20 each of [4/1], [3/2], [2/3] and [1/4] Pades for the non-logarithmic ca part *)
Ftri3LoopConstNl1CAPade41[zin_] = {(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 72.6349469352933773634403841335964551252751113881686759879127`49.69897000433602 w+25.6994068416234035640423150207539861533633059241443411624034`49.16175721282287 w^2+0.9145606253632916964714333612272088210477610452850129458141`47.62101599484593 w^3-1.8430034898273258598253294148623911755848985900828681314785`47.896018995685445 w^4)/((1+1.07487346183638561886168205581767779927575821176061061840005984011006664281105`49.52287874528033 w) (1+8.39541893310473960421816429800702414735992850137461715807932048670363083986617`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 69.9198442257457583917252528658636385880012057101310642936059`49.69897000433602 w+24.668128605925751946686507143955266277505597388935629250158`49.1611268886534 w^2+0.914342311710718146987171578665719807502999353643979133203`47.638047931447375 w^3-1.7799595639140043140874503246447414698318695992930794209083`47.89821380509974 w^4)/((1+1.07494250498471389349915731751071096256632874986338946645666810165468104587189`49.52287874528033 w) (1+8.06642313580028562599008695655742819406100764615488507486999347077247148957068`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 4.66487995876909900489717960862501846443416556792247685229502126857120009651784`49.687826532971954 w-0.34134270768985033010340170551193557654628814684342477651056085872533035306079`48.784962896878184 w^2+1.00171429351316461614202580823618496189904874208828376068672117525803044207549`49.19157945262766 w^3-0.27589004487835251181460930071864120216229158366628703369033902001648688584496`48.80069377757703 w^4)/((1+1.18921375153910578454771236559448213961625194347159636892352289817902992656735`49.52287874528033 w) (1+0.13116267141109694887973572624928934706039150772088938487606990579106251679313`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 40.38503098827175803684939422477214837765673805812324622393060176663408193104665`49.69897000433602 w+13.44861034504543145289399390410822288233869283268388631257720329194532498769514`49.14819840805011 w^2+0.91250652920912152016101590937538108972226072998142789128234333711061968883178`47.88728108424428 w^3-1.0942342071358520134949761130756106196510936716829846520546`47.94056678254706 w^4)/((1+1.07634898753732571762064573644105067280755212300698551604363771882817636385435`49.52287874528033 w) (1+4.48745196570243680089900247905452760870314070518817556435711595035361407543469`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 69.770063347759564897303520939585612425578000572058909168499`49.69897000433602 w+24.6112369657052100733812414144019313505023556393291338526598`49.16109060263917 w^2+0.9143304035238811056599068763200916731472990622029841110225`47.63900754576245 w^3-1.7764817100466960600740418866553054520294717689468906867874`47.89833975969766 w^4)/((1+1.07494647828400331310643216979711941225288297489625935300197396548307269132543`49.52287874528033 w) (1+8.04827377045811334105078347341405327466902674742696920970151471385594175625954`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 4.68967592337557755534306352181631946343384498320136167937309134544015937580413`49.689676250552644 w-0.32479554035024413373238249109777719685034285105570109309173219980662183590242`48.759988422530895 w^2+0.99876400975284696678159480160130043665028062577385712517752060523010650339309`49.18417061385719 w^3-0.27611074726072227617258491383477187915507552973866068999782339072164397184495`48.790531020444064 w^4)/((1+1.18562381206732274114991831610433160115232148160322293879340811617520158479675`49.52287874528033 w) (1+0.1350645877943186136073962472493428303185330723550691811381122838875936559136`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 33.79399049053558755396926821507264806964675425514494729708192045160372571970413`49.69897000433602 w+10.94410127400198386265627952123783442155747362515521329451899554503772690847213`49.14181714224354 w^2+0.91240401389630365152108821866101832607941132839349910560267101049432535048246`47.970142673628146 w^3-0.94124343695962076046532275962253893472474363718232493355042187194607114740176`47.95978684731756 w^4)/((1+1.07703635412506244544460471477153277428625953634844414789429274448536857997716`49.52287874528033 w) (1+3.68866913617384993996930738001162933482921240535631303905603114966386635147455`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 4.7690639698526902670981326282362939457664187089892170668464302985412872456316`49.69520965957824 w-0.27513080542318023432146818319471391796878852598984614514751134552975124957185`48.67723117537283 w^2+0.9906905021392660216674826105297945693514424864358378541877855731019589351379`49.16200958401232 w^3-0.27698245883006322335369825347390579561406523366833451887736539150138046394424`48.760846504005706 w^4)/((1+1.17579837189405219100776556157213900232792917827457478297220784852392783569632`49.52287874528033 w) (1+0.1471400916199962049505197887245867823524479155416953506385007358763005095014`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 27.66867783327743047797941357993129475496444932551333224647672988874180161022286`49.69897000433602 w+8.61589677910974752535224876830311239785011084276485472029827180550650170643535`49.13270027077892 w^2+0.91258448331059057878193137418430854292637288629065423428324984294195677771693`48.06470175620145 w^3-0.7990962328849071570339997197531510691354397407603594120645249047437490914945`47.98557475868142 w^4)/((1+1.07801043815003629423082986566426432115654677573113098814574724969487342299185`49.52287874528033 w) (1+2.94624507569480274331368097683858675171529929252309612886116782511484924719468`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 30.02436649533958845936762727157728822324103963777459510366080000635072826128958`49.69897000433602 w+9.5113892298499006724846921756608504268786752656735133177355024294861059367442`49.13671454514374 w^2+0.91247138575792121501891430522275419778581306507137945243114062637261475140566`48.02584561723791 w^3-0.85375832541196776565269293035637547973430583696451055553531875833289422719123`47.974449133738304 w^4)/((1+1.07758269493651726599141405275571921352234377641313870801121277494716072874522`49.52287874528033 w) (1+3.23178173237415540446717058180610415184732298250187463887302815634191123920796`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 83.1928077178781703213851921473429723467892727602172113509226`49.69897000433602 w+29.7095133838124043018306484808698489784019069756572587130465`49.163797699453404 w^2+0.9154462931015429017989063216233245780045759492440104255885`47.56057241172692 w^3-2.0881584791217326574952463680586498840585450954756577688272`47.88882367513446 w^4)/((1+1.07464965749525659377767942668393370494170471938234220898058161371662926549863`49.52287874528033 w) (1+9.67473020546941865903367743172805258315107622707580186462919012112249031775118`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 54.043742095500828997123490875712812295679140912257661336873878803875084980521`49.69897000433602 w+18.6376097009896943461149976274150560516402849291377246305487`49.15607300875742 w^2+0.913187711412875596998814225618721758103681430988692927027`47.75402418162437 w^3-1.4113355598576342725117261983245232720911866865424454210977`47.91535607672066 w^4)/((1+1.07549451095244092432049469013292536102534894537295120552453874408061220341511`49.52287874528033 w) (1+6.14263899523521048515938990093606726341889223556188445405691854323442139279147`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 31.74733394617391254497813459043688367857497778696212838889031234355154426130941`49.69897000433602 w+10.16626923989010744779378898346148579037573406332243695146969008976923583608127`49.13921883354591 w^2+0.91242574297784881579638598125737438786403257813636545985118444377789022024465`47.99949017127979 w^3-0.89374302294819184541078902150947810440754581016679917839489163758411535881406`47.967328125859055 w^4)/((1+1.07731492494900845476643532714847827258929631991400289481494711587834990641829`49.52287874528033 w) (1+3.44061400387657300931674084981715542341364747215084765972461970687993517427737`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 82.2468286580450363939608777334681132546026603481584219343498`49.69897000433602 w+29.3502146945377892481897249167472527024492397327780998735566`49.163637317925286 w^2+0.9153649266527976705228335058662900042965678646475498376177`47.56565232961947 w^3-2.0661924727906248936540385184907722806085713697336195162856`47.889394292916755 w^4)/((1+1.0746672648895166139635014357488480143956302166306434946252786270015131977446`49.52287874528033 w) (1+9.56010516492986431799721827647969841501603385592628714191756904496732095849201`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 73.7960096073403122922947067775016197794106421117077731363908`49.69897000433602 w+26.1404103771020010546473632296784157543676587631094838545478`49.162011799055556 w^2+0.9146553205990258541387879464990674241162268099520417579983`47.61393471453074 w^3-1.8699632011641470806386185410446186076004484194652001185815`47.89512882443427 w^4)/((1+1.07484556317610978761036215051090951225894944022958331287533659465772930103879`49.52287874528033 w) (1+8.53610739923301424890403455581072008083460654578157177355351910303597238325319`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 56.47971132100941501173446480631829530867975591086788108998619290059393194603666`49.69897000433602 w+19.5629523914747717712071756386515619669813677027866068380321`49.15704691540992 w^2+0.9133472218718211519964668852377111174324028727224017319819`47.7340618344796 w^3-1.4678937167414346302876173585878590279762348901450012328241`47.91211403767141 w^4)/((1+1.07538835521046794031883343830929627361017903276271652256422165173406573673`49.52287874528033 w) (1+6.43782254167215989630346984424792534510112956246021958962896549468958493240174`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 4.50480073213326606618304401921578134955489406919058914645688631972014693987716`49.673460125641846 w-0.47072262690637471740929902801013414944820765522131106811054169499095746658148`48.94714480699978 w^2+1.03010150934803816840872489019519028986914714504793862589855269398687913226934`49.24885895349063 w^3-0.2755891887589213821248545843017889521554609763479745866696371619875438616752`48.883807062774395 w^4)/((1+1.22374517285708616211008042656635953299142731115657106506084733840688959624233`49.52287874528033 w) (1+0.10313363282845947675181115011407134800262235458514747424397028438107975356695`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 61.15081224408146837663986409102019085837698481273715593443288565502923856261972`49.69897000433602 w+21.3372965788354491160483782588586047626915387807742018112881`49.15868233317119 w^2+0.9136737043226527125718214494062623406421739581486749384628`47.6982014692871 w^3-1.576349475418357475412756810463334259484492134109100636317`47.906604898084396 w^4)/((1+1.07520985995151344514814146990781469896509874248777157950906589195310281356539`49.52287874528033 w) (1+7.00384647087134471035322112565608347152525557255036403392104654982109974956346`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 22.50796853486511051630320178129754730142156123657271953901697923788447229630011`49.69897000433602 w+6.65336868592226263407700441848433824923093287332930622160193175064710836734792`49.120329392162695 w^2+0.91313616991268204022971806191015437785872203239221803102768875645291201583562`48.16446724918859 w^3-0.6793821263254189815687094159693051453108190637951714143938937050810688097874`48.017804849983975 w^4)/((1+1.07931706312556066472920628557897789123446822879629029551807483343578318112765`49.52287874528033 w) (1+2.32061515323814787891394474328908556319527764497989442690735684136996030195984`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 7.15453565829609239198772433924543826020507673553313368284131557740563998009428`49.69897000433602 w+0.77132648596414095211140863775723899901052888570372358362924123784122689594559`48.82486312718758 w^2+0.93274838267364951305575304238895014618416114818809352373094466662247904587193`48.80712778255885 w^3-0.32538434694380556828234894113452947996658108068301968327463285056417163934205`48.38843556900166 w^4)/((1+1.10505561656939618301406740486162359440887620825207254833462601866036326081757`49.52287874528033 w) (1+0.45386419590708603016588706592945805886444593599252230079993381070158654799404`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 11.46660547589309808448185066609222670179707186518671205430390005238674869729071`49.66791486188084 w-13.62396940156898755610075302633736156960460376980464432278179754801667483402619`49.37580848460441 w^2+3.83043288357073742064834658145765913973445548802670916839243463535918774873443`49.45340932976061 w^3)/((1+3.19067974571019844855206832890805188877069653598948981397107829878107495521224`49.52287874528033 w+2.04217130853220156966399149276090649545834886901165638011620725355377983755515`49.40005923613398 w^2) (1+0.4549350529732103714435250784841636071659693165365239827518691360943219451983`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 50.03629952325558874929974380505651748412371919800607244772201688456869330677642`49.69897000433602 w+54.53562750815926794162205891768420570936248132007242914820327946058576136051456`49.69897000433602 w^2-13.15417855383855609202863169521318317150620988244206169294840520443078157799708`49.69897000433602 w^3)/((1+0.35898426345565044374344921968860377132655945628411101016161351246206302746869`49.52287874528033 w-0.7424342152307995980966104414806077930225411125220639597460583389492028505986`49.69300007498103 w^2) (1+5.83620017762820144265144549818009630725994905248318970355827347989687470252095`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 48.19080877864426972411505198782080006814971388075366411189537219107376367886167`49.69897000433602 w+53.1761930017477482122034595614816964382679127163045108791170638986624812823393`49.69897000433602 w^2-12.85598125672727063040399285573543445588007758483683320073716935435976368291675`49.69897000433602 w^3)/((1+0.34627115358747906621219981621035024486226256798551283256144627223520599823539`49.52287874528033 w-0.75562866545832541008374667128005732174391184998815514486671424511865983189234`49.69897000433602 w^2) (1+5.6157674505525306639698883269210110860129488630039302460478221223770758034641`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 38.26712941157842209502222914544337947556345456890026998768947245338050656650431`49.69897000433602 w+46.67793920083449517106104324681856314954914842403160263762627402690863714232059`49.69897000433602 w^2-11.50486208361575455162701660639100774599566824849550257883010828894405992706098`49.69897000433602 w^3)/((1+0.24000678635175547976110896932906963706763506953760428758404014130197951331412`49.52287874528033 w-0.86600543507301332505233185898326371621254319411589283701890974467999495044409`49.69897000433602 w^2) (1+4.43991954028162444260141190390813125028745501466196757990512952693762387736017`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 7.0743016801580920362856114183766361595743370691140721023001655206130658013089`49.61474349395588 w-5.01964566524643241928768005455049006744972351669167165107573996512485077181522`49.35675349984015 w^2+1.46542967405758351370058444197236084020057465706499145258882873607345515809407`49.53050667342609 w^3)/((1+2.44814074871303123500552137906602206232501528891788928068627187753854081638032`49.52287874528033 w+1.00895639040689523813051213820573943172390687684530633991922604843999205083319`49.35311511685588 w^2) (1+0.10837127080806575566979393964717090374003378011734309087488016194697794684879`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 40.83775140049884739635984075355917541043677885865772882904120060657576319481917`49.69897000433602 w+48.15613492976961443172961871485175910815885399683534389207744603949883124274656`49.69897000433602 w^2-11.79023579668341951357803629454360524944678892577493047053005841273560531311658`49.69897000433602 w^3)/((1+0.27651729753116283099046117564700339047103726553923385785895550335700972219619`49.52287874528033 w-0.82805430614521365478174933296580523229200252771337816953801365457368335603785`49.69897000433602 w^2) (1+4.74226427663734336964562988241762997607135612090289424215714889021485406168994`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 7.08309569812008764580277690406596861685257650471423280007438061455069023900127`49.61170122908779 w-5.0283108430657774919333731876961570572835521332137043705873187533299855970621`49.3617814596898 w^2+1.46794702460210227628661530744477536058378538951013039869781255893900178523886`49.53313359441409 w^3)/((1+2.48048118455125302791192407275140384661255403302750159143661783516147911583918`49.52287874528033 w+1.0102965309476477370085122001280214460000589805735468674581040883580651603361`49.35679725910249 w^2) (1+0.1013516991296862471829087461654871995262237903454166654299659726714320410543`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 72.7153335605817290490662010222896059642718542632175223777841`49.69897000433602 w+72.4660904889453921777585296507946005856146885483929856389598`49.69897000433602 w^2-17.18667807875427842304466431558169347693333521288082015525930849213418539049799`49.61905080468982 w^3)/((1+0.44928687687209172764384474280416988103033946384321657408195029889470452444359`49.52287874528033 w-0.64870072068206028345978746958773402239203180601783179758787247144391066078164`49.60614362164251 w^2) (1+8.5615557170761233055964834412102427043899453576738466866301953668651244123416`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 75.167566178852978558668190912296324034168408815276022523282`49.69897000433602 w+74.4749825309489178317252050303816128034885046271037559149239`49.69897000433602 w^2-17.64344659290459809141163266902064554113221492449986441865810407648233723219466`49.613841009780515 w^3)/((1+0.45505358937106312741277489744842777191511037051010484562322461331984624460387`49.52287874528033 w-0.64271214738792095019456345999143951206920377107311879974355122147608840905353`49.600356580178186 w^2) (1+8.85724161910596461399107358232589816107025982296551971218330342622642486601017`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 7.41396482936098335928652079852502487412141293324119365213572886168068211941884`49.63628295430491 w-5.43078699102525278823738740117039882710681309329136897553491881936517314693071`49.33124863149909 w^2+1.58254214738521927425494723205165931556162482796746882887004628560048250088321`49.502401153148604 w^3)/((1+2.35460664615848235390880245397957192653724427462373735511390449666033622420809`49.52287874528033 w+1.06716872840587264487668740908686143288392807518325989844135342556918517149579`49.340008104282404 w^2) (1+0.17291047182528450049656943622176439803819087169903796143451923480097155133021`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 72.9394901337518264488483592886265589968235328122964446855351`49.69897000433602 w+72.6493910993528564119472685677219743307432666185069576712202`49.69897000433602 w^2-17.22833432581163458936057940776921440339208940503097834600401827706961432486872`49.618557373526365 w^3)/((1+0.44983367834431607429824376303697174591051722893667824364967897370135129038124`49.52287874528033 w-0.64813290501704381700340758455685193725091573450155427501755301998398311133827`49.60559629159198 w^2) (1+8.58857920520956762436832004744078366481427701891665324064747445544336844871556`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 12.72359129338751841111860834070952364222628621388852154626971966637699381560668`49.66517539387719 w-17.3210215898998683117317928209174886654990577315175348393629225931825519137919`49.394758972249114 w^2+4.82584856666414376270785004833050878353745252023596681246064740752461984751914`49.45736837890203 w^3)/((1+3.58236060089168903875438460094996696707988418227559005267547541346956062430907`49.52287874528033 w+2.44375992852382212801941947932210021732438783675418224700829905562120642437057`49.416810941577886 w^2) (1+0.50931896867108486467446792984840061412933724113367410202688714119225463812255`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 7.81535017200393658930468819860194383303427278343488397507160519330154926247602`49.64613078809733 w-5.97533442408432436613619693158876527637759850981855522224576191340086219489891`49.32707120423294 w^2+1.73615698244837973762185823044211246215019057210363050927016775038282280641975`49.486061383769126 w^3)/((1+2.38397172181409634483078749336130255943148444814570672917740099013484401569134`49.52287874528033 w+1.14094080445181555579755943424109554760939661724643136390370270236744382375714`49.34219244005558 w^2) (1+0.2142035187101390789623494729716619225281359734411604722539743491763465513257`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 11.18130045029659363520532697292608959690267900018535886773008716545038167722377`49.6681292812012 w-12.85539434062245839439505080880688902742269873085366086714117952392704873929227`49.371194572401116 w^2+3.62267370198920365575508667150309276441255194713410856248685441016794561067225`49.452898721001056 w^3)/((1+3.10841804565463955753072454725633018217615261019523623443401658936923255625974`49.52287874528033 w+1.95709661920863253113966599853064900778001600370346906754718640895268576149614`49.39584868539238 w^2) (1+0.44093116705395021466081309033086548934194803070492997345951403514096227868106`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 76.6649727919613196210018358441386015345046477532634270133989`49.69897000433602 w+75.7053415247842725053402988218009074208311643321364135825087`49.69897000433602 w^2-17.92343415777955187291096720886941164988346468813500519428557650662705114569076`49.610851753301326 w^3)/((1+0.45835579997564897136574742270221709810458532476373635566424234598451351129698`49.52287874528033 w-0.63928264549643039166691711623102323715003495557578758168822899725692967763177`49.59702787437353 w^2) (1+9.03785105763196383040354110325908505744471349276394098145005823399996318672829`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 9.34470433887137296063947895950970755298195884906682511665886950573231167421381`49.663720670273044 w-8.59097016849096902939968470181040147307532550701699724714425619088778575970901`49.34113518857136 w^2+2.46145695095296993502176814129551662874022112023090305646212971196977556567788`49.457578612125886 w^3)/((1+2.64745183988354034034650229964257089028836004330722474372379377882741488237496`49.52287874528033 w+1.46809995458654990810876118675698471190944869339459005259268769406364902827044`49.365779457935574 w^2) (1+0.33363944239431376227886786917800105153958542065449187729760273061951854560231`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 54.1614714626829965769151992316865465846608276919855327876462095835239819901577`49.69897000433602 w+57.658134141305772791971065721595779418965396592736711533702199217754301282259`49.69897000433602 w^2-13.84614967319875181723124776515381415938705606268102469584511952785020582979712`49.67800610637152 w^3)/((1+0.38305124690942755694969687357372605105021310835789511982307105551356290985872`49.52287874528033 w-0.71745696136341650893371477923871658546938955883240076443356202303476760945499`49.67047700359303 w^2) (1+6.33001462516424058140396442516626764590042172533830555017424477939352390168544`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 7.21595741013414548619965144570180155130823302598843598287145859472211128661997`49.62869341531974 w-5.1852116896264983488003933338479150058856699198639852081544370243273351426156`49.337978198386786 w^2+1.51274029588415761791261409337197031298293164381391222372304303779995366864872`49.513906787143235 w^3)/((1+2.36294980276167046771091227029369715218658538832425101306177670914632495750329`49.52287874528033 w+1.03273368501716506612982205647021193346142497746108554526907454962971381755294`49.341949460465266 w^2) (1+0.14683288642760431621574226619240034089532150036683039909887240028191556027613`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 7.19887601705357781091066636321887704532011887106890751912405500355327160168207`49.62782973806244 w-5.16480855279915981279645902603029279393130858261578770965998735515840145190652`49.338912669005474 w^2+1.50692158757378443973207547938161333809039290307653492662035353448735338485391`49.5151245785313 w^3)/((1+2.36552177930281770963338387367637109808348167234671817274158914352097210718307`49.52287874528033 w+1.02982936605528490342272817563089588901967737139514738039177018440504324496135`49.34235911996676 w^2) (1+0.14412020569167343515618575446851838516436020723272223851217589851996127861957`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 75.5608366570712027976590297041184555823081429450490285175326`49.69897000433602 w+74.7978608237406351514848820914739237676214803181482875545172`49.69897000433602 w^2-17.71690620985188983903055395590537881294911355359562055842877910721581025810943`49.613042463914894 w^3)/((1+0.45593620933926728479477343181316451453533426497243492921941824021547856109861`49.52287874528033 w-0.64179552283155269136966011789754355709860150091659204137521214383926597175501`49.59946794761561 w^2) (1+8.90467203304945113172002207363101508560417136877789569178660452282251152535986`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 41.37461002467485161883532013899805754710605757357680341516427059462104651330366`49.69897000433602 w+3.31490665616905363568321939540847800709271010635515719353258498279624638551914`48.466369723996564 w^2)/((1+1.32349478832376226272276242240758048444260980852133840920611027072604017568252`49.52287874528033 w+0.37012671918517729106714971552599046458760525335902004690318594932661622607728`48.95731945020528 w^2+0.12596433647669125291016352857282692444401503181645808464361926760211361074326`48.94682827409345 w^3) (1+4.54556899540711025283850007653278474886293708664018229911119938062912948173728`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 29.53246107160685023023826369250873556679102957497966653022435442741837867359881`49.69897000433602 w+1.951275616848776814678996723409851973984784230452529905941246993764202341817`48.386513409406334 w^2)/((1+1.31766080807617140501351889735633457628993966813080984035837439548226676307973`49.52287874528033 w+0.36452731822717160044923025771929722532409068063692780531975948548243369031733`48.958791809518246 w^2+0.1274882123517819100392867647619439109511948026774115913411395790415192120571`48.97298486152604 w^3) (1+3.11215991875561746718531223260766188753198700270722980916206507408484694311466`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 8.07283832681132433422802894144612516910187740910305381251800903165064716031563`49.69897000433602 w-0.77388016131723242659634167460635105942771165719893810108846993404438789991969`48.5662537679193 w^2)/((1+1.29006646336881044277809298317789578544880295818663809819070478041546488870692`49.52287874528033 w+0.35418219822286026001328381108649392824748003534238058864741136428551382177317`49.01835677454164 w^2+0.15735465296343485063825375434956159207292255044154418271465789583280308203808`49.26369052371751 w^3) (1+0.51887868117396285908486204698464634818710091860078812912216647257643385921654`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 5.31407769515057316922952452224026843854109232118174233305727653079251737348701`49.694897865827215 w-1.37413650871196754937073870387282464799915616674133367769700634144332982323145`49.00927952541778 w^2)/((1+1.31203568076909323389444017751471199084078608139219387706267065884835229619746`49.52287874528033 w+0.39596446673839853643046422591726650948414774539037702231396499414381506567679`49.13025682202128 w^2+0.18799368750163271230905008665401784450426412139260957567624973016339747024588`49.4795120472663 w^3) (1+0.17911797805797177189860420210142301600834436886008394547340905804276379957423`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 68.7490704385948980075478706204463810287170250231286146285926`49.69897000433602 w+6.4448546955222690948879334504950226626133783602270066788472`48.530990262694345 w^2)/((1+1.32955318215299318643839681775034735478072988423147366054600656589053437967789`49.52287874528033 w+0.37625650797358368118478826673988075867615633235271476152456831233915409599387`48.95640837144082 w^2+0.12479610053277780063933206980709303277703063369488790593641100074572943854484`48.92221297610123 w^3) (1+7.86091231663588000962127133173345804680859996055200888170385392924340244776776`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 49.83374421539168194187542468102479343685410916946386339098332811923037464281318`49.69897000433602 w+4.2837968096099323293174237564887880406685739457084212762535`48.49537800471989 w^2)/((1+1.32605009780545517162020556877276811097885069571481453920840920330963118971203`49.52287874528033 w+0.37267654329790207136025995404076751909769018095954902756992268495234511830146`48.95687097454289 w^2+0.12542502608231395577059843553558072216109985575339758924753341007923988927546`48.936167330410136 w^3) (1+5.56989087264655381672579271085272098998742653419214095966911477229975112094607`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 4.71450993191433358739193606505123006056246634268910240369787528913386982453813`49.66426697230427 w-1.55356534372267140534308880840899081516841500775925695883397491031180648781128`49.135119439375885 w^2)/((1+1.33255433283073916769473330229305253314828458646860922149693353733356725872596`49.52287874528033 w+0.41954188474030490714851280440954113860538094001898818871302331137984332544225`49.200403143332515 w^2+0.19992586159408511793959632794884353998959421126293882082825847012493829975629`49.54159636073534 w^3) (1+0.1013409987554661232323478542180532904315922935307130482121844054970440649974`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 12.87412626053135134531912892179160955491308476034138817227464830802162790919818`49.69897000433602 w-0.05316671075250403723945544651208277887180906458019077376301317904088787155678`47.201883791223054 w^2)/((1+1.29691428767555060202970061902901499800606011785204736199178340117092164947134`49.52287874528033 w+0.348976482146635680714135817978110862634318456612876486423637895955745050108`48.97567614218718 w^2+0.13880882725615456791449141408641567594676718996915792950357405147155324600342`49.106324505657206 w^3) (1+1.09892028907088723831522854474662143399255182594221787479009153232258523754932`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 4.82305801119850957266887305077149391130570631660324511727068286923291541781306`49.67044108028638 w-1.51818607759551042623229396821433957272065710880814867939946225516511202962537`49.10955170062663 w^2)/((1+1.32749385862421209657702938482023102374360480597682002215272313529102845935496`49.52287874528033 w+0.41445016176242884906257744531949945059525282346050088785329615155651570265675`49.183778888486174 w^2+0.1974539357732418664713052336435298746512259963039065115631359260521210979096`49.531301496861396 w^3) (1+0.11575846993784965563636097011039473809839469059082733985621617469798074825203`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 34.57733236800161216301913127379430440651634602387449510768613457266519843070241`49.69897000433602 w+2.5338170212421372058480811812233078650006357917956274305406`48.429478111243576 w^2)/((1+1.3205959036440595846447802338692876745193006570045881725028351442085605334182`49.52287874528033 w+0.36730322453522509998399459251637875489377000264606361096722020777524117972036`48.957964012374525 w^2+0.12666712009372667417996784379130806480392494176762187793057397224190945871117`48.9594822371303 w^3) (1+3.72269376658944430748153671534390641790898623781826904011713441251430625691117`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 4.76524677690135683877727006169070761441731487712372683254284038350854459872468`49.66719668603444 w-1.53679875854190862351765652128160434380244286391417934775353063963705483134035`49.12293947896421 w^2)/((1+1.33007583408207790649552952909758386905223466692958362977573065897774967387337`49.52287874528033 w+0.41710263634654523099144633190684580947847669243257527986314726630813104678461`49.192311502037704 w^2+0.19874572072191224875714095683487279761913910271421767112088380420843610006395`49.536903986718016 w^3) (1+0.10810821150721729680535720324542931536985546452607760946728422840915626915192`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 45.57008220746700316846695654923926575576553310004663836135035518258466686401407`49.69897000433602 w+3.79575595987089631075209478264183084554337815370567564974139374250313985059012`48.48239935332496 w^2)/((1+1.32487518169354177689362161984548019933637009817922395557361439302855932473873`49.52287874528033 w+0.37149738821285561493926215920794066977480461980612142561603262538620015631163`48.95706443743864 w^2+0.12566412950676994438735065985474522253583976275672841598711798425250433958011`48.94101533000511 w^3) (1+5.05357310015034657825333806978738682318743209687416090725948418729913680549787`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 21.19521619382190970827080065166754496823891909112284094049599100499140615021561`49.69897000433602 w+0.97611483252863327443818878762167393172516007197547406027786213722799812537931`48.23548239959208 w^2)/((1+1.31023827383725138680228005461014270313052168018930735353600035479750464993082`49.52287874528033 w+0.35795887899023832387020520797657391517757189730426539121953589073631448963718`48.961952116546726 w^2+0.13016708200159335429586504873522590644434324156345166986646584166241090260917`49.01107511306508 w^3) (1+2.10382370622579876924191312093588748587220030381831112515536931659081449544908`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 22.70834545042433346967064302664533262841285800210526173810531049269372114468579`49.69897000433602 w+1.15504826873815265463853796629029972484197530312732677281699616445461564457964`48.27723806715366 w^2)/((1+1.31191810144602292036904463753206600917032112608448477943078012563955672274679`49.52287874528033 w+0.3593802701652160416409205497630060895676576622707155680062093656137132456909`48.96107310001096 w^2+0.12947338103293222130038411484169347443978005088596522419921048262508030028966`49.00186990332563 w^3) (1+2.28674379264801619271279326911088317257908764764274524644238238959350133142894`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 6.12628284561182936652507697295855499509311180844459775504004518186664882496764`49.69897000433602 w-1.1690111337014738807499703235534008223536864382905050724303819180665029115838`48.86853859508024 w^2)/((1+1.29892323689854713039605398526995989227599296618671714503557669906400437878948`49.52287874528033 w+0.37577201381122832258572380127059673562133875933549461241438458333403851855532`49.07816303057354 w^2+0.17591694301184000275103080634298954278594698121630561107795084013359829344665`49.39932975248853 w^3) (1+0.28080785842608727103444448610835221744652808735870027445230202058534197040414`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 35.92880938626924667295559755848822502433251541877568093397209163262969328639218`49.69897000433602 w+2.6893885489088562999651674297024835503451020065857498786435`48.4382734380789 w^2)/((1+1.32125343175513674859583744749528865075819169473195543066092549733018964467514`49.52287874528033 w+0.3679368417870822650747521291369363714848657489192109369640513137306326815846`48.9578038665888 w^2+0.12649873173212300704486599730992684930729854000634221609225049011663142229704`48.956556016970474 w^3) (1+3.88628264886475059812867704273785818731031366570648001411270277861517250578647`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 53.75058465939196112216700854114805677064464671279268364013812499245163058062404`49.69897000433602 w+4.7317378963810218406408441028500330905087216982522143374466`48.505165004957924 w^2)/((1+1.3269712244818868997002108398837372410954025713611928532421687050761938123929`49.52287874528033 w+0.3736087545766203723229419189017023483576237508297689334789106930569950326719`48.95673344695575 w^2+0.12524773028367223544049637059792254022498229173234666279239431326391684778102`48.932427541560635 w^3) (1+6.04424905958604591359872322958929852790919553954332174952626621906924085968577`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 6.03117797592385092236410594955724560482381407560186776469383237971770643399248`49.69897000433602 w-1.19144075825110733339447951075827955017566915730081054665125763416305787909317`48.88414838723595 w^2)/((1+1.2999899190922485960521348471111077197712069318244347522795776285522645999511`49.52287874528033 w+0.37764693628529702084433446361455503165408589788040938106588847265483276086364`49.082925180607596 w^2+0.17715986300160098458881578934811947443267079584083360452603883701994065385335`49.40795118989936 w^3) (1+0.26901769716933451247714477611679468501532363758571579109338209500981379365543`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 5.29661217516147173638987869731125312345780215807165354364313337574334729069739`49.69410669585227 w-1.37893608769546882853902014100448806812599521258477410566300434031407656712858`49.01256150589563 w^2)/((1+1.3124483783395601895384558555492343683827139831084818660659955846205254748476`49.52287874528033 w+0.39652177667143835434813570317205078235160263020690856540373448865406093312524`49.13175534916811 w^2+0.18829525372468935911217380816143715315770304873491821811449705202588478502432`49.48137239393431 w^3) (1+0.17689857388689231068317265740517649428415441442339617100950212067773333352084`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 42.69039301641122135003525329002877576509999050104085176495949748616149943515479`49.69897000433602 w+3.46578980574488680993495058925570465767104087600700756593790069545588573694851`48.4718178963899 w^2)/((1+1.32395538959406537939552597765250570597106115636873731327470881157192184612861`49.52287874528033 w+0.37058226949182613875170705971027200780242700302124154296262028090304941542686`48.9572308877139 w^2+0.12586179323856711311888621171048020146713688988774523074772797447947315123147`48.94487415392698 w^3) (1+4.70488220169413693271912291509425320723026657327651236494713275262342736301696`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 10.13466234126730633930935200318299528770580456538586993345111423965926426716846`49.69897000433602 w)/((1+1.24978495671667733603398091075187087178211649352600927398639932496179120239061`49.52287874528033 w+0.29596825106644524572037849247293669583188216716549247154676148414453315609056`48.49582660906919 w^2+0.13375782964725975993395783737472244365396972140019102867362374390846766752612`47.46511317660697 w^3-0.0052768856009971444489528338347373495885556334888483099347`45.37182734684245 w^4) (1+0.77877233135327388033934355997112751598064213159891124983040202004910635035065`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 10.8724194100105340348743887506146504271729904701069585120193277556150866598555`49.69897000433602 w)/((1+1.26351771553963727047698762240781455983028106811633460282172736377756257120637`49.52287874528033 w+0.31081424730723389508917650937623906435527232051416454773562317500288114033821`48.47404947916671 w^2+0.1345610837067202547709003127904032516488026287980679792478119854330461707178`47.39440792755672 w^3-0.0038021276686998405791873818844344318209067019736797573896`45.125338192716185 w^4) (1+0.86473032376636138872488962523640287031523325102670377051245514196943434561687`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 14.71972451648045217375146150611036440489812042091546848241157967964463268752723`49.69897000433602 w)/((1+1.31291561610798171562665465113727928637084135208025684838169398141703116021853`49.52287874528033 w+0.36714867242194334628210785647775117387777291390539721647981580312262874010139`48.370253441353434 w^2+0.1402844939284831947300984344881483803097836323522629267791`47.10501230078333 w^3+0.0017778371665876920780430037985974155883658660704715525378`44.355309978286876 w^4) (1+1.31854398824014960561098831868578898384649628466575043979415681177978165980602`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 4.70971362790900207687250903051155904993846049713800250616283682567459658478258`49.69897000433602 w)/((1+1.01810930281249151635091675116937272109201172862705536409508739259034873807052`49.52287874528033 w+0.10178825641033016710229965897735052777640906682256400713769610255940375259451`48.58010905092712 w^2+0.1516111224701257625351068175734552001204299935106728004313250764743586079559`48.38580455568824 w^3-0.02934923984162703793321474822185685922888659175628595072628915260711419246539`47.3337476086483 w^4) (1+0.17937110657945876192193149783283232175080214196429395931415947599679643377874`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 56.95679886096846523399480379781911753724723572894489869790563121978708558556295`49.69897000433602 w)/((1+1.41673867004604990238902277064465299190017407951036092851150929199213150072129`49.52287874528033 w+0.5005387846663621326074305860068153026132686125365551784378`47.82609257475509 w^2+0.169675419646856915541780082058816758292862520222368456379`45.9178700501978 w^3+0.0171974695464208694425693166110231370663599979055675484814`43.482768307930385 w^4) (1+6.41029182239973569130996886550729633324404180232695938199090287724975754891453`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 74.199025077489344447019094399631874781202675069399966077213`49.69897000433602 w)/((1+1.4251556719205049566237335188741166791188846143363556498496903515959048900008`49.52287874528033 w+0.5122500910904068878933465879071604139500973973817178680984`47.71405753935451 w^2+0.1732567883476290246076857184852666409005638558728507005449`45.689480007556675 w^3+0.0188556592889560918782549722169239794166081431627342051191`43.17041484417079 w^4) (1+8.49736170411620014969990132412668881971288262803492188595737343718038644224971`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 72.0662461249288471233502672891805009870778199860854269269725`49.69897000433602 w)/((1+1.42433279344967578852159694697826244284269940456305328194725698733834793118775`49.52287874528033 w+0.5110991644093489460103343304215618893643280792337055039406`47.72645239491394 w^2+0.1728979426182051039581784831187340506843155465685850333145`45.71467121015717 w^3+0.0186897069303583367675498267009727349407862573769764900104`43.20533496436031 w^4) (1+8.2391468136917516657299347630866169706678124058301339755122931653879845135372`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 38.20718144884431906782499854757221295600924711159582119802940615991124726364708`49.69897000433602 w)/((1+1.39896592602997111461453081831910199841587572816011114735960596391709234411239`49.52287874528033 w+0.47625480599017935176406094126524222572014322946167133067740493530038837906432`47.993234404361694 w^2+0.1627487801486392163083233857909341905902372823930940050799`46.262891929465916 w^3+0.0139600343882900181375434963097968266045102943730916153867`43.928765600432314 w^4) (1+4.14291609164205269825421151474495772709575149005287576861981082635426296927701`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 10.10770492322604127624497997121025289696121627451821912486875317883317726087206`49.69897000433602 w)/((1+1.24924545192057468574981989842766790950951395374916522761294640061733668724371`49.52287874528033 w+0.29539226946034784107052986776056270883553098997629152234342460196783952068674`48.496630110441004 w^2+0.1337327225189754713481315693704201597075568980927257917768613520227388362404`47.467826742161684 w^3-0.0053344161251461434097818685588943577128120154423537325868`45.380501669404616 w^4) (1+0.7756408810504266163331246280726790963065986366023846634215506477487314090662`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 6.2489926701903463145136521598611159684743860925520262121618585406550493253584`49.69897000433602 w)/((1+1.12454072407775473383013131197107565972107707780775919415817061523280470897943`49.52287874528033 w+0.1772626696739480820304211938441562311094584192075712322782254238988493614897`48.59930245419164 w^2+0.1384429196949279877875993487517946998146792958638743516610320622369738296848`48.010696515405925 w^3-0.01843140148296572755128508225838607661412018967205751466223517829488854172459`46.66136046265931 w^4) (1+0.33927176338714705365276824133616041952101500524058960098269186166047989717884`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 33.14869568779635407128230254823619911845726064173877057403233721121057559213249`49.69897000433602 w)/((1+1.39072857140131470757232387700698195438381981313960018431288036835049814904303`49.52287874528033 w+0.46520377573965940304239970447242905159454605649212745368195769005793404724718`48.05186314788312 w^2+0.1598224544183665543851707173263937695084917985456642959123`46.3859098883884 w^3+0.0125678642985248977967263138272348322994886104556696712364`44.075749229490995 w^4) (1+3.53205819633542472062951362379036807282006232491748476973255399402811159273306`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 77.8559101143583659698205792648194983427590412504291561132512`49.69897000433602 w)/((1+1.42646167579625200293190918949651880024583914500370746902279072392670017591379`49.52287874528033 w+0.5140794104983381748072420430695910010204058894547697757939`47.69359319991668 w^2+0.1738302288302662859780535130926933673876102971205802086761`45.64792324285262 w^3+0.0191208073666249100396208940716481172899568043513000228789`43.112591999455944 w^4) (1+8.94012587644333627714111415493615746169557678859985814890485783632439050592525`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 13.94929625217595479217899491252363012668984870228942410072055262857691100839804`49.69897000433602 w)/((1+1.30519721414990289249646981132019664069354283067204025405727589370983437339084`49.52287874528033 w+0.35804427117332490991421030028379887070707971526279625033000454419852711049497`48.3896095575178 w^2+0.1390781672628664497982748511038131431080126909091854885746`47.154905629115234 w^3+0.0008660343525031350538692994437798976856519687091728585201`44.12004845849535 w^4) (1+1.22712376369680996923883408367745237549649298971308947864555120725667468147002`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 22.67810289029544978803202171290392898725970213550127588857196381055873664327806`49.69897000433602 w)/((1+1.36201251566392503608230382161993514683680446540797736079631064318701858836166`49.52287874528033 w+0.42768619911182124643639267890718701099457577257437875541041412279322018428587`48.20529711733261 w^2+0.1509626687065132226757060483661077655983629806754643164999`46.71703963937518 w^3+0.0081582217799035386216520789942668433064400901307167305331`44.40899902221061 w^4) (1+2.27055581457954797969388227034295709369829312690674580385778214855379843895506`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 21.4188647693705582048795436481228368025744426627438484581831423325172960506809`49.69897000433602 w)/((1+1.35666987779059727423024251787473963030491563675481169228715715548511453507175`49.52287874528033 w+0.42087826281089366953584649585589093424495125603885002300305423502274359498588`48.22783755275653 w^2+0.1495358592156501328150766599248668467879319264705896301627`46.76738907539211 w^3+0.0074027922719291574326653043657072807347857652509764635252`44.44612109209706 w^4) (1+2.1193144416240202772819481837924063490238891517710785139156244567279159899876`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 5.08906224620967233818404622182343190561450208299387780842912328039053915935827`49.69897000433602 w)/((1+1.05038490699745256387525830367257642425440956801445751363244717421933662688224`49.52287874528033 w+0.1219982202109072304567932834254703315394338216022743889392893999299948505777`48.59542555136366 w^2+0.14739449790693831268490058848340261294766794908397806589594457967217384337157`48.27966970602881 w^3-0.02614836326499635357911724567149236231485970236955801511869407418532567691457`47.15152622963965 w^4) (1+0.21726641633069325427301287121000445517929432934983315053106908130056882085789`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 5.04933696413185530114442748498229522605485626178010732483829017880822445261411`49.69897000433602 w)/((1+1.04723744707019675315291919392692552276481756057151707462291577467780918608018`49.52287874528033 w+0.11992075343873451216016186473930533386486645689986295727561442555712175095519`48.5942841862241 w^2+0.14780767997322897254122803164847592012661714182083915314495924243970234093129`48.29031975162348 w^3-0.02646706310010974033167787779328110293145060381668388384558014530428082206841`47.17002886820186 w^4) (1+0.21323992190818562810447227661202394551473424033819836610496164672900421544248`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 4.7796305915877353597838465396351431082815874814442819527952185281230440097808`49.69897000433602 w)/((1+1.02445379510745141371908491518212592877030101095789290837648160634729362432722`49.52287874528033 w+0.10556739425065350708534099143011481996438250542231067285343798886643510809668`48.583741424135496 w^2+0.15079144159068585021792286493145715665678342185745302375843448151594241563597`48.36548659396098 w^3-0.02873322989699064311460243750004433424639246379413477019089539724636708953791`47.299207716607754 w^4) (1+0.18625655266878750254777857814860078984063738474650155639933984119681753198543`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 5.76943057251029432277161079181006616594241494694642521252350090671542181718289`49.69897000433602 w)/((1+1.09750135204990110604609285986048309727857853802344866147674762266971986793767`49.52287874528033 w+0.15574180946416984240024541921813828826154574265730644179489113054809740644961`48.60307289557617 w^2+0.14143913203885558828884148289850737035005576213159723897665169219911320514946`48.11275595149139 w^3-0.02127339760814006549167271965549205039155401224354672930281971464816036729128`46.8533073755656 w^4) (1+0.28792491433078486214046968308912831507795199524792405723431270075040358261817`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 14.34330259369678101310132820411363501058295566744263192534800378529945017196271`49.69897000433602 w)/((1+1.30924774614913940363716268480954949510971836905744074475440464247753922628614`49.52287874528033 w+0.36280820395973857959869875395347667880842811200004971648565781286898150284433`48.379622364558806 w^2+0.1396960802543466893292792766385267478760342604625179973969`47.128991309136374 w^3+0.00134218370947552450904998414784902172794901433525482828`44.2703331833537 w^4) (1+1.27385136135430883390141698396780207284587842660913699533185928580001216114849`50. z))} /. {w->w[z],pi1->pi1full[z]} /. {z->zin};
(* from 20 each of [4/1], [3/2] and [2/3] Pades for the non-logarithmic cf part *)
Ftri3LoopConstNl1CFPade41[zin_] = {((-4.98636780798092951184259297446051798441413864687217020730987481715218644405901`49.69897000433602- 1.87274699600499914750253424604539361829713703295170275451566254923678568378493`49.15924289811666 w+2.03775110194878873332501475335295454816277237258864238446974134465106489999711`49.299068886502376 w^2-6.03189708056360303228852446806092668842949270915805592177486007231637497842128`49.69897000433602 w^3+2.92950955784023068630534922134245286833269572470978948161072802005848798318787`49.41554010348796 w^4)/(1+1.11364658259966845289168103037369705723193838607688189504941214025494524927319`49.52287874528033 w)-11.33069297014280448609999631762259060525535834078279077281868505626023339691778`50.37145535603073 THRSub[2,1]+1.4307566839440558274406932390316338829219648571580311922649572409817849540136`50.37145535603073 THRSub[2,2])/(1+0.73959152865677482516873662883303871829799011823982160101707887197460769111244`50. z),((-11.81474344769333933810068244491077464226774469907038192013680997618158590809126`49.69897000433602- 6.54986240485839916451717019899458976266022853049914614984930083674405231810776`49.25976290165829 w+7.27494929750682953674858119054099425424925547507807978515206878594651173688715`49.41966753210732 w^2-19.92422749727543436046035419876436697222794386120594695802977598667815267777241`49.69897000433602 w^3+10.03224588001762846038923930135864562160812229404875717854447282521125652305621`49.29710456543517 w^4)/(1+1.24691512821870518597674561589834073360188822459312671443057853525765526666153`49.52287874528033 w)-27.97356695656278660055006301273741567491403390255172137028287798461198484629152`50.11511518747553 THRSub[2,1]+3.53229656847319539903407826778074459766725949493852292944283286902818374360469`50.11511518747553 THRSub[2,2])/(1+3.29475763152166600990669973576703365186599625574565964109012976360405624014728`50. z),((-3.49085290716847812853747519353994635089388735258102313538539496279441644200133`49.69897000433602- 0.01031512129681645655603654321569295493968038217363880895981261339027262660248`47.279504986216565 w+0.21653318149455295407661594501382780745487431181180349424089572941101803561218`48.692902172306226 w^2-2.44070618329800997759527786537512959075434839642149849427680761496543588858242`49.65997888023386 w^3+1.23474864134246919590335961866489081326765986268257048812753022219897587455537`49.64901949402717 w^4)/(1+0.77478362238544946601169432942885221567471795636792296786099223316847551449238`49.52287874528033 w)-7.68565828659641378691027645005273643399418141588363452701425248971047701905558`50.81666574783649 THRSub[2,1]+0.97048847700965007565720694481464998313451977498977607347279082681261841996427`50.81666574783649 THRSub[2,2])/(1+0.17997249442240944339165187326004759169399893125151504767346812064006416283743`50. z),((-19.19553436973041716355904475584830555859487050649843334834588097838328837085659`49.69897000433602- 11.26951555199945034815435534413919076448000430329151724218257626880776811265402`49.27444354643142 w+12.66565548960096453726116790671591982833578975490661080934087235663795949694062`49.442470012372304 w^2-34.72057710425876477734445839447889673185789625077822899624916284270013107864207`49.69897000433602 w^3+17.6536636614250291264612035234698752848815517800452541029081`49.27732027685809 w^4)/(1+1.2668387944548297740164398309302670763883361438556027384535471775732234420367`49.52287874528033 w)-45.96284870040504210785446043614099182324753463577419456993262445248442290245476`50.06636623666478 THRSub[2,1]+5.80385093519880788137703824857126105502926337321146262714728755170284670054184`50.06636623666478 THRSub[2,2])/(1+6.05663655725638676286707742113323979461170585390787609011905889754546986834286`50. z),((-14.22700364849661238599226944299491576954842215586527675279647514512592388130378`49.69897000433602- 8.09998146938079445613971964094546180698495915238081794993107277465337552058893`49.266564972178294 w+9.04290304398828058441258995526184802159632923976917207887863597984304128611037`49.43002090438437 w^2-24.76508502426401056020961593164717995266448454262625268068103846764716859402772`49.69897000433602 w^3+12.52441612242685782235488412449189327134428373701740244208235716359810224284316`49.28792976988001 w^4)/(1+1.25623484432905756615101104621627628743917121398329450539286962373598122433931`49.52287874528033 w)-33.85299490000204079423171953556077461070658688025362638899629391993241658162718`50.092805363107814 THRSub[2,1]+4.27470754457231632828563253679917730910775606212884936405848559403534384701215`50.09280536310782 THRSub[2,2])/(1+4.19742113769078124624443631295616548232287273501507781192517548200128644640547`50. z),((-6.24378337883704567105741132699990730974108270297953433964810775085158046973337`49.69897000433602- 2.83857163410426662389554302146595150862174992308581026508713529943853916163681`49.20921134686515 w+3.08627076278832853906342580205503278931862608675796687824343969302196145153184`49.3527258965874 w^2-8.6585570677149709052210299220081241643525479070493054131690149038161789894076`49.69897000433602 w^3+4.25485161997872206881923983187534251822638092142682069621653719388177849540085`49.36208942061837 w^4)/(1+1.17682906822463656439553511598529941039360329372027965218944431938533791583264`49.52287874528033 w)-14.39540557508702642640116812965612772395591316105421543889049063907952639356557`50.2615883554563 THRSub[2,1]+1.81774608127800197490542742778813621464474355008210622511795758363231117364781`50.261588355456304 THRSub[2,2])/(1+1.21011421419569934647253193769308026186426577164070851483900207889434889178134`50. z),((-16.24877931443462722824759092848890874692716765155171652820657010406865396804804`49.69897000433602- 9.39225625029683558075243121081416265671813918795754078825533922865077670076341`49.27044663817897 w+10.51910315394044313874133096650337724302966608234181532950816535723321288359716`49.43609226543067 w^2-28.81779906505956908042881247797491036610743105526261614220116314693894104393117`49.69897000433602 w^3+14.61201338994027434849836714250616412742216249684966465318310463493489072948334`49.282696379221335 w^4)/(1+1.26148860383967292340917338200162146693167701308824337741051968989609839005724`49.52287874528033 w)-38.78069065260915424873066930399027780523664829482590282289424513619197586722739`50.07985332836857 THRSub[2,1]+4.89694077011849441376054253572334261606493051632663329001355685606733824787413`50.07985332836857 THRSub[2,2])/(1+4.95396602065792310422037835754682032449448319319355345335245531408064723815491`50. z),((-3.29714084923630719714760760091741838352782257734155309330912915887668708669557`49.69897000433602+ 0.57135836508987269038006753292516302594814278152219583550871095776000239343947`49.09776268469856 w-0.29321055366362391858167967184588679320430838022369656246637277706746266986428`48.93575007272426 w^2-1.75278817864454873163711354279008413808821578136080194753687316964630746011589`49.64302785001915 w^3+0.95899603640878051693317573796837570125105210123871858216596154984420597349173`49.69897000433602 w^4)/(1+0.60515205969715892377156898479533899377756580525622937731418844111811281151935`49.52287874528033 w)-7.21352178738779819820257197705623077795834946937409232118712985172138093172599`51.01298712978717 THRSub[2,1]+0.91087054774824493933955166083844307513932953280688279452724384314457038415531`51.01298712978717 THRSub[2,2])/(1+0.10748578451356065370544079501446242888226530615661179686460704629423639159079`50. z),((-27.2065011904009835898270856663308503556433895619254808588606770335162295734497`49.69897000433602- 16.3553819254252211772692699056005530141573882917538326673136`49.28055137430364 w+18.48705500021221762923416494468975480393023919704642575654254523690445538096097`49.45246625736953 w^2-50.75618392316777499616553160663407255480357338944573790561174377118233549757678`49.69897000433602 w^3+25.9196766662004045655278140311598601341160925458064403870825`49.26915065834181 w^4)/(1+1.27487869959056611081361298410008551152752094440324788438129587569909569368976`49.52287874528033 w)-65.48806499495368533133323564620050984313133508255702458394504008806111539105239`50.04549683454426 THRSub[2,1]+8.26935183549606281585943629848504609761242769082756647959945278863952850446782`50.04549683454426 THRSub[2,2])/(1+9.0543261911287940677170124366777769210116281189945593883218967829988824577705`50. z),((-3.35857174019033554616741733304205654218965318661726994175951047361863616620533`49.69897000433602+ 0.35724578090658699133521327047315938059529874564255518474017361787810221935133`48.86659770948502 w-0.10770997698064196804439703616337055448078283822022356609352118089835936838658`48.475868095986854 w^2-1.99033844783304981148614357590450737936646516417508434113268987056891594607486`49.64817445679396 w^3+1.05131856332660199587219018542593661088951551514785321811494670500755051750687`49.69897000433602 w^4)/(1+0.66989319501609094847202070400534132885291081866879611963818567920765196198734`49.52287874528033 w)-7.36324796400225006283812774495535526547130242935842187742935714392805391539792`50.93773920606877 THRSub[2,1]+0.92977686958725380992305664343125264358541167536212338611870219423374391994315`50.937739206068784 THRSub[2,2])/(1+0.13047311539817696112085277771490491873713986167899573168894660761140528090905`50. z),((-3.54749309740365661862042551126117965390247022224801361909233772042519764726807`49.69897000433602- 0.140328853307608446291805839374402216130627648263073573091184901045166927881`48.37744839172475 w+0.33335331362398671717327275545826320783870194184803609165939238436628973862199`48.845623403252574 w^2-2.61563940087086614114860659285550289280105580871338335125745323048143977189284`49.66501031819463 w^3+1.30877908570671874357749758860568854043706679078358699051674984564718191959048`49.62804652737972 w^4)/(1+0.80958893825724497062274219181598642432954748118487424098874985460190150715357`49.52287874528033 w)-7.8237080364034752117059042990147047068763553502210555203092850914915032067113`50.776046376860556 THRSub[2,1]+0.98792038543517406284326899556104870588907285370272260623507014321428544544443`50.776046376860556 THRSub[2,2])/(1+0.20116715356023661523125401346566592103113365143150012486829907396388596857302`50. z),((-18.11702720892481683244705921225559875568096079324854311518931423812891465391673`49.69897000433602- 10.58308416252067131371180002380669865420327423582443781611011727249445247193268`49.27315269733642 w+11.88053777308476386699722243803843267448143643392795005719108754066328084558288`49.44039615946284 w^2-32.56059120401914889648357418862110111160154809808352162459582816001667032343689`49.69897000433602 w^3+16.5405320554052888290328437076070343231565714890237353360051`49.279054592809 w^4)/(1+1.26511800958473945760119574550543318488369256659073329855047725763015167303494`49.52287874528033 w)-43.33419150317223517755479237343723775355622839205564191900755960020127779546491`50.07073783264033 THRSub[2,1]+5.47192341190884567632219165392702201327562370645699899192979989418128692373397`50.07073783264033 THRSub[2,2])/(1+5.65306108273788346407820113491883598485567306680601051839626183690103941113177`50. z),((-27.98954602164766717907895990019686730797762131105809463983018855793987195810619`49.69897000433602- 16.8517686270675393938188014959820138069782928188506344143345`49.28094547713683 w+19.05548213782537130593465157889240031965502655570981842858377810933809009806636`49.453121705225136 w^2-52.32312593432959057359841885035013491229810308135691277773299075389248627807296`49.69897000433602 w^3+26.7275281340517293105965280773716375517022560929723194395311`49.26862608232991 w^4)/(1+1.2753912401375294152803740661117188559250997945847396842208278775924378228258`49.52287874528033 w)-67.39658865266870344222646022544245415244964800054294955394032184774326520704705`50.0441406788445 THRSub[2,1]+8.51034618482108070823750890079070017084691710455554323759067416146890454968777`50.0441406788445 THRSub[2,2])/(1+9.34734018382550411925196590786633260106125987402920649699310579218334538699402`50. z),((-3.50960229765449256292633510941071186110003328310163064208717648336209199437798`49.69897000433602- 0.0548271100423569515511641027946703524975959361269036071459397754488874155987`47.99252582759364 w+0.2563893961129416778964531041876442534074129459584338916067513377368578183153`48.75415353222322 w^2-2.49957810984964577306766587648731747492466621902261328451221568669129094418298`49.66165271670559 w^3+1.25949791557444932559843483547077206558469051063020538131500718443405907135759`49.641809648408895 w^4)/(1+0.78684948442340578079929891129607163550634597483602823988659954169629018988812`49.52287874528033 w)-7.73135637932671681077845494308566254415048848125606675290958378310117683519547`50.802631646423684 THRSub[2,1]+0.97625889650558601371914651462195832138703997872675356202068481744757747590211`50.80263164642368 THRSub[2,2])/(1+0.18698848322370205942324686377091412061328083511298903933020539535371158089991`50. z),((-19.64224089895321691322607545563818494557616976021477906228471905358788073047319`49.69897000433602- 11.55365469928683236181706672938326486399721100784431849894004418754844188618116`49.2749314477755 w+12.99070344198023104420434438439967956777267407596573795040714013107894730340339`49.4432573772462 w^2-35.6151072701614672384716343932148631515671494392409379848497581953605879164458`49.69897000433602 w^3+18.1146823359888301675153123338829132625983277424804297878976`49.276665340578866 w^4)/(1+1.26748734197999220628793168985842658175486996603872060067877861375904392193789`49.52287874528033 w)-47.05161136769720193829293899599624302251283239646620559539332991358101946207411`50.06471014942615 THRSub[2,1]+5.94133188782560763790354733176019312663156900744253037429250231094641207979697`50.06471014942615 THRSub[2,2])/(1+6.2237933514374689736069733382501329286014277243332234368415907010285411028884`50. z),((-8.21185168960035771551252971472689791650394761962995594974877306529272495550144`49.69897000433602- 4.19350286157653789528757052030763738579806312339094451633446195850061327101006`49.238867197538916 w+4.60128033309156239675996675446266953350135882978126583355044340549333000302921`49.39001160097872 w^2-12.66710848714553024429316015119828411535645307948312235875613946807593393575462`49.69897000433602 w^3+6.30314793531398149727584600714875490522725418307573408451032362687534022990985`49.32492942416831 w^4)/(1+1.21778943433734266168757938767533355444081903274864763995177274031303211909598`49.52287874528033 w)-19.19219980858056548504231130324380499513979323407702297853387711153246354370898`50.18004735031492 THRSub[2,1]+2.42345002446663183628803973459498586585793422780819593804948509563457734073005`50.18004735031492 THRSub[2,2])/(1+1.94656189972413883519613561881899444104619445892546696639089803000075542344027`50. z),((-3.55191537266755816105924679565816438655218153114879864256629353936062669220583`49.69897000433602- 0.14994773663216425372121148836988202015205407717208333282303512576313209016098`48.40368872173626 w+0.34204618156673789041080068034307710409653727213017987998276308320552736325292`48.854326799404674 w^2-2.62894941203195654056852800607715594827531257098564233857014039224789256493707`49.66539959243698 w^3+1.3144712919460566781900505662363805896360621491332248232021293369487842649499`49.62650628069909 w^4)/(1+0.81210988187709324859967583976007252672446594009196989627177320547033495794337`49.52287874528033 w)-7.83448649585470061632681871004790129907057648378393116778805517726288053008691`50.77308637112283 THRSub[2,1]+0.98928141012652322462581594703269181980916383757332346846911244281022515615743`50.77308637112283 THRSub[2,2])/(1+0.20282196115256394929110233763784173630959825627895004939233500089855749323271`50. z),((-4.1657963160790982544495828275379934768581456654431252518126313573362167139643`49.69897000433602- 1.08363554536219092418741152491861875940943134174697001057943398088605523167621`49.05581121923862 w+1.22572959810723955420903696738194220339931352259113011530337659946379861484427`49.20812366368524 w^2-4.21380614484310227384109128204945797062837712625038158787452898361878205631368`49.69897000433602 w^3+2.03820601901987777284787777101446658190487062070965652214579955983218753723134`49.49234390438581 w^4)/(1+1.01372051042734118388624358369595261217366626700669118482497969317911513680338`49.52287874528033 w)-9.33070517551321681347550092337635066495404404519376164246422683548193477371908`50.52008389775311 THRSub[2,1]+1.1782129152166652889111363609123910839514935553603138581812085822097568472839`50.520083897753125 THRSub[2,2])/(1+0.43253512582930263961018877656820601269314612377805676241716049511445262256445`50. z),((-3.34330601051018629979189844162248250785046989492814840901402456226659889375762`49.69897000433602+ 0.40728209571890375606046864686407370332698368428976528279007624252436753480919`48.929845556719926 w-0.15125668036197571812854272186473819941733200598088414432910859930728305501973`48.62908443479704 w^2-1.93338075102274259731128970894343234892035176049949515500829986879281692307898`49.646854271513504 w^3+1.02889673126010740249378232034523714967878292760562335270602911611095209509618`49.69897000433602 w^4)/(1+0.65497553406373734627390718377955191049074115890206061394135918128916678243328`49.52287874528033 w)-7.32604063552724897332704773290551365411377887327477096774711538997236667832535`50.95498231100289 THRSub[2,1]+0.92507860143652490805680486294522237574773797471849996012356908430300074935001`50.95498231100289 THRSub[2,2])/(1+0.12476070631696556420527880448081233611560319442137926932186155928702208679765`50. z),((-27.36286830734420485631615902432157781935853541369942223971209716464255822504157`49.69897000433602- 16.4545129904769266010359367341240200835716132686981469728364`49.28063202350805 w+18.60057052641713710613231639107521453743443655551955892152792582523789987573766`49.4526002849197 w^2-51.06909297117005596744276542456031019932590931066928690593066551441312900162761`49.69897000433602 w^3+26.0809986218543192452064041860074970302714842903134514842134`49.26904327998253 w^4)/(1+1.27498365065469085303446098467519539590807617472110939276502335092612413183857`49.52287874528033 w)-65.86918026456053335970256770566576879082320786984516026771472432071476682208281`50.04521939808066 THRSub[2,1]+8.31747627243738665307815089313209344375323680853351519470519346157432502542419`50.04521939808066 THRSub[2,2])/(1+9.11283849008498578391678507380608278524120635164165608400915547057227826780907`50. z),((-3.31719866837583486464700759953063509042933909398670739053927901905309920587018`49.69897000433602+ 1.3517141095315224448816444213309497593604173281208735992599893029418019332996`49.55018867902436 w-2.98012354150431098594809151144095010116527866156159961510443159446633264643519`49.69897000433602 w^2+0.26576864880823370211672379897238320351318964918766358752950658263881144180252`49.057255947831216 w^3)/(1+0.37023394889238383102905953513955798788936160059195377900918004295264744247139`49.52287874528033 w+0.62893889990357590332372432786926560233409429442232139924147289127760370728425`49.69897000433602 w^2)-7.26240892746253803898765469438312387239796309612430995128939358177439169587429`50.986606206980184 THRSub[2,1]+0.91704365671917505434997080792531646474531977458095867375089001322951717643905`50.986606206980184 THRSub[2,2])/(1+0.11499138500581392877483114074579330030779903797233099187990104907987270124046`50. z),((-3.2837371561514402264074083283214561915577475072717565582260542125652122205654`49.69897000433602+ 1.48380629071544741978498011886924282093199602853754395095806556410717563945467`49.611257675022784 w-2.96294174491703002587248708449776203997906653115344706832815518385363652506993`49.69897000433602 w^2+0.30848460862973290972561663268493494312784113873174209989696292105010191242893`49.17344028432294 w^3)/(1+0.32706236972008819332120665097825207401837133758310618329772832409623377072975`49.52287874528033 w+0.59529395247575755291546254981977511355836356561126158587378777503808344863778`49.69897000433602 w^2)-7.18085282089645192207486867824406175397099315040258718144045678700133663030505`51.0317694820517 THRSub[2,1]+0.90674535061438870549856589377513849741816858338438224877623688522250437749328`51.03176948205171 THRSub[2,2])/(1+0.10247014623723713892438634732285722311870967977979105552124718929112699674002`50. z),((-3.37156019005658068476231325865689829255988198846639224272471594910219743889768`49.69897000433602+ 1.15444473784487426982220516560517635092483734194034932054827002108102859601359`49.45203865835286 w-3.01511656443945473443815014421470139876982287429514208741237591721916907415826`49.66650950068597 w^2+0.20246593250697383126011046279183935680702824052931155231884483439790580351585`48.866329578456316 w^3)/(1+0.43340422451304064669539643365663836259397998644979933898537387654465435336572`49.52287874528033 w+0.68007441858918061305220399155533395042915960720661379246681570919359114918986`49.69897000433602 w^2)-7.39490485369438708236286239971552129365717008921614561216175732069275997169358`50.92371850529126 THRSub[2,1]+0.9337742690966444414694473891314633965148684991702308296699149837102776687158`50.92371850529126 THRSub[2,2])/(1+0.13533337039557007019881595914112380281481042113402259399529307270297858085314`50. z),((-3.37980840276621945333162929706567166136767049689595579628140193487884604904628`49.69897000433602+ 1.12616336207878902771862449595167609626876965359500243400846783762533347703989`49.43711560916799 w-3.02109753628735056027487793268442443469776943342817746668924080468908899898381`49.66013338507532 w^2+0.19343897705780422997085327402796944896751075093138352058027885330757362353184`48.83642529688611 w^3)/(1+0.44232320701535409701459832335970769952659568231962567301146672332614798315709`49.52287874528033 w+0.68748884516572826925015375646978284932241848272672244958073547500714159019888`49.69897000433602 w^2)-7.4150083119665636979643557087187676553430836375987414399111294489849267938914`50.915104121186005 THRSub[2,1]+0.93631278614666954695414157433420199561227859513126639076723511701550109909089`50.915104121186005 THRSub[2,2])/(1+0.1384198370220276612239490060357813114514334334781091584474893605993700263041`50. z),((-3.29106482211499798103083307569685468509527520941051419108711446722000042441499`49.69897000433602+ 1.45410606957676313630110637471663701637831668205135754739761804126437454392214`49.59779488029291 w-2.96638712797556942863205223183741265199671485993809162461884324520964744391382`49.69897000433602 w^2+0.29885728326739015536145345825771224209221010797239096417557825343955391185233`49.14788176642588 w^3)/(1+0.33682656670777424243818183148609964374471017902696412147903179726833928038431`49.52287874528033 w+0.60281590915651144464799537199025303997510509530671792734591927944492236810734`49.69897000433602 w^2)-7.19871262060296115125616141060725342378832633667288066808922824949223136805527`51.0213797704939 THRSub[2,1]+0.90900055494048987536790773774107518826268176881915225486869193966481433986448`51.0213797704939 THRSub[2,2])/(1+0.10521214589734783368227545758797995935970468843517480525226516605130045497054`50. z),((-3.36643522885395067746554457475566332266629793729909629135568530783210525088453`49.69897000433602+ 1.17222252780216265741313468511351472307579933332999884042563352119867430397446`49.461297088820054 w-3.01148376677203473371743497814297795485078918356944941850629675067888912534375`49.6705369256227 w^2+0.20814654614813510735531844410869126560810932563879063984386142465806114240735`48.88473320397346 w^3)/(1+0.42777946234275717611727428380778277642183786933261126901395747201320292024172`49.52287874528033 w+0.6754240946985738996043685659882070073814303801020469627680657897659977363231`49.69897000433602 w^2)-7.38241373018550892409491937381543265186958478189566135843418167886859144768445`50.92918251770509 THRSub[2,1]+0.93219698176767069477300125619342340966099983675526572144167643134987660706242`50.92918251770509 THRSub[2,2])/(1+0.13341561896618189317026480263931974368171441402780205829491521011140270068987`50. z),((-3.36479991523026311443596576991235819489883018500134917782085102131301590298807`49.69897000433602+ 1.17792896380224238667179369429719633374620362950564957809171403999969762006639`49.46424958617916 w-3.0103383040301108992555627856250061734165356635053435523647317484374415403762`49.67183285154404 w^2+0.20997096709517363801415903681945270942831492576243282011972616040902706891154`48.89057984849745 w^3)/(1+0.42597103001762471108243407354704623879036813539080523835155989078581918285723`49.52287874528033 w+0.67393312169208333482682965060235635572903905107318695160896054359951290281453`49.69897000433602 w^2)-7.3784279625588681896354984749585928211936554771732476645290320044970875757145`50.93094452001357 THRSub[2,1]+0.93169368830737740132065517101631741780891109087665646619401377622190848364703`50.93094452001357 THRSub[2,2])/(1+0.13280368749678552013956561589151202984196430303931262320915256377090022218837`50. z),((-3.31766817885880989240118613419436184195544763373185196215027547027483139304047`49.69897000433602+ 1.34992271152203326310916123314972641444134712631613352448104201665656579902689`49.54933791271661 w-2.98039002845781610602274715334779382957380149790966287054723429282436288611991`49.69897000433602 w^2+0.26519115187200443038654380130477621072723961594988105215048878592254571259901`49.05562985954077 w^3)/(1+0.37081481121185740047354944568536424723743595699124935185483089086515568662004`49.52287874528033 w+0.62939853752406719262901340474083125219339561026458663472747118746327195076902`49.69897000433602 w^2)-7.26355327045357267883102661690192560474303950988124191186559734813486840432013`50.98601160170492 THRSub[2,1]+0.91718815594684468456604137966274086232654519396095947253378660854569465962315`50.98601160170492 THRSub[2,2])/(1+0.1151670749992086157173289964688265856845852442707168737957539325235426283382`50. z),((-3.33741852962709207973225993416391674896476273637292977054716582780402877902446`49.69897000433602+ 1.27601098602840722128590807975269072107352194488876348353247514853201370504442`49.513637951515676 w-2.99219021837190320034196341095621146724059893946349638803423668475812539777591`49.694349486662205 w^2+0.24140627657114153948986390709659695301124236116698224704721881916278350780469`48.98705290387972 w^3)/(1+0.39466828506801010517884751550500024112725120820036050556675028446756625215423`49.52287874528033 w+0.64843944828189173249215212460647009154232283642866378628331346003951942065218`49.69897000433602 w^2)-7.31169101453321113669707738037714150501532129530964574834922458905245628217289`50.96186831930091 THRSub[2,1]+0.92326663669585249139520009833406873830351679830312483372617541144133244439546`50.96186831930091 THRSub[2,2])/(1+0.12255762137004823382430545418223178038663224665527939931855597777289965097133`50. z),((-3.29033766138355736460255286160771576038376124786373006399809385305079812771091`49.69897000433602+ 1.45703324518344618779135797040319515742928156571513518551469930130098130000527`49.59912820761131 w-2.96603696195527384645342328858610867186142742584764518225438667170253492728796`49.69897000433602 w^2+0.29980553813216000693213040434050336196306631685702254846794637541333580434952`49.1504134898667 w^3)/(1+0.33586567702732698193924969920880505047122528683026748438447680345044493527651`49.52287874528033 w+0.60207344878044405558454265075776393984492420980208648778329176695547528224921`49.69897000433602 w^2)-7.1969403038676520693384891526868225150243249433291769966541348106114367660485`51.02239747248078 THRSub[2,1]+0.90877675980088179736202741127543907296491522890770627309095474490390742504362`51.02239747248078 THRSub[2,2])/(1+0.1049400436360859213885006535049327565662208023103512907604985145391174638387`50. z),((-3.33524531300096191427756722367873415066374261978772082327830264858094922162922`49.69897000433602+ 1.28400889423155604761483624255311329518969780581859032015579441359775793414372`49.51755976960064 w-2.9908367263099120039613367220394497387406905717859179772461255898369417273755`49.69620584987181 w^2+0.24397603163590927032060290760321652705313624566456280518353377011648995923427`48.9946245016102 w^3)/(1+0.39209786902933376394506080553193850400326556255865829465720263609774844282539`49.52287874528033 w+0.64637189004762314283408554817317605933752042207426332165286686335285429496204`49.69897000433602 w^2)-7.30639421008626064064604923609316550040373863100176277744509694904055482476783`50.96444489244914 THRSub[2,1]+0.92259779513550055585733134583583158223612359887809011898780300843339283884114`50.96444489244914 THRSub[2,2])/(1+0.12174440754727967939596010317942455915000313150255279005307533277116351475428`50. z),((-3.29541288087271875330227738679948394557303587764920222769378247087962114236708`49.69897000433602+ 1.43669403177088668984562654685689855728532946454809696932499898128207276942492`49.589833606772274 w-2.96851829340600714980579537943014537346139044495268248142868545021684402474078`49.69897000433602 w^2+0.29321933762811461135832413647446146401251466627993168355685408417595870933484`49.132760969696655 w^3)/(1+0.34253574109332880241126929702899453641472095454620765630333998450062272553811`49.52287874528033 w+0.60723739210011012855357042755694623828398839052850189580259483776338512672599`49.69897000433602 w^2)-7.20931019135894615468430135302934076310780365358371242054146833372288991891007`51.01535397119886 THRSub[2,1]+0.91033873833603770351979729446369492690038980575809639481173890458457788137798`51.01535397119886 THRSub[2,2])/(1+0.10683918180415697714039004509296991147356825713874337680371418576347891298522`50. z),((-3.3626253182096107607761288850433236576239550789671183340976798661212684909367`49.69897000433602+ 1.1855428165924097423001077051515616975866719919374713039215147925969343135895`49.468174637799905 w-3.00882549896727559400442524157786319300389952619961702873027236706677018784638`49.67356435572803 w^2+0.21240598436618092689307316936583079002534666775253982637333596324391008195196`48.89833650075783 w^3)/(1+0.42355589116704967801527671194539479760173969648162478653093269072807456191542`49.52287874528033 w+0.67194508837731010816508134240596639045832631926203822558323917958065778140363`49.69897000433602 w^2)-7.37312779366138121280247361151103186453417410462548135703151057246875140684389`50.93330168605137 THRSub[2,1]+0.93102442190892372271044799493454014276858965611007783986046946702585822455838`50.93330168605137 THRSub[2,2])/(1+0.13198995713282506604708968392412290821483473723189376178634566757816927182627`50. z),((-3.28666208214105829309150667078468206851110587296997372515590714930460524494381`49.69897000433602+ 1.47189681157196347219654331607379454058566248074950333344252142654025586292066`49.60587656607033 w-2.96429471911899034266936071936272795001070047999349054314495913832079917449739`49.69897000433602 w^2+0.3046225592385006478235676325442066716582244283711903752698747666700199046499`49.163225392314686 w^3)/(1+0.3309816022130295545637901312575100648466891442651536900426745518315273023601`49.52287874528033 w+0.59830715769629353710054160473325648104546301416872819944015530731736257517628`49.69897000433602 w^2)-7.18798177472577998490014374601866542865683172334661050537093629234165077731225`51.027586244835746 THRSub[2,1]+0.90764554254154769780927976022592891019568104501766669346820010525559022685116`51.02758624483575 THRSub[2,2])/(1+0.10356464837601745340085647591703215174766440183302144513637858796428050187254`50. z),((-3.32316553151118673359922720737060293990110468884912208436286393047660705338334`49.69897000433602+ 1.32906874230448505737293558948538501973846187073342996326390209222497902181954`49.539385189235624 w-2.98355967681028016231630436383286718881169218978771084821927136088928652962028`49.69897000433602 w^2+0.25847197182224517472849812974256700792215739207710348974420685078909304016797`49.03658232002847 w^3)/(1+0.37756733890653564489223639010117467060438343845052548690778556873463862252998`49.52287874528033 w+0.63475576169085598070555505512363704737764966520330329685610040722595112221879`49.69897000433602 w^2)-7.2769520276807413898003957373320227924983083524148406181413175814854691687487`50.97912314080154 THRSub[2,1]+0.91888005259516360435734294502797400681253441930346806689087911776861401139628`50.97912314080154 THRSub[2,2])/(1+0.11722417465130674016290497716272844266062704865160255953273412102016208445375`50. z),((-3.28858804866753135047401390999176657624508442720965465925708738430899448311897`49.69897000433602+ 1.46409433248529302736075050270853601530950632231768218331560379411948389561148`49.602338636808234 w-2.96520183921913007790966506113143919862202301702117721666090214775755144625828`49.69897000433602 w^2+0.30209349859446595670551999413384597465831903323487358759821650641116621213134`49.156508892496696 w^3)/(1+0.33354646342605650627626075009044554521148398763705155929372808528256348985486`49.52287874528033 w+0.60028344963656862421821147902530874135786117246045790415886537461134992055985`49.69897000433602 w^2)-7.1926759538239152624019203701857453834581627007639140035859863890350826392484`51.02485803908614 THRSub[2,1]+0.90823828899915494876306720180956771060232601358326929970739207337323595577528`51.02485803908614 THRSub[2,2])/(1+0.10428534164823228685637228546479175258557286326073881709528412095285111500608`50. z),((-3.3148161622841494420392786475691845722371092981864013537884681312675641252191`49.69897000433602+ 1.36082980394834987635411325849698929732075562689960199634177420652498141481152`49.55450780662953 w-2.97878162819490528459983211494785488310292743761517354186495470548526752033208`49.69897000433602 w^2+0.26870804461839135417523497286620761870260884556828286164288836181849981030605`49.0655064883582 w^3)/(1+0.36727621328954834923276045475359637285972216179486268961828978830105844308342`49.52287874528033 w+0.62660136541091428805193064629239153408513787871935221961308243765319659529265`49.69897000433602 w^2)-7.25660201953187409701091429546056841653249032205928036410419651277741077440458`50.98963902371156 THRSub[2,1]+0.91631040303762723733533979004680870048096127807541074789918491299870545488966`50.98963902371156 THRSub[2,2])/(1+0.11409985543471960925445048592658704890639041422396693700539542197876626153637`50. z),((-3.27784100553386824403965703241116432863688220463280263902283605765966409313324`49.69897000433602+ 1.50803716015008735444977762873143947923360864618355616755820477206810708518129`49.62213672324501 w-2.96030619609090580606736448260891648412595357503577332306875634338644808247244`49.69897000433602 w^2+0.31634886329831892070541143531072518702130743806165686905318205990274496247486`49.19409306006912 w^3)/(1+0.31907245257475120382636839183523717841930383384968400525755343672181435618072`49.52287874528033 w+0.58917586125624669345123123362628958833911232011924525877193778744210181552727`49.69897000433602 w^2)-7.16648206906456592105071930239045842319431339348277043772220312117555517485291`51.04035259674229 THRSub[2,1]+0.90493071762671954595379196407893344895957436056024531506245784316937489817358`51.040352596742295 THRSub[2,2])/(1+0.10026381709099228732062403410324477104576316676445848111368901774599867234428`50. z),((-3.31562991547610992897658952071950474322484917965636172410488884115739438898591`49.69897000433602+ 1.35771153315822489196780821444577924680320923717145348222041823598676808413556`49.5530322177858 w-2.97923801128783153628892068035114375709747923170412240108476124945883353191592`49.69897000433602 w^2+0.26770240355093912746425272395159704605332845407814016218640460109934496047341`49.06268863415286 w^3)/(1+0.36828835588762380430295225150320750645050417396717299778847777818517497875626`49.52287874528033 w+0.62740072389280617487705785683986028510262822878361634848781728073761812834493`49.69897000433602 w^2)-7.25858538901012614755977790623893072866183368790005395090147049228390890876231`50.988600225125566 THRSub[2,1]+0.91656084836742457198843245365655462168583627640956801667270627750259440576742`50.988600225125566 THRSub[2,2])/(1+0.11440436044175274836215597368966222063973613855382042011663844384336132144631`50. z),((-3.31839911185100062379427938840123889193417283976322255452127905349829017081117`49.69897000433602+ 1.34713712299174341991846341331591765472996754871658406815322595984447997942328`49.548013684926886 w-2.98080622600632645408932446685108122020572995662732368972271971232207307192619`49.69897000433602 w^2+0.26429325163366775396595285333970752425438442745452417941102559394026646121698`49.0530982040736 w^3)/(1+0.37171778809257240326207272538914636461635373104341134043645333837111845212837`49.52287874528033 w+0.63011344089115089388750643007854792332397941081143451851846719833946165602317`49.69897000433602 w^2)-7.26533478136091045799095742858003711711566516599342297915130718538310948555794`50.985087910301985 THRSub[2,1]+0.9174131120589650399270766475181243352835094232085199771194692654038982821714`50.98508791030199 THRSub[2,2])/(1+0.11544058883377996993283964433032680066707372011878988354327396326846496934079`50. z),((-3.30071784282135882433106898557334997534647995170371111550120090471906400225891`49.69897000433602+ 1.04606599703315788182625394852100245650352197566892345108871280181700835049176`49.40763297306132 w-2.89813390995857872544754031975282882125397119519408622961831972791898988756164`48.83855855413939 w^2)/(1+0.4613912060999130267174949956330217465986373422523631752561254876573017263037`49.52287874528033 w+0.67760306530310757269908646296328129415120111895130107153541547504460944393594`48.708713835586686 w^2+0.07472039519858517623799461168762625798115733220944201803595256167604530617729`47.90287274547028 w^3)-7.22224003263781408038593716883274967710659820536500658361583007619215023803949`51.00813689158185 THRSub[2,1]+0.91197142372260880293787367524721899765213114159523249195676549082924288013037`51.00813689158185 THRSub[2,2])/(1+0.10882428919475215633234019707160893031348161641099124472134893259915302002044`50. z),((-3.30564264555444607455650650854931148363882548985891636518358482720505458886644`49.69897000433602+ 1.03583119227991889943197710244582195168753550334491434710943916723521852284399`49.401591018809455 w-2.90289598371363574600276760073881236596235441381132073064481998952850194354253`48.83780385680596 w^2)/(1+0.46478218694463370298077122893821686244947604662011345727781241956606576190991`49.52287874528033 w+0.68093688511951853443102646867386489098420401484413222172894784543643248672425`48.709785200468964 w^2+0.07315101760136528093592717469909809982108142741760460904692105469919782603822`47.892928981717496 w^3)-7.2342433077385670101532860139058930041982769227263234311261731473640410188922`51.00156523066325 THRSub[2,1]+0.91348710913786766046623968058180461479971320152018185582988390172300307795409`51.00156523066325 THRSub[2,2])/(1+0.11066714167839362458653858041698848421890429917158101411754557564957740626476`50. z),((-3.30603867204421768723280741380902123801213586929381376599705151811102986559455`49.69897000433602+ 1.03501030660524230768352868515383193156800518589167337830260864483039118202099`49.40110476530438 w-2.90328016150215581302088338867757891029714622922344553925678407384062959787843`48.837743968944594 w^2)/(1+0.46505378455139256937544973708709073005768162047645485888492673562293435599229`49.52287874528033 w+0.68120435939994818241096874160096916341977467740259700395337557305368232110347`48.70987124649347 w^2+0.07302537833482660134672296784622313049642377941573672880892510815593692577989`47.892124758412905 w^3)-7.23520854739618355937626713567700142479870469746075119772142984989131998742275`51.0010420061497 THRSub[2,1]+0.91360899251211333506977676441168349388388508964047609915286934120672352550769`51.0010420061497 THRSub[2,2])/(1+0.11081533409133234992796810372869062386738207925428654309220085136490061754609`50. z),((-3.27876802355543587381367258295519349949133256344883020180337699738529998431091`49.69897000433602+ 1.09229679899401534071424465101346496793194765407148291334478024091614569537121`49.43446722211858 w-2.87726381676948482185901142342837596353620155060508462740432440379500567901892`48.84215855793299 w^2)/(1+0.44596637652232040653027370033404216733954492202569201664958246467610140596649`49.52287874528033 w+0.66256973651904144457414511247068737539112696244695042538967803670664112117809`48.70391313830504 w^2+0.08187609789415305479103873885542735797666117393367889208757528250834123367211`47.946009677607776 w^3)-7.16874150014014456535477772552792714333418684892556143767113316138521369743791`51.03898953808136 THRSub[2,1]+0.90521602198734545299936172986158679067985587987404951956747988729992368402451`51.03898953808136 THRSub[2,2])/(1+0.10061070559719553479453798955622707200203208639387527622503910007973314079774`50. z),((-3.2789204358248241330340105040394829002043601490703542509779240311350348998274`49.69897000433602+ 1.09197224633009991616087701722948570383570467816112091631636382450902431877324`49.434281345739485 w-2.87740668971121770019203309138185319189105991842156917524407097059322732328701`48.84213215921924 w^2)/(1+0.44607527345135331419814546210776554155998174447131852980672532972013886363502`49.52287874528033 w+0.66267512087972052419636813266176719939030625662702515105044495053093259080051`48.70394659008215 w^2+0.08182548325148343378031349787028232657574519764538775852570606886029522254708`47.9457162585685 w^3)-7.16911297621692348239874607043166806127521796970621795545239100739171114334063`51.03876592678883 THRSub[2,1]+0.90526292925781666516393812667024610944643416739572889881715668015339136805734`51.03876592678883 THRSub[2,2])/(1+0.10066773799918242874099236876459031044616209498430381517761395028909979143649`50. z),((-3.29578359333671584237689060109890211828492108070231890375534048958223775331739`49.69897000433602+ 1.05637034814390698421785486920370101464930912074030081177476311704550122460048`49.41367794145006 w-2.89339150992355060414217206792518920175493015377372440325803130984005779008094`48.83933355196009 w^2)/(1+0.45796841260016687483900212304879934731566509126508018118896585687431683959936`49.52287874528033 w+0.67424859792188716909755452908016109405622237602673945821660610791491805009167`48.707638064700554 w^2+0.0763058660306401525462188706842813630598463751075168424507732713478046879038`47.912732785827956 w^3)-7.21021373286706369251843698642536056596987863718290333442147821468083088165366`51.014844875819726 THRSub[2,1]+0.91045283092113965132227000706468818157462884804947667536146567969783132080054`51.014844875819726 THRSub[2,2])/(1+0.10697790175336509918603134765994883305395237142264517511226588713092096045851`50. z),((-3.36304840939440465503404570252474049700956504068048814535974482965917229374816`49.69897000433602+ 0.91999833934093606850156309593771895037828339645060761429325783107953331122618`49.33030195446574 w-2.96040948360852538613936012819891527818841649286867275493463277212944584196573`48.83023535979785 w^2)/(1+0.50254500400526509717049142289255315562262587285218008916171494470238310469855`49.52287874528033 w+0.71878716177657673420537260281856682483255174157365985205036271786796754183321`48.722048892595055 w^2+0.05576735482525626851537265602015285683206190393537233576066662466586865713382`47.767594187738766 w^3)-7.37415899839363675646427871278403046290351569395115767250613548961462288728262`50.93284180463273 THRSub[2,1]+0.93115463486827909076963139572232993313910360890955647283521066845860636328209`50.93284180463273 THRSub[2,2])/(1+0.13214827710683455618247747299977170159110334583640603104970781087230849666593`50. z),((-3.34470276282338651376231976979411834204865465674162574586933733398928934300946`49.69897000433602+ 0.95634680080407887803856725668370327651997625052910797954880551150367675218549`49.35328782427716 w-2.94164233500747060089050488742152031116399651651714520973350846647133527073328`48.832426948367626 w^2)/(1+0.49081784026119890896303471152269121057580269123980061312447311224808871617351`49.52287874528033 w+0.70688853275226570779176209454713987632530573375441654285852488148893332379018`48.71818032777385 w^2+0.06114721717619413499731556393344700325289285327028946856569848967699181052015`47.80981104693744 w^3)-7.32944495508513006630993813395610018930019182434769935115291243706452196360702`50.953368478149 THRSub[2,1]+0.92550847390545109228688459440591051825531991015215385226503532937025559701837`50.953368478149 THRSub[2,2])/(1+0.12528336856536782480003175742352755330323342667133896122742181773173963195269`50. z),((-3.32202488104410033176491766014420269899070132043445400443347513641815609015005`49.69897000433602+ 1.00213553449553497061459065473162789334795309655536866569396512545698920475288`49.38142247193211 w-2.91893911343986189276366979484790521338674313269426334293404514024915337537529`48.83542217721165 w^2)/(1+0.47588444463646946002358865146281740985510477996655322870168100705997503528443`49.52287874528033 w+0.69192597830532815652090676734053228861648380648611254678113085508103225897`48.713329946869635 w^2+0.06802232582247705286215580794979255296148482513998976750891229609427442819281`47.85904965706577 w^3)-7.27417190792929350164350888739778913256964794878684896474502102105188688840958`50.98054140130232 THRSub[2,1]+0.91852899949302497839109764772040978391350582329114708587704045255393175353517`50.98054140130232 THRSub[2,2])/(1+0.11679734526134673920073685088170543776372975229930668003915244478077609599993`50. z),((-3.36478409802481827076960758204451163088535770960128217533360093284088094472644`49.69897000433602+ 0.91659037193909522871000003414677903126014792034106990695354881963360840746288`49.32811525766596 w-2.96220298587560042487335171001850171781871695924111409861636568007541956147361`48.83003795909022 w^2)/(1+0.50363868831149421161647838892734212149872989978820788382478875815623391740882`49.52287874528033 w+0.7199035903474511791753719557801748455471698228803650100660026651775778501298`48.72241214537927 w^2+0.05526649479347162693935072038259519681173193941939231659884052912865496129748`47.76347355758179 w^3)-7.37838941111253227362060174429169806160782076356987370833963662208500794873211`50.93096160685639 THRSub[2,1]+0.93168882031389578752598693249977315996274267799514999084424148551652015993843`50.93096160685639 THRSub[2,2])/(1+0.13279776872644727660545415802303997614947592546858301553228631984898851052952`50. z),((-3.35465365794039616104295003624353318691226972471196827607246957491004954142154`49.69897000433602+ 0.93655611030968997892452408870140123264519612997478077084613885958741934648765`49.34084787494712 w-2.95177852161380715535799383662379642898100605896422097311940691552220484148319`48.83121395281996 w^2)/(1+0.49721702412740692871089900374226524210442151277712985448237037066800622067473`49.52287874528033 w+0.71336491068666126473892185396154356790942134387816819430906079212946477039396`48.720285185279856 w^2+0.05820946823072135097059319442052664347009156749708508988816200467902845292553`47.78720526689815 w^3)-7.35369837965089524577133847185241090072723692148688068794622641077027892813837`50.942083430330456 THRSub[2,1]+0.92857101821738686484830210687584210430374084581214951500030148185726217676456`50.942083430330456 THRSub[2,2])/(1+0.12900697594107712141065634807799948758836063727322395451085989119699708436749`50. z),((-3.33380865009341394208846133796537614316268679854787918529724491733379406202414`49.69897000433602+ 0.97822189078575960768952880520215681351648664330581549176260618770974040209931`49.36683802849869 w-2.93066600584251547084584861314123422712104246876101697627054549097764015347621`48.83382427780468 w^2)/(1+0.48370575178665576645998494027730019747739450262283235923089727412596565964155`49.52287874528033 w+0.69973636697295173267864343658783898515765080084772091329552698559743847286904`48.71585914374288 w^2+0.06441813911975596873064644420750433921158240955047083179676364709551678692836`47.833834251754574 w^3)-7.30289261600402709993690497675650625084630664206420031569968209123536641153553`50.96615870294846 THRSub[2,1]+0.92215563955412383725099791687757650830951843044058472293225104036302400888164`50.96615870294846 THRSub[2,2])/(1+0.12120681082496981785246239952942472897855807732236510184729996998040248998136`50. z),((-3.31770587362720201480734882008489458668170707002665923716311930175543172147293`49.69897000433602+ 1.01096753648374329208942086122293972667867104323778020906739025597002354774118`49.386751008549446 w-2.91467975254287036028671468740669219909833145491874033198146624700080316583143`48.8360314568261 w^2)/(1+0.47298361748946362810988160570679991258117263662784288892228384784337406084447`49.52287874528033 w+0.68904371765118670837671149539171882503193624197052061412413201300005475030818`48.71239846669039 w^2+0.06936094580197423174806948211727360957927079982249376467690517989351743191699`47.86810773880387 w^3)-7.26364514432129736103538276196920740425386014839605499792075349091695530829314`50.985963907072325 THRSub[2,1]+0.91719975710404427148864569727345197014513550851031911737071163117243300441119`50.985963907072325 THRSub[2,2])/(1+0.11518118031495761142418521666052763506213476644236951282093498963942058742582`50. z),((-3.28790862239559388449937246318249918177572559264303429985245045592888898825707`49.69897000433602+ 1.07292100594979243441246862757949262498077425098330329278468966537451269778795`49.423309475851724 w-2.88588336720478503366503973635893595133521835275884014414805065973431161142395`48.840610876060616 w^2)/(1+0.45245244869431318642552733486376778888237372648916486138801377396248276525888`49.52287874528033 w+0.66886507816662751433058415317906180672442291841077420935998831915894353796743`48.70591677560004 w^2+0.07886379216269917769033082483604870675822506929674442686750218366933166495847`47.92826770711548 w^3)-7.19101998080433565961093590877351645915921128482619329520474195932940256145837`51.02581811097074 THRSub[2,1]+0.90802918488942063685381306288253912583504584778995961798833880119315503268502`51.02581811097075 THRSub[2,2])/(1+0.10403110153739919366217493741208264328330303148259716361779057751515364001222`50. z),((-3.32466383657708570794296511461692418383831737729925462970888338960540063781776`49.69897000433602+ 0.99675695654899413279939951307560289214860153635958748724936959008488747594927`49.37816236468052 w-2.92155194572280638489315688744621471376353733372606811788761956021938994554935`48.835056239344034 w^2)/(1+0.4776477965075426437309474167386025495484357127799785935784557973548347215876`49.52287874528033 w+0.69368187132016098460719867076246098114145642131800974685864391955937160541628`48.71389794056529 w^2+0.0672091002114006964093471831580638214467511466299556559081523812582578551225`47.853467917333546 w^3)-7.28060386286390678886358317132844030984301367661403664353263068568149130484263`50.9772688262467 THRSub[2,1]+0.91934117951923999728568455602887882694972539169065966338006584388729106091934`50.9772688262467 THRSub[2,2])/(1+0.11778483776038798681854186708567867116387187994784302583318427241712626905721`50. z),((-3.31106411143250258115288561318397565254264789195245140211967676909957290488632`49.69897000433602+ 1.02462101332600130023329592114805925434047238465784536083190214428041653707229`49.394929048126876 w-2.90817110168349782335940626911215813095175532155959738837273298616657910835072`48.83699416860363 w^2)/(1+0.46848632704918457574121910590405230719083874294125484605289891258332525240587`49.52287874528033 w+0.68459062517370013257166179182610544080178932456396400908949087326967796032399`48.710961682079045 w^2+0.07143825893682438599455809567920643678826603806980634541718202257885579869819`47.881858018552045 w^3)-7.24745710530784812236118737234638039392493484122975166178053997974065335679739`50.99446856331619 THRSub[2,1]+0.91515565043912351774254594992257306908415985377721435226894815878634969004948`50.99446856331619 THRSub[2,2])/(1+0.11269584463358606393764178634448488973644032074787650365142550072919482049426`50. z),((-3.32735179437288240840178928320155905061043388755283580026821904742611381401343`49.69897000433602+ 0.99129231942582386289360331382877668235636087555352028850119854542830680140043`49.3748382190058 w-2.9242212796649009859805186785043433296609172004301321591704232831711571645018`48.83468836283232 w^2)/(1+0.47943686443655090994302396566293757622585509301781720107226743366563253272988`49.52287874528033 w+0.69546633854048352790715901748268149740973527901185534633679292926797484022907`48.7144755580435 w^2+0.06638439725892438652636856738180944865994876451303821872943055309417844833483`47.84774462645565 w^3)-7.28715525154499929762581003074732115728621881488913635405121791918437420157936`50.97396651453354 THRSub[2,1]+0.92016844076171547870351741094448460435484478257654869264042657229177057297446`50.97396651453354 THRSub[2,2])/(1+0.11879066681961654804225711934940003798307472393033334341440785009707535473999`50. z),((-3.36396237045264279572878072886590152813216149724989396383516013708075117059825`49.69897000433602+ 0.91820315005958459769156773784860242751030773253166714782644908689229715480947`49.32915077993721 w-2.96135350709134897859027359068417444105601428024647247530236527199872036588572`48.8301312072164 w^2)/(1+0.50312124097888370863460876780385322200662597109224515351415273581935254091333`49.52287874528033 w+0.71937523771481307529640736972091611762700616958933318206030886834589267102818`48.72224023143988 w^2+0.0555034446457668635555577698418664637772855703794306172586363617476492891583`47.765427289391845 w^3)-7.37638660559091641110262133890467935496212672863236889778739688795761760944853`50.93185046610691 THRSub[2,1]+0.93143592074330087083334021539695912219443948961138487673508915265566517947312`50.931850466106916 THRSub[2,2])/(1+0.13249027972042348556952857039283424576712154892265630959022992512022893969355`50. z),((-3.32050690096761472880295805780042767883835402518895539728087843395001911363545`49.69897000433602+ 1.00523552375167531973572577901273254696036614457579394385661454516092867380555`49.383296249418024 w-2.91743969873190859825377631162128345629838872701883136294545216017511875630391`48.83563483893246 w^2)/(1+0.47486701535867578434390140610106408032773548629905076562657915059579939701995`49.52287874528033 w+0.69091417049431416331458223545884758701946661114773911726918388695619604871111`48.713002826908905 w^2+0.06849171545201625247632128939124357157261058144321921841698739078538640533213`47.862244035632685 w^3)-7.27047211862949011833566315390808195808185122716293283977965997397389293403074`50.98243772965141 THRSub[2,1]+0.91806181727532415994009877526241892570710461440589527890786022375990014337175`50.9824377296514 THRSub[2,2])/(1+0.11622931979805754819954181468393492463992974720135675024418588031921862274158`50. z),((-3.37502600756520594894010072057724684540384152407845395690909611349424443666322`49.69897000433602+ 0.89658705066804583901284630592174016447848714671566995869377176020640970837645`49.31516586232211 w-2.97284764311650698174774681470836492098484523041381329573279728891232422219943`48.828906389259544 w^2)/(1+0.5100378660998808674477431797894532825507339645792392239599926462222647474456`49.52287874528033 w+0.72645915377273798876601824783539393985708505994947904961303045069726542183358`48.72454553383047 w^2+0.05233895080964011406627687501530396009491446985130561020382063694649445483629`47.7386667734529 w^3)-7.40335212828785213583792683994768550393552967553151431498722052327525676330252`50.920072282242835 THRSub[2,1]+0.93484092888678776298504029389859967688192984059206850992643278278194998746286`50.92007228224284 THRSub[2,2])/(1+0.13663027318534217757480015928533692994152990996237517587254139731589205568227`50. z)} /. {w->w[z],pi1->pi1full[z]} /. {z->zin};
(* and 20 each of [4/1], [3/2] and [2/3] for the Ls part *)
Ftri3LoopLsNl1Pade41[z_] = {((-0.57653833259402602318044596277777730335508415187517398404194849388638285092543`49.69897000433602+ 0.4849766547624912320149875317769261740825864825900959397725268513308187663909`49.49743313261993 w-0.64364840289442382324996139757633631502685402683223684379607399937428420026198`49.41006534924177 w^2+0.08494156884343130362284572372199235900936893950886273627482935755940403901742`48.45605877773824 w^3+0.06712396010356496474279795740774934663842565665748122712193695511336107961582`48.36878221516523 w^4)/(1+0.91732447372298770577103797839992820766530348861627181578748026069876484427456`49.52287874528033 w)-2.48845239294305244583999292980681629998478576524012694488536423822584831692103`50.925802728679486 THRSub[2,1])/(1+0.13459823850769050441851388241615800936868345536128396491219449705716316301438`50. z),((-8.12296560207561016996920407291558001860505456137341018528668310129102480466846`49.69897000433602+ 18.12399431152114065816957118809286767790199582191708165458864991878933017475193`49.69897000433602 w-27.47266111038472003108854076954248256562345223205192942284497786455268283894888`49.53474410746731 w^2+15.31445245110251827179628138307519980366415458939765301984478758574483022628254`49.09398333974996 w^3-2.9156728495207746158783450683213242630823665685933103724784`48.312334186526535 w^4)/(1+1.00334536739434590019913233128406760372209636737918176024680685879843209874305`49.52287874528033 w)-20.88144140239875894073100397065620058250535934425551063308017317347820912611186`50.0481930939797 THRSub[2,1])/(1+8.52079561572121922851760635541990523409006825494093552103275623207336813927158`50. z),((-0.55414024615643327166983341254536277331834296659899166488590818780083090996671`49.69897000433602+ 0.43915378207975380761891816019430904072468069718834652864506383694044905451199`49.48467718171829 w-0.57188894860910419445123337590662903217353721421273417817886284330502294570512`49.40219745431403 w^2+0.04802158294161015671237373669493878966798743080454135793633389160894728552937`48.26537265549898 w^3+0.07306861115654611001290810207792561735192260632005673446349510008486361255087`48.47157198937949 w^4)/(1+0.90179715611325961375051981656462522814136127303304591548536347044663150122751`49.52287874528033 w)-2.43386129400733272379091174559676795459502658654747204714688973958260537666186`51.00497155316286 THRSub[2,1])/(1+0.10970768208542660830382402095361198437358540038211208628855744548114619087376`50. z),((-2.51080951017983969555813353180143294094904181179597612062537909195258994071973`49.69897000433602+ 4.98074277378635817870280488356333063488186069737186765617370327690906834725112`49.69745944380572 w-7.48974889083234916778040845756843175373105229477165318940318326755035841225244`49.52328399912163 w^2+3.95630229328335302633623671180001201734336271410677774945911242293334019318397`49.06763369982891 w^3-0.686105986988350149997739260642592560741591738639310882902353305061668542633`48.251454983485246 w^4)/(1+0.99877172290920169028502521458719789008389861066782243763309211651670217308566`49.52287874528033 w)-7.20287250728238379075634549502170273535290499056544706947041454761970198779165`50.15770032940374 THRSub[2,1])/(1+2.2841160562821694177772550986025070334631882329256898039198152441447376540861`50. z),((-0.66680305369606556497921493186721636453671117964587633492621317057644195685938`49.69897000433602+ 0.68224696092078067307585612130895141942964353301624755599118419375516810482567`49.54396466813882 w-0.94802930787942877111936578252508641274317687875946816556267183497802060656493`49.43906063322655 w^2+0.24971360687427124413472957974953893069038813432644770245124864383445444546386`48.7511092630985 w^3+0.03755312800682493266755512221680603183199767090024087285935577406431437474985`47.92292345546619 w^4)/(1+0.95042614893058505383690002975382148211447476329797909865891883626746041166606`49.52287874528033 w)-2.7084555764210866835602530193869889296579920846176658515680208501962401873733`50.720737303089045 THRSub[2,1])/(1+0.23490766180553627571623122763902550266350983225890763591057645857010372800407`50. z),((-0.75261392204883198638247744024979377878950562122093654085299235961155058037244`49.69897000433602+ 0.87707345937742872844453903586700832356524041748094638184850968861354856222712`49.575794331429705 w-1.24617680593037612394742499411000189747983321326719727283798951657099485277992`49.458098118953025 w^2+0.41560038105310683508295665488046749044321460738060585964100840737262440458385`48.85484951966829 w^3+0.00619480993856322483452803315760314691787292522645667148682549554478032699741`47.013266981854244 w^4)/(1+0.96484628225700475764045477353967521113018266222557151555986287121127727685426`49.52287874528033 w)-2.91760333630040621326932556501815515302397149383661995607003514816511368609898`50.60507303764027 THRSub[2,1])/(1+0.33026760544755871657442996027759095234382560650924201753872506988372642336137`50. z),((-0.61936503369292445963569816852075492634196949334402329769121050205911307930706`49.69897000433602+ 0.57691150243041690670155570736452886880594457193963566782356550405604667528546`49.52118529762839 w-0.78606176254886221959012409628649470674104690909889471733582786788857986174159`49.42497777527098 w^2+0.16101181544748277380357389197874088061452925653212092833918521346581167552431`48.64271647403784 w^3+0.05383382515186231487029124803939872261939233166007718483488379782644221651856`48.17007151441356 w^4)/(1+0.93691505181683256887905081004339762091323216720587611341711054219539309998717`49.52287874528033 w)-2.59283437589925959475330726907173319032436200499156465718154740477573763726713`50.81216130222877 THRSub[2,1])/(1+0.18219071579594806566223165373724137393795085464602687465911329352313892445409`50. z),((-3.90639062090286159447159202481748525537875566947540732017904151935016428023519`49.69897000433602+ 8.24850032456833964207364087697533405166233422225245024011722797576353158880467`49.69897000433602 w-12.45821159167875266609266320615956541752645100840012594835505785010966791388346`49.529497350383046 w^2+6.77999868488343580773017425466075717337642877365413526467243100953815777417258`49.08218149085809 w^3-1.24027245591944936241767928464877897145298832905569993242149563891253192072823`48.28589911981029 w^4)/(1+1.00128759463662295441048222365755531736791477034452810281973902766781197474238`49.52287874528033 w)-10.6043374806665243593873523656083678505012730360771995649231789550875027128157`50.100631154312985 THRSub[2,1])/(1+3.83499811377772271702711979587187004751694037049934336081477587221406174056434`50. z),((-4.40237464845701198531126968447463168099419696359878551031747644865274953506071`49.69897000433602+ 9.41003042840089785614714667419810293581938299325211431256413390823570158850544`49.69897000433602 w-14.22420292081199509534043245081048051571645080002206163963017050504997725458335`49.53067900126748 w^2+7.78375997506592333047644686282661045487077705457047682490331932069562931224147`49.08487668001968 w^3-1.43730203236638317879909473369811369684024701447843189869046483770810643118049`48.29204885023522 w^4)/(1+1.0017562157459770461289819591729365492538327720483781160311741558292110019301`49.52287874528033 w)-11.81320472895523149744827351630499029964054796025076434859060697865170557472055`50.08919449564974 THRSub[2,1])/(1+4.38617548586152703855474939021647331622678290619437571380918126002523076415073`50. z),((-8.39786816000033378327644250876750999493720532035998157511207285953255077684114`49.69897000433602+ 18.76786638293875346663942828195567062812388753868421637435125353614655152718563`49.69897000433602 w-28.45157761558000559802549234886187644001370937578221503334680195257250042343921`49.53489562255298 w^2+15.87090313191559798830029475860969564880149512502892441417145892425182439101209`49.094317934418285 w^3-3.0249161419530327873243963979693495037704782295518417529311`48.31306550800391 w^4)/(1+1.00340392347002181148133630231650413853860969893025154749030417436653056575221`49.52287874528033 w)-21.55146438758391301266140986080038092978419790473188216266505456469399262024283`50.04661138716414 THRSub[2,1])/(1+8.82628946439061482928129053184682132059332725387559573901359833571219562229743`50. z),((-0.63221076573309108528508172433291980057023021134800374872099253076948984270127`49.69897000433602+ 0.60517076717870904204379731630581289880480991270978617072563013822925077942761`49.527756741152054 w-0.82960215807421514668595842868472801620957749264751105056412121317582676403131`49.42907373837263 w^2+0.18469591765316118637648518988637650593436016951215685480549977871845311621405`48.67844251169584 w^3+0.04954297618709460772056113412099681488713469169424583981458350089337745619077`48.107457396065726 w^4)/(1+0.94119228636211976165024664419599439940781309741950136033741687621857434920813`49.52287874528033 w)-2.62414341788641292477341616342643426163244523186124315462877861991080277388878`50.784613093229524 THRSub[2,1])/(1+0.19646592716375518471467161133947947349953936596447363763188955164954373073413`50. z),((-0.85243186327715403847147563911922275287178548055922159981623153512298058415339`49.69897000433602+ 1.10683592171097428316821962874549555100442086144404712934834604245583310228474`49.601937700647426 w-1.59676842841494139947215910501771884019886854472754514699301163826627161086868`49.473117401990535 w^2+0.61253959228240570874982149067234739373027728818967864360968536150801694407216`48.91778456641028 w^3-0.03167774402261545475402738130991548332454258417622899225424325220997382967917`47.606428261747276 w^4)/(1+0.97429086944210062092439856956669232724685064783907228763067977703271844250768`49.52287874528033 w)-3.16089068677733556517476898840371796372197067235589540453339477167398477660489`50.51409330137016 THRSub[2,1])/(1+0.44119333586744709458186850749681918726148112092633288679839160883273439395285`50. z),((-0.66204870530268918582036927222410873634271619616568923712514849244090495283959`49.69897000433602+ 0.67158457690924729561642218142318181167980641125253160837121864340137556044933`49.54186421751012 w-0.93166949889940976997410714856297700817376612168339434159762664471165175254033`49.437776686491226 w^2+0.24069001638096796028124155632057517259591916119771029458477760617322199137118`48.74268228513581 w^3+0.03923176560568163056916955644700248019463515851074881107221753739161226290218`47.950186707770236 w^4)/(1+0.94931857104794130412817721584996931935520910938900982320408969831843442258245`49.52287874528033 w)-2.696867751530739274190985612381792054728097165207751494610019544078202421037`50.728754672982404 THRSub[2,1])/(1+0.22962424720375063485220914550514522681987821189754110983182980306271717598556`50. z),((-9.19408138631322603003198951245426324547060453543781598351438128369468368259773`49.69897000433602+ 20.63275225018247140094226992206997786106958494789133386154268631859895640735255`49.69897000433602 w-31.28687027409759774658549757104790544177597193358072979115481751919783903825905`49.53528140096837 w^2+17.4825886831821951337804658988087775795388090756687095478982`49.095168324592535 w^3-3.3413265795681763898886942644852251020555280701155194370297`48.31491986857288 w^4)/(1+1.00355280010262755704067680275384553491581694983842710208231041986250548940206`49.52287874528033 w)-23.49208351737807638370192906105724138675811536226415587918573843451782625163613`50.042565623915685 THRSub[2,1])/(1+9.71110568692430148764225663807798461272571754014364580392467135777202481878629`50. z),((-3.42682498518085054308781565388163323509729777924781783972573981321986939636411`49.69897000433602+ 7.12548297939049818909189418565171290346756343738627038502521757639985425374937`49.69897000433602 w-10.75075522213739674185964048167261280265606564600815417258660135383163013900519`49.52799443948208 w^2+5.80954447853093610947268580471387672701467069155946741253545034377874279020685`49.07872127988795 w^3-1.04979313734701885484421747456693392342437233288098267011585089694673887720449`48.27790135804875 w^4)/(1+1.00068710493351724072613430187192075881004727118161600323970509797461809188918`49.52287874528033 w)-9.43548695681412408786088481520706660156279356609286533754209391652094556973059`50.1148913138396 THRSub[2,1])/(1+3.30206618017810982608386831048736376278343000163362730862184730531317683131133`50. z),((-0.56597679400272442662591597397564242622490079333115377688205031260288904757696`49.69897000433602+ 0.46310161843615469286841815489174938575704378147030426422554919081189079503185`49.49135724276925 w-0.60948834335060312624023528855117094391084843047891908350060136745985216920859`49.406279904343776 w^2+0.06719272972161073576078647218745060822409648748458444938359801811531780250788`48.3801555914124 w^3+0.07004639711432481470124586162871644247816708567360062323164082697550153100989`48.41708147217723 w^4)/(1+0.91062910329532693711466236240085004287451541004343874300022982117840127134445`49.52287874528033 w)-2.46271064041621765097380292514557701215121437615896972967617373081041061219365`50.9609106715571 THRSub[2,1])/(1+0.12286140674997882166203162351866361085053761941830926654529538036718542027447`50. z),((-7.01993446084571957856451467836882673802219922188257336408089820618449687656504`49.69897000433602+ 15.54051462928982501758569416268362766146978540947036448421592535700262927153779`49.69897000433602 w-23.54483867998918383565979010242430726553034443539332365258429801479812378672109`49.53401084008872 w^2+13.08175183903927123753464333856694419468433596808569872080114651140683170959389`49.09235921650555 w^3-2.4773495955299555376680801801625085877851658412230721922279`48.30877056321249 w^4)/(1+1.00306130442867195982408108518858483719947255894840543582372491079450459770921`49.52287874528033 w)-18.1930116417654881117309307982819465798277840872128483213152569047835345565086`50.0557909604164 THRSub[2,1])/(1+7.29501863103129508044745609837023581100332809870795992949983642972391303269439`50. z),((-0.68834425947426130404304136042090253470197648424127093801617055056389549292209`49.69897000433602+ 0.73077295506074624995506421371189911706658818543947468442535563498281766862691`49.55299878438241 w-1.02241383226823538249804469555307299503194691472804460949056584676939516239162`49.44454523103958 w^2+0.29087251737078804241383549238823974016854912390279495962101081922369773241933`48.78471183119135 w^3+0.0298511131468849042517604039752571071493802641516891199451129398202273899383`47.7876429305791 w^4)/(1+0.9549383191771320623922798905482846791762848908490981630855359217174496810905`49.52287874528033 w)-2.76095819083454225450084083478190773243592245631509201238533510302534359805165`50.6869311681632 THRSub[2,1])/(1+0.25884598347063489427953834107749687164289764788397291564240693038604446571634`50. z),((-8.18087344878735418288072798212545658335560894200035721060655166832808020142906`49.69897000433602+ 18.25962493247837251867018012772264861778578297830381602011531339876472613095969`49.69897000433602 w-27.67886835142390788218018651278044208702360259308417438963324181605522317238368`49.53477690669067 w^2+15.43166783648616627769402609495977856003690203489004619007736227935159593395662`49.094055800007574 w^3-2.93868473349807069685371476244022232421839220655666240625`48.31249264437548 w^4)/(1+1.00335804737016774885449304734038454815394572547873521584741326926992776182895`49.52287874528033 w)-21.0225808250812917728252852609059551225537412766480849437990236043268805222682`50.047851039383566 THRSub[2,1])/(1+8.5851474758627762184756870411119784287595105468265806970443814507563854826074`50. z),((-0.57632256036397160739807304370178571681092811760197443939331148116443931574189`49.69897000433602+ 0.48452567856894254413581141076050830262905547110854634253711398598382403774313`49.49730888084431 w-0.64294560881515564339084009461968742295612108113426856426186367426181519320775`49.40998755935894 w^2+0.0845737993069833975913448722626171757515124081024595337154668277964085921705`48.45468745746191 w^3+0.06718547812493295378772365552121798097811952996093174639901888117028352235409`48.36976785682797 w^4)/(1+0.91719720345162516220563576878987680426087975517528413261243864777463722358196`49.52287874528033 w)-2.4879264889471328966501276194431647192643959445859617574167772961807288436318`50.926485311114206 THRSub[2,1])/(1+0.13435845503862088687987080618689296883409542337170729149495192898566960526793`50. z),((-6.62410186971113298069829831538649299841793467416630875769575620539978114701557`49.69897000433602+ 12.6819702475470991337189605479396214098114286968247866777579776540173217635442`49.62850503126246 w-18.06652434725952248199165864198719295620484384112197865837371273744826138301241`49.54884151814215 w^2+6.44304289553829149565900784621032906848891367504996016006013681168296589010449`49.126054615115436 w^3)/(1+1.29451387935767817564848826631392706963766066702585309016289885372170333456295`49.52287874528033 w+0.32144652876311593069939115198516935537033304246725185810484616892717322690345`48.94484602146015 w^2)-17.22824457539939615324553828515134781860566219474495932002773161876861699786814`50.05913762049187 THRSub[2,1])/(1+6.85513759606618283983088334133651432293700362418780725385509183926311616106995`50. z),((-3.76845101246186181150607107262387443893921558106389785135294814998906724693135`49.69897000433602+ 6.88274566352058652945316891711920676541278939823230222577961586596782637970455`49.61991889012652 w-9.87171163725772706049462481816696540378563234304501424372200841153893885228796`49.555337264187614 w^2+3.49256521538716659990082308801539633944429105908067789003926293418473721723997`49.13037526968548 w^3)/(1+1.27783206076911514392576934057523328242578718114637840580895730249970841355728`49.52287874528033 w+0.30291410456886874823335746526467282600404894328860735216271199965301280046921`48.929488921916274 w^2)-10.26813577734072991342746791044578137082782064549303514472029858260720737059921`50.104354968825184 THRSub[2,1])/(1+3.68170851842179460455476495722988485668702463200545135282026931720152331194286`50. z),((-0.65887380864643795364321220234639893844826059947335828931887702664252642960145`49.69897000433602+ 0.74863580043236468343613373352064034367903878319148880707388827922865449044472`49.611755704785345 w-1.00882124360214381468223737443224143747943441693779050081632178340099200343977`49.69897000433602 w^2+0.35852806367186698604893600021834276479096784002682615257358748762238494201216`49.34011281851414 w^3)/(1+0.82081957801142364632965577057074635963031018584443735523086464691518779697464`49.52287874528033 w-0.11632478128475459639468419778147631099068824620558044379693150646210227388305`48.79774791259055 w^2)-2.68912954148520627107928910728021436584432034801183327380415378845167694125291`50.73423152370112 THRSub[2,1])/(1+0.22609604649886168933826477974165369836704569667085142335463077726049283036781`50. z),((-0.55335228198891839326968410927622509999687443357516969675560659796452004893474`49.69897000433602+ 0.63934129511423596760837895806728283165017347134004132259314151164266330401698`49.69897000433602 w-0.75097147902952667359169025264289536560879793496250874827114167758227699945873`49.69897000433602 w^2+0.2916277073368325343357149643733702542080588751737509127228363989669634805655`49.525607636830465 w^3)/(1+0.53654250427807478321379946229871605320650862427797911846490709597458045719948`49.52287874528033 w-0.28879352704841818622229569498868568021339865378116869234440836037729003821234`49.3495515438552 w^2)-2.43194078039799110770876454519264306803891941371793384346448076171316278814525`51.00810902225232 THRSub[2,1])/(1+0.10883203288097790959390200558287819801481930194557752787657608459487593410862`50. z),((-0.81378413237915686065517649755143045635636123807250677655451543604740190656056`49.69897000433602+ 0.99027335619460457301250106966004157050268797631051007836583076221205332050956`49.576510117372216 w-1.42680151956250759746700241812907608500005647747965423368348658492847743493216`49.64929736906553 w^2+0.48749789933049282016785850945774878397738141497038804836995940349635732518859`49.23808730691962 w^3)/(1+1.00482782192373423158057004353379550046011505087549458739821490850451715949204`49.52287874528033 w+0.03299274843330755822237886029823440343032735497065285617534465242926114571163`48.152995280544324 w^2)-3.06669415320415812302430535215452808065450147610162751807133245991330611836026`50.54543304712537 THRSub[2,1])/(1+0.39824486662256913325857266267529390653016363194338008148719500161311374162095`50. z),((-0.598725732602452400422022955343459455934032685649690679873333474384374394188`49.69897000433602+ 0.6781459011499145068524038583390857890992547723803042662172778918169257476464`49.65578541608116 w-0.857105296866042189159103660226708707897918191341884797323341346204750457739`49.69897000433602 w^2+0.31764157006391970133150894169948012773559021867668886098062233193847071568241`49.42545035430583 w^3)/(1+0.68474046908922732924365834410876035555704562086191941850206874048772182778796`49.52287874528033 w-0.20902293802875699479336445685153972479831147419093787635036849117364696675773`49.12183366253275 w^2)-2.54252998356050213691190483945619566876710285259223501140389953084697640985936`50.86208669358363 THRSub[2,1])/(1+0.15925466321217652424947368055698466978035034731497750651095269810841759067753`50. z),((-7.90106885784628402857642725908856665326426712963911282479347775253389376000977`49.69897000433602+ 15.27703200914357972637415862225006070853241662680555000836261040713579483361566`49.63032924232454 w-21.73152962907527088689410876084869295116372999933086982174776487423965958732106`49.54752900646186 w^2+7.76323507943582304273012321552873193474459041563117260617699932228148174484283`49.12522820843583 w^3)/(1+1.29784256190865674670066397434023699027214615067337701153558327773576899741542`49.52287874528033 w+0.32517592020077333220615400974872981971807310144056094116537909385607330477506`48.947781780985295 w^2)-20.34061006167288784615673934346961826636573333953193053570405677500511097664753`50.049550408577836 THRSub[2,1])/(1+8.27420609355173941590276748761519068632568709985814517074298770336911489360045`50. z),((-7.92827440551393420207051286574544508168508767849828979457647073483575568235295`49.69897000433602+ 15.33232475520895034138168000708828560975679582651267101197673664098428115326825`49.63036167698966 w-21.80961342628682686326793795198716731997886452586478859239540988374075368020227`49.547505863097406 w^2+7.79136399920032724700015883046534240145753455665054696668804768387755920331552`49.12521377543182 w^3)/(1+1.29790112830288761192180725674649088523432379930119146416944439581376814939762`49.52287874528033 w+0.32524163151469313337871363425034842172707540774652470711522937456321017617887`48.94783306720523 w^2)-20.40691843799169761906100305155448442741046890829986792616643149655858763743229`50.04937989314901 THRSub[2,1])/(1+8.30443908783484456297165225476894735449455627686776309857559958448399109821385`50. z),((-6.17526622630578121747938908750061947445626749810350327877894585552407938036873`49.69897000433602+ 11.76999781233671264617641246363647243244361565504972964669685944484143888781213`49.627683454235616 w-16.77837108034126851077245948547528980081984681195052896429250375606885009402864`49.54943979110856 w^2+5.97908445348756535699424496175900664454695804465439273970999657576333669380669`49.12643646378356 w^3)/(1+1.29299187095758381367477716292018692473694865375020113144398184950802438885421`49.52287874528033 w+0.31974481335353264065752541512507601496553851119022424550303382542367050413923`48.943489877866206 w^2)-16.13429259502421953277558477195632901271360777395856266804940528406581376052477`50.063454531868096 THRSub[2,1])/(1+6.35635530331846723710743086095724328792472409469125217004395320062107506540641`50. z),((-1.5134015595930548227099796517893872629078647465241785279523753242374574606336`49.69897000433602+ 2.33016163323320850080252258485801310248881031744760958001556013203679162053243`49.59144855109631 w-3.40837977010520186967878559123652353388085655970659355057585230673948091395511`49.58326683041088 w^2+1.17474977437242061321004947773559653372729730542340533949499738582220705185138`49.15351197386411 w^3)/(1+1.20236827263888930144549707442468055483650643717062726086206763913208840007422`49.52287874528033 w+0.22221250913573358257253985567235931203417559460521663947462737235089569098244`48.843121928384114 w^2)-4.77187929447073497874144133997542187336423145492529069166855550114378438326207`50.267299766480185 THRSub[2,1])/(1+1.17571606241362342340788897279643797966438018325629092866964954982742683082811`50. z),((-0.72870185607795737981504080631305628699154085723805023191419959433738650828089`49.69897000433602+ 0.85000103997332412415194912037501507800129593702152683481914731914749549729852`49.58771260252724 w-1.19410065234270410517468297061627235018327639336753865907949154429685369539945`49.67484768634596 w^2+0.41357326999682597274879847666755087597922170142215391601441879554031004268853`49.280773584949785 w^3)/(1+0.92381800838540948757469569347998693147948085709059238512823511730371324537836`49.52287874528033 w-0.03595444702603553820409122284894150383878533989171126146941908751658886499676`48.239326818358606 w^2)-2.85932219863221130039479517448583218285508679594918732286637982615679430620051`50.63273880441881 THRSub[2,1])/(1+0.30369459311102275897128772530825919697688000750996824496932724046506768004079`50. z),((-7.25178713543983892922104133359432929527212046630782324943532124298432507020063`49.69897000433602+ 13.95748833104224979166150998164312929571956663521605937979162439350334266669391`49.62948248396721 w-19.86801579864869138563108070039798460424415958982921323986485763996753561456477`49.548135567835516 w^2+7.09194409893018006933681201724650586755803307403926619866544121132699018836243`49.12560819584567 w^3)/(1+1.29630602168885870237200625832131227847334356608361520748494883861617783650074`49.52287874528033 w+0.32345309748696802444542423992990607897958938766101818837412705066139626545762`48.946431726372225 w^2)-18.7581086795211442111377362954555686218661463309410824782526625355733496261716`50.054001192586234 THRSub[2,1])/(1+7.55267198435311368811301696980223484184965826210127682167310669009685847789102`50. z),((-1.95239565110378976009165709233850937709947850924429690665057146421489000711432`49.69897000433602+ 3.20890719398053830220950090137550082069573948418071682388920529587023323269827`49.60166038209808 w-4.66434170458622843445967613499530294928679379020051315242619786065402296256785`49.57161057100492 w^2+1.62260176749983276454067255705201054217324106246482524508567523589209778322945`49.142937584902484 w^3)/(1+1.23457193445489513576009412986750447442232892918582926779827299577329462216198`49.52287874528033 w+0.25604046088356819375081043981251080038567432789469507825393004549923535948323`48.88387827802441 w^2)-5.84184435370168774940017830702323446593572532037785075498968673880510024156231`50.204423855151184 THRSub[2,1])/(1+1.66356163057113221815063722608959349985597535554739355243193132708866407796848`50. z),((-8.51720781269451456757103938092610064030051889064120556451366718953287480547559`49.69897000433602+ 16.52931970073550956349245941357669743340517410738128813482615828730320892706024`49.63101272080828 w-23.49994817475390332182975489745221545688348349532656806403566714943738336749242`49.54704271378854 w^2+8.40030548911204007647319281515422856933513269613623633123601120260822410930314`49.12492594881429 w^3)/(1+1.29907223623332955786550449637214927438221126958420829900604396012891681357732`49.52287874528033 w+0.32655629991221061401747659839819072049045694372385418018438745400807045733062`48.94885596071831 w^2)-21.84233221708955916627830775536152524415774470112482566325496474801669378492549`50.04595663730943 THRSub[2,1])/(1+8.95890929185106878012086540959623074204127785255704553714965540072855275747788`50. z),((-6.72921876839699569408322380051755286702485193339873933147636626775341285672871`49.69897000433602+ 12.89556714861318096193577801653770929630520692294046379362212254462804825308748`49.62868151323346 w-18.36821256877807476947501674401812024630939399844126214907200278663279601054734`49.548713592376494 w^2+6.55170779914022398771250993543240600996917215846970563950962304641668824014998`49.12597338586919 w^3)/(1+1.29483894001557403911263332117216364397803873166276722094978816968513897365261`49.52287874528033 w+0.32181025532543837255766622046494860299517270209558959314724969743111111189758`48.94513452879826 w^2)-17.48444713234393043106401412394784269734773675105707520771133268469138384964112`50.05821028700844 THRSub[2,1])/(1+6.9719519545143443002845581563678293293614589320849046457148753372774324553334`50. z),((-4.70162875325213859372005872966270727373927829771648047082602073137910326816136`49.69897000433602+ 8.77675714564529943718836840543472038816371281060480184893397999236804586134995`49.62387588041518 w-12.54932868182970504749317496864609584202821608029773425947333636073523616845429`49.55227419513475 w^2+4.4562434823501648297766094470905405251121064618462674439960396286417554186153`49.128289708166804 w^3)/(1+1.28574120636506291586368665297396962709110497697789516220191531762259026277009`49.52287874528033 w+0.31166811696279924172858010557321069341766832805738647625993397995099465363843`48.93690743264383 w^2)-12.5425800033702712980771736182201165963017286704323578999268133937128158558734`50.08347445250928 THRSub[2,1])/(1+4.71873073341586743113097989927456341853038701072458901561523755365450838991355`50. z),((-2.20182823473606622145076169991311346169582106484101471824487300805673808611342`49.69897000433602+ 3.71123450349126826027444665772659454104637943271017329862370846119045261455943`49.605863449923966 w-5.37889304511632760901349588039727738609646116492454781839648632416253933350568`49.5674702166171 w^2+1.87841975893899781846388549788589935855715016833031097533394990122755511481707`49.13950099440485 w^3)/(1+1.24577179491932845816086610347409842407861445466093716408023810651972994705221`49.52287874528033 w+0.26801546172104029097653226764519351462227687908954598856091132849101856187345`48.896582855065844 w^2)-6.44978909437415307765439220198082135099492880198036100922515877525065600890026`50.180488420015365 THRSub[2,1])/(1+1.94075119378443944426464219395832273411014261626388227458734217501957147216786`50. z),((-3.93171556908686755472159665992054233854268277152635102660389718096647183604723`49.69897000433602+ 7.2139802244807909076645977040543798517967237204830159404026093371254363421442`49.620746769530015 w-10.34013715432248568673478407417706221167951309564729142870246838268135380324297`49.55468577007018 w^2+3.66110578801584128248220228141408569967043849624643135287880372466123974425592`49.12992443001239 w^3)/(1+1.27952063460284797254342832864061688422307292826065003156549212299877714670133`49.52287874528033 w+0.30477816720952658831158326739856628882182387562374105408973476034377666802752`48.93109423770759 w^2)-10.66606225147259826190052866156171088596251644652657547134986841630420438909164`50.099976296432 THRSub[2,1])/(1+3.86314123454927812102445726384462708048417033604070987305521536487788784565256`50. z),((-8.58281554618225604211392291386744835768885627296170664307362703986108826066827`49.69897000433602+ 16.66267067485001708344735226876490788141848783860819878254309815896046597565178`49.631079684099944 w-23.68825434813388410956122671318794129907720125110428302911759648450557972085901`49.54699522616201 w^2+8.46814423969444976230177052215620890090846507299226461458647120348570987256025`49.124896545951124 w^3)/(1+1.29919221169585503303662122189019791991895307154061573819014935609614143520494`49.52287874528033 w+0.32669105674371244628198485037722748895921175410132264733750457044998994556636`48.948960469203165 w^2)-22.002238657300732907756929395712071307090341334854185109550372902664788949492`50.045604467470135 THRSub[2,1])/(1+9.03181788592509855899550275031916136090728082772727494727775878398265340087404`50. z),((-0.57552450773256003524545895688101169667497693585608163351292660803480740721656`49.69897000433602+ 0.65668778197554253820268064918121397923119592360367400198686555240234207747126`49.68247331863469 w-0.80171973996531951834469730261648969936802843749522524614827646559043356477186`49.69897000433602 w^2+0.30389155496072939991221119028654970973608970370616823318836856474924211722748`49.47193673163541 w^3)/(1+0.61468798859786270922514616582197079712256096874280252065087396013590798529758`49.52287874528033 w-0.24989634214012351404390528544236275584052323275027997025015987873649001415732`49.23873619665821 w^2)-2.48598138661534713965166967573390548947522186016246015118603190762801947163665`50.92902179153775 THRSub[2,1])/(1+0.1334715947210918684358835054363681812135033326815295777797119966126264074354`50. z),((-0.68706021749008195913057344209933110986600619832666156035949096347919603227136`49.69897000433602+ 0.42546567874814565023287730062137797552577956448915243231343444838050974928218`49.25925230043715 w-0.94953496447686595716069797629562495065444044424984958814661355352619398843511`49.16752642958659 w^2)/(1+1.3948347851004804190884452779792385709258975990339260804120107180380399581527`49.52287874528033 w+0.78688632856180005790998998185288445257139680964428242000170049517137814539819`48.736931163507755 w^2+0.50617541753317480418788787788400243554531393179455848460698324690392703126539`48.437876223670685 w^3)-2.75782858138369640698160489132014979660606959809694351701456848909533354795957`50.688839348860526 THRSub[2,1])/(1+0.25741905266809412836309152330855545593341237588435253246623799646599119378321`50. z),((-1.07140547328978648813715225192037749849233586034219998381436612937402904342715`49.69897000433602+ 0.87299986408185928869212331331009467061426100790855820676931827669455754269904`49.29093470785773 w-1.81294407417233292751683383543974093397926486381997114066404760937291963657016`49.4163378377667 w^2)/(1+1.67754112426915760037643977849613113619005697188957446124512166655662421024902`49.52287874528033 w+1.20567149168515285948276769199115389851914395889445092213031040359684024784329`48.923973219375725 w^2+0.75152512675590131299240785579533561356847732827747854726537427062556221095857`48.62344483373168 w^3)-3.69459744078145528372228130148225443637336707577198880760672391825179352873349`50.39108459292361 THRSub[2,1])/(1+0.68453443601868041135973169458834633597700128382540159387661391955723568182241`50. z),((-0.57875970395713577549401343305556303239518354107433827347331417397913693990317`49.69897000433602+ 0.32964519374807308521450672979102922748299987136674439550405600550773076417559`49.28430844342556 w-0.70535013017556690123505056215648829375448024309989078118379784126675421444972`49.04124522998141 w^2)/(1+1.19503796325664045920102255039959319990521786225790054599556935843064629894533`49.52287874528033 w+0.58187128703973641539019390674056476216098249601632901896576794062666101978857`48.598580545579374 w^2+0.42114281204075187831419192252237300274774699594902633682863184038509267450847`48.352402610979716 w^3)-2.49386656545258278794886928527195508307752095083207606140741344549023308753902`50.918853691106015 THRSub[2,1])/(1+0.13706680515968289685234114740473391862208658756584409653759368660935678329392`50. z),((-0.91333799486698155187132142879560827806070772774939972979013431940186914975524`49.69897000433602+ 0.67980080043755348595013786576558357282720965368811300901849437331668588909772`49.27575978345273 w-1.4621626906499276895194270622754235729173142528509052139877905239689282303939`49.33961314722423 w^2)/(1+1.60009092453240548419845361018850222544646772006464961450253597747162001704069`49.52287874528033 w+1.07540951110851195273718565191422427697244013293267365352247276852077485767423`48.876206131695895 w^2+0.66465562375165041070287225962873075769430037430958852968727943490069683544594`48.56769995830533 w^3)-3.30933786170348016429438265107416846570318591434460547392010014759144736508862`50.472040941946204 THRSub[2,1])/(1+0.50887713149089870627163616096341224802782916696541227893665646170781555584933`50. z),((-0.70518676027607572637755094960643662965644378654533282215354630238182206689754`49.69897000433602+ 0.44392346884907748720014871692875534961590120777349779627548145309980314441597`49.259024012246726 w-0.99087464311139362734459369755273908117581578036750686979075029370919872455983`49.18550442487882 w^2)/(1+1.41884823031326213908663108559751978609301465221109376994249790899717789203185`49.52287874528033 w+0.81647264547864731816413184623197510235261260450548102400104217700023544016966`48.75386235972131 w^2+0.52019281681711499091468262269814652938439603161876426283987929984417891095817`48.45117484744672 w^3)-2.80200860066123137827966009041706957252826575999909090651799567832352977509111`50.663021088291146 THRSub[2,1])/(1+0.27756272597752927519700402784007973021272487864565355097656127981835600164727`50. z),((-0.80152870755103631777629298426250097940911124385976709700651770669563189696432`49.69897000433602+ 0.54891801245846107029826179001224339405473753643127489202970262107913977612024`49.26456183888231 w-1.21017666431721588792967496037399734208152767786914542767614183463043457074708`49.26712440102329 w^2)/(1+1.51965297905078668861708809864922866420781670355679402437641793223583572269356`49.52287874528033 w+0.9526204184164740764357940596433091047909561163189276414465482447892279082628`48.82342979412749 w^2+0.59129399578909423491391228907438627032811985846595502309860753660014851542275`48.51289681481009 w^3)-3.03682387338559744370193795639558067884777670074330518651605221768233497573518`50.556294127655136 THRSub[2,1])/(1+0.38462565214131932265078900232829758230067392800879339503605836451847251249933`50. z),((-0.78763613009157689874713834964931643841647447692252269112022520261848604512648`49.69897000433602+ 0.53321120415190965530892533199561126988096182606073546908984292314685850270841`49.26334816541873 w-1.17864995336184359063557337342744306289225440831511379962974678562835766936424`49.25663308486492 w^2)/(1+1.5073577626165727153537672635515322004189393703359627173231212290528764149808`49.52287874528033 w+0.93496732438682736115577607909715410844740769764124931289664651060324455592263`48.81511966467079 w^2+0.58146034180133656208086524538872215661993204497308262765881502468939957583459`48.50490651382808 w^3)-3.00296334370710721286091669853886313288019338003285197414193915028157825829682`50.56921627943447 THRSub[2,1])/(1+0.36918710188530420607723148916821902988660044767762172389037410288852395166739`50. z),((-0.57630994261002050465523210099989433476134155475021876059582090741810333773934`49.69897000433602+ 0.32785344504108690478341422110297176822254668871718272938371237246063010373139`49.28566116800058 w-0.69996096309915520940937494402012154773071483143386205269463729355130144304744`49.03814688571299 w^2)/(1+1.18899812044407174620647373862831583264928147975895410966362035324574856521432`49.52287874528033 w+0.5768101033204227169651482931132900010062837406421492379146428436798982273248`48.59469918965877 w^2+0.41922086940889676313997546375525140728690812851378424868488698708564091671941`48.35058253268242 w^3)-2.48789573555861417418597038691686772474056953168811928720687081195714695755406`50.92652526877795 THRSub[2,1])/(1+0.13434443317485510349643933175140696652594206312943503564918094471166165889199`50. z),((-0.68635678289333703371921849592666971882600192756036746668017406669063921772374`49.69897000433602+ 0.42476007583456031649108572888079834635308704996970802223367963933031406745564`49.259274473335104 w-0.94793123454457831272087899145866981139510987521955686451142249676447580845356`49.16680989423886 w^2)/(1+1.39386176247723236087901699535978793264785561823508412901655190803407472110154`49.52287874528033 w+0.78571023756591254537585451726182924956960390098640818400675715842022566782235`48.7362434734599 w^2+0.50562857306911347749190471812075162361335654351335333465284446868000560556571`48.437349822986974 w^3)-2.75611409261374247113183411723735106395522335118110486910137453944720911745653`50.68989011568893 THRSub[2,1])/(1+0.2566373395262845999715095785526558308295051908407115980525539696098919089267`50. z),((-0.6382112512202680663021637814877912907296026200136937283108790392483294445686`49.69897000433602+ 0.37869843390875957377420954984418873587525102741108481979981452668281051168936`49.264030555371235 w-0.83844969921974873901734296593507880580366685105605990606334789933868713108145`49.114304819857686 w^2)/(1+1.31866957099617764689557698041473486992411426977965804855394538467819374639828`49.52287874528033 w+0.70012554562040646595037157027512686840323764201842601418033105109479548046559`48.68301664090799 w^2+0.46787394701271713513852683453252050702171136060746442479586975247010451851981`48.3997667519475 w^3)-2.6387684662272851663484531228733366139147775512571447152220640282528910449399`50.77253111359723 THRSub[2,1])/(1+0.20313414960301131148517895839115830936262242376521756275271873877404641995999`50. z),((-0.58908091646663629057173890584715790547175797358480468073178178046560306406299`49.69897000433602+ 0.33740888214551270616420194440531700590035312389985706093618046294177833017839`49.279139767622986 w-0.7281618132643211679760326491596825049376339903195354085453483346157331286864`49.05430935292258 w^2)/(1+1.21956845010795023123834848056781533061846568092695731268693710662061499671055`49.52287874528033 w+0.6031173453034841649835968863093540291982981117200826590912444800259737827759`48.614660738102145 w^2+0.42923563495758614611510180284250985851659069564053125070529982292054515033526`48.36028322055359 w^3)-2.51902256861439965076780838903551141093284072343295413188549047652968142020566`50.88831144397312 THRSub[2,1])/(1+0.14853656723197843876036229018685687970870665052335867273142976128307426851313`50. z),((-0.55954708860627096403736701620860082419988452176404162358751537975783056768932`49.69897000433602+ 0.31612962603456720292451237171447200308665509090810494008691661327667359527672`49.29633762558536 w-0.66338658526956023939553774939055610693881919281784805989884114482272539777906`49.01720184524693 w^2)/(1+1.14529176044409796644006178230019306237872751879358576569481146325889825854599`49.52287874528033 w+0.54221172701869386066869317821405206306832494816081541657788654376373502318976`48.56775345449356 w^2+0.40601591865173188289167416169559915408220455955054893675522292149217200218178`48.3388650408923 w^3)-2.44703944973645499062715937804989600018121585460195143151243802616902429605968`50.9841595735528 THRSub[2,1])/(1+0.11571620060056636095006182136596036713676191519205217549192674971620741429063`50. z),((-0.67893146857165781182328261115559090248945449230117167390753262230852063079432`49.69897000433602+ 0.41736369828222980713670546697185295195038860219115497708385476382784018111943`49.25957690507922 w-0.93100663866856559301071059198674027594720062107118936791008385622982674899731`49.15915862267021 w^2)/(1+1.38339142420011951576407860434515213771302276859977945505529424216228190763161`49.52287874528033 w+0.77316638311609872358370421468533972233286817297732298048293744249160970744472`48.72883747728288 w^2+0.49984481964661761621624724508564621920439754264822463000136209424889599755954`48.431748088375265 w^3)-2.73801629350518733512179415066564714952111754526711860189471651312628568471605`50.701222150472695 THRSub[2,1])/(1+0.24838573260478436710239790172625879255306756842614909869066122280582800250174`50. z),((-1.27651283484103160399560614091894079319319935249723669957489247533218563359925`49.69897000433602+ 1.13032097968087317944649748453762665703120517602706754755475593694384909209617`49.30629908100218 w-2.26015634170617139629337088343046287700026249985005281683417260216878107181956`49.48900513927589 w^2)/(1+1.74425586566266673411361290597869151759324074249349623922077763026449041576765`49.52287874528033 w+1.32723903913901241959875863777098157592456846517357408522919182525962466838435`48.9623872268553 w^2+0.84027266000976464314037169671207462223241018130970107112707827201364917221524`48.672483334927634 w^3)-4.1945078370595699256028786693863745422810665213106181369009959219848013253461`50.32137697114312 THRSub[2,1])/(1+0.91246624481571957212316597062485950950890598775988630710654103970917455636219`50. z),((-0.5547128778277699187670026158129123244112056282644443986851214697076866342875`49.69897000433602+ 0.31292304093470537946936646280899469967747244349974731859859936170221214975371`49.29990808865461 w-0.65294868407869685220124303592067276671327918615386227281497025905127703503161`49.0113236170443 w^2)/(1+1.13188217559619952230392458564220307932118965196036923936856914113140815552007`49.52287874528033 w+0.53232034945220141044205707322778241401082867682703247028182406587279673264247`48.559963358214354 w^2+0.40217271642213087204390138287458805339317214077885016476238811666193299043266`48.335793754773434 w^3)-2.43525697538889922840299278933742816801123492555807749831018427735830198791905`51.00270869755861 THRSub[2,1])/(1+0.11034403648848212009320869958477604343867210823899319953616802922624215818651`50. z),((-0.66657249222174676607679496573487707473875775095388045753518535848781350844316`49.69897000433602+ 0.40527343604889578895713714837342218031824485144395688000529387089584236672659`49.260384732037465 w-0.90285901116978446378092294142130620413650372639683254033894941078790460059079`49.14606436554208 w^2)/(1+1.36511606997019281860687766935729104852487747972764619225857480552313338809199`49.52287874528033 w+0.75175966515469223989158971561058737983913533463041726588071892779220306722042`48.715892452052124 w^2+0.49017791057173529658785049629896232498135279612976299589566689366138719372936`48.42224978262886 w^3)-2.70789362643976248852635048655389954322912332333965852951486263774099072322757`50.72112113854911 THRSub[2,1])/(1+0.23465144333788626900912123478769113945816219580088156315896324928057871237012`50. z),((-0.63471615562846228706422344706240005744566499273796093352130223038652902482203`49.69897000433602+ 0.37554847190522953545641174694950091920700374014584229686690844218005888892996`49.26468906191566 w-0.83053821087488374275231386774859044894941299005706262605869802260607479262538`49.11022872851907 w^2)/(1+1.31246151263228344292353035970976489314867926132058997375068237273893345521369`49.52287874528033 w+0.69352357455141482151616388123092602823227820695630815562017448847103828093906`48.678639576236 w^2+0.4651200444267031620647672435138696933011270893586906667940730616623715617861`48.396947431941626 w^3)-2.63024983184422339454137422260325301325034255059246921901874096969773123371207`50.77951118247886 THRSub[2,1])/(1+0.19925011806882470620399221479952689310653929833227667401011201469718506200466`50. z),((-0.61038887315347699091371423857260516961219092879238271849983095795481973190525`49.69897000433602+ 0.3544858027616261124820225584477384772542882245369231418044900148633135804932`49.27088411949709 w-0.77571011309523455070900313349571784810012151010565599122072367413158971074189`49.08095977318509 w^2)/(1+1.26586853211728804523605393469737789026670223593763664801929836676903104804862`49.52287874528033 w+0.64621517203195156601801814565318567576085543647320572943630833784138649208202`48.64609472682461 w^2+0.44596453709839875307794071971064759541991950938291865618178536623987819141941`48.37723989377288 w^3)-2.5709566824883868969913603965073457777336697641401160620258654478904952793103`50.832934827509504 THRSub[2,1])/(1+0.17221568373305598532941719499912983025501095592933971279029862586751781593831`50. z),((-0.58143195446370636236289276711524183317037787443260062931415112919102237733305`49.69897000433602+ 0.33162215527940037294270270236560698224889130688077232851675871954791814992878`49.282889336365166 w-0.71124022485386048806543166307524574926825214664847511802782484075474932524047`49.04462816081353 w^2)/(1+1.20152963847580411617965651553640389858217404920646385906504075167742328464824`49.52287874528033 w+0.58738615506717085776959325762847099285108270943023694463218517648121072352036`48.60278846167565 w^2+0.42323849858535405209303875046366869542950525397450005116011511545787012753326`48.3544121588692 w^3)-2.50037967058733110778913753940773841670292526730700332926933430309105535939102`50.910677712469294 THRSub[2,1])/(1+0.14003642500616149110144638296800502497134980253257113408822113754238283547944`50. z),((-0.57785339619347819421657887859725824013032042325101265061552596672851693335686`49.69897000433602+ 0.32898001716595625726008296683180556716238747918803901452061664293277196335171`49.28480305660667 w-0.70335517218906282299401836050004493050043011583264283800724407333980100572992`49.04009853717719 w^2)/(1+1.19281343590554405045299528418053145534401890951429353728110082316330222905895`49.52287874528033 w+0.57999936715094004542434273331474557368039083764961125705939809476350015520455`48.597147132494406 w^2+0.42043187611267673073704098745808776469225453475262507248963061106594844680858`48.35172668150805 w^3)-2.49165761171316863613830404572034196053216485782286090943615967132932374235902`50.92167180520787 THRSub[2,1])/(1+0.13605964302598415180470427209969703819360303132620129084179821031830750068933`50. z)} /. {w->w[z],pi1->pi1full[z]};

(* Sample Pades for the 3-loop triangle form factor with LME to z^6 and THR to (1-z) *)
(* We split the non-logarithmic part into the nh^0 and nh^1 contributions *)
(* Mean and weighted standard deviation *)
Ftri3Loop61[z_] := Module[{constNH1,constNH0,ls},
constNH1 = Ftri3LoopConstNH1Pade61[z];
constNH0 = Ftri3LoopConstNH0Pade61[z];
ls = Ftri3LoopLsPade61[z];
{Mean[constNH1] + Mean[constNH0] + Mean[ls]*(Log[4*z]-I*Pi),
Sqrt[(80/Length[constNH1]*StandardDeviation[Re[constNH1]])^2 + (80/Length[constNH0]*StandardDeviation[Re[constNH0]])^2 + 
(80/Length[ls]*StandardDeviation[Re[ls*(Log[4*z]-I*Pi)]])^2] + 
I*Sqrt[(80/Length[constNH1]*StandardDeviation[Im[constNH1]])^2 + (80/Length[constNH0]*StandardDeviation[Im[constNH0]])^2 + 
(80/Length[ls]*StandardDeviation[Im[ls*(Log[4*z]-I*Pi)]])^2]}
];
(* from 20 each of [5/2], [4/3], [3/4] and [2/5] Pades for the non-logarithmic nh^0 part *)
Ftri3LoopConstNH0Pade61[z_] = {((97.078052978774181811544451222403993281712112669883451232791`49.69897000433602+ 293.2773220649261302972210659311056556206427250856317626296112`49.69897000433602 w+1281.1689103109970694473687715913326384584531416836570314898929`49.69897000433602 w^2-1201.4465343104592351820595826150342264826476772204498391545319`49.69897000433602 w^3+95.0626168242942234808933973339130507269304233800725947085873`49.5008039153738 w^4+49.2361444300731924775186885736856144953982066015906491094571`49.60766917397249 w^5)/(1+0.30762167948418385363530680905969043865538596574410664885620210191614150562868`49.52287874528033 w-0.51144656714073413583584926237332012734182099537979364024628899091693055587535`49.682753618025025 w^2)+217.5489723848904942370127936363484149632484597218558853281436`49.64306995754137 THRSub[2,1]-115.1206964557027206217039226336881674941162675229906391854350003597495986928938`50.05038914366192 THRSub[2,2])/(1+8.12847713387814828027794965232060895614776711852325143850018697780435308135794`50. z),((18.65451770724998177116136751324526611506099121554518437438639488941387459759312`49.69897000433602+ 60.424217933560366464211958040526365701380184226596706202904584688171123350569`49.69897000433602 w+68.032883669073234032123947012259714160965905589883789596375`49.69897000433602 w^2-32.2407596560171208436566968712427237778861696327964367698343`49.384558443486284 w^3-25.80889152650109807215323649911466761145852710775595355972369695678518029338221`49.69897000433602 w^4+6.26488555572024531972958612943348255572592272445499259596201137894238032892415`49.32637790180713 w^5)/(1+0.45196744294793535592957148769674027784402248864431811260857603847433208264062`49.52287874528033 w-0.43353404792701887868189909081464079757878748372090446705866047392613954876768`49.473686054307315 w^2)+26.40643952498023425866949229787153521194859928765064102073911016338300143144775`50.60369143385503 THRSub[2,1]-13.97353283587495108057797130225235516689012395115447736735662216466645463305983`51.01101061997558 THRSub[2,2])/(1+0.10802904168376568877440851132485915120827394320842555110101955305015699400329`50. z),((19.0388671854931806632919737990104432531519650163576010054782698686862639699054`49.69897000433602+ 61.36269807472694151545202366849512554235546169397671106029119337792035385885952`49.69897000433602 w+73.4753981405046910237410125854372009720238724528215783089525`49.69897000433602 w^2-37.7378075560298957858955823500520402411815110170360828458321`49.43717019250646 w^3-25.09890659860613663134510286504605910856512318878001488497017926143450973321745`49.69897000433602 w^4+6.43928887752712233135682306587222199490850746948791307662028554449615531725953`49.35952466820318 w^5)/(1+0.43771259024535669350888349528993430860419263535734021165050210375638535271603`49.52287874528033 w-0.4319841888320064106789061861091857235459721547122084227033330250477486545389`49.503367396973324 w^2)+27.34321867578530569855335257486258699325721090825473846280598869794022269293216`50.484060449499495 THRSub[2,1]-14.46924957994241985035465329644563314706981799442891971963268827860254093255107`50.89137963562005 THRSub[2,2])/(1+0.14733682127873749799087609378216619469503544689805859897906515149241118213804`50. z),((41.32028246553958999010713865138963286531723220067261656336111647240726846002113`49.69897000433602+ 127.0816723608002244890339766502888178311044160270014291052901`49.69897000433602 w+416.8256270044225642114515139071320834414696936489650689088833`49.69897000433602 w^2-363.2584139070216542159750289925171459712291397029549255605616`49.69897000433602 w^3+6.20829288660869289805142125119648129794827560484518361504701254241295732510855`48.99175851970978 w^4+18.71119070913655021575860655002610875774295557095909330860236662842174464713641`49.5559221413904 w^5)/(1+0.33843762280826490629938998221561886669194077513478726741871861410223321003949`49.52287874528033 w-0.4858077541522295542626613195816801640086605002231437054210096872316861654183`49.64694563414695 w^2)+81.6499537341575732692060677777187426649184572667284253056099`49.742573303421935 THRSub[2,1]-43.20682114196444063166131802543631433157446081951841644558654125014525290256646`50.14989248954248 THRSub[2,2])/(1+2.42607794223822534348976811895315963979494019096502406960430137191707597021205`50. z),((50.15774490155726221297370408243966958820101325365166864120973052193006074833452`49.69897000433602+ 153.4003223854065161904594940542974142774190882355178185804645`49.69897000433602 w+553.7370483545827131843329262718482159573080424569460480448686`49.69897000433602 w^2-495.3380201262819047636019729223965855097636603451692174740365`49.69897000433602 w^3+19.9088756998935448239784815420127110480939205745831393672569`49.293620951792384 w^4+23.56190654996594981120136767620472424627606872572784005668811084364169887258581`49.572947870457206 w^5)/(1+0.32852721134443891154620953216619843877121853184330983585422246657829526813674`49.52287874528033 w-0.49395949562562535465890487139607648108748150663495448660664356083626838814902`49.658631995574034 w^2)+103.1895967536439576346662718687453998425311501566555296229928`49.70672768555158 THRSub[2,1]-54.60498440896182898358948412678205231683466210273992580007782849908284815857621`50.11404687167213 THRSub[2,2])/(1+3.32989346763362702478014699614050525527213932108313178415014578681688877543571`50. z),((19.24000740238458762588102836784281904895758525749904380955605996286143147425914`49.69897000433602+ 61.8926773306544799508213044093556199183185168093117577543321009413060267094253`49.69897000433602 w+76.4171456728477474203982979147017338057662179227339709362984`49.69897000433602 w^2-40.5848191728446682080595590323715657361352584548555290336334`49.4571968254454 w^3-24.7896943864093311830485344369241966083125744419877000943461128709153327217073`49.69897000433602 w^4+6.53923410310141974181613183814759544161210772199395140512407265489899173465205`49.371255813544266 w^5)/(1+0.43249878054137174510363693755231554715224928535308723927585455573417756580624`49.52287874528033 w-0.43197831239508748814536192997354195136194716706385881929632780087577728065687`49.513489217736776 w^2)+27.8334599073684379029161006669511136689104096434588278277607679521908353841878`50.43501890264471 THRSub[2,1]-14.72867122368754726719568343985147232772570210953979380877462067648514308370129`50.84233808876525 THRSub[2,2])/(1+0.16790761884919616127857907349989672915192587908063071288119961563210868481201`50. z),((23.61081985098668379080631533883124959867624028074778826129781422601573967779003`49.69897000433602+ 74.5100916791115068880315230487690855396389950548820356719769`49.69897000433602 w+143.0329420765209386404040174161539773386769608045559571313321`49.69897000433602 w^2-102.6518016322172794613681671493269371101305517903621419926032`49.615049492548565 w^3-19.27740835561059574699173665847176815137824529478098308376784363413893083990835`49.69897000433602 w^4+8.93207962438587497367769839532318221041167225782984858310609357557963037184924`49.464849954977325 w^5)/(1+0.38776610412962949172387886210955775107094504850886628984750289783904866729883`49.52287874528033 w-0.44853947430484276539138470057608554941140782797107127519204723281670594419834`49.58487256427775 w^2)+38.48648848085566886033026190713911488173681507033590956111195395317238968076331`50.01201553321866 THRSub[2,1]-20.36594937443245864805673772456326287771307506907286676096726263301030203070561`50.419334719339204 THRSub[2,2])/(1+0.61491468430928928565074372551820525731026417587007385588053140005128426800162`50. z),((19.04750825509199607756776720180685306263099023467427449235613499040745921331737`49.69897000433602+ 61.38507518472683247503588246825836227301683683426571434975120600031951303049114`49.69897000433602 w+73.6008338540521673941813481244021018574066668022440770356038`49.69897000433602 w^2-37.860376646694287888879680035361719140152890177720273897026`49.43810978490263 w^3-25.08501618942062580285679462075799538920196043024464075643273782952739498241059`49.69897000433602 w^4+6.44349618180630466873314432288750169897817935379210390382897730386238822727768`49.360084408106836 w^5)/(1+0.43746581013935064644310987958064726695337331699988132441955456648944103444212`49.52287874528033 w-0.43197606152485988869367221863638473603403692765671090060080194951129578483321`49.503855613292004 w^2)+27.36427964841320092344535423249817616018789311371347493250251753736635231361732`50.48179770480396 THRSub[2,1]-14.48039444452338526807835777206170924433928438578023563772161338903853945923564`50.889116890924505 THRSub[2,2])/(1+0.1482205515255107889434434424008261702156498861027053588010424874575857160796`50. z),((20.06920548374001650597220568149077404990673715676551768703148745420577222888978`49.69897000433602+ 64.1928298278559120818584952956147255969828953939090473326531`49.69897000433602 w+88.8236282552349258968535526691599814456554884078377054358628`49.69897000433602 w^2-52.2719473558490956180259868129593413105886430841189199176866`49.51418770496891 w^3-23.67929544050871197115249845880611650354658983290938341058021473620180737168729`49.69897000433602 w^4+6.97608600585966797555168954630313711074301158721830885576873887894903340158788`49.403213863200385 w^5)/(1+0.41785448536757552713777547207116371416314517995528852038796268312934158424787`49.52287874528033 w-0.43411712119617413002768110610511324645544947922788501600178532699679227404907`49.53971350749262 w^2)+29.85447338201097395826342319685937376961174174914412422883719605750396447711453`50.28790827196467 THRSub[2,1]-15.79813377364426446686872136220498776448305520282661745400379854223000600963926`50.69522745808521 THRSub[2,2])/(1+0.252710479962666281977957487020575021232926298558135913156673663317171013327`50. z),((99.1019553711159690316472150008361795960241320625381246193005`49.69897000433602+ 299.3129349236155424102820671134172933709415994259512738732549`49.69897000433602 w+1312.5542667665371674715814085021868174539903923027662114945766`49.69897000433602 w^2-1231.9771605212487694142816467460845609407596908536210107937926`49.69897000433602 w^3+98.3405432141959535615649012727225754082947123828135027453468`49.50334717085152 w^4+50.3424029877902434669600598973522134638875091499155949202001`49.60837685674413 w^5)/(1+0.30718580040759137148191390122822584311448447307510928041001404107108172194586`49.52287874528033 w-0.51181434734732627847115905840578121399085306986474029910163761724728781333554`49.68324979947827 w^2)+222.4818516308215143048772736964850214787002942452858700502566`49.64188694492473 THRSub[2,1]-117.73103512151248667227448523706382089092473315378280649436862398844402811372511`50.04920613104527 THRSub[2,2])/(1+8.33546351909074449197914425215696246276631006895368853516456887555479368567775`50. z),((67.5830096218433498471971889200670226978629794336473637366029`49.69897000433602+ 205.3318271545356995423346592852168693571645031799297562834659`49.69897000433602 w+823.8306663971533947023598550297687049247290780838479971591256`49.69897000433602 w^2-757.0093998082403328974780030910129548498362220922207336952007`49.69897000433602 w^3+47.5394198220831560808081734439796213291016825287391396090123`49.432998716479204 w^4+33.1060650119141449902152858737507648802230470528828939326864`49.59205680808829 w^5)/(1+0.31713793671286776560872011363887200027571204943443712371912925642603668566207`49.52287874528033 w-0.50344624411953239727617654116516514692740850660582794593062836741417883797623`49.671854968309916 w^2)+145.6603833977052346732173343705722266654825465854605284967442`49.670273431863734 THRSub[2,1]-77.07931046018185974738283290885295488321121432247776371178268114505085665730168`50.07759261798427 THRSub[2,2])/(1+5.11199154186501533665402565440318591557844326676095771585639684254950705586095`50. z),((37.36947906767747718911250144470910115706363555573660707497223945459645803804467`49.69897000433602+ 115.3243759954795890614951323731306222636030570359225853005946`49.69897000433602 w+355.6496614843968547553248034740373378260463635208617419430854`49.69897000433602 w^2-304.4721422553015775061930948944286279336137637416638084310717`49.69897000433602 w^3+0.21182161321399518176512828830897248665543303297626626858498732400005532419301`47.66201525723471 w^4+16.53851208211859489892117195018218470024269315262358242678570457346005296838139`49.54511779742736 w^5)/(1+0.34461179160573981367537992349381072075486763708805963357040571870096049957095`49.52287874528033 w-0.48079228677093528830818476357717634356908066013522907818869890133396928754539`49.63956851377374 w^2)+72.0206177741768575162525642418615764361005794757610687336948`49.76719230357957 THRSub[2,1]-38.11125185489060165493198727316327493284450229824388983434882154905571041311733`50.174511489700116 THRSub[2,2])/(1+2.02202559410946174852146255641896806538524115450255475068793187894518410211478`50. z),((20.72698736039340138234685527340816092083733759768203189343452029509116811661332`49.69897000433602+ 66.0770454298901590869352883140308558299466137833207567517754`49.69897000433602 w+98.8109611901406033834360429349227472240928226227829435463154`49.69897000433602 w^2-61.5533646617563413956353664838449255030542075901260107705638`49.543879607243696 w^3-22.8640342256231478807352960736307976096735321556600713499172982485361795393284`49.69897000433602 w^4+7.33459789789374543499439245821963025389595471681860820774410806813177078201087`49.41991729474183 w^5)/(1+0.40994463269006598248275568820313223815504272314007140196148176307076336386778`49.52287874528033 w-0.4367198030381216261208170707493412535268074420645366576818595157838055741703`49.5525715949119 w^2)+31.45769228227554793875092707182982155104034909103797439285521644751497642401127`50.20812281573612 THRSub[2,1]-16.6465113795971488561596763537511506275958381651705254991950936460976128552659`50.615442001856664 THRSub[2,2])/(1+0.31998244595372642319732741677668163907027496506995984284393823933590313658449`50. z),((18.74457093635200860404890390500220655323313664598839661648267660167517739928568`49.69897000433602+ 60.63128661807967480860179652749419611161721049863587814158555700206350071807371`49.69897000433602 w+69.2772454858236959364720460761920520254859512086833101533323`49.69897000433602 w^2-33.5395627530596897182989806625439724662683124712499016554596`49.39926470488346 w^3-25.6214190988006416527394005963645919537855480275375631362245395493848983858785`49.69897000433602 w^4+6.30286119449952600600140069854546409702476384498513362853362868767818784932627`49.33602619476994 w^5)/(1+0.44789128594985021095217599488273428699333118199982500764766089648679806679142`49.52287874528033 w-0.43289917542641509847076415350216214405798710130474756851620817452401823399413`49.48246425056967 w^2)+26.62592723671343992801384037490557114373809134313007181197914555408211572776606`50.571755228857015 THRSub[2,1]-14.08967945776517734026644590143175077005116029973154716419089180663759436598178`50.97907441497756 THRSub[2,2])/(1+0.11723886941018230158441187682909685436927684309281320443820055258851517732068`50. z),((46.61025190376228964271101199054000042002152028693137075671953947765972881305657`49.69897000433602+ 142.833226203942012815246220426103875545245356669582769738101`49.69897000433602 w+498.7700340351864299018930098628679085911797918369134851685589`49.69897000433602 w^2-442.2433721263816861512629807180077529606718116966308253140509`49.69897000433602 w^3+14.37171644711026576740354308985609799232168391236876036004737588516746543002818`49.22272744823791 w^4+21.61598007405787193775041082592702128651563669546618517256456263067445819000524`49.56702046697027 w^5)/(1+0.33200270593171128073532354491715060872046685573956665679817100603266922806933`49.52287874528033 w-0.49108825461375178974512881489552619712306275416738149954685863107689849523777`49.65455408817536 w^2)+94.543253604822169721161693563630116276678714289026232248124`49.71882221922959 THRSub[2,1]-50.02958681376505251172536167218375679070209894311017793146680983492281895988942`50.12614140535013 THRSub[2,2])/(1+2.96708805025825408198379947215301967155004106371640778078041530944768276624941`50. z),((107.8833345570388471965107518960829271234839559312663973729915`49.69897000433602+ 325.5013036099683737485458476742961271968479160548207644596096`49.69897000433602 w+1448.7333544153333121715325591825775117890451644791876595455545`49.69897000433602 w^2-1364.4756029957713233427345862665560290796564072758243299630978`49.69897000433602 w^3+112.5784096345808203008814649098515661993979533956143344463901`49.51287707556498 w^4+55.1417642720043234164835691182974891716180027971236284506506`49.611121181363416 w^5)/(1+0.30549178238354416243741184985486266656998494314151579407287088568907663032015`49.52287874528033 w-0.51324471328264724668486602714397081964133944489403737807891037830921256939039`49.68517576886853 w^2)+243.8848023367438714004298303875652443804182396036397899942282`49.63733845497512 THRSub[2,1]-129.0568647242083421295725662632630797237775259684488237392262`50.04465764109567 THRSub[2,2])/(1+9.23354335819414883092810068061747499266064795798017239206568738686602031860953`50. z),((24.54228258582565552726348439769206476925042604454107539134617296356952728209248`49.69897000433602+ 77.2568760603751339489104658330126769543770034924824655994931`49.69897000433602 w+157.3775962323756200034499053040549091705112497688830827573084`49.69897000433602 w^2-116.0621870348868970669465304761210097874397282752003782929274`49.62858566600467 w^3-18.07363348665372741769172093275231001077820877550091473192970062505742679539288`49.69897000433602 w^4+9.44956650959841351705049028560920275760190670014507911824251261194097327269944`49.47483480599545 w^5)/(1+0.3826515025035945623222496882839974880796352980797253629196963629015358372321`49.52287874528033 w-0.45193419832471829207277135932172438257557849540008814716935589478602333588598`49.59176388473322 w^2)+40.75675270428436734110647223123121169492917571291279736496856843603247107062001`49.97435554152092 THRSub[2,1]-21.56730829456187773859154226555281160711149686585184932535307253588205767514605`50.38167472764147 THRSub[2,2])/(1+0.71017624690938852055016496668826099539235410383010667551342215441181894971653`50. z),((19.70091338463095176253064489963197974990256011716866192645201631558525899871306`49.69897000433602+ 63.15573434972946262871329381076922706383773846094957317069960999599212444967082`49.69897000433602 w+83.2756245871345494475991214682062832995980411204272640445099`49.69897000433602 w^2-47.0837814612645091918037834321353092470797780188771698060728`49.492595462286275 w^3-24.15254811054560190823987707792394168209823585628262332120832965320936713617541`49.69897000433602 w^4+6.77881881744962486191222479737698526450549458472951732612310276748038986648892`49.39122962410861 w^5)/(1+0.423421287063745844596241055353872513933947950921761326506657594296827087588`49.52287874528033 w-0.43290007352042079364580666800653949408917986775819512998940644843947826537495`49.53012785751734 w^2)+28.95683105547891799735588277034899755554558383482260378245474287994654734573039`50.34474398762998 THRSub[2,1]-15.32312711805932310275820708855801815602513744412461048122853954359740233921694`50.75206317375053 THRSub[2,2])/(1+0.21504490350730186518658582031505153227843342855322765843588466897042065455391`50. z),((25.34660860835853209179083407186748232282809820631789461901339653323173667553327`49.69897000433602+ 79.6329055414723594180111258442663683533619545660943301193918`49.69897000433602 w+169.7761867798114082458186220364813959650137690244695102514108`49.69897000433602 w^2-127.6870488570449448915526798454865602351478009183661640348312`49.638367059174996 w^3-17.01511277342511112652417504938890047047386926112103712324897471598766980013017`49.69897000433602 w^4+9.8962215891663530286139204349526310271167364957368020723836767021166636541929`49.48245398706354 w^5)/(1+0.37870148626072660285833021995789133209002241125723473438480217779419279062844`49.52287874528033 w-0.45467049451574837380389583602497173895875398751161766283641857486249891524719`49.59698541393765 w^2)+42.717145240272158044899522650698001869273734744987163133587779084752267939664`49.94716045217175 THRSub[2,1]-22.60469197693660579401293154836465994404895633040455590445721102603569995885481`50.3544796382923 THRSub[2,2])/(1+0.79243541937070067419596632252062997254211139307784640462622382546145788304429`50. z),((64.001910280223441006903555135998640473727180958752530541185`49.69897000433602+ 194.6568437897823084248730977698640903181292167924583877359761`49.69897000433602 w+768.314120771417490043928095022368329139613094675416452385538`49.69897000433602 w^2-703.1487195601003212112537217991689557519840727910464023426302`49.69897000433602 w^3+41.8192322607630230560253374572053734827960652483472637640428`49.416659993298474 w^4+31.1460065124464428464199930562948564674749296387971474589529272889623347861984`49.58907445876769 w^5)/(1+0.3189341313850550996483523116890469168332553223291874121186724112722631904126`49.52287874528033 w-0.50194308423296622490607207413820441486859605319847747865547884968126474066785`49.66978311447559 w^2)+136.9321311426869584388056689654660765652749123586658311294881`49.67572269638281 THRSub[2,1]-72.46056890776922856818812946733433547220752924741640533176094753150187586378145`50.08304188250336 THRSub[2,2])/(1+4.74574917236445289684220005404099178040093033987115189841859949966945646759824`50. z),((19.31028467559996543972569966928901067741057623342585508599380963538300425215757`49.69897000433602+ 69.3404230665438062335317820194287350590604537458751072378016`49.69897000433602 w+101.6994443760010310791456162324133926827363590705529399675013`49.69897000433602 w^2-8.44044582902665928846165154147979353502638715460720388418253280498773372372301`49.41396749187253 w^3-33.2160212364669753766170160119598276378181140888526848844059`49.148884582044424 w^4)/(1+0.8068014592925505510422642715488380907496377485615627372262941357709738816229`49.52287874528033 w-0.22301853588338542409746185302437959729194291230331681661873625794258910061536`49.269773686507186 w^2-0.08515610240630857521979130385589581592782806537051496059120830391576258716111`48.79808937675451 w^3)+28.00474746738937456745877646540246903807012960926427395362849819950428778340352`50.41948017193348 THRSub[2,1]-14.81931170333514381614569303873567427642119876873829404109869929896104752469414`50.826799358054025 THRSub[2,2])/(1+0.17509494112347732495788035573300333708458943688529303857706686930492169420856`50. z),((31.96561139184163736403944102616497346753063967799583265277216448217402998039098`49.69897000433602+ 133.3364675072618200182127496414295747731186934710162680230661`49.69897000433602 w+385.5637046790317434970387729172020967342699348634333310290934`49.69897000433602 w^2+94.3433322492648118036330777420522325749765923545819712657972`49.0240522321256 w^3-164.415437611088694116055146101974176406431403094172353876712`49.35092421178131 w^4)/(1+1.42209930465475208714003726197473144946896478149813859365108684135348202025153`49.52287874528033 w+0.14928477626810031304177550080972466329910444266396445170999016812006179080186`49.04681000480979 w^2-0.26474300522004867726921065737456230693380627216575090798083309646600409091757`49.29942128477938 w^3)+58.8497124939846374318657218771092202786607436898562546980738`49.81813617112469 THRSub[2,1]-31.14158533711334289390367370196227827975150955436097004639081158115003400190241`50.22545535724524 THRSub[2,2])/(1+1.46936700710406505094710254379638316568125671866317087188464348949931440215909`50. z),((21.11686862016251611708449182979056588423013839111216565852943895886942290891474`49.69897000433602+ 76.4046225869994616531212851796986125874055007415252052202991`49.69897000433602 w+135.6064831957946011113122835180136695915782284428805793053612`49.69897000433602 w^2-15.19992839151446094422825295895746534035390430731678737464785445632481758380484`49.10904627145851 w^3-39.6952543531474380135970598909442733412324939612177165781348`49.15377391339916 w^4)/(1+0.841669221841673607739236072953829392298935304616026359270597181731416851991`49.52287874528033 w-0.18712388137425421506868232556396039693855499168708538873500067335853166445445`49.51500691294027 w^2-0.10225218893611584538873264075218495501454249103477614856969326585891802472695`48.88067952628889 w^3)+32.40795410417457531905141039906851837154575419280491714309726848395687750974893`50.17004501764239 THRSub[2,1]-17.14936276773764649076310755844440219332594977394837841008989294403091115904825`50.57736420376293 THRSub[2,2])/(1+0.35985596600444733408003601476136140117229322714642495543513873056948863477109`50. z),((44.825525615610404475042537041087479573413408813171946336159922104809192794014`49.69897000433602+ 290.3309639754346918119310645029145522780143715434919881274833`49.66638927778729 w+977.2464369197126157045135228218632990344514648943150382318315`49.673003361396745 w^2+1328.3811439762073091798226742209993074140031641726124346184634`49.41494638077579 w^3-930.676117522369551435861143925953924358694100387183826243283`49.46795777778374 w^4)/(1+3.74304342087456567463965958386286174437600567660262660779350597243916304851227`49.52287874528033 w+1.48164570472065242060335432565329172675383068426650943936103707717324327879891`49.43012157698613 w^2-0.86891239369813053852097879564053586483307275870997513811387373358593126437991`49.45889921597137 w^3)+90.1933208710082021133771955583738374907208156638802082978268`49.72593952845361 THRSub[2,1]-47.72772677571275218120640737066042252082787541845877858420228767407163842622867`50.133258714574154 THRSub[2,2])/(1+2.7845624282834626392534180245005217103304355590520709414212365466869807297103`50. z),((18.94604643227276965748479495975666381209957026274734417004596959799978288231433`49.69897000433602+ 68.1133096171161165574591406531648267024718121211406361208359`49.69897000433602 w+95.4052901116549234274381923544684683064226729057155050405386`49.69897000433602 w^2-6.33206272513170947720553608692114169252067784191218378084518925795005802620146`49.49030274480751 w^3-32.431568340675293612645528526213567038970564901415850565118`49.17243510428204 w^4)/(1+0.80937190630747754988845144025233199245543867672341586945157743125646299320442`49.52287874528033 w-0.2313884249498172088525905484829404747374041420220035848126800457367985532272`49.254305056261366 w^2-0.08225761751071423864368020409559144993713995491583073209120497945567065627294`48.81224935134973 w^3)+27.1169856475102312615403157668272567507395682218130905831285671251221587226467`50.50937579158446 THRSub[2,1]-14.34953352938699968843447482468710380319224621269932072128519934558788012039008`50.916694977705006 THRSub[2,2])/(1+0.1378439562796635787831614099319999436592918802129231112335776425163972167716`50. z),((28.75969902165580515505177390477271571467391030298813330322570806378943021007609`49.69897000433602+ 113.5296213847915416949261970521421103633476398675738119139493`49.69897000433602 w+301.8826454547239456604850839675344980963792264499927239024872`49.69897000433602 w^2+26.1139603000270659299037415086917048510564799964136609516359`48.67168591679332 w^3-107.4297900008945149600908910370368827812852482996603174732377`49.305659799096226 w^4)/(1+1.19243968906269898756746829096295684470047711425463038639332332228662959953978`49.52287874528033 w+0.01802871717093871043439144901014955438352607915014658808740040047651317687234`48.328111583538536 w^2-0.20332725471757207164696266554488895505838365562984938533838220521017988092848`49.2243678152107 w^3)+51.035907512576937921520318914484455753363611994576849615415`49.865923801295125 THRSub[2,1]-27.00674313782576290869979195972878329303820619520387700114827360275953060446022`50.273242987415664 THRSub[2,2])/(1+1.14149535908189616713542782963570799341214165211089510201263187951075209801107`50. z),((21.77549942130963678625445409853715334104816195175951205609760396242923790485129`49.69897000433602+ 79.1772772469527653467889980460142219695264619555120042807056`49.69897000433602 w+148.5522021609725824187038679761977321220571059289465693180191`49.69897000433602 w^2-16.3448862871205593125425749867785074567224222203581643200059`49.03532723208131 w^3-42.8647794265596859718403236778892307946608924688493614821274`49.168554609446375 w^4)/(1+0.86199990917333845748903768834048139407472168212129424784119074396339210200187`49.52287874528033 w-0.17370830881774250106880979467525883048476392204961302187573113374166814180175`49.65896928392289 w^2-0.10914687174571514847484650664194323068642266668781128397426437922584234327208`48.92297678707772 w^3)+34.01324209731257903805766995719687661111555244750536322228525960427371913716683`50.116523898938965 THRSub[2,1]-17.99883527848373461079851036017836954482509822201445303153145673546356036016096`50.52384308505951 THRSub[2,2])/(1+0.42721475229521248743633252367000736581545472476509785843466499637364466347229`50. z),((19.42256821985030756016943718609186832230002885173415011754894316089601058291952`49.69897000433602+ 69.7419607320477856564656573482734538271049912989526510612443`49.69897000433602 w+103.7018366594220888921370050639204704801743633843539805588761`49.69897000433602 w^2-9.02699455476722890053497851453725076714747867507034991567900173855305339297974`49.38715523679795 w^3-33.5071937752715585776233660712585108937299536123977102090476`49.144781088790154 w^4)/(1+0.80722587996865338739059116728028130961864005033022263553609520657666312836071`49.52287874528033 w-0.2206391654876515054752219612143998557609887267598306552230589860563243672485`49.27820453692979 w^2-0.0861095100568487497517282069122930559805716549614627131533947891488107704644`48.79792185353507 w^3)+28.2784173672758079685248072806266852064131490739253895614180049164422909620184`50.39611611548403 THRSub[2,1]-14.96412999012598863816305438343250130145370905360197019060405972678095901595062`50.80343530160457 THRSub[2,2])/(1+0.18657828391272387616135673035171163380119985494456799413659841786622373107864`50. z),((20.7878217304777514860768073294150133974919087150204354823227766475592759749817`49.69897000433602+ 75.0506681868588765009347073151326098756413463196255221484391`49.69897000433602 w+129.2351933404051420583215554958333404196737561723094521802728`49.69897000433602 w^2-14.36551156691419183933041275770495722380529243901607222143393225720739728809062`49.149108207027396 w^3-38.2662414501395118510547621895461202100438583708628860298249`49.147190456825605 w^4)/(1+0.83253250803744116424741308563490129163681009941312703642622737961635215058756`49.52287874528033 w-0.19364779645739587163179680896835408249383154226481427613710826723014892345801`49.45606762239533 w^2-0.09892318244158323662809496542407328640669479477209232633999381364342111862675`48.85961100239 w^3)+31.60596455210628589187042083881310758402555985500096886808788396039732317753219`50.201801831324616 THRSub[2,1]-16.72497282568379534855732403579164431878753355439823732344442562799082849352564`50.60912101744516 THRSub[2,2])/(1+0.32620403371808263552992019715263067080321056146767654901471930180646047333941`50. z),((20.93279621289984848163169627535985283054379403945589108101359762301132748653315`49.69897000433602+ 75.6444693878874285725382610021530998347729102879837702834434`49.69897000433602 w+132.0339955025494357836075125721266756992826668568170236916401`49.69897000433602 w^2-14.75443684539586640941996300942850955383962668984205875990085012226488385602482`49.1310394276634 w^3-38.8831626036837544770897448691022078993643317418862205431078`49.14998526908504 w^4)/(1+0.83646272079736644942893856113849050690549202540040290883952179486486712698066`49.52287874528033 w-0.19078539763314284756048453340967023715084428109031803823009285885686509675836`49.4812056156889 w^2-0.10038013110337046870008517170639244169596333675000862643601909236402720512967`48.86883680487079 w^3)+31.95931243006500909213238530794185943586098481007107211561417364271082331002828`50.187326048829654 THRSub[2,1]-16.91195442047517604496769976745699050192267456816947657446130709523341816961`50.5946452349502 THRSub[2,2])/(1+0.34103070924263498695312279643074360799278798412566020523179905436702132822474`50. z),((31.4766607023169388919642946389472114852748933085944451502011029476464043072052`49.69897000433602+ 130.0897825932861187783237384559812103458716143267162945435567`49.69897000433602 w+372.0556227426500093054735996304890094783178051273507481910189`49.69897000433602 w^2+81.1582088606275827155124804368384220061832521148849274988681`48.98862459900102 w^3-154.1678477373699624358772372418597543601659334986273500004751`49.34457583062929 w^4)/(1+1.38292130992093167015221951974193850905906974757831138749669680944929151004103`49.52287874528033 w+0.12687875901704132793915162846516178346840859713845036998239998462697729583927`49.00274276267415 w^2-0.25434345183693506846844136724146216495906278017366529523339187980838998428874`49.28946283725819 w^3)+57.6579876767372597235874288986999026227651717384938103150681`49.82428855021869 THRSub[2,1]-30.51095863526737441719966582356345275463259180938682495571614065755058448934859`50.231607736339235 THRSub[2,2])/(1+1.41936156407732814302937114042272682074233675108927405215269806600891699564443`50. z),((28.09900133343520799567337479082330184725317077004168741389018811209148868710325`49.69897000433602+ 109.8301348283565757303546448781449089871192052469521117673098`49.69897000433602 w+285.8991190156554201904340353407899921217430865918694273836087`49.69897000433602 w^2+16.7425230722754365454959787509887079582771015700697076245773`48.5244572211079 w^3-98.3130094111888676816338600018959939526164995737727869423093`49.29516926469712 w^4)/(1+1.15220773254824930458951984078803691198876274343478074938543955866724071319684`49.52287874528033 w-0.0049519793936324230550643203167589466596280790775301996663347509470198386628`47.813895522146005 w^2-0.19241303806128368416547338220549994456549748544262724156498257439684187290269`49.20550192706527 w^3)+49.42558187316359273892644671068822372866496007525346249450693254270949709473952`49.878499871099926 THRSub[2,1]-26.1546048486971929202604891284148262696158147170207003127113562526123281335389`50.28581905722047 THRSub[2,2])/(1+1.07392519032249005936583555438094259360447183745085684152735896715632393398908`50. z),((18.62432066793537150919685718357162609574175023083287762586667544914764771068647`49.69897000433602+ 67.197576164412221753822143445164671062636975700978038884451`49.69897000433602 w+90.2875333433512369966147332479272159585734128780917347473223`49.69897000433602 w^2-4.10365140511375662596523722346655729622737292721420465837108636269422933239153`49.45005111282982 w^3-32.0495672476303084899659592591336673833997084751014733374015`49.21280101487539 w^4)/(1+0.82075480714201615267903193639878384620375313749203487840035265924831758487336`49.52287874528033 w-0.24050748857800535611239744932794892424158588634191927523480658514879282372637`49.26271676617966 w^2-0.08011271695980185472847094293234681642196319735271248189711372393752757230314`48.85237778258936 w^3)+26.33283995363368848947537700909788789010843600246370029149953631621132078871117`50.61507559460921 THRSub[2,1]-13.93458604693188366769471400368916638890647011923332118299988799331917870120104`51.022394780729755 THRSub[2,2])/(1+0.10494076231045967731093067980921620837628315111529724386845274603556326869218`50. z),((22.09249547706635787230018514091013675611548099325014053200748954600760256029335`49.69897000433602+ 80.5394320695572448021014364767856739128515986808974334145971`49.69897000433602 w+154.8698161025514794832822241119300977480472435143710341296383`49.69897000433602 w^2-16.6399012358894108757712956428176834232817092077003066942443`49.00069245351198 w^3-44.5388301127874222799487617957368144214249610637298687198121`49.17594495736195 w^4)/(1+0.8726061605508293922765319065264224126043319989411526959669922588378017029978`49.52287874528033 w-0.16704529300030842057295823544951383737357776294452777653006525816831381369363`49.69897000433602 w^2-0.1125724325012137684378975604415091126390269548205315044913472351277259367303`48.94277940538137 w^3)+34.78586002118143475091337953952385175100991455276870852995461689370599196612277`50.0945124863043 THRSub[2,1]-18.40768259463000592812121833482548217624722354377789372921844506789635869705785`50.50183167242485 THRSub[2,2])/(1+0.45963423455681244947275086099152345310913998547954209462133434566607785417681`50. z),((30.7318033953371030055938825777909769840641393319401610880141581722539317713444`49.69897000433602+ 125.3121545634153224258284469551185216912785114639605901862014`49.69897000433602 w+352.0332796802724152680127235736314720777600336382048493325762`49.69897000433602 w^2+63.1466269854238043790144166868033589198520077320009779446089`48.9260848736361 w^3-139.7184647453945781915868871118907158930157588295183215985023`49.33453924412704 w^4)/(1+1.32631878993832619903535187412651360918376101555653534085340380504866027524182`49.52287874528033 w+0.09451933347973439102605682484133916696737180447043251590299224999776083949344`48.917368982348854 w^2-0.23927188933903318463030005868545711713530106519541006813556070676911138250996`49.27336163266373 w^3)+55.8425388859833200531382466925921072640702747589024370833835`49.83435165407824 THRSub[2,1]-29.55027503892521901276709423833270173875830137144510813477487940729817346550019`50.241670840198786 THRSub[2,2])/(1+1.34318431261780769362445213654203128830315219612989034110892964749572829877995`50. z),((18.69399275617136697636394607907852149900661336147041685105545841950784309521364`49.69897000433602+ 67.3747860625484025120712942144359862244767905436517652852843`49.69897000433602 w+91.3408249151214035376313750244072754301877275403186503159061`49.69897000433602 w^2-4.62670504588324970582099729906188935206892714854204727951207036584085102000014`49.47924983390771 w^3-32.0960016003961658154008198477215784967777732241299224840972`49.20197998429202 w^4)/(1+0.81712787131855765171332276900034446979821803699335411808427404625133103716878`49.52287874528033 w-0.23829946817780623497087410163762920109029685304078773528169684796168223678729`49.25856531321218 w^2-0.08052615070553721271957886577346971531259734696674163759252065683852222381235`48.840602204056836 w^3)+26.50265248974238491101958197133917475719912312395749424139144974260611238228563`50.58933683778235 THRSub[2,1]-14.0244459860960920005397090938891555934506528972169439940992997975101182689807`50.99665602390289 THRSub[2,2])/(1+0.11206619175248702282955636755271375760385697707881519075747658491183350799949`50. z),((19.33947727223183725466802731019132502547139085680477355516523613873172977689985`49.69897000433602+ 69.443984020802543898233620435946152212332616838357577733075`49.69897000433602 w+102.2177948808118627347564283789126226588466582970903088278563`49.69897000433602 w^2-8.59550776257374840709073995931633712355026376865088911751861611350792368395403`49.40695949820638 w^3-33.2898077822162281000451192417590792429475370593092136839415`49.1477014445709 w^4)/(1+0.80686911208220312972403816983653058126771868206409421663003479003015852843072`49.52287874528033 w-0.22239355165356643439591087266249983844735365854152496969243226645244787352408`49.27182715725458 w^2-0.08540177289987110852154401207430494004777867136721709031323899760146377014851`48.79789506511747 w^3)+28.07589889969415817901599459020397295579898296271690302579817342325806495069481`50.41323942488817 THRSub[2,1]-14.85696300708966510093731175983002345682418629764489740405055073085759572485699`50.82055861100872 THRSub[2,2])/(1+0.17808049520684842360784752264250851430628140134138222261096623048010097545876`50. z),((29.40749359248595144086761839426713427273671602684377795662238452851086883393098`49.69897000433602+ 117.2717901089610905415329066503852130340196437362512381946741`49.69897000433602 w+317.9331867534427625865290228628316672248215561007506632261527`49.69897000433602 w^2+36.7067697778245530011346701801184991988630538743970741828843`48.77601745887425 w^3-117.1555158964738769227430155157791950099571169052712082963596`49.31553463230367 w^4)/(1+1.23403900133513952347128978514334555066312268909835940658244571603443660367922`49.52287874528033 w+0.04179074355432911060181383467807080715600403157024112791853558331243263839852`48.646767455755565 w^2-0.21455031862801711974810260990881910260096493629372077728853190974222320486489`49.2415893259235 w^3)+52.614784244066655381160800122453497218643598497712455790892`49.85465432667352 THRSub[2,1]-27.84223956400618715109745541694782327961059714154555587765653757884980246809724`50.26197351279406 THRSub[2,2])/(1+1.20774591399197382044960394033622535688779551979712195877651335439868129476151`50. z),((20.89789549481030825157768034134488738550223943362191114870749126446017092289298`49.69897000433602+ 75.5011169546281468197048918620885047910050284033285211134992`49.69897000433602 w+131.3590016412437314256042111599139530787678596327756946223668`49.69897000433602 w^2-14.66386708907027243296542990849855881228115945217400150350980566654208476771074`49.13532233465734 w^3-38.7328169395726047507317246768435695154006068916206766805146`49.14929522296238 w^4)/(1+0.83550229511705046183429595345792388617265072319981668061546564969338418275267`49.52287874528033 w-0.19147607954569465400122516845849908269042458118973147951681747798359221451322`49.47503997680879 w^2-0.1000279663887113967977828307761679781720831631095884303843983329056639735679`48.86660503827895 w^3)+31.87424853143856358916783960119026894632310842538335168684478100091958080012531`50.190737985828584 THRSub[2,1]-16.86694103730097985965586019391208314841775927224828654508024031348926756089627`50.59805717194913 THRSub[2,2])/(1+0.33746138025423491397674812910597810423171886295367613210266250149157697426621`50. z),((18.59752237264243686136769925129468594955960667709452409190906599673502789578578`49.69897000433602+ 67.1336779465306859779559048383497460114229597995024648868823`49.69897000433602 w+89.8934719288010557819845471798807880508054440117458386359668`49.69897000433602 w^2-3.89479368459552550830814726054208538481540423937673085338245843331462332251995`49.43396964153192 w^3-32.0387882645334120840891058804322548117984568790414080175169`49.21732523445593 w^4)/(1+0.82238630403468359784617641986257524100062252973732486364750947265026605757309`49.52287874528033 w-0.24140546774750478995762966183365817759308297841043997003046161383442800612985`49.26471975696588 w^2-0.07996391629038586969471530885974060587272920878066014272650370008903983250134`48.85746620943316 w^3)+26.26752417794359079591123812437142038766949638716017193285464383690940605959634`50.62549003307603 THRSub[2,1]-13.90002280581629043695685908514699693052692860947522472138368067854339334785729`51.032809219196565 THRSub[2,2])/(1+0.10220007565801386944875925303932628422750758578108812040446369798479223508063`50. z),((18.88577034635619707916913554173973822055905782380269922501238895757777120384737`49.69897000433602+ 49.61357754647432082518963589173599970247228711312682881974431282781932468605747`49.69897000433602 w+39.01995291588659651093349684509502768854394780601665642419607592092246167054699`49.69897000433602 w^2-68.777738845571303665646703090940640074943080548740864358722`49.69897000433602 w^3)/(1-0.15899996418950168108749020624355841869632919552527134802145614601956561550553`49.52287874528033 w-0.46412288923973230549779881329235024114375257767829481263994457165642435850217`49.69897000433602 w^2+0.11830766572664723976686176698158460628254332081012455119955174258639758803568`49.69897000433602 w^3-0.09189426535160837528262861899041533679423233451361859715040782310174169570514`49.69897000433602 w^4)+26.97007408973506587412910029320060151663284317210440560962483206468087038075829`50.52688619663315 THRSub[2,1]-14.27179213321737162377783874698249110572733074307154401847630550426042343208967`50.934205382753696 THRSub[2,2])/(1+0.13167946475781735494751711000978841586850208142388579905473978525931594636568`50. z),((80.2492448458015557677065443187160872843622164718697204727922`49.69897000433602+ 261.8306988183554218416235014909694004341622261684143456438588`49.69897000433602 w+1087.6843147871484730017897344176398361119060908776731934452379`49.69897000433602 w^2-672.2590528380853853956567518228770645136411630775156039135623`49.518413552077014 w^3)/(1+0.5456158908908607959213610044053333091729936826854795367141230432520188216013`49.52287874528033 w-0.30123198558021730333684350238209391862356431667502642215490462287037393450326`49.30819346875975 w^2-0.01682065051163293351354763021817105385482698612002465954940518595520288501298`48.71728638642489 w^3-0.01699496660149715600393188856598869051961932545467925984738189603402150452604`48.97595536877788 w^4)+176.5319358484384308115225023492550931924021422713871987923537`49.65566496423758 THRSub[2,1]-93.41565339867875406383838655979629677152573559307373391843711855106533594180042`50.062984150358126 THRSub[2,2])/(1+6.4073792311033514423615689974939538940087107419998522322360967112187840785294`50. z),((18.8850365654474170034883038808150446022523203644867599176155454947730923896961`49.69897000433602+ 49.60827232692840886260579266024658210472370406710511093810713161948680121301612`49.69897000433602 w+39.00022118693588754550820034312060477429349136214327735911401933932689524633489`49.69897000433602 w^2-68.7708884138537523850803343133063829683538618601417362106545`49.69897000433602 w^3)/(1-0.15918231490530591307154924341081750537494764104896080628841048217233452861223`49.52287874528033 w-0.46410123669427510860979491657812254859690708549174400495613977218958570181397`49.69897000433602 w^2+0.11831143049133259879149204591400512458912058802284095450569924091739835244206`49.69897000433602 w^3-0.09190849429554506473581948241726903046160872797049759976659962424761527371616`49.69897000433602 w^4)+26.96828563756974506341427108614926678220070063862872298533763314778842599692567`50.527104972609926 THRSub[2,1]-14.2708457354633745062417783271692600072009350674837943690058842935940910649297`50.93442415873047 THRSub[2,2])/(1+0.13160442029993188176804657138677400918416009241143793973312700289729325246168`50. z),((100.2234368397473811077989711683530140942217960686650287879639`49.69897000433602+ 327.4964703163451888198441321041636658534438026456825346803725`49.69897000433602 w+1418.9893628519026307894025702366324040979856456222370003765077`49.69897000433602 w^2-870.4042174838243198528238020121450674258880363204312838934072`49.512993478017485 w^3)/(1+0.55478900747857437745086397441755796841477104471857496125359648999790150594438`49.52287874528033 w-0.29590917529951100304613123857025396541397565907552713256615509967032820391942`49.29357808091626 w^2-0.01904138308348047318016755128503562569320989362005972752625604645316293832834`48.748740510837514 w^3-0.01685231470869799039474620303313332728426113131962261053263230815006124900231`48.96116106886414 w^4)+225.2152505744865268378227043265301415115949587152378722978171`49.641255051556 THRSub[2,1]-119.17747169455811191812495503950243891335576897184858868959232012826004501943683`50.04857423767655 THRSub[2,2])/(1+8.45015847481256584586988866914667244009897731064648904488332285112907901182421`50. z),((20.70240620642981230734860330443596965071896517258592551586788526994007223948357`49.69897000433602+ 60.16291363646409233485666351944173697669811021470438716103488393901788133999051`49.69897000433602 w+81.9935603519679684440703703964483132889294322148614068358997`49.69897000433602 w^2-83.6431267389206941023957384314225793346287625043726569512605`49.69897000433602 w^3)/(1+0.1279587225294246343093658151657499937896965211653103244050732000398808104236`49.52287874528033 w-0.44674909521221691321096271808812140139782563579462243271053966476215849148264`49.69897000433602 w^2+0.08797963011120479168803924067222218481666712383860564952115514080876886522899`49.69897000433602 w^3-0.05871681340059206264228610438351205739226354803167065703752605136439176870027`49.69897000433602 w^4)+31.39778036918782109981071155194888157847281737789647951895825694577338085227072`50.21072040538673 THRSub[2,1]-16.61480770807416780182126459868783952749624654649451933607560289526794008597828`50.61803959150728 THRSub[2,2])/(1+0.31746850841280060924747173312238937024693712725882673291022528068119731584857`50. z),((101.6011185127099300290094137708772371042614569534222684020952`49.69897000433602+ 332.0235882618761621495328092523923375155789166572889448207305`49.69897000433602 w+1441.8339033932815740744142995829328563360092047511179145970761`49.69897000433602 w^2-884.0682679905796439236734703678884266668623695904604617804205`49.51271169201909 w^3)/(1+0.55526853522296816677713678447742575800477087284302918873197659237841838169527`49.52287874528033 w-0.29562703112572136696076476683067850271112927773133754263009164907861498953826`49.29280605790523 w^2-0.01915542754903331787975558815368376606435780677012564661357260481690789869679`48.750179552762816 w^3-0.01684588527067578466052537546949695948794444246415109860562096340806746757189`48.96040497803902 w^4)+228.5730890541343231337620908477030447698108231423325410480274`49.6405006945495 THRSub[2,1]-120.95434381730439216953761191102291306308466055445963502617376555752674652442735`50.04781988067004 THRSub[2,2])/(1+8.59105526437078650939114260236370418046016710041014496213064452261533700292403`50. z),((90.7427915440977431464605390951078922813683423301817717401185`49.69897000433602+ 296.3364901942814084713565269705872461900402283681368969454315`49.69897000433602 w+1261.7626107628392503467683753965310847070107148059017824466872`49.69897000433602 w^2-776.3656667425155340783059484500092477045794842179142120749201`49.515210054460816 w^3)/(1+0.5510259582911333908620346595142108922021801836945681964312125889356783870791`49.52287874528033 w-0.29810979311572250491991428449718425177518110956121937387649675713587741676255`49.299608508119675 w^2-0.01813925589785888810584146707668177297364758643334199278479494908323574654777`48.73677701916642 w^3-0.01690627644391380091069834557261132016587799037305340950074382266145942473782`48.967153714226676 w^4)+202.1079709972183133680925967499160000526178882655241044380098`49.64717120669378 THRSub[2,1]-106.94975997994967571914344856656182059787381803966243899739031709221320263961385`50.05449039281433 THRSub[2,2])/(1+7.48056403851233488319809066038465785990970461584802476440138935368334601182453`50. z),((18.60062774990199622646988552729080066725590930275430266955490291079888814096773`49.69897000433602+ 47.48716748908389020738284151863830355672338730453643877216557096000089111279069`49.69897000433602 w+31.29495017716330913664653776674228084166679868356912011049043636581989718121741`49.69897000433602 w^2-65.7404290698682074714134439496918011042661916345879041145064`49.69897000433602 w^3)/(1-0.23442942762157278436709926431750969513201195428410529657485937210148289474676`49.52287874528033 w-0.4488497882628048532589236685550108068352997466986107645561091953253096171368`49.69897000433602 w^2+0.11738052473220301561599765902359687201892019432694149206762577294187669620033`49.69897000433602 w^3-0.09632160977176649414678321562711519568443995021597715136591510210060393428875`49.69897000433602 w^4)+26.2750929476097712338071234823335274481866955768249931369527757170946875136925`50.624267662764424 THRSub[2,1]-13.90402798233232533797231136339346702524090952189221785464993941568865971368223`51.03158684888497 THRSub[2,2])/(1+0.10251766548651042224697705409271923444673980440622238814626380000951689649139`50. z),((112.4940904194808612923038562849240988856491000486254898417441`49.69897000433602+ 367.8120791247135657021864105584660553675221573808042372563476`49.69897000433602 w+1622.4396214847314866598850882521154804747360693161276861671104`49.69897000433602 w^2-992.0979549833506277959157732548041016361795114541088704702113`49.510763514293245 w^3)/(1+0.55859084281865359490767418348127561964125457883028327849675377788235093785623`49.52287874528033 w-0.29366152737141766583774852225271403032037976828968983301347296232424578048029`49.28743473255742 w^2-0.01993975310741133747076780371848750548562407831775225209285774526840484573639`48.75965461005608 w^3-0.01680407183709436038143587718028888515208571896619264889291334974512955290816`48.955213020112204 w^4)+255.1226475944780401806931086275241519803951842474630994368454`49.63527157098621 THRSub[2,1]-135.0036111443335881458872810018037176196478653109591183913034`50.04259075710676 THRSub[2,2])/(1+9.70508966036556822192440205977837436191609303003614914857302330614532719557834`50. z),((19.70689816484311220230341189759200629492466982970564286373649764180945822966173`49.69897000433602+ 54.93340686271623850438566278235079439223396424908757160243076706306751010173336`49.69897000433602 w+59.82251003426842397865626155034027226874074734570124638103344938054878719808347`49.69897000433602 w^2-75.514242197966027581474357757947699016417579391329749535182`49.69897000433602 w^3)/(1+0.00524305346611491211708034207701092609770267566860497450079571392203813955921`49.52287874528033 w-0.46435953012179719212367693158647964343198035268696900095707073391554168203016`49.69897000433602 w^2+0.10625692982799230721233618805648563003311494793420662429054388874709466494943`49.69897000433602 w^3-0.07479642481833406147833723773086827493243796127180673168660580878116234756388`49.69897000433602 w^4)+28.97141782518270088066456521975841366933251180563320295079437671285921518785006`50.343728355062794 THRSub[2,1]-15.33084601955046643111457110710873423593201018668471212903189058061634769102488`50.75104754118334 THRSub[2,2])/(1+0.21565697256117240712579980501934555888430852932384770410390775136312170443544`50. z),((19.64342880999897726848302846157380387411777180265493899659987879974815561292486`49.69897000433602+ 54.56202858741789078162355578931165620888956118027803149242533585857892145691243`49.69897000433602 w+58.30846331692936378248658456294790606406660687236652438151348396491591311868111`49.69897000433602 w^2-75.0135721099088327575183060071071080059666543246364758940149`49.69897000433602 w^3)/(1-0.00493537649945465287799662108512430095686373335484210019179592968252205079587`49.52287874528033 w-0.46524506401486784267582291943223231967302673161499844297132171514947735635825`49.69897000433602 w^2+0.10744451708612727208313277794012683115355078465708989206724978953079711819696`49.69897000433602 w^3-0.0760429776533950249516585182712924519279455470126460857941742597559718920991`49.69897000433602 w^4)+28.81672327842592623430342575274348370635144290007518614390146782575732264939118`50.35467581710934 THRSub[2,1]-15.24898608812761394177666623502982452983679920367907725095960828435103528726724`50.761995003229885 THRSub[2,2])/(1+0.2091659024479727444845617619447597458130046223094852809766337033712610161621`50. z),((84.549639929407763461293607798722018035429725339817026772441`49.69897000433602+ 275.974231267216177468971593803979305201057479320832550456869`49.69897000433602 w+1159.0322459081216409218532363541160049621258859248746135431977`49.69897000433602 w^2-714.9265228463617034315720520884879195884203582608571030245977`49.51698386747759 w^3)/(1+0.54802616001451026418270643343055848908752080320598387365872744317599160775117`49.52287874528033 w-0.29984702785807194010452225038641595423858416472809543915619734183463048725631`49.30438089860007 w^2-0.01741119327323844890616700515182463510535351285038055916435172077161543335085`48.726326317413395 w^3-0.016953814365141339969544473346113284900994883380384891937162457912413922462`48.97200681497412 w^4)+187.0133354146890780348807670346043051415928959426191745364297`49.65188264613093 THRSub[2,1]-98.96211038567153261890806933742448751627589425019078472667223361401783663939085`50.059201832251475 THRSub[2,2])/(1+6.84718464697211707756319505319277613503637107370383770097884826202997750610905`50. z),((19.00543443892079740651877868691016285878144388503390773576557418678785999719026`49.69897000433602+ 50.46518066667370343898232308897729072126469500116537472359931527075313464066004`49.69897000433602 w+42.21519044676501049125880812549432192059729908356228170580421256182867852672329`49.69897000433602 w^2-69.8548468886953439322604719544788915442844732574880263623896`49.69897000433602 w^3)/(1-0.1301645917516048060703577708194089376577480187984549077280271640150978860349`49.52287874528033 w-0.46681505823633560486701712930423303081919547286322035592046703721928589535544`49.69897000433602 w^2+0.11740492825051681092349828826914070441030279345841663088398698748268545902243`49.69897000433602 w^3-0.08947630975194345886269354479759314556690525123635918408070278842968331588051`49.69897000433602 w^4)+27.2617326800547715041223638775514768279870305017281381683027490600060427190287`50.492961586891795 THRSub[2,1]-14.42612952068840961332231076657520676248454336268323202700707371781088726503759`50.90028077301235 THRSub[2,2])/(1+0.14391762310646823561837288556606494622901987351519706653643357373848996984441`50. z),((20.42346825369714380537218586493699860256368100374764240675065905824486449548751`49.69897000433602+ 58.7916529943976293853046093297265792077606674168230570771579868346475692941939`49.69897000433602 w+76.0366340708448306202439267171338253031540879378492621733375`49.69897000433602 w^2-81.3020592503783137018451016971381919974182165150334752989445`49.69897000433602 w^3)/(1+0.09938459581567665795781554293463173646770212397761287793006030371186860816836`49.52287874528033 w-0.45190491394544433795173919478272646647293983950389256736405485453666893821803`49.69897000433602 w^2+0.09287000988966839589030761692559686152157815315435111696007812468029388886476`49.69897000433602 w^3-0.06258614893834400867781797400091605304260018649975530160521807677740964264173`49.69897000433602 w^4)+30.71792187248167096799377154393736137865318302221680493333496520706618160463909`50.242104373107615 THRSub[2,1]-16.2550460287881345555042321090024701431458202822592637960920475210466344502575`50.64942355922816 THRSub[2,2])/(1+0.28894126384151852290320793175334298344489103903908752562089751472627407967297`50. z),((30.38856966484439821416502464933779549784596313211168000031183995073199433787827`49.69897000433602+ 96.5284687877794103079081693727176244744727344917654555624785`49.69897000433602 w+256.3145943419866491446732958905053831501760295584446837138173`49.69897000433602 w^2-176.8055259437787664726798564790540050360364817462365068858399`49.59658702754829 w^3)/(1+0.42456101644675211366341101814147773180617107521439860694480663654094447811008`49.52287874528033 w-0.35987452690737250122101710756772910659700160860464255521859270055621825800487`49.48075614798689 w^2+0.01661330749132933382453557411153886439540847751228434611130506133406116272219`48.99117718014502 w^3-0.02285582478019577586523589420968477569104782379601727556929863354009402764574`49.221265945950535 w^4)+55.0059715929866049372909394185432913497208969941345439147728`49.839297153374524 THRSub[2,1]-29.10758754495049431076609638322811103569214062567117610819440021739813005308315`50.24661633949506 THRSub[2,2])/(1+1.30808147889097165926908026938629021528317300212842507118753761113564501231261`50. z),((18.93347749762619355017454217509067866698894453686701612785722346333177448387294`49.69897000433602+ 49.95634678254486855808266383267370247882235325074708932203617277326042408973538`49.69897000433602 w+40.29941239338452185129695563930533064671211517724393717838373592275713708948237`49.69897000433602 w^2-69.2161381676278932855211389747991974865850293529603120455057`49.69897000433602 w^3)/(1-0.14728835121684164964633478110539258894356492634752152870070090683792942342844`49.52287874528033 w-0.46538767929721092369021418963120292497338875968703694473585549789148645663613`49.69897000433602 w^2+0.1180135081441823264694083200696919157228180101312947888261295923887289791788`49.69897000433602 w^3-0.09095146033561065579222431571604249791507026827859373947791209610228476477198`49.69897000433602 w^4)+27.08635124681177693914578036306850792711184754473955775164865978524837625543011`50.512953815576466 THRSub[2,1]-14.33332268037563444156407176079087898956190412933365836558388085440824097961775`50.92027300169702 THRSub[2,2])/(1+0.13655851961121934130781108829916912596709689144063059142085580847156000864287`50. z),((56.28733977708785790356781658437178154554727825389524118064891933344244738999723`49.69897000433602+ 182.9015715230243822232232550239291880889789560133686211278198`49.69897000433602 w+689.7462633997031520761224855127030121142380246624974605278651`49.69897000433602 w^2-434.3833080206275121265547797933252977125277434034316877988064`49.531854937569136 w^3)/(1+0.52329236681715723450014930754563202618517587693259096553429711283165313080804`49.52287874528033 w-0.31360996236965806929982465701157850740767675151389679567709306628674466055968`49.3426356995033 w^2-0.01113728596675256162151382376559753915720176684681694728096446750022148568891`48.59544271916336 w^3-0.01750704116517704758248194550196978721387686061529585527692346055359471055932`49.0146249707975 w^4)+118.1293248066773578547292769403618864527927837366864602570329`49.69053871208237 THRSub[2,1]-62.51066136744079045562432794753189551722565939137180883205795647062562557591982`50.09785789820292 THRSub[2,2])/(1+3.95677285218522759747609098753838120010321814508931820432706400028274698465114`50. z),((34.35343106717182437831940300101669436792055605239275459273053041526836133723864`49.69897000433602+ 109.9996641956021412908978080218287672827600136837534127302622`49.69897000433602 w+323.4371054794195120650540247189149456637073195431216901571474`49.69897000433602 w^2-216.2437152329394211271513344549679248020868998343757123205592`49.574558655056 w^3)/(1+0.4565534452063311176625623671927656497731260503409369344611437959855821429577`49.52287874528033 w-0.34622948086943933346443841957563856532975094161743881724969715024859726059454`49.438035772108805 w^2+0.00739730962271851424108977662658370168759446754145797046994900817352950093951`48.58283953206583 w^3-0.02056702802087714382984440515919924975343023687848762873080081057372734202672`49.149989376599486 w^4)+64.669571279680895814038938809209646339147296455719451042935`49.79231984791518 THRSub[2,1]-34.22128821660038192453907426118600659962190953552071223772808264202003453698556`50.19963903403573 THRSub[2,2])/(1+1.71357155224728978213244136596501076045312059861064830660927175369150295547604`50. z),((113.3164134899738376083370693696928475518580764851341001702059`49.69897000433602+ 370.5134025153992115629141244158982298033619122844251846678764`49.69897000433602 w+1636.0724958766062560761641169133906880176854747182707590433631`49.69897000433602 w^2-1000.2527073467004425741179973130190082692633684142516098476182`49.51063392735809 w^3)/(1+0.5588122653050780149103905687517217629031804546154146218595066546447948270345`49.52287874528033 w-0.29352986372678495940394478893448601077229283665991926191398465487472523928463`49.287075335626966 w^2-0.01999166108268993559994664465122920259953400819625130835413655120208237890184`48.76025642665448 w^3-0.01680145331742311818672424569578350533690073675212610081672794887758011194687`48.95486986021695 w^4)+257.1269045306001081968886504148580928478894623827198911608358`49.63492289961821 THRSub[2,1]-136.0642066131751151718645191249157574624379887414603641461045`50.042242085738756 THRSub[2,2])/(1+9.78918940770630849922167651237041137474111831010849746567388214855188091129999`50. z),((20.83351428095415176901464073716665975731382639841411144894638820633354077667051`49.69897000433602+ 60.78800316868469450595515029097902407590298966305120745795824131463682739951625`49.69897000433602 w+84.7392567081042196901901760717534940901657890091433622226243`49.69897000433602 w^2-84.7607659217288825479723383272846102915321477325514320195525`49.69897000433602 w^3)/(1+0.14019192012561746910684486104876829880606836272764206009777978785008926514056`49.52287874528033 w-0.44436242497858658810536857118044564563906124389416578601892535298874813829021`49.69897000433602 w^2+0.08577117469792938267664281519937984078985211874577438846687856758943198154132`49.69897000433602 w^3-0.05704889667160509128501226946192015883515999177966574305384312208049008521295`49.69897000433602 w^4)+31.71733150082454537384639967567343316728703767281479344416766679686345359128948`50.19715210143727 THRSub[2,1]-16.78390503096174129709537117216964619259750177164110894089163745071432859951294`50.604471287557814 THRSub[2,2])/(1+0.33087705346945066844156974432574229276649527763748144881187284024014901675942`50. z),((18.80056865567645061413939221496154652616503442970976704551388016370069688214632`49.69897000433602+ 63.68550865729295848945818436035309477823245964900529695200938501017735162769407`49.69897000433602 w+86.4713698876245816566558281674974933637367947443769838314382`49.6425346554165 w^2)/(1+0.60098120850695892487877433989005867802461296939669360117039324059381249716103`49.52287874528033 w+0.00730263295357194530062075444367602634675611792028404620574164426394340813654`47.45967181757001 w^2+0.1476835878925014979447994426951602885216465571733105130352115204664627660879`48.140154532549744 w^3-0.03943557927348702333398665017598862993208995346834884069453257627124627969951`47.209094854107114 w^4+0.06942203335915994505724354514748887501330345265458646942581238754853501745488`47.32108993700172 w^5)+26.7624110852034821187751872041383760090984315331444396405734645184295584938723`50.55326297788796 THRSub[2,1]-14.16190280830957883742064050205462125118219858103369279855703206712345704350376`50.96058216400849 THRSub[2,2])/(1+0.12296580839052735878283064027808834450705980955931067665114853671892342211244`50. z),((83.9283635648988133335483747909135435332403332942240447846929`49.69897000433602+ 318.980792855478533201673469175159933141830628617716669016596`49.69897000433602 w+1320.0515382890043132216302664440205912407281590495257667748144`49.69897000433602 w^2)/(1+1.08445897646557537578859014548665414480099635911701327105855061393235319672076`49.52287874528033 w+0.28335970314927461907246450832801301803139147800757195882733122687995512353467`48.39030529431896 w^2+0.13371517009164924848484367303526873922154769710682555597792908433276172655066`48.5715594903166 w^3+0.0414243260781038188678219096381596402099231883861843586857`46.405956419888874 w^4+0.0905337071207800050591145376863828359584469608364380762472`46.12873274479655 w^5)+185.4990917950016487867557588185938197264222591519386210512728`49.6524007123132 THRSub[2,1]-98.16081595439464989023675012156939710119960119108152937653348642367716333500338`50.059719898433755 THRSub[2,2])/(1+6.78364613375412675226734567665269194903433086937867974288144280300076476012653`50. z),((19.7803833606120040050368416575448408285313343087337943517708844919979069695281`49.69897000433602+ 69.0454834356470699560356017505519093026112206376378333538225`49.69897000433602 w+109.3896473791435004650571702610424461215150646782444490830125`49.69897000433602 w^2)/(1+0.70864617841519346920646972441771695829899489373148881391275097389287857939101`49.52287874528033 w+0.02963699644587246198238076539667711857633644355933795488624388505575334272806`48.5740664430636 w^2+0.13831627320896061393113902303505810197537429352310685483857536166548381329119`48.280166409269185 w^3-0.02238642176245853778860533278317680030716380988515520413829202062458773704456`47.02782721339065 w^4+0.07001243400060877812112262487506210139922528605379377637936835718426163786996`47.322703333370434 w^5)+29.15052408962666728222157490239434868942409645257137061433173718470860249771279`50.331528047430055 THRSub[2,1]-15.42562393404178178784284182330162040976527329058353659437254983233679597627662`50.7388472335506 THRSub[2,2])/(1+0.22317237206679946329241104508433099131753000422848877665565202868708850122901`50. z),((21.28880063658415433596979380984362095304514760026552834577464778449227992582035`49.69897000433602+ 76.1621891360247909143673041604885317252052922526622488819947`49.69897000433602 w+141.6405205211605429021990771957248368107345750361097634088127`49.69897000433602 w^2)/(1+0.80171146571640301150563330786967890401028934900515613466740095946457315441065`49.52287874528033 w+0.06713048474979714855626270642722672944758769663692858679177345389611719069177`49.32519307657694 w^2+0.12733622836626041088301126090642088188837649193201763958769050808489933541292`48.29711551822552 w^3-0.00581827306341706587066245782697226711792188579784953423196217211818123501558`46.372342155257805 w^4+0.07142551299047602700780156902270043704780838725309875887452348183888451525149`47.19161834699606 w^5)+32.82700587204962606290855854731067196886306087185951043866778874067077382019988`50.15490590352707 THRSub[2,1]-17.37111298259694614112315784888937040710569771686415133702454129311383220881206`50.56222508964762 THRSub[2,2])/(1+0.3774396136724806055237765263832810295715017875089710767858400709894268945443`50. z),((18.81743144458407880486334962226308875171731149344450640627770713719881324877285`49.69897000433602+ 63.7876202007004118851646028830565821441866662028977774806591462775674826449175`49.69897000433602 w+86.890610406105256876296798741090586543246094875884134122618`49.64571644909435 w^2)/(1+0.60345323255422100163782423775283768783251313020081735250355448111612502224185`49.52287874528033 w+0.00755590516424252117433059456122917501278688281792141571710345291104761737213`47.48611541814396 w^2+0.14756689493220216144438650034034046684072221653713383280885859522126874196922`48.14635428143499 w^3-0.03910485951384834998531067315676042755888143038231626477989228990747535562581`47.20992530763383 w^4+0.06943724030225795970571492839598107632769466160795833069120676154956029836684`47.324276386486716 w^5)+26.80351094345045409664882431182544276379350557995166245522716300604167192632324`50.547880841074445 THRSub[2,1]-14.18365167824793523611670377187451791250354317238511345507464862052210718262703`50.95520002719499 THRSub[2,2])/(1+0.12469038153881759811780305686678858879720799914904918431428566053511383027205`50. z),((26.771187672046374751546387379300928969466566099758630706695088514366246512918`49.69897000433602+ 99.0141857824521312498503601292203904152262599350111211511984`49.69897000433602 w+249.9869242656484453226876485843857226602104094214595899349375`49.69897000433602 w^2)/(1+0.93905336105302061729253904519962926492552819056344863079845309212515883763485`49.52287874528033 w+0.15275524675261795528672648048525705840183411831321695890935983883530185459121`48.76321039433232 w^2+0.11807185172478129941130228274794904638203383359446442617882721966219242692014`48.319926064335604 w^3+0.01727185731282448757545307140981250196672431900565673017996005664580647154299`46.590944311737296 w^4+0.0772498839771200917327904731764917713614380858223300619015`46.839353890580234 w^5)+46.18928723884086676264379470544107501324674753899305222423177975432555816179901`49.90780106409457 THRSub[2,1]-24.44205025395546282271162368344940205702140027850577215772477583552385571657495`50.31512025021512 THRSub[2,2])/(1+0.93812844881621131386021647292914893980424501118863574530269783815736682101375`50. z),((18.68178797247513134508613052486068541840780431679655491971616708331571756244609`49.69897000433602+ 62.95134384812676831650246958753545524075889332029838035755124656241036543156387`49.69897000433602 w+83.4822514216331634249291932405153698460018458877215519419649`49.61523057915879 w^2)/(1+0.58264460726119661066379863749884329619195949990970026899084620116838529023417`49.52287874528033 w+0.00581194920438618525548940919083761881312978049056126596048307688006113883479`47.26914047135341 w^2+0.14835163738453606931296896103549757384586018768832796224811723448189136765602`48.08648451679782 w^3-0.04176205672209078995050589862547053039915169828900018620309775614128429078025`47.19320150133547 w^4+0.06929211366536469601298678517956519139148151059461035896488590755431646594333`47.28967227205463 w^5)+26.47290563810366668622460730920329188246711750022989059665013727015572576845538`50.59371342460979 THRSub[2,1]-14.00870480267209001564392926079529742059902666539664896671391115483074251779051`51.001032610730334 THRSub[2,2])/(1+0.11081799714135143539824664251757679403601363992337988788506794919127786721048`50. z),((43.22186221708906187718931366322180327573037969819931170104253304094025558102902`49.69897000433602+ 163.1100174645567423053869667081946659614296863821154380640821`49.69897000433602 w+560.6958845203009866505078109798654213420266512361702586799858`49.69897000433602 w^2)/(1+1.03850773593080635617441092228624036736250538504449447069034362931970160187077`49.52287874528033 w+0.23757105201920594182812799344343695263641336761468123148272657835977452082752`48.5402884736453 w^2+0.12479692370976643093656467306290172740200279411695853878500847008290925077853`48.68179110856359 w^3+0.0332964587221331787361068417173266767013659304184187198083`46.544025682865964 w^4+0.0853412585542483436548485990166092398861016018010216691079`46.416630114345956 w^5)+86.2846946813469672464624778292691351975778824228631756390264`49.73306271715833 THRSub[2,1]-45.65939354386130886219859092309211307588593707683385172282764654632662697636419`50.140381903278886 THRSub[2,2])/(1+2.62055427689548605796552048687906516897255898393394336458410101058565330272569`50. z),((40.1366023052728375628629879794511824222174827659768637293559163243850505512885`49.69897000433602+ 151.2194840323696601356042953705589845066508036408254611785647`49.69897000433602 w+502.8696894565941048930486149054796736625379051787474706232253`49.69897000433602 w^2)/(1+1.0293152874860469495742820459343986429034471551299042929218550043843606423471`49.52287874528033 w+0.22891540070221457850133052759759029559874391813241269832591672769633002703025`48.56483575933693 w^2+0.12350261962550705892173225992970282682242093200558237985642089039544801176696`48.5871068479371 w^3+0.0317605121650726503409184546113743021541587246766773465191`46.56223359607001 w^4+0.0844263968913340223509920748802816840853752051995613782881`46.465073016639444 w^5)+78.7649572449523212379629831878365507935129333399833025633451`49.74918010129907 THRSub[2,1]-41.6801634819964136233277648341932909183204386103283299734067300859840259011847`50.1564992874196 THRSub[2,2])/(1+2.30502186831462368614219667085897592018401336229211046520194404619004756170007`50. z),((24.66093497621557938817531492268414606180318994592135858578844323509432589889674`49.69897000433602+ 90.4769853997557085454049278743438190432741206650585997461989`49.69897000433602 w+209.0871595472921557717852230663220105792808094457735414960924`49.69897000433602 w^2)/(1+0.90391451809006168136390152339174877950282125673456456380399576885758954578068`49.52287874528033 w+0.12739805563990254368392495559425511027348858134522194668948325061419202652494`48.837888219797065 w^2+0.11890312326047665614358680430827833828567015600155410618525845096953027702034`48.30185120342249 w^3+0.0115996905405376461929100859466647065732804660171432346441473856947302486192`46.50111988900594 w^4+0.0752332668094458763221874493964183308081555738131944027101`46.949289030475676 w^5)+41.04594546192389595651011392935418860455342615227483096663918672836222208138107`49.97006818228392 THRSub[2,1]-21.72034083387678200789947169656218023879272237047281123255228168177366575923958`50.37738736840447 THRSub[2,2])/(1+0.72231093753309358257100594951841040300885692265015511620291850672560895729518`50. z),((18.71087375651115167906242370885960446017691589793085730777133318195299326735536`49.69897000433602+ 63.13365692451870517805700881295229561176071002434207736150640350329273062326173`49.69897000433602 w+84.220299810615169897151848844525983677076597991915259782953`49.62285722959554 w^2)/(1+0.58729187290665347080752344159900691949794003668032665466480158596596597044052`49.52287874528033 w+0.00612491146241354665668406176611165979769805430412921062666993855644915275695`47.31606554943503 w^2+0.14821635560468461478843321011367768636575629237711567152277425771627689349846`48.10149682296545 w^3-0.0411943733398731610278393113654122147221769809989993921860697671924659723174`47.19896958919475 w^4+0.06932821550100849201563096426973122202251769631897053173330175630503608529279`47.29905885795244 w^5)+26.54379673491041763925629724310879438070381019356998528489243473453233921703998`50.5833710275619 THRSub[2,1]-14.04621834432405060182109849367360978016502038158593808802747394608734652926926`50.99069021368245 THRSub[2,2])/(1+0.11379262740092839804527148698071390836019488822804052527206104082835372475412`50. z),((21.08607307258549068838157678298332785820099560222665691087409871967792038679223`49.69897000433602+ 75.2486449539812936699023881877384118734367944195797996209135`49.69897000433602 w+137.4275484992214959842696374841817977974045103472533759222585`49.69897000433602 w^2)/(1+0.79201385764023872233624823821250678753081618902518098924131245319612140782421`49.52287874528033 w+0.06244922383559838400280338518866564887427519585509993766636085504509860488219`49.487680862493434 w^2+0.12843182783336779155389808519561816351575374094508913181066092633246587655275`48.29715465264548 w^3-0.00753824897254987834235577937510289440121723002606913029073745442996596698326`46.49602184953726 w^4+0.07120234974236973560169027857717741706178718401805389027197008114070998855048`47.209326499280266 w^5)+32.33289578215044873575187414855816254542103296965468210294909013693864540283313`50.17285571732649 THRSub[2,1]-17.10964404964172045910694566009528012613816499362924777165843084026545868140126`50.580174903447045 THRSub[2,2])/(1+0.35670647663295863035236790288079073291067581636556346227266888489262452323628`50. z),((73.4407735923045234542122590985460966683142815237484814145234`49.69897000433602+ 278.9014865930088216831062986607685195593432678070289028649201`49.69897000433602 w+1124.6967016694719197021404493464752127746490266640168001693105`49.69897000433602 w^2)/(1+1.07856874834080390740538632587214528720754204121395297070761325856080562807403`49.52287874528033 w+0.27725467645656610755009504176098260343434071010118164833501073931058013970906`48.41287229289903 w^2+0.13233143253569838113073991613536739023248925779698980370027564551481983117815`48.74082892829112 w^3+0.0403296320581307345427103048853183740722629970641211681141`46.42870657967401 w^4+0.0898054639871580443185606714449477423423758799204320242741`46.170854437102996 w^5)+159.9375750383634915423382694101375034515192117866229188943024`49.66275509337662 THRSub[2,1]-84.63439209116394684938820128853519961633966236184606382376981765639638180664111`50.07007427949716 THRSub[2,2])/(1+5.71107052623808484397164703781932566847688013933023531778936840775668891160452`50. z),((18.65276764625165571451854066196515504166739746368897076799790173084777051249435`49.69897000433602+ 62.76767623393219807708417213252700195169205923250971429449446739087104825285251`49.69897000433602 w+82.7416518434847589251347523862088920788815217459134086221508`49.6068364913599 w^2)/(1+0.57789874081264064525364886627606208542655931471278709070791633161862202235033`49.52287874528033 w+0.00553792436351800640758729077413527854609312627029158524848188867412761420274`47.22264323997542 w^2+0.14846486296848122825384336472853298845333785800006786627199553126188632681979`48.070010378822786 w^3-0.04232558808515023297289812542216694187407810270962910842315070178413238430068`47.18594755738246 w^4+0.06925270132180264383041018506673902452244713214844819749080446453309176983843`47.27893596993441 w^5)+26.40217408233318685467557412112653084307490783155852478354707114315135443993508`50.604341403610924 THRSub[2,1]-13.97127568557524202188719457215416617893681279727223948061824790049383746577016`51.01166058973147 THRSub[2,2])/(1+0.10785006131331120064560378283059619008995712697143109086611995736522347557421`50. z),((81.4308969758777653317769040402277953251529436039906391152806`49.69897000433602+ 309.4386558809551031824816957319271397380343655807302615609358`49.69897000433602 w+1273.5385242037090832469479135082429951146251434285605676481453`49.69897000433602 w^2)/(1+1.08322052687386820295325079800026664530586133455485154918014557006948924084569`49.52287874528033 w+0.28207031822935480176802653525907197758894937084127451604030611048000815265883`48.39515546814736 w^2+0.13341807945953331624780995957422396271285638262282923062892596742396110127517`48.60381865533047 w^3+0.0411926119075724782505087015716013393285982587841901519234`46.410885162053866 w^4+0.0903789324814680862409917112562646175953521646993341745871`46.13774464178759 w^5)+179.4119893976704388227417651900029349593813342745090595596034`49.65457826460587 THRSub[2,1]-94.93969539613171370371535214054424294278699749245314094834026588283303997912183`50.06189745072642 THRSub[2,2])/(1+6.52822789648796877976588270091615196777394439355888816965197261066764634407367`50. z),((19.58822900459038790073576781633981828766417728076146572737560078024449442508798`49.69897000433602+ 68.0635344940422174428273993223061369379440383496203304465382`49.69897000433602 w+105.0741147968072712311011907496338967045640743774453591137238`49.69897000433602 w^2)/(1+0.69191403927228328117026910536842835994634557843581022360482436090098770239837`49.52287874528033 w+0.02466683926979071419032696247368071197802673691417664219962032248090641484012`48.40121660220306 w^2+0.14019577500236488622047935900108457108744203593916445821623413831716124174051`48.27045656249656 w^3-0.0252907319559674938392681509498029072915623296552463080050994257792458750478`47.08357137795833 w^4+0.06989063911897820240002692193556742937386485273856737913229786862105280815493`47.33593579773298 w^5)+28.68218419417473393477658233235704328824663399880863104708326462259268147277189`50.36452602656308 THRSub[2,1]-15.1777918512175551893802073630380157727581919453732383831317359882683172102213`50.771845212683616 THRSub[2,2])/(1+0.20352056686795870241335200397090679928651587327453258192152871683519902454831`50. z),((18.59131986324665644375358529086059051694505376362044018239473533415440050303841`49.69897000433602+ 62.37258661375888611593859895623528671662488058535061067673159172101347351821556`49.69897000433602 w+81.1588216897666351952273622957592282548775995923117712844132`49.585783692327766 w^2)/(1+0.56746792053255758616376765907500534302220902894777811318885623102774509071028`49.52287874528033 w+0.00509791551173324880334597852815639585939870545508839345083141466414803906261`47.12687791003612 w^2+0.14862196863572794364521753905857839309517756389293892641730939373175183856462`48.02912882719504 w^3-0.04350415777070494326021318392552190082657902875667655238251728700332135963186`47.164579459517746 w^4+0.06915607087708115791470169601282380496099478823048878561078103007805064889231`47.25064732159279 w^5)+26.25240673453974386553584133059808284281333619232638472090463660227167936370178`50.627944000125126 THRSub[2,1]-13.89202308697504713265986787711909248426682974400333261714372463500222663537721`51.03526318624566 THRSub[2,2])/(1+0.10156573923747420499712814577455826062151003755992460183464020416038083378848`50. z),((18.76784117610038845532224404215243594715214168867544306749368824994862567692755`49.69897000433602+ 63.48589057077244046276107065560499835747922095265718163094119105572374691309805`49.69897000433602 w+85.6542097886656567148465353924864552331693897549267266629206`49.63593449432472 w^2)/(1+0.59609413152603772435125401508414889650940189292153278107321472406776403530378`49.52287874528033 w+0.00683842681442070725968098273959971787145604171673079437959434732602279407162`47.407732201795646 w^2+0.14789618224960302660436770512527169918061805279474691200510068648551650886916`48.12723092058621 w^3-0.04007784267776527457697754769413211451149145228961481029385943761154511406311`47.206586994743795 w^4+0.06939050700234806888531384804989154222743544731648112525555786803041268457412`47.314112898908256 w^5)+26.68264404437025748608611666590009745427213841038303793157750107150337165251037`50.56395175417373 THRSub[2,1]-14.11969237084226273801660677687167575046435619383829490582143199051173106955938`50.971270940294275 THRSub[2,2])/(1+0.11961873853172352015249115134044748887422443086104817133627834697037940196887`50. z),((19.92748151143360336924392209842337380297034388819944796914363643936897940087719`49.69897000433602+ 69.781555372927389910398163301533649014840978563419683266948`49.69897000433602 w+112.6513048862743907385398687048822179284888226315522956745922`49.69897000433602 w^2)/(1+0.72045255419391127195084916309003626598600775788553649870382325466549601987044`49.52287874528033 w+0.03347092384029656063660803657292224734727443150395841956786231632333025556303`48.703041973120406 w^2+0.13694197122307283391522093212428400290303372551802906359137928784528550298565`48.28537982823681 w^3-0.02030846821820017305752087644607653732122612880835556001791027384987074363788`46.98153894030362 w^4+0.07011617835239571673817444881776146767471009360633883534102510984294478222165`47.31123556759264 w^5)+29.50904800760233200908934877333750425937072027546357495850434703488191326888148`50.308505948389154 THRSub[2,1]-15.61534454122701868697495573310863405683401462115105587732054195261880850398355`50.7158251345097 THRSub[2,2])/(1+0.23821623713916128354849449797526501146137473370804098694310624281514252958106`50. z),((23.17917815408382069107673880337564461764088809789155577401821669382317269456157`49.69897000433602+ 84.3354259224487920797566872797690374395742075334282670057997`49.69897000433602 w+179.9033648249202110027522296489501735800812394217785798057989`49.69897000433602 w^2)/(1+0.86907599463214774111992555351800368638512549933838961933145833642246419350416`49.52287874528033 w+0.10460691324912596255526679458249634061445138051011348419066246094527613351568`48.92771074207299 w^2+0.12094568448005327169764330474644240844704627951232877147324104841308142876179`48.29623285216659 w^3+0.00582675648731797167161133984189940515049720087219699670465105001363098214082`46.271472528858546 w^4+0.07361136559485684927496182735426282434512589187045537195622000943311134725947`47.043829971875525 w^5)+37.43444349272414353538785382145640871512575726667037649981287718117630247121051`50.03233213547741 THRSub[2,1]-19.80923724470490704418897426929712086593187497986160626042805078246285986107948`50.43965132159796 THRSub[2,2])/(1+0.57077028540595189221756065925203708595927813811857609370370773337050867029904`50. z)} /. {w->w[z],pi1->pi1full[z]};
(* 20 each of [5/2] and [4/3] Pades for the non-logarithmic nh^1 part *)
Ftri3LoopConstNH1Pade61[z_] = {(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 6.31010911897040163471902736827498135556004441775734004912511234818657242830772`49.69897000433602 w+31.8162441849784200019448129815112296819791815095188667620591736688951456971712`49.65447436427313 w^2+115.2778373430952536547737284918741084656104866562114652355385`49.59256384826912 w^3-142.1276388512893318813425617768637058118861766308318746302015`49.12410407761072 w^4+43.4655222406560037276029199148617517909002605890536168909619`48.39848958395327 w^5)/((1+3.02579355527719871163406278387126867424208435870334119952041864531360137409455`49.52287874528033 w+2.57939791956657200444787009078119747442222787362954077909483130838361118596918`49.037345703644775 w^2) (1+9.37987440890830256139841939178853933977006912672989236007321078167627347108739`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602+ 0.08673760170544172840063485264378117923990002978283038345025782984826586793807`48.80908636137586 w+5.57219561027735959992096812660357908851782866815542145039287296160004871082228`49.40731603384455 w^2+7.6881283587651714682834261080100705155924185804415844976272164441211446372878`49.42930583134099 w^3-12.2569331379326221118846336672854555540132875014830356264279`48.66352592306657 w^4+4.1034840270038185749015727176040702515351243009924453789672`48.040597032250794 w^5)/((1+3.53313704595473726308822741139761853784460315277403451812046976685906574629284`49.52287874528033 w+2.00330502519350628949631419005102668055833162115944298996107272200892527600983`48.49074664874751 w^2) (1+0.28083794100526749214626109387803818869549137192207820318599181142632826736986`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.27204053381917203387288670071814225563824330471321392489618011191632442794911`49.04175835977457 w+6.93987648223126143378598298457873239316151774710261859440932595176202409305431`49.61974752751643 w^2+14.13982714987600505375739304750475849068013838857873119978604491614032731717905`49.46416974177056 w^3-17.8432114137106960611192522266403419491441003002813893057387`49.356287617428066 w^4+5.10254582057635358023604741378788914481516908918950732719987729380798770276726`49.01027277912571 w^5)/((1+6.16854978394565618913950582820911618106908065205927359437627213045346163639993`49.52287874528033 w+4.31713511834819419715914423593328166526363733723258816849855510964467381220302`49.69897000433602 w^2) (1+0.12520603750309992070539379828669275148468992080950306969669072327465078484761`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602+ 0.07281829418334934486229017119162579593700173783135658525812520998294635620555`48.7101499461448 w+5.62308730285863653488066315890407886954503998366286632792884553708064108360998`49.54426363940133 w^2+7.94711198632034839572673232142123444844219156631221977315665467940144528731851`49.69897000433602 w^3-12.4382674953944255955664256039309743868746567686538178182004`48.94496483322923 w^4+4.1167667361040334580932069817668747202576102810033809686171`48.374091540079505 w^5)/((1+3.77729339846716618498561709125597856029908382448220215785855301573704387147346`49.52287874528033 w+2.14029346498408317444106251573410960083214416127581037317472208196961551172704`48.86708688007651 w^2) (1+0.2393220374536015268945269933528349544677545225763222565741937600727730315428`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602+ 0.07027348358851918851662053871101132391402136253409555648921006623727363207804`48.69223950841853 w+5.63265783206790046861347021039384619077165607985527352734357724863545377839722`49.55192835892864 w^2+7.99339548037533450583004265513904513959180917050252044364851036778210122818131`49.69897000433602 w^3-12.4757583087796344283195068367051317553845942208163287194145`48.96528911635223 w^4+4.1222977182347555877570255205420161049818000753596646583243`48.39994702424308 w^5)/((1+3.80706217364336666770394197954718468266813506480486299173928248271534636610078`49.52287874528033 w+2.15952596874404318921886509107514225718860817470535328574700187427831824106211`48.89916743809918 w^2) (1+0.23544918838996253459588499605803813788174990122428116083099400049001764670247`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602+ 0.07739526531174105996541125729947110907607542270477508306338451632578399790241`48.74164526544018 w+5.60596041163631239029312476354683833500266918797797447213475140705278301296405`49.525857396132466 w^2+7.86352382085814027120442980878767945020544474145845134904019842654971928867246`49.69897000433602 w^3-12.3722432323869192259207222386066233593577628938051017150694`48.899228091477895 w^4+4.1078248130460161173099538830611058888260693311755589868439`48.31700258022108 w^5)/((1+3.71868334202897972953621352856654167279074966840379399588466476323523605841116`49.52287874528033 w+2.10382185900484406333314527890470681745308464874031468303726875169758303929628`48.79828200644247 w^2) (1+0.24755490374670261827457817883496958129263081527996042017173545711315787921548`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 4.8577539321956756481986982190695623426622761935773860588505765738253453866535`49.69897000433602 w+25.85246895956090116779938348315941143773038991271131036231821547127237598345634`49.66629597975021 w^2+90.8714837139027201561059896922928553482730887628195922398587`49.583078225591166 w^3-112.5556575964876190962306148155161083483931579924076849071741`49.12504506352995 w^4+34.4671288894810800156581226346549759395656476559147961169444`48.39908999147073 w^5)/((1+3.02318208849724337649840612745594442390065448805370260028263058378380983125113`49.52287874528033 w+2.56340362021218178279337733908899102611531171725126621653894921549389009861739`49.032887539960626 w^2) (1+7.34345766298419520629667708687697750114816726697096484435805212829481890210867`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 1.64130820188397389838927938895460312980154441168152615265068981715355609117233`49.69897000433602 w+12.64828515449431736444654650247623901762150661475740324805856339870384524110578`49.69897000433602 w^2+36.8064020109342324786228278505709602407770799638336912292853`49.52031272150705 w^3-47.1203619278740785455058308536888204665938542152882293785249`49.127810565269414 w^4+14.5789602053664992678174600546358918007180701076145944135007`48.40033177403694 w^5)/((1+3.00813830748820964436792080093972798224581181849638202701447646959672632241709`49.52287874528033 w+2.45286778976748408073648643995034189343045762031739918085862035222976107041346`48.99899966951446 w^2) (1+2.83584018130575508115504863081232258573124114936358466670230037677981009535969`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.31196012317421778812351633390667175004003881507847331976946315050125856508606`49.35313526213165 w+7.20148333225619987488674270667241129873118821087806514207766895374968532308087`49.69897000433602 w^2+14.41962890719446885688243049319252282494843432908936350354236289981971075785689`49.36651423415689 w^3-20.2464670013395926497919366793580728551549870340847077218769`49.0899022130233 w^4+6.4811530924100799196064862121132843132159549241607640693302`48.36619253465848 w^5)/((1+3.00574099355986247824034972207522200894026706997919165113189434094869234881755`49.52287874528033 w+2.17908926783143570930328299141798023823397590753498634984774044879687938719366`48.875728094351174 w^2) (1+0.97189934744169044530119581682485701393759351268598791168015253493200130207824`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602+ 0.05202203752108169159171048243325974376561456177800762995221789634977984560432`48.64008543111597 w+5.7181970883964170587162842329246734314764360287272178418153683286113381274616`49.57039612661491 w^2+8.2577036807544312125667020828484975956368567333642715155098`49.00376501582042 w^3-13.019969689209296318990698930110760717646743875449488553696`48.65743734773935 w^4+4.3585915289350210950653736635300486264035486934390308343281`47.9652342298221 w^5)/((1+3.19651830853960017588812596439079980628837592133165918510994557459416468112428`49.52287874528033 w+1.9282218156522052101124577223395000758171333992681687035993196209508932921025`48.39074393299931 w^2) (1+0.41368458551373856882114141644450020965237714789332930224981789018229807835793`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.1873211827084698013759422636574823495426062503723140930262046109893604487631`48.93001448572783 w+6.61629101745533928314845820869235090771045884660608636650145739843781459846265`49.62230912192172 w^2+12.61888579871330925253776055236101528678146918289097750183194383370118985655639`49.4666573788655 w^3-16.5136635365865700403419849097972626342369301458891901669849`49.327942912427154 w^4+4.85849088497674005074588960005285870165341767983856588146076016560907136651256`48.95323626375673 w^5)/((1+5.6480841522448839657019675376189816707791433163512964424239122180601785852618`49.52287874528033 w+3.78393137485595267919726370843472393120281548950316268377724452172913858061301`49.69897000433602 w^2) (1+0.13649530361068465046516799168031378349446254215445673602366049936870531362023`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 1.61295915718479550798013962396420269640586643677182110540816512694031952908684`49.69897000433602 w+12.53197265074324159970335284128015068217201671602173415789980568360150306105506`49.69897000433602 w^2+36.3296190644688425379387680554842827162938998958313322587023`49.518977077363004 w^3-46.5447094726338164383037429677189973666440715357164455307455`49.1277897149265 w^4+14.4044423258063153913398354566157244518333327734392256607904`48.40029437069957 w^5)/((1+3.00787438643080767465826811881895794603141767494798481123018815362537749268619`49.52287874528033 w+2.45044646936413287090313488567710846938243377126474453844435909330941270073473`48.99818871901633 w^2) (1+2.79614386510892029872288914395338201937271992823443786536549490629663191227129`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602+ 0.0372779622788186368050641630065928239658071086281344769964078676025395941093`48.393750402249054 w+5.75790383343213449761808040291091894345046289203326746164260880332030708357865`49.59651480766911 w^2+8.58887075423378378502979074358102730360729522365265588359431446049101679203004`49.5785045489315 w^3-12.98071382261054322442300754332915825788575979449004517440248952674021231607901`49.10920795822162 w^4+4.2075485874885335773653399325019277203692281285160614117258`48.59403087259348 w^5)/((1+4.11885307259380480102955973652786652360256263949368070991544142677445516651045`49.52287874528033 w+2.38368808183067047168473478417418760456434896588885444254626907986130939688962`49.16706940391873 w^2) (1+0.20378089613868624262614404481387024900407988316043898257933629995253143338014`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 1.36909786004012338067340098301622715009396560830264467454106827051056151383988`49.69897000433602 w+11.53157391995297470546238216613018580297187903838946365610558587036373756104224`49.69897000433602 w^2+32.2277526255611726088428467714669373177574032718891553703732`49.50593969798266 w^3-41.5950569817756632922968295666687525408950995271564353742536`49.12737582708819 w^4+12.9047724228713680726293520006394566286584407519266046501147`48.399758319285084 w^5)/((1+3.00545611138568109715401633231377187515953979719165949550763068285587234952187`49.52287874528033 w+2.42671492452928000213043239248320860488324701114583071087978167506678100747711`48.99006025377242 w^2) (1+2.45470921190105142687651347730199855005581550839212556628542558066314848272158`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.05055613861740170086442385264881116859124528849482477501069325450148177413195`48.64556283734229 w+6.13574487331052218831273416612600962398190242715736584409563318523794812600953`49.69897000433602 w^2+9.99616919606147391721254215694026205795066670757256977171178657374186986066458`49.230061539443575 w^3-15.0487916898901782657697393695623227181369128318491699898824`48.970933947787174 w^4+4.9511200560915043697963886876425717750909963108543159201448`48.259497051298595 w^5)/((1+3.0657349803408539863947343825552328602080123185600091734759829027150351501686`49.52287874528033 w+2.00919768439034977392191425172397164531167110510167851144018911240352421106235`48.7115407396981 w^2) (1+0.59025630097844078353556084682369919986780394247540950282657441256868249926883`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 4.67617261010505900451442347087779441253164567075743684280515116972176466531144`49.69897000433602 w+25.10687404856003794343767537146525586077886645111171284945740785059763080671841`49.66818890658034 w^2+87.8199545042733903438199627507779632651008892978646116147188`49.5815337069753 w^3-108.8588742892899287068881662831009655447839951784268505777314`49.12518749493454 w^4+33.3424339679497809303951462604946190820602385831515233823921`48.39917936207135 w^5)/((1+3.02276311565158433073636420227263260575403515901474361780671180710621268652095`49.52287874528033 w+2.56077886998129792655344924257775105843550937201440731716272961869521424062819`49.03214628048035 w^2) (1+7.08887691547110870127093207720253355368341824904169824829005395762902931502131`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602+ 0.0701413354087223326060218827378571935229799840179254941040384094001817115949`48.691299185713135 w+5.63315551595546535339346819788160447080811023894110270003761294669742670527092`49.5522905248583 w^2+7.99579610814156768815336034625021222098339760002748497158389990320165263076229`49.69897000433602 w^3-12.4777165727417696521193105731980654975497307523237497726819`48.96627110744346 w^4+4.1225931165666587791664883403901640865547374318472996673616`48.40120442336143 w^5)/((1+3.80856589538664948419703797414211812528001936890506982526929487856234233132525`49.52287874528033 w+2.16050939591072808452094376106807615993835313394254220923421778963745458019611`48.90074387341591 w^2) (1+0.23525860864788287512643768370931316790712257688424730107613351130162398480367`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602+ 0.06586216677692720839076623353111331128991936130344419932191979793963922972453`48.731544009673605 w+5.6615580712572233085596554886627058437230469154807018677619431370491956163983`49.41370555557864 w^2+8.0243552683229259708787154333385818339858299734501664683104`48.87517358556384 w^3-12.7413119578622950134440457417973330660415158036192463332686`48.48036249439147 w^4+4.2751383275429223163058927386641291800801800303225796757585`47.79409469490555 w^5)/((1+3.24335601516067267793099214032667739734154351863163128105792195900727475021056`49.52287874528033 w+1.9239096299871266336680906536683019402260565576170568442281986547056402701624`48.219275250023514 w^2) (1+0.38256302951260919896889213066094398990694345183135838689493735904391456245941`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.33192450177019501441767502666984614127737116327863495746971959000577311341505`49.0961957500908 w+7.16846478494429800046385173965880143167896488671552608632484052721641548669113`49.617478492620286 w^2+15.21546228145738357806446447793164732306927798438394683586820100681778052596085`49.46409992500713 w^3-18.78078965582715321132347469603646523367398121565017626547886302812505696730934`49.37139952735052 w^4+5.27364763421253339230188601713050977656633866234747741027017767414983861305656`49.04231283674099 w^5)/((1+6.53005114331404617537048333707125699474633565930634384277986261395377265256188`49.52287874528033 w+4.69721110963004424030103633997256639656529888410916757642560637040464991745827`49.69897000433602 w^2) (1+0.1188237955663333578987810990293915694812957628297548781308567173081241719828`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602+ 0.05510396111234911695617870507181179114251851512959552315915248772135791503749`48.662810064747475 w+5.70560653435169983904011662320052776870973346675513406316713943290117228744327`49.54539861698635 w^2+8.2056541930284988705438887011356526041380056592523711207254`48.98320654696544 w^3-12.9582738764036383863709500997298295384535019369176888524613`48.62833515187901 w^4+4.3402621672799495906756236572507871737192327595977353979877`47.937285256499464 w^5)/((1+3.2053955978430996437459447011419501308500159119003347782202628145580667093554`49.52287874528033 w+1.92678440024627537826002592324899143295411903282792724531737014905024537617788`48.362489457882354 w^2) (1+0.40714256516374835199483519920523702959371225464114179735698712202221055782249`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.2895005610648353140778343345286648288249876911588216406634802627745237991654`49.074409922272594 w+6.56289078373223611868640454962053859645558510329759567859903591438583950676396`49.69897000433602 w^2+16.11190257634384986751170781002600694886640213148302832510120048735264631799674`49.41992872582297 w^3-10.16958052829067961961600522046197646066118571896946185903235747783413068470524`49.69897000433602 w^4)/((1+6.03020085696179806908576705744161783739059360297073917674382874540969823464622`49.52287874528033 w+6.05290517663600787736789556806317654773505434855687372960425687254059125486182`49.418819331939936 w^2+3.18905810688903924429022522264049796397080703036277455415407047497016718222677`49.17134403916723 w^3) (1+0.18428265811311164892836543190761198551039471861573760332713462036640775611004`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.36741009203264699891521059328839936880496407104544611225293190113214720088667`49.134665774563565 w+6.84095710718100352538133319770192671457419379590860795776112351514446737126303`49.6891199941815 w^2+17.5810182639546035427259339929312621762550838532567026219926835512585819432199`49.42707369192771 w^3-11.02770797185502005941090285293298438934318366663449424649960937287250216173403`49.69897000433602 w^4)/((1+6.52806442082302149652515879661553061909944359686201511015610768486802800819145`49.52287874528033 w+6.64905534096720430310427690059317560471123460572811249977190805758354763692644`49.42784924816291 w^2+3.3979178703653458799743355949195007448523111733150656109562076785484571710788`49.19908191850736 w^3) (1+0.1690924729208403630092530288810341838213309088150646122685294870999183907285`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.36822930251206006947086812415917376043307579112854813243521928406189243616826`49.135205720523 w+6.84388080419744452140629861564593855957550443644678383367404424554545855698255`49.688988909135446 w^2+17.59646853685513972333383714251280490619018156298779343235156857166563566428411`49.42714354441686 w^3-11.03674202665430686359393600754671767052225748788930783779029940886656936648201`49.69897000433602 w^4)/((1+6.53320733443752301918429209312530164974077140633417483036231190806983188816475`49.52287874528033 w+6.65529085940079838844458602707301864443903244462925994569667452738520339579098`49.427933623182376 w^2+3.40005697545476164906892580525718769577152081832386153043910098913218302354815`49.199340951092786 w^3) (1+0.16895576700782032805889844935156070273029851188825946876584076238130621565739`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.18059624070161322992526774399575610026447551595225226639587703380350099321948`48.942023321609 w+6.17413116543348947435170172027402066177692459752617480222871794526945152253236`49.69897000433602 w^2+14.059710721098927644763863548239301842559169385129628458388199823171735884959`49.407979759208374 w^3-8.97582322539886101360006212471298492254530202543149690942643905994665651386198`49.69897000433602 w^4)/((1+5.28299037118376040037664339616276059479575115302239877557638433273269072781086`49.52287874528033 w+5.19517352810760130373913623043214882816133757778565739650140268299608758500221`49.40083538040018 w^2+2.86732926628092964153150369086797220067948461877287849873242588086663089096334`49.11614636978014 w^3) (1+0.21833636268453035067087762284350626129501033211178821371168232204530253393893`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.39867579897980067158065567537577723043942512533289219211039928039564326592343`49.1541754724753 w+6.95254021439462490448341076611771408504160819318642004663122622281536414845122`49.68431201173049 w^2+18.17072007631535755489850557917678324022814266208054162103430004537070219472521`49.42966891245607 w^3-11.37262814177984641411898936824343418943847560501972241527629765901696949229605`49.69897000433602 w^4)/((1+6.72328622205858506315872450206695269828122923019671885429880053201720291456944`49.52287874528033 w+6.8867212448398364420933973312755683680222939296181686716351648475202258186678`49.43094233848464 w^2+3.47888002992669681356920443816084644976944872029121784361920897601308528115047`49.20857575055713 w^3) (1+0.16414022196639877846603132804333202839629740779365158382288251578308896931879`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.29208915620328572899825332114255766069777216071696058398317788936550954397322`49.076746578369395 w+6.57213021255740969547634350814442582643854946542834201286943802259317549567176`49.69897000433602 w^2+16.1607054235224960391363528081151321007527951541788109023896015168388450593478`49.42018316941569 w^3-10.19805339583971383231203342220035933326148116643345800090870775313960431825477`49.69897000433602 w^4)/((1+6.04707700442795576953857932052872315765388288350585799841203061698082828111341`49.52287874528033 w+6.07284539452108672776895294359786861901222293444465643082425756053485250778588`49.419156624673604 w^2+3.19620033354560594927653534155206568651676786582859811904275898046633087134932`49.17238055431851 w^3) (1+0.18369437806413903954769808762025677027912723890116493608177696312422703796217`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.4249428878549299203350693134199834840308089931462343987037153978006517258572`49.168998509703535 w+7.04628143215435036154138314984046006649416930278306392131558599700943693602611`49.68055387623413 w^2+18.66618927027753017957980358512407044764482834040633521761636875295904451570594`49.4317422151824 w^3-11.66259048245608090008057618810856796933832336632206514925897697002251416091578`49.69897000433602 w^4)/((1+6.88578934062840490381449221993078573050232018961693159443405216564600239272594`49.52287874528033 w+7.08598184399716082173373159185360410342418368675086956269541650950106173221055`49.43335679758679 w^2+3.54592049546556693279285266418936026253002606653739281269415326569456499338708`49.21598394969411 w^3) (1+0.16035659295399523213944878700301371044322541759887076918031573808058952346462`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.42942828461025113003392720308205432821628350247570294444355280057418630051044`49.171402142330365 w+7.06228857734646447092841755792451859274633325465237890740236604280235236479501`49.6799352961453 w^2+18.75079994461244563308296690482208406437090791925505612935866452712730511289125`49.43208699258223 w^3-11.7121200929144744265412460723463481482345517104368712306810141828399769770176`49.69897000433602 w^4)/((1+6.9134164170508525162298041722439813400801141738687471443255621702657236968439`49.52287874528033 w+7.11997858228969235402905473081940502648982361304276099014042175109085890159765`49.433753859018566 w^2+3.55728786551720586091054292589320205186029755980571634107614514266604810608566`49.21720204572307 w^3) (1+0.15974102968701567510674615065852845963359831124478165695095570208081852946913`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.3795168309941502931881204726559288443609094111584894476130871921304126766194`49.14248196866261 w+6.88416484174351427604424909880908106724657322448556287178045660296606565774458`49.68721168539817 w^2+17.80935556158691527934891900784242129395002323805866819572143416532314191724051`49.428095686368444 w^3-11.16123739488544374064469617213276332277870223950211321511242994750338702613365`49.69897000433602 w^4)/((1+6.6039109574380322859626037264034492025079648493467546470904516890418437352125`49.52287874528033 w+6.74115851798482920339899036613337199902939116223699846893859763653123307568181`49.42907734605477 w^2+3.42943006382567525378885165802509931695699454125615965422472249361637536205206`49.202851891844105 w^3) (1+0.1671117193884169615131939648976023738139031506576301837107465931095715293191`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.33408185305474376999215274613336681507706970217401773995086489828885450869198`49.11120583016444 w+6.7220089929866210247658132969292141735943579631011099862001716884410390384263`49.69471562432222 w^2+16.95249215386177717259835510758775393437674177895340507988935155718000802880164`49.42414240150981 w^3-10.66034712689214176853457757677427224504220060251645815668091634107791714286829`49.69897000433602 w^4)/((1+6.31737869649606677872885115604438040769705257382933990646006827969558049288672`49.52287874528033 w+6.39489117807130029408107210507480905486486743452716777223879173268259259641963`49.42424627932583 w^2+3.30997804532352894545501639090245443117341312551296584810729383458023029202587`49.18801790408753 w^3) (1+0.17501780257902646163118386768949036261202487446785612026622895537639493481155`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.37156541069579774058286690444199083518616459963086107227757417951567196960875`49.13738772951757 w+6.85578708280487086252858963557688021032061928045402158665445644412415307717489`49.688458063331694 w^2+17.65938787560058155251393340336931500766953739871667763414060888217722716756306`49.42742695342313 w^3-11.07353380006234021332275792363890956701809682763602443450383771582083456117942`49.69897000433602 w^4)/((1+6.55413473730605845181668249400401713864285270494465410345626904018303768699008`49.52287874528033 w+6.6806789572853446868712489628897285913427086041678973469154521824829844018614`49.42827528975835 w^2+3.40875779118201991489937581756771524387661699431555297539873456310293026645847`49.20038984089761 w^3) (1+0.16840313296398086574620173576232655872988976279732587086301870550958548327547`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.3654129831784235036088774255393007245845368348551627531861652073345755477644`49.13334255407213 w+6.83382957391425475687698158267949788236876448994105086492164840890169869935188`49.68944078121124 w^2+17.5433530807413005730915752309384131956807636345336173240828445074292384028183`49.42690297220821 w^3-11.00568515171849137364852034986131125797872956724733901261910914692166799925561`49.69897000433602 w^4)/((1+6.51552008294995378494104578420567110118084819360819141759495356846798050912264`49.52287874528033 w+6.6338519961015635694894057654735499626718974930968754269256596352775833276641`49.427642760205096 w^2+3.39269881100632726890904721221144495820918849421976178659969630837381797389466`49.198447984252134 w^3) (1+0.16942741769746914164445034540034771816064025951747589207539388378568603061961`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.23855158569489912144286816744232759260840924997382722767236596287649177652734`49.02204784329534 w+6.38103030019307126661305829536658214192117769438931252643010761309805618247735`49.69897000433602 w^2+15.15154059758646504435144253436298683498897294168344580056664421978304073952597`49.414654220970554 w^3-9.60992422077313948159474814751247072913058078375429545629006136720111680684788`49.69897000433602 w^4)/((1+5.69140762449728120420554621222224370524029946271901334775432400810706107091715`49.52287874528033 w+5.65736144065637807012053362353814425210073570251703272524196675324597020506371`49.4114795950944 w^2+3.04460608973125528788970816416661909718154488088505643906064380838445275066535`49.14878989994127 w^3) (1+0.19752006571036932223184472054590458982861147902958454674124702579544018172574`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.28071760570490396405597035757726400479328247975175448026440267140498446572057`49.06627340513208 w+6.53154162827014812927927383739422536575149023038919408280043801717561580870631`49.69897000433602 w^2+15.94632318298447489330092631852585490213963503187512409620138544022690345782911`49.419056004329015 w^3-10.07299804395216303905684010545295708303514208055034922116771730160973355270545`49.69897000433602 w^4)/((1+5.97272818415572039744948591204651001982907363190405124379970579178703116782151`49.52287874528033 w+5.98515569144636471278605193697933862907963464682670667282781801445091321630229`49.41765196011532 w^2+3.16469880334253000664198015861879736178576120773135092690643216711880229671456`49.167756550326 w^3) (1+0.18633187593966242005352260772715142047968168759067968220009724488246643217257`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.16079973654926428670178066002596812913650420980688942825730166398042211674807`48.90722794909287 w+6.10344666856192650883769618237222374138652619221631221452679497083108317090089`49.69897000433602 w^2+13.68699922172586791027822506858865461721186355437262239847011952903608890330706`49.405521749165004 w^3-8.76023944316288361453934485094131938859642026236869708545714275611604983794532`49.69897000433602 w^4)/((1+5.13388982212810446332229375141647837064411328429489361898094068304123722746819`49.52287874528033 w+5.03153526470470054366192612763762656960320637838657029053865472025439610235148`49.3963033912998 w^2+2.80158590895878982073355770911633095319296704896131957635042175543905018806733`49.10230578561457 w^3) (1+0.22784497464385101197165198118933524743914186340146849169159552807766422074505`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.40990913758030638069057830334935303387867892029021028088096526228774978035171`49.160676343575446 w+6.99262968543425826888352540380273757209920568209034528745494049940958156018591`49.68267557102998 w^2+18.38260677747762366268098488369007439509371542651793491782424726537494373515949`49.43056710542461 w^3-11.49661358409368527467301444900344111762906946502421297465762205729709280223422`49.69897000433602 w^4)/((1+6.79293699344208147919524983904758217469996633704503980967314268371288650241744`49.52287874528033 w+6.97197524000230246172695991123715449396799973119338109392357525720356848200875`49.43199411121204 w^2+3.50765212108282227112350571964283611514639370006982351362992586457869342653047`49.2118031307461 w^3) (1+0.16248338066409112359809017329357968229731975258014616905659523706848242973549`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.3714835834495225078640844679047548697054451455875370212531506011204309133718`49.13733453057112 w+6.85549504900973893754200283362255008767935343687635886327406023819954477044234`49.68847102701056 w^2+17.65784459612921848863115793292534669196610778199388270529802641539535624133996`49.42742002222038 w^3-11.07263134268498324511320710550257715374530389192651691381110197362770279850447`49.69897000433602 w^4)/((1+6.55362174588380965549877716808855000010975363560293283360411059476190146986828`49.52287874528033 w+6.6800563404889515106719624962726354776591050862511240105333860359237343257059`49.42826694640201 w^2+3.40854457721915158573234748081766218304861290673406784738327680546670107506687`49.20036422804906 w^3) (1+0.1684166101364557254279052991110441969746229582278335660081306904065568306758`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.37612645910845098235065634455644638426670240342463723573501273389478646654061`49.14032791645736 w+6.87206499934160979405676408653772398709541192879425159917119348470119769254447`49.68773991928856 w^2+17.74541095983705471971271231380442570469929487158537524615315978557085043659251`49.42781170428024 w^3-11.12383970754062691963065189923861162684465287097574540363296659517963230726844`49.69897000433602 w^4)/((1+6.58270455164771928317849404806358243005395774945466738045950776213100790504709`49.52287874528033 w+6.71537616662421468392937128472599689414403909010027286862884244946491301774741`49.42873744896146 w^2+3.42062684742887187613299556407524482459113323216049260196126456068065098890068`49.201808552806206 w^3) (1+0.16765799403527410090472624377160665536669899270524792662830392862207736556543`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.15025253461869062727655472150926730649459139175143999836642468774954939476829`48.886576641183446 w+6.06578371917131885616231303993553676502013703844893346338109070759074883512795`49.69897000433602 w^2+13.48850153049899582698102410383038217475363211187489050364617782500627426129674`49.404174641033705 w^3-8.64570668468656494242763340832169867233855844029870993817622207993798470471729`49.69897000433602 w^4)/((1+5.05129490784585438830897296241919375498683753659987511875137699520387839285886`49.52287874528033 w+4.9423114811950194090588364155381033545080638399467128313406970873401287573447`49.39360715596692 w^2+2.76489568154413062723239959460096538824507065323638384332852686972836764922001`49.09409739257642 w^3) (1+0.23370022518192060581687306986977732544012853603965858271739607715380233785986`50. z)),(-0.17824074074074074074074074074074074074074074074074074074074074074074074074074`49.69897000433602- 0.35477194585953661779729954495480219771187390513043083046854200808995781936703`49.1261222426575 w+6.79585224041639965825896076247980385182769141780404131962735342051600630193149`49.69117996568027 w^2+17.34266956743732251757428003771463405714549960697454530612909719387234586300417`49.425982934381366 w^3-10.88836263653170765712720335512867156438977081450494765673711038737601758446335`49.69897000433602 w^4)/((1+6.44851600572335899433090135625354047924781726053512039716070363443606113687663`49.52287874528033 w+6.5527920895756363190350970428972567738575603980747267882022904881621777307427`49.42652308530667 w^2+3.36478627425068129477707031255562693332523528074342442362826621068745139121871`49.195010171361226 w^3) (1+0.17125334569970506439243565884129153075756557187313170938452766057740949178899`50. z))} /. {w->w[z],pi1->pi1full[z]};
(* and 20 each of [5/2], [4/3], [3/4] and [2/5] Pades for the Ls part *)
Ftri3LoopLsPade61[z_] = {((16.02897763917025166611338985515134536559196443320004024396192270638515385532962`49.69897000433602+ 54.8286567778596038783157488791765182857061992555910746382824`49.4876968085073 w-2.2284907140941836300053699969616156339730991302565783904692`48.19285442330028 w^2-1.21582334696549658968387532287474918202876658578649484726958740933804433436832`48.2697862359344 w^3+0.54954182151374918160113375142831752267807814601983441669614642876153319236544`48.466442456602756 w^4+5.8508738366404282289028504181797744057075994735102926163160118508736642041201`49.65960449105583 w^5)/(1+3.85354644310207937397536461063755514514570876282860488387010981978325246436606`49.52287874528033 w+1.36772913371166566274703872654235432998125777738347263735361240175171532567501`49.006208963069334 w^2)+29.79227918237235820031958158314245007398967682025420449306072127243688518181306`50.81419163210965 THRSub[2,1])/(1+0.18118699614993550697198584363803430163262752807566512059604934628690401506635`50. z),((17.04229528384046329269968426119126551368487375046270679811421416320578006186532`49.69897000433602+ 48.7385136892469600297059455655066170628053306558126435258723`49.48404044739017 w+2.2069803538029419809052855452552755527216670524821146690294`48.19809545429135 w^2-2.9293153389425015423967755697771601235177804541709835479149048150703170429118`48.69377362748333 w^3+0.59061195877599217320338286928420585394895663544664922053430678091058158370016`48.70326976045937 w^4+5.65339630101218810023920547017433045113547249886865717632151248089536891045874`49.590535143912895 w^5)/(1+3.26116176336773844881093723617327798558195296516253908616550673329670818741974`49.52287874528033 w+1.28725277927951634013420880965226766727015284444869090807365142739091603653036`49.03113388050598 w^2)+32.26204926508159144974211380904180883641437244888202856878368958968083785421793`50.66113613822828 THRSub[2,1])/(1+0.27910700714736184257397532163420367967607011719078791811369469209189325570286`50. z),((15.87372365774440586830944040901178590808731714362653771253472481642548727077809`49.69897000433602+ 56.4503987681021339794923357186835810866816768192921512919062`49.488595719763566 w-3.6043895140770475393695001830521218530963688265908337572741`48.394871768972386 w^2-0.68138718751231288252950105704772676776352990212290776783816719644975314174308`48.01157410310993 w^3+0.49594756040181357524348398042613952811787856036664294902708314327866387592848`48.39326775980221 w^4+5.89156049109386200285623774733669278448983520651830416444426223692464123372438`49.67125148700083 w^5)/(1+3.99437234134867320173190055231698238870502104516001087227896697739474139228823`49.52287874528033 w+1.35969970875027464714467940577268824925538752714667987491842236983804618026531`48.99419379528651 w^2)+29.41387697003168432525049385141555090339151180415789975544922354406308182435778`50.846177142609555 THRSub[2,1])/(1+0.16618432482710390747581946688356202637800294243156767602726945304117159151416`50. z),((16.28229886510379671281643063319972558481066819850286560006898389648911345058921`49.69897000433602+ 52.7278991059391457409706871363099031019174083157715035532807`49.486479418402894 w-0.5241656678180226446092953314056874572325512241617370632703`47.57300520330183 w^2-1.87146234711549836696830201891806489398567647876823219581927803078846673050007`48.467951947736275 w^3+0.5946269706248493016578210382084270388427952020162036678767577189329217250901`48.54842636100899 w^4+5.79518346945325499498166543619288716377748679424822969836513021366708992835036`49.64124141053591 w^5)/(1+3.66302738745696637785695843082617923554992873757534715122342556253567928661778`49.52287874528033 w+1.36454076950029105868121535801766365756646305383444531595457957061487089634088`49.01942786334225 w^2)+30.40970175309006705662683779639490091932724739310090120810397576621562979359802`50.76806414816673 THRSub[2,1])/(1+0.20566620793487112985726112561010073585988561992425928991860740205927789341025`50. z),((16.62540971486028355229860995526818852013651590814472659679598479760621617139148`49.69897000433602+ 50.6095462269292900102092968681984698792086444687882032924912`49.48519902595839 w+1.0455206494730325614395946810500261210462986747643068988442`47.874599656336976 w^2-2.47283436331008505445690295100912797850237356627258955028197024594637032509727`48.603311844015664 w^3+0.60744992369739119395406120964324961139492000623729283518719080833137648061653`48.62555801113122 w^4+5.72992934405214357820112342891433919369652403998065519146186116609706834238723`49.617598079813675 w^5)/(1+3.45796564244872462351247629009937185656903275520863638389451799338189792424874`49.52287874528033 w+1.33879092103011762449591366587722119552824672239903515770161162094560904027819`49.02869403840119 w^2)+31.24596954753600824038401624454988833679142065032967805614390404830722901462818`50.71493447827072 THRSub[2,1])/(1+0.23882206815126547052302315182801026394214211254473648622952693178442451370419`50. z),((21.60463872074739897539084311979644049921021164969742624230625543985301238552602`49.69897000433602+ 40.7763247292368724564403041943064952909097016575641167400324`49.47974769422039 w-2.4706884748607566301728965678226424415022520715498295133636`48.25731057642772 w^2-3.3683504717521289478505091124956483261839142906925281481059799134781425577635`48.921200063514306 w^3+1.62134644086045475269612280410582483017064465387471995630956328016286809346968`49.218605717328835 w^4+3.96459958087984424746317999051372533141009843629622975422139039776308745500863`49.318960720920124 w^5)/(1+2.18298586411199012417071930186091088371687410892249178058569630902431194586846`49.52287874528033 w+0.41558988903867615649441677842489298808626802207471275974288466873628395514866`48.72019502260589 w^2)+43.38189839312550998299863810588866003283230846017041953733118973912776880313286`50.37820284784967 THRSub[2,1])/(1+0.71998033237338995931335162173006430592845231874727279323535753509391118494847`50. z),((18.84179906504965772756327895880444465126867978661073920076392888711529632456797`49.69897000433602+ 44.3657062428670830933949458558036491094025059628739494270116`49.48145231626547 w+2.7045996687303630530464353672169919041061773844904540930508`48.28926518190214 w^2-3.50397993169633060752142040898227237823487268886290161316680665802444396446499`48.839943949241054 w^3+0.60557282922938633737268598217290477976925391668435708348424310692775375686739`49.394162303552854 w^4+5.20808779107884264332351025204863778018934377696754088775389317963902040689673`49.48587999783346 w^5)/(1+2.70814108517342963887349061321676741378311428511504450794497469139472588132335`49.52287874528033 w+0.96601088356265834017520299317385496824983672582582155949804360978475069288042`48.980173998936905 w^2)+36.64799934295578602640714405353983356891426171485938010268582226536159066821794`50.506168329025634 THRSub[2,1])/(1+0.4529986106072641149779467604677147601769442688811283297545940367826406467261`50. z),((26.11944992088892957819004904995196110917014623608585362695547450342776124686178`49.69897000433602+ 35.1797036531001722452346890682304932906879993019192378137693`49.47656712944494 w-18.0398626849950888401721013788939757249027774485948474767896`49.10346501071262 w^2-3.43298927031248832441682429591733843415497916111529882788859455127114512721937`49.08376365530749 w^3+6.08637579643411082234593011998421776405053442157326266103403724547961384331256`49.41127077409083 w^4+0.49771260770889431950471032150618729036277360901033745806918586761911049808007`48.44410819049067 w^5)/(1+1.57422328241864426848672877707568042950124925067556631036664383153291934990772`49.52287874528033 w-0.42510642051421612546583769010654669222252080828738966002703418601480693682526`48.858176238345095 w^2)+54.38589668511134761661423400955657121086463208167874515670127849844297964076858`50.27064554271716 THRSub[2,1])/(1+1.15626047088123404858172663804546389827479276326969239830652087764081869389575`50. z),((19.57029825807537869174204951335114651203540920286929767278800364185863303572837`49.69897000433602+ 43.2764134601426720057483918275554750750052034402807816173052`49.48089790648978 w+1.8116566740572013747095595401761535205584123832383876969547`48.11918292687458 w^2-3.50061546359759076819260205473418513768244144788208629244659336025082635086754`48.86597084917215 w^3+0.74257920264598894434640990507938856752923667049273626739595356622989953482995`49.581098770752796 w^4+4.94895383219500798937165803836164473083717170204877235310006094799421888775836`49.445098922118824 w^5)/(1+2.54797569857671957821132351903825002278817276064384857981695806280950770230209`49.52287874528033 w+0.82115963736858988124078767370245037065446531374477276852717445319608890795139`48.93763664956942 w^2)+38.42357832519911787730157615377877188889294114686911577271183225228968824187917`50.463982555618365 THRSub[2,1])/(1+0.52339573570214091546658988537022611443184163691565622313412137484274949396367`50. z),((17.87747203879258312733907580131175568080761042434041994184213308449031575554172`49.69897000433602+ 46.2432399897680360111899238524163288340178016515741824510976`49.482513056026974 w+3.0804676174660534334658738697632549251574869491207042945777`48.342975667553226 w^2-3.36554503302049591065078053375585620557457458955626385777432506853591031942454`48.78651063993628 w^3+0.55389064351287404503654667656929746757792222456960451329256266893444496220183`48.899083630904755 w^4+5.47755975160761164311283571069993520944198659341348773816848153043409701403785`49.54032348119155 w^5)/(1+2.96459733137569267302510565101441118595896212098110620750207003552865917544903`49.52287874528033 w+1.14960537743411631846466532910149639486602107299607817114617275026260022961868`49.017565246226255 w^2)+34.29763462570781287397645371618094702461293499220541272967787964458213776478669`50.577402592114105 THRSub[2,1])/(1+0.35981271424705634939424526234839208527422428411243316105395477854103710118466`50. z),((22.21608042717789804889870588241275543145868010810985681363173458423873472604592`49.69897000433602+ 40.0703155796058146919731445883540811929536151865640351368324`49.47942148003588 w-4.1493073694929844028920152836682741360518606208996259121209`48.47975129696257 w^2-3.33373978391483621836412455608810437550966579639477601634468411873485837394605`48.937967563088634 w^3+2.02846407083327267210820067588068430485802769774879212584219775400371057870018`49.230573845817005 w^4+3.59544166023250597646559872227121656142327642974755987406349932176617418709244`49.27302460995536 w^5)/(1+2.08839351283492438713957520390951887050149334292033247907182671711890097334348`49.52287874528033 w+0.29618474189610542961359557385877403420328210535478483184521902057316391173519`48.597268316778724 w^2)+44.8721718940416055338377501236963885156381156736861759455946987068429966802511`50.358617861465945 THRSub[2,1])/(1+0.77906583131133187667645235793728773986391540281177807502401747279601473070736`50. z),((16.50388780306716741959809298320812594355896175314850175770230448634104567098648`49.69897000433602+ 51.2850758565423600329296473397907359578755282343858234047339`49.48561218027795 w+0.5670978645393715680572414902561030163010139546977532890994`47.60937553009591 w^2-2.28916302768723208979831698259946328418778547165290108086523794201299760240578`48.56476089026753 w^3+0.60715412893268556778874634092080045046929122527932358113201836355314226903977`48.60079445429553 w^4+5.75234988906246692612171605324542164783821789967063269926460240597930464462871`49.62581822636497 w^5)/(1+3.52508987808264493874987703337961010176073623398931823229958473993210547983054`49.52287874528033 w+1.35009035975355900127516014155902856092109022343200438294441123644295122143322`49.026319352395745 w^2)+30.94978287426639642021606611066567291297463339856813254191492022963926355802898`50.73269550268408 THRSub[2,1])/(1+0.22707903081070586544101402236992627423839914078012254941275967419942996040959`50. z),((16.37110053814050927131383772901333057909022232255452725961688357560021512927131`49.69897000433602+ 52.1128561371284712792117669916131988499586079008769838849188`49.48611252931624 w-0.0490332060205610169358993096478529070341560584940815765894`46.54650445048213 w^2-2.05334124667816645873844157831626000356206063175136450295416577122557105448382`48.51198560467867 w^3+0.6019169773118145564335474982226299973138329661343281214069364394537986847803`48.57087303645151 w^4+5.77758903158220464511779585014368244056465941134981947271801488563310196353049`49.63499100433834 w^5)/(1+3.6050507934822354880965717011347999587625239741881423754186068998856198526524`49.52287874528033 w+1.35982962170590870248732705589071323891825432163602643800613415250435421551513`49.02263105985773 w^2)+30.62613903365471997198790264048600854709235181998068176231136649788744190500165`50.75339164261573 THRSub[2,1])/(1+0.21424738763314306187536952604065720998896766611111288452199396232379423395401`50. z),((31.67413766815919205027523128935871169228933950386820233430457193693037192003541`49.69897000433602+ 24.89745411752053129154927067479708697815248677908692968803326749508097268413265`49.464362082606826 w-47.0868207224720492951163758474140289927360110270028075317615`49.51886936042229 w^2-4.44592098197152891987599014888932679039628422554621946759394543389532078073317`49.39236239315184 w^3+16.06651991246113842695251407656517285318147236997063776260126405384962986771112`49.65615127571174 w^4-6.15783453314172127005771634504355664561095491065034506512381232411438162363023`49.45450961471829 w^5)/(1+0.95611827082041779744825461403608972244199180794823470255067958608215940233355`49.52287874528033 w-1.39702045191228810554226938145483609526060326099536400939797287542558290509581`49.469717930385954 w^2)+67.92439736074547296399737305232731249630885271894146924366513495854796627524836`50.20157681494589 THRSub[2,1])/(1+1.6930270890890841734690672865777440116223394085790092001231089256954491583055`50. z),((19.30264480493898966577304833149130451491037046619129545331093489396380917611542`49.69897000433602+ 43.6555181257757239141059771682390761104362997697719266312104`49.481085474880516 w+2.1887724779799445521412874376403513259359292667863908267457`48.19967684115102 w^2-3.50804311258971255441882888139104242165808533928503126318023278398287922178347`48.85723053923474 w^3+0.6816683028312418481458946851003696033976872917350321419164372560531593427558`49.69897000433602 w^4+5.04988792949624938876602067247798132962494267597194013233369503869116452063782`49.46015946354289 w^5)/(1+2.60432275635144519679858226985711817139829829088973798012058904539309058268137`49.52287874528033 w+0.87465320353060414558570138121935046247554102719139631466441528065574001676988`48.95479090426429 w^2)+37.77122366171626656121964052422624551505245392488866734329536015514001207880484`50.47855535114427 THRSub[2,1])/(1+0.49753155657483078822223651029389726820912779292861437086798848803434108092562`50. z),((29.90752430359971612259155605944845697173649656813867628941574660028031877122921`49.69897000433602+ 28.95685778131116398294440602625869326097103356210333809300970389406130614373778`49.470548281557065 w-36.2587819367561617053302641177073709444738200176574526446907`49.40156103579081 w^2-4.08299441697908653677655942596731009562769799344850436356167157327142173819182`49.287413914236616 w^3+12.28654021899362216810033423378601102983055273754719663129965035986728506189402`49.57974861775315 w^4-3.68847273075755725795862616090083784712812656175843880878516206588891480894769`49.25556318366383 w^5)/(1+1.15419064366320001260770810791785234856756237013615778155272015368059522989376`49.52287874528033 w-1.07609674561188586152671944581821039292993691582368684797393652760501213642753`49.32409145121056 w^2)+63.61861145200084449764448377934301081742410053383026814760998140818958331433717`50.21929493299895 THRSub[2,1])/(1+1.5223137880864518893649581610999370536049716328437284146846931642270340954785`50. z),((16.9850693888649247150758302935307975337250823372915665755016879764675551363506`49.69897000433602+ 48.9620019016777550544303225456787180831642355315949710366834`49.4841793353934 w+2.0843831999771568921017742789059086052445132806817912316188`48.17336196292404 w^2-2.87953704622559206600886749043681659812984391810765474809657483908068312069665`48.68404349740234 w^3+0.59381512346563536978793146162453138682097989691776472617614439746947574152618`48.69266240729658 w^4+5.6640943281919897858206451781402430600107063617027429712888971762977226348747`49.594154849303024 w^5)/(1+3.28564158838034019711080317498373440140821415224074005755099653814058144713863`49.52287874528033 w+1.29526782132560772536259661623661147389612541691957928444770314315749248765119`49.031245041511205 w^2)+32.12257197076008202974254572494121331904282046669338549938166880796010342545851`50.66794550946233 THRSub[2,1])/(1+0.27357709232271077906817076935100098118843916011208424699737047069539226245144`50. z),((16.4897969854485679531830985563346956576141566566569990608608472397566472770799`49.69897000433602+ 51.3681961034914022010220799016664656189432160588362695315265`49.48566273515717 w+0.506605218344845302909926488851266040959242959572321282256`47.5604453220508 w^2-2.26599100857628426565347992648373101504224883479739986370210742034391962945719`48.55975539936229 w^3+0.6068698249692901296663573252076133047628259388681494244494794120099598170566`48.5977837561276 w^4+5.75498287450696684072837965231834410516795347580537436899068138508018800583965`49.62678198139805 w^5)/(1+3.5332276582095612529360621577895212779162766185163159336176996498741005207343`49.52287874528033 w+1.35126159477358760095882048257771607952659769851991229350122252587536201466493`49.02598512358186 w^2)+30.91543917169852563270358890557897533229021243659553046376326362669942623829995`50.73482532537425 THRSub[2,1])/(1+0.22571739162142179717265096070625571770953343089911803511908969091277886904105`50. z),((20.02620244836833549006911492875925730453041332458229546019058048039266065375676`49.69897000433602+ 42.6708490908577525380546330296226289451913765151368955617233`49.48060888710293 w+1.055052672253648115369430931003754882637404622317875726943`47.887645445805084 w^2-3.47764778103126789398990641710412828380896234588271755912700422851655259902505`48.8794438714069 w^3+0.87537130696564147252319240286797005829324922303937792750847274726335124134997`49.35935866671153 w^4+4.76162508369197165743251324958713597883556771107562697476329381412826725146499`49.4189918331737 w^5)/(1+2.45747169089011805527012940451188860284896743259722825340095807223958775544072`49.52287874528033 w+0.72976191966708926559634468922478439796233938879086068763016150798519114578976`48.90381767694179 w^2)+39.53475855154736847502049657147605115802903782855906269419625396035637815143023`50.44126552725459 THRSub[2,1])/(1+0.56745116448310134839082513031090914302792567783940567900914834103204735514385`50. z),((17.32303232362656612765603650677823804518134160629035909228353203001857640861606`49.69897000433602+ 47.7588454945187231743776142862829899867482220237022796367271`49.48343325944092 w+2.6736286636725167299938848660548165488523887260074659054734`48.28115123564537 w^2-3.12892818746321850373707971310746820775508590478819438210223092841410637037479`48.73349091094302 w^3+0.57437121421820602256146719259925881488565037533483111441398071077270097244304`48.75827817263961 w^4+5.59894277176489020073730871901652296760649764989992141580876594774620876917037`49.57315629086849 w^5)/(1+3.15014979637407172337229200382234298425303227046905702958523163151506858899139`49.52287874528033 w+1.24472218121588866350705748436257508245595894083756468719664030902818139317023`49.02889454424869 w^2)+32.94629269617049154707453941141288300950448169677479584567438744326084437314136`50.629965955099166 THRSub[2,1])/(1+0.30623549362722252214491657124089813559612911333320424784307817737458468998571`50. z),((59.1722902414808540478867439309765840705696490218574454388072931084195102135907`49.69897000433602+ 91.4898648790133270107993245985570471643446269357684128193562`49.51455006138324 w-27.6441055801292704460139551506116877228032354947430471055404`48.766476663837985 w^2-70.8518393007839409164119953453140159727624423442869586085867`49.3151545643824 w^3+27.8155347026552590128103340297864669860999377298080992969`49.29326016780932 w^4)/(1+1.59106708998157340775099512367688179018776069638134952567354684091527506580065`49.52287874528033 w-0.4265655544601865358277254580244004896584353647698479684497454108046295052901`48.721459763154215 w^2-0.65537155500635430425408959199156043419049547551907371709527628108801232835695`49.07613909045677 w^3)+134.9459427888492959437283680372472659559070974574912552177153`50.089859702717895 THRSub[2,1])/(1+4.35025842869028931613327628919431731010674365547906595244307606934002125273495`50. z),((76.7062079917664209087867194919535615284899854106598698714649`49.69897000433602+ 119.4864005273750094092532803587120890678057450778234416206195`49.520663014496364 w-36.1031872488041067693388339733237101821420540100224962632662`48.77452559800701 w^2-103.5056786453428534059401203156507479312825153360133179875638`49.361405949267876 w^3+38.4418982527057643855883442417889388831793021234445574866181`49.30938945955264 w^4)/(1+1.56966630644863729531366323129017176728350047185533282302878444872028236519706`49.52287874528033 w-0.47163498653968927081562761325362975105424800653976018295433951010342249569151`48.77330870675078 w^2-0.73297848507788974090613013774101608658303681010645916121053005053501086361502`49.1422726015971 w^3)+177.6815506410478866936470882815856332172885956940384695690248`50.066488618549364 THRSub[2,1])/(1+6.0446150087483723280097452955506556673209437121382702504090371478249801668472`50. z),((110.8805310301949271943017584079636877051732921030304742599693`49.69897000433602+ 173.4868174218161089907630558506123299439925307982238344709706`49.527029840245035 w-53.8815767341558024208725189873501142355024221679675301133214`48.793056198768156 w^2-166.849416326230361320535490985026266201676678967584339341725`49.40111123685104 w^3+59.284115518995769411983609341942903502287465849066347240269`49.32477249617523 w^4)/(1+1.54230251229933981557448239664808533770327085872734928982864634104943396442775`49.52287874528033 w-0.52854796451429138804135768626252583545689410807140930727242778095122315007996`48.83101541062426 w^2-0.80808112550797125825247607688803709287201524407470906932696877481385089454407`49.20064729963067 w^3)+260.9749987331521528318212959526123701056829283504593234748626`50.04414227239762 THRSub[2,1])/(1+9.34698530236109516498488625124675614224169272840790161567330687801846481904924`50. z),((101.5141369198749252528163053770285578245876430289783176959989`49.69897000433602+ 158.725996888110043016108675062578612148423513475765347555749`49.525707534294476 w-48.9129824712440986927576782867791300446559630785608507350994`48.7884208174134 w^2-149.4966186771379103056048289667129996318130836778022385112987`49.39343216099917 w^3+53.5565264044338453323628105484054716484941315801940104472332`49.321629342492834 w^4)/(1+1.54835811146668699667178556904821776207760265742902538043593559571992014622186`49.52287874528033 w-0.51597615769299183331244235356713205584080599951087549707167256513973127207535`48.818873952664504 w^2-0.79289335773507949600577477382992278242531434204829637256234548919416816005621`49.18924365036352 w^3)+238.1461848087079734525077065168039235517510020409470287559761`50.04861929264514 THRSub[2,1])/(1+8.44188173576203877376764138651296641756685999047258694589258664733950401408279`50. z),((91.4015407430890524235202688403031958823354685849093355869209`49.69897000433602+ 142.7617115270170808168451511045878204740758149719452209932156`49.523979252981945 w-43.6166143982488488735099953715530908785482975811636915523823`48.782969056510545 w^2-130.7584478561816653834364815269051682306343156270176994581786`49.38297643125231 w^3+47.3845378911966447191266725178877979279420757003058185793022`49.317494101647455 w^4)/(1+1.55598863376786360541136188479330712229964206477334640811174218259921289172457`49.52287874528033 w-0.50012293937738520399057879767628696841803390125898259741393871180332843670468`48.80310048607368 w^2-0.77273527035355160129796057497591557091940475053115641028102635695591039737749`49.17380282251707 w^3)+213.4986444966333788087130817597488940168062898186910097558561`50.0545994159903 THRSub[2,1])/(1+7.46467036077835620582532820580342388629673337730639686862649260192665022855816`50. z),((83.9737285856941368804066410014713864839788927600176267084725`49.69897000433602+ 131.0111305700968330608779960579318731568201316718156881459727`49.522447235141115 w-39.785951713414051351611133691849392762393995310865101936043`48.77873086788488 w^2-116.9889646963244384263984167769118388636597019617892377131788`49.37327371308875 w^3+42.8602419410427964059373854465364731132565165069345148927635`49.31378518186148 w^4)/(1+1.5624706274842902226346376973290570808675443456446653151887048088313217534577`49.52287874528033 w-0.48663753463454616151880267541891660850998712240074313565500383672455167367835`48.78924369833073 w^2-0.7545531773125470963255144402968641653497401859442757783895325450255259214968`49.1595654061867 w^3)+195.3947573860044700399647958324092123204858258312122530824195`50.06002369373526 THRSub[2,1])/(1+6.74689795055289313173600759412415704491259448860722440047104205003885699909137`50. z),((107.921793988420092805409764048842699985113410869938393255355`49.69897000433602+ 168.8262579455121836693238283985968614468106145731372912527065`49.52663665328549 w-52.3065000386593239544015225678616554867466197417264386684224`48.79163663205161 w^2-161.367912138139870231577738589500657132184353273195730528907`49.39885540461629 w^3+57.4737938670336721184471475511875964647412739298723162739238`49.323839046885766 w^4)/(1+1.54412235957892707036539407837873816524876443497144492451066012461065019557059`49.52287874528033 w-0.52477038746377449723148151869895801163648378689896270281331745599630100959143`48.82739982093989 w^2-0.80358541103111781012747274685369628229152914085889552513933910619720210045229`49.19729187573865 w^3)+253.76363685979078632484762639401689072139761946055582486053`50.04546466886854 THRSub[2,1])/(1+9.06107341165936474750049284088100852189126146927168470087603498887502361267645`50. z),((86.8630308698283230043509452039057124569445993762008862847668`49.69897000433602+ 135.5848711399193616827141105181859009791083701253493677792148`49.52307406619413 w-41.2689868193538883701366143013835023237537111966807377544528`48.7803960971001 w^2-122.3460367887849194906646517783927705512915063626308992248642`49.37729553256165 w^3+44.6191395534910655077138804344683537074697260795172534621263`49.31530882636168 w^4)/(1+1.55985144454954050372762776563701148344856655190923568189943347115748422210056`49.52287874528033 w-0.49208923636685848983196287345626613981506341236224705467658960529980701091774`48.794896462574435 w^2-0.76202945308894248666565127584966759413014028094551524055857090651053611501746`49.165456088458484 w^3)+202.4368851716905441018553201679394014926947178972519640819181`50.05779023867196 THRSub[2,1])/(1+7.0261001463553615416452596836754062011018840065284183495538349359159746739565`50. z),((42.82260863104144718804056708339236220992001724192485739928355525319426772099735`49.69897000433602+ 64.7689330237731054594801351747016842226447597337607826682966`49.504155179174376 w-20.9749328557178090831993551480504250210760608204257913903736`48.777423570761904 w^2-39.7746938443892539498451018445565366266358084299165292922126`49.20751303273515 w^3+17.8855333960319443680951377215310907735360844845989331341481`49.257863853240494 w^4)/(1+1.6124442738040185063653724388335031862897037236519221338492124810125822026668`49.52287874528033 w-0.3780343766615493092390095906829935058974381786093574220775693413271165765337`48.65388634811466 w^2-0.5074639863907507447299820906019245409167923425909455780252150161480648035078`48.928710235776094 w^3)+95.09668652091330716676600008323268409295998068548894095737403931031716779459446`50.13384751601059 THRSub[2,1])/(1+2.77033824125519817074252033454308484239550537769926256698415952446351767679895`50. z),((49.55931690075651885837900178692514863647389150186761633917988811787779360130962`49.69897000433602+ 75.9106196489606189346543492804202129912677292141462589887936`49.509318359901286 w-23.4785587987961138018115809865050180854774396604375163675871`48.76798759401734 w^2-52.7355572894651647310717399308572309337539371131158990327665`49.26663352787484 w^3+21.9944790984780519737360886591810982051698968180965189499189`49.277188432449094 w^4)/(1+1.60458327244953231109105494923106746850686365700426807533368116209231759904806`49.52287874528033 w-0.39708030306348463860567689935841073252798301034114104193156783385371077835404`48.68295498037457 w^2-0.58369740127380571777010738646270265913663155053952632882726049725488729286887`49.00872440274444 w^3)+111.51613863249388916349190487527742048968273562144094383755370455113756779557305`50.11135804736011 THRSub[2,1])/(1+3.42132715013938258851515009314268734835491342853413455478516120950555722403093`50. z),((113.9499066126594159259994591018674619571001824228335376865264`49.69897000433602+ 178.319738184981203188164169187476893583336812372391423738108`49.52741640617158 w-55.5203909524649619802073133128877110910317625597402785526689`48.79448547478447 w^2-172.5359606660341404849354936726605778765182706856794165417903`49.40330712047291 w^3+61.1630778599265970553780938007000713573465269989880812188171`49.325689627202905 w^4)/(1+1.54049768143881751228346539138992277686078818787520549028503555995640706274232`49.52287874528033 w-0.53229406991411716191900008033435757091936775106550364156175785870196630366257`48.83457390474816 w^2-0.81248483576471970261575640341084589693642550009616748770569268137720787597256`49.203917836357974 w^3)+268.4560211213847938610903865449981671841911524950498756638505`50.04284940506276 THRSub[2,1])/(1+9.64358853666870548913754052031566539855859398014921413089271700110150300473582`50. z),((23.00913576039309909365678755888159878949139269763238418871946662554504870751887`49.69897000433602+ 23.56323840954361682172876361736809721186935604691957381168313873029251540485947`49.45219790016767 w-25.0425038077268041060052079911123088575586107367732202485688`48.98084697717233 w^2+10.7287725567015369331198287527225895464970681487795545754558`48.56559626455119 w^3+2.5531130465282630054861492300075647876072206967537180236653`48.4651656397112 w^4)/(1+1.29557756280515579787740766998736812240533135858298041608698708786691998974223`49.52287874528033 w-0.8438419605723253640960900382020058642878894891172837182795353718262872706431`48.8531512493826 w^2+0.4144064591709824458533745520453756476010968966696219584456841001259006330815`48.43182724885365 w^3)+46.80509425674788303168850458052490917506814376113252428151794982154563299149584`50.336185903335625 THRSub[2,1])/(1+0.85570121544625785250209413181663381727720377473143595061975673699680316679382`50. z),((62.99523068052550582107646808491368095857449810660170848346418066679800085509961`49.69897000433602+ 97.6270084093123044354569311164146143728556276970157439761405`49.51617570513978 w-29.4176408901757624545729688717602335088759945356523142969047`48.76761816865256 w^2-77.997454636066899592653023605849795316982439714872135784669`49.32840744353297 w^3+30.1291200287871254855149687752691703501794780433306955696178`49.29776133759346 w^4)/(1+1.5859097521001228819951334695149702991952212003939879124421726183224293108777`49.52287874528033 w-0.43752540129409352862908743867124606765873207627474057099902638669360314479532`48.73470411680323 w^2-0.67661033197974311153935650074338823827991805200599701900482560228528286971008`49.09488908784626 w^3)+144.2636369728922958960153495934023098077050550322649096839869`50.08345916252368 THRSub[2,1])/(1+4.71968096051207499251918680194884324215281138914533974903344151936577403207741`50. z),((116.913642780189949510011629122704053392118762398658532156403`49.69897000433602+ 182.9846203084516760367113948550095549941439260186075315714155`49.52777063788287 w-57.1071270963102496502904018801245472229981522727520706685737`48.79582423073129 w^2-178.0269113249879484107541399627595633671952688809155859017128`49.4053006376044 w^3+62.9782392610795979697879628821448716278695290295725919191863`49.32652972786626 w^4)/(1+1.53883033209204502877005251193450883366005384478477268045909304297690045677158`49.52287874528033 w-0.53575463857473238889982946147864500707366867384144267471794745423464679921692`48.83783771947923 w^2-0.81650629934205499960534425754577659784555543329313743870306786491395207063022`49.20689058538307 w^3)+275.6795674181558063537317858728583621609232310105814639023274`50.041670979444675 THRSub[2,1])/(1+9.92998350831899167454910891177773792720765877367733461090021058537662934292406`50. z),((61.30816093622033187196499193502596015350775378834804967042840237937299011005179`49.69897000433602+ 94.9217070390272107640462760704384521916572885160777699480422`49.51548371128149 w-28.6286779783949212239794943660512626838186064345539709499504`48.76704121325219 w^2-74.8467954736048317626759127466536721469256891707404254019544`49.3228592389919 w^3+29.1080037002038098139823041636320580827666768980381163363775`49.2958681411434 w^4)/(1+1.58815582465402566070100705079365469423590026634258340183365369770994391097268`49.52287874528033 w-0.43276362167923596792447196882693824544240240878110727586252390883372646108779`48.72900741117591 w^2-0.66762582665768739589119898952372983455298884288911309239558749819675259918751`49.08702066893257 w^3)+140.1517235922811296121329434783596393951134145629680634467347`50.08616729900716 THRSub[2,1])/(1+4.55665420499796155019385990464394551324325987694932706047095078898872342245463`50. z),((110.22690876602818936207026099757641884401146248043822368869`49.69897000433602+ 172.4574025858643724342337873485361385313403787960133201882366`49.526944775082924 w-53.5332153699994795365794957793793592572010300208290822716724`48.79274614588719 w^2-165.6384799752869509472901858990871886437621089133852179631041`49.40062511995296 w^3+58.8841139929468481864340055147724944125490335876408959269187`49.324570607119895 w^4)/(1+1.54269759663241905502708112578749483890629015641138561289019994491953015280997`49.52287874528033 w-0.52772789141476866165692454473193400086909731599164147753255288138737850313418`48.83023284197669 w^2-0.80710991656267911069573036855992453855605616953011031467650323005003181980499`49.19992384930263 w^3)+259.3819181015037619956773370523823366810819981133017904471722`50.04442773783684 THRSub[2,1])/(1+9.28382376596428287976527310011044662477258167394475062559737052855778088986767`50. z),((49.10365239032707734521631212604944701322959731133495268227635004939909676186038`49.69897000433602+ 75.1646720959907908053350502197642400070326438481918459643534`49.50901709844255 w-23.2954204796814331311099922206248460666655316543861272443849`48.76832067855445 w^2-51.868461192191041798313271157719775967089431504073423020522`49.26352510603668 w^3+21.7178817921203715154832409575691306792037756085543634382387`49.27617044708101 w^4)/(1+1.60520307808073310158693462774937921630244239807905072418110031755153955564872`49.52287874528033 w-0.39567608513511283384730184843838050673608481956659615305065267619523033749552`48.6809784162811 w^2-0.57940550129466619390776515922188024346905328021788306879532789428368618370417`49.00446523898751 w^3)+110.40554258047582161264890942332420934591984858291368721926624404152365306534183`50.11263682250696 THRSub[2,1])/(1+3.3772948823632607879987661108019680372010043001011640247322571860284989908222`50. z),((71.1051047147679615090525962794431436625413342879158019874822`49.69897000433602+ 110.5791231278522141022650323368532905518353612195778133259079`49.51903970495166 w-33.3223512364297437292423743000176306405372136906852665697533`48.7714069652197 w^2-93.1007476396454418965891430009094124328780521436936864143607`49.35002405857756 w^3+35.0425495695786233036602118909600401990592315903288728013665`49.30529383759784 w^4)/(1+1.57586231665375205543353820715516101667480931188156170116978507113661119469488`49.52287874528033 w-0.4586752147145379742125331374097482418031846944491837333345440397190441232015`48.75905938463046 w^2-0.71295015994225359768142356583694875046639974398268656226599289866877414947091`49.12581371736942 w^3)+164.0299208915258686174762675405568914852738181158991703554065`50.072509834751415 THRSub[2,1])/(1+5.50336311466938546395802527673834195784631928630576250363081868868904200152797`50. z),((101.6024028236854552686894152475511325864091503054625311741972`49.69897000433602+ 158.8652001525688704487899858900150468109427278682042623197343`49.525721119861146 w-48.959550252957315089707020587697794606461176053848326821141`48.78846642167726 w^2-149.6601510379971284593912791373993008374378760126210272794724`49.39351242167536 w^3+53.6104547106685895492034702039438267239919467022515619340546`49.321661704120984 w^4)/(1+1.54829683829728683463705280410164107283845989009673659698519390030313038426611`49.52287874528033 w-0.51610339551708327573342243239959654927261698847053082279858449558860874098624`48.81899841571298 w^2-0.79305040576680923058414938394368420337376204806536836057032270470014032061819`49.18936256603728 w^3)+238.3613162531283316834794781471657841320353556656818597704497`50.048572863578734 THRSub[2,1])/(1+8.45041114242665653378507207256956199038868910030250099722708764236098484949818`50. z),((20.52809940273348644405798953936083457276179826074839520204558965185118368678222`49.69897000433602+ 9.16160016266928467167386830831715407071982000637797277398592161579231707222943`49.3548261761902 w-35.4804664686268781765407179576919585661413563762720995737894`49.19831032825138 w^2+30.3154311254916694851724570640354495526609063373358502544827`48.784687610963786 w^3-3.4267887528449435888146696829906628316424259781785166762006`48.38749889712812 w^4)/(1+0.76260137701961283154934956396216233026638432763694351243018963499837805525478`49.52287874528033 w-1.60948820703304502457928915767569163940134566856669499427040905284260456345819`49.19189190280994 w^2+1.13237211344337930908358598916182708705806190832660084204716278910040151203109`48.62502819695987 w^3)+40.7580374404661085532148181494869844683233916117229650987345281896176762288809`50.41888201604309 THRSub[2,1])/(1+0.61595101598524809354696107823356951266481322005375798350697903189882898079176`50. z),((33.20105790505416393575482707238199355477466024870401397115180987801752706748201`49.69897000433602+ 42.8013176977348643101080133161566480969867251875376975855506`49.488835084713614 w-25.1380009177554308068717895931586648560661962166924691916125`49.026384435501086 w^2-16.8111945340804011094394607775670308611066110184439348632441`49.10735712863412 w^3)/(1+1.44683698892040554039434427577641388588295143061027366898824413223861770579806`49.52287874528033 w-0.59785390364752232563893712427951771741925434866077610022006274034813161599497`48.90606563747699 w^2-0.23637889434015648337732116337960491095229310649114361602134353263102664984076`48.71451489156348 w^3-0.40071145297248314658367033125824245864934182442314411790969407655854978090604`49.31167023804643 w^4)+71.64597661045234085091915493470635059741719057368404052622857711349984636686419`50.18845248385821 THRSub[2,1])/(1+1.84057810349741324352667933931156857123949195669475307069489772681272706034203`50. z),((39.54183861760093227934199436357465721200604423862966236822877896634774519806015`49.69897000433602+ 53.0415767533427974249213438664138793234820365064287784129976`49.49843859059443 w-29.5035036564412230325610709124238185367341151106451580943688`49.01104207085298 w^2-33.0736986319036131499558619665285926237439638384721365158687`49.27375950370862 w^3)/(1+1.45788296305765010699655067798161715086658379225585979343354188612896467521525`49.52287874528033 w-0.63128152185829300685827273828711757439068553763273254955014547444433455437821`48.92523152440281 w^2-0.47275081476905719471104707939981376021379674621560759701652496864370699811006`48.99985028944002 w^3-0.46938689942620263589157602411025758622111923671987543868111985814371063673473`49.35011163092496 w^4)+87.10043019392314096582487619260732067265518289198072930222538346286537230968412`50.1484832750346 THRSub[2,1])/(1+2.45330731074112932550905539382899325391733911054626534970218581789119462931623`50. z),((36.5763946568266933560062256742955523333143002163517564374384274495585628896025`49.69897000433602+ 48.4292806005209310630197019997930667440627207912408439070539`49.49452939770977 w-27.1421171124406917483956734042112911474282356139295286906831`49.01186155066019 w^2-25.5286370070842687906487831992433264452313641571117562388796`49.21574403067683 w^3)/(1+1.45802876504604293042572609326449264702949408224808054877497328873428966402206`49.52287874528033 w-0.60759027966286608028126429536358892544021884601630035278510626264342943072837`48.90988796522474 w^2-0.37345721380653451908383638589013830168851848020715572513283838544792423832302`48.90335812804347 w^3-0.44097044019561538010528672341725886537568055403110725251172686966440343328919`49.33472177468856 w^4)+79.8727214741617253756985594457956493284284391074061277741644520255496133453491`50.164805144260995 THRSub[2,1])/(1+2.16674730975963142318777021693550605129720637032348895811290336909653242927753`50. z),((24.6225271316086873083240879081195715317879119520156182659961188613720429525893`49.69897000433602+ 25.35967082264665040660664731843393479964832370865428997451810537989093236409285`49.45841671515281 w-25.3299785644712995061519488387792132618732351919766419554275`49.19683528232534 w^2+8.1443953665551555969655384053228629299621148915812799204137`48.988862186477455 w^3)/(1+1.27713951632343312610491304583457611726294150365798694903982144561153905402937`49.52287874528033 w-0.81204526457681551207815539837485845089187241303714773139885301926009417620431`49.067403836406655 w^2+0.35122137726270226468844972437906241062027762444871032751093780458223040954082`48.87540814864575 w^3-0.18744459223131463630433880727948110638270958391603104629741194473551790081006`49.08613220776372 w^4)+50.73743053973674318905524206445021467699173000015606242302936951796011383703421`50.29853105573497 THRSub[2,1])/(1+1.0116082024049221961516781660947995289863981724575008348627041006836236256528`50. z),((23.76245464097717884033205941318313293839981067400615140387402234841081697392053`49.69897000433602+ 23.16990678224568547663535285240482937309749316221203015771060950728860387376267`49.45188474961549 w-26.1189955203719412772155779751544909644597971768107905197293`49.23299637693098 w^2+11.15523265453627371424999290011625959847457536459295645452709008983594920333313`49.12946960462789 w^3)/(1+1.23480558561288235628857143941855089255275539827080125530129566233323043570494`49.52287874528033 w-0.88169155926411146644063109047777536912583298064918351162214660391737933186634`49.109507089824355 w^2+0.4443220033417995351628821917287937299330818652686731396614684165394770020056`48.970555702959544 w^3-0.14424366196661206301739930383750881593176916512951538621062403166730389169554`48.99301099496636 w^4)+48.64116653259588223502876519427708488511102271176518093578253782879769494214976`50.317438524948784 THRSub[2,1])/(1+0.92849674354087531476697657903108482397845466348761352372743518818810262852658`50. z),((21.60243855661379137108682512282460281322293421995015120681242569436584928751874`49.69897000433602+ 17.09838292926554150823718468667294666809487725927172647333109251358250747589689`49.42631266584206 w-29.3302885775499474080621611986913309352525849900014839791293`49.348685408520765 w^2+19.48878377018888265002559185452318503895954363021542151270792337330008181916922`49.3762948541258 w^3)/(1+1.08714104011873523320454980666610278803174614886693026910136636437674927836739`49.52287874528033 w-1.15168118238126733829098157583983092789298969373462949804783484896896447310323`49.24709152536053 w^2+0.72106186877085869280008627273444860364310930439277111316063815894866333991503`49.16352639251432 w^3+0.00683385913402040953002064657397994596800057508243498955242606342425197394279`47.73549764963929 w^4)+43.37653590922639419661751168844943164870907502268315883160811527282377185909854`50.37827742608488 THRSub[2,1])/(1+0.71976772372368158927920142027295008627247071133930075300163085594095007231196`50. z),((22.5437125141009059609027178386600201205917916847956603841402345727122115533726`49.69897000433602+ 19.84967364007821567166751644015324461992972648777819616024314008531336245562475`49.439606234168295 w-27.6799507964229260679733339127527018103695317184088833425778`49.29356718831858 w^2+15.70790917752809349908121591794588086000938591050042099457688619405966876877426`49.28175527746088 w^3)/(1+1.15964726520267089630367867698469908472300084622888686651362302866738226103951`49.52287874528033 w-1.01391257217655434472326271494170021086046467300234227693799671920893580826169`49.18128333469682 w^2+0.59261096835057020526956635415027102237365509340037998840215694147710153822253`49.08572191774712 w^3-0.06799786140700481362991652162019651898449113932863390339486481356251447381908`48.70258850024781 w^4)+45.67071313199802695202957768662700712499109868684026007916448327917444658927488`50.34897865698489 THRSub[2,1])/(1+0.81072593090927365396316030015683386372102546901060805310952469645494528409759`50. z),((35.77794563348065224769520282289594760766529495388755683211596483358177043474821`49.69897000433602+ 47.1374610521437320185328954219126921775768161417220720795703`49.4933229158398 w-26.5984249391161534073988296008388837407130913916116529164425`49.01378986156849 w^2-23.4858043176428244287766182884790753338722812528955535225761`49.19559798812106 w^3)/(1+1.45667593535516028286508322545929332470645410390476683505756313900535417813536`49.52287874528033 w-0.60330824754192709106299788718159575621552012335980793639785575985910310103797`48.90737544400209 w^2-0.34373158236273770998662181478256589624697569951721171482102063761867717570235`48.86930904380133 w^3-0.43238203061053600358098071053338001832336173443130882477496892259141707702877`49.32998391814237 w^4)+77.92665301201602849458149699571330601063525401261173397038548410718419104472891`50.16983972132641 THRSub[2,1])/(1+2.08959071670299516020278404797072452359331919689607905338401040992965818047835`50. z),((21.57596381617854823363122327433890647506472396562543306283347674003999757467615`49.69897000433602+ 17.01865815167973699343570064323307115001270592802149030739417178061498136499516`49.42587148962886 w-29.3833039697242061086387923938707105150972088568586702915413`49.35034686637855 w^2+19.59872196848034696260361610063024359631814192960725947251739677570592653367913`49.37873475672653 w^3)/(1+1.0849017409042647421748270800890700507883154272169766686223939595117438378215`49.52287874528033 w-1.15610398954789089703718498997690088783357205776547717863963485498675819732378`49.24907585397741 w^2+0.72484866853578130445967901166866276675903809686687437304254813886014776099796`49.1655994857538 w^3+0.00918309544443938160736757994697917325045510815229680695311630702694451256683`47.86330082380595 w^4)+43.31200873729923779489413295422019906417113109094191863378372208093904289419852`50.379177288478225 THRSub[2,1])/(1+0.71720938785712641335063119923025753185606889858707894847672148916962703781132`50. z),((29.54117229053049993655526596196629351139386756330438107332137603872446034799209`49.69897000433602+ 36.0855345812938769131560594895089512522797270382021209470105`49.480133944259926 w-24.0071546034639973144511976507717997861284332303981063898941`49.06745940727654 w^2-6.917858719273039907222464773253542106194957950740361316919680388485338887799`48.82042464945461 w^3)/(1+1.41104849573170167309176775161912523666709375000048481684164978404279082681361`49.52287874528033 w-0.62483235537373259575445711716187832027171647059556826537545660339871930474592`48.932173040432744 w^2-0.0423496130025897478880213754378888771110374458944290518476896978606511093293`47.9843419526376 w^3-0.33929345867677405594675634696727101622336175255563928957319757808964798140884`49.26950673106878 w^4)+62.7256977182099711254653263776793717088365164104840299742391723414088420864576`50.223375144171754 THRSub[2,1])/(1+1.48691206253933383533255420019531123671873402089725132729957356172641643690974`50. z),((29.99233179883938656176859769121538114928720958100782526177185564238543638153856`49.69897000433602+ 36.9574776158632573108782777954192568385988851792133773275309`49.481414226691975 w-24.0734762345235707065916056114569120871819770198944098944409`49.06048525800088 w^2-8.177141783823082443168631529430158762983514724226285967296`48.8794421513037 w^3)/(1+1.41740184125834227603701826578792241937522112753576609189946135231413051047407`49.52287874528033 w-0.61830789302915751203999450197763904774326218162665560724967551413493080055048`48.926480332793346 w^2-0.06968343467675278279180540035106987547414753118706252575413961258394401490353`48.19810490697804 w^3-0.34836217590017004435488341010445330807833376612970227707080254373298932367651`49.276467714294824 w^4)+63.82531367971208874139922086699276708754002632597486892970148491118796666465692`50.21837199871091 THRSub[2,1])/(1+1.53050899805857804924831756586638558560848035320184417591892567722374021242358`50. z),((35.55482975002819896570468587574724231138803951194677936231423219493967858076375`49.69897000433602+ 46.7723809028478450340434540298732939386211838271931901214702`49.49297196028139 w-26.4538401824094068550110451563225028414566349537502556220165`49.014479181466484 w^2-22.9133507123437279695746982777259767036963472206663739546868`49.18949551390792 w^3)/(1+1.45617177146543004251480145527458863440918904284465727673811773146646477966409`49.52287874528033 w-0.60230265176803896139217461343665501721157630782337756204476181975694552021481`48.906826539439955 w^2-0.33515646707457902722965575409811543758885004194000245849647753497464012932944`48.85892240488048 w^3-0.4298928628328415170537665296649710352197433515263556676060388148679245529207`49.32859688826509 w^4)+77.3828502500425616092685892640281950313120909098557083801495533666372857957409`50.17130274405827 THRSub[2,1])/(1+2.06803034037255528181319141084567068465030233353781152753887321528065788571199`50. z),((22.50299877412161206315276138475632730291005015821783293202112894986009144310621`49.69897000433602+ 19.7340763685429842705388906805861397108320260584187478535949474218370308346455`49.43911369030595 w-27.7425449076612607671396205040565718115270792451822155932797`49.295795204024515 w^2+15.86643430498266795770073740006640997288345406386221508793717171081150646401614`49.28619159982306 w^3)/(1+1.15678798731820192865215991318754471525240611780684358149326905012012440252363`49.52287874528033 w-1.01915258906847584785784920885328165624092262475539888375120569695277470705806`49.1839394099947 w^2+0.5979140586770351811503690875827641700798136470317077802528562230245723043679`49.089263932390146 w^3-0.06508235836241442568463321420405810876180559099905095709105377683239781853677`48.684937273525264 w^4)+45.57148109208936782739579234580800928869335649346228438661538555556659506505253`50.350146684048184 THRSub[2,1])/(1+0.80679163657670402890222203731274689870379461364538734951341839239211882482198`50. z),((38.83899019672635968907375289708718034021391633428303850979580347022637407972337`49.69897000433602+ 51.9735670022929170779695581799870800474160454067395333981115`49.49758369625537 w-28.8963194241622097622185216856489845620797089999804225952377`49.01042822660042 w^2-31.2876373791785953320082620084675856657235538680824066372661`49.26187049614934 w^3)/(1+1.45856340874675148896172924482568995637172110979605128788006722421496072950152`49.52287874528033 w-0.62469281993255127918854268981741378120912115554704539331079710446348961604608`48.92087341887179 w^2-0.45059656128588080592319707295725630063264855756469226637994507732265167236576`48.98022340586961 w^3-0.46306286865827324545824164097064438919529207171227539125993967125097587514209`49.346698842557736 w^4)+85.38737011677389284060040787674743376929670610471629313119741080872213366524252`50.15204937195926 THRSub[2,1])/(1+2.38538889891483512902104531574450615959914435414800049556184651129128857219204`50. z),((35.4249145983682544776983472117575813684999143668784766951241168044226564667277`49.69897000433602+ 46.5589549072296608494664774196839212931694206992064164903188`49.49276467438453 w-26.3711597064838306062834629134962062020708087811119183371452`49.01491230131191 w^2-22.5796517942803850853833014081236661048293578343606862021977`49.18583654460299 w^3)/(1+1.45585133448612576702520644992962242809993670697387738031885634626262788484181`49.52287874528033 w-0.60175794057942774945720116956910222982520894655547331739399849540750433126757`48.90653993606777 w^2-0.33010654458580664591441811535372665606473713263708832085792762595147852434558`48.85267688092396 w^3-0.42842426107694003468796047044120079304673146890471284805074688707124461764352`49.3277752151198 w^4)+77.06620664223803249758064509633933646185780264512047523495824877859641256257603`50.17216645004365 THRSub[2,1])/(1+2.05547623836299807983060645776395503945339840581315656923790571719615833387558`50. z),((33.5359212180324223626320646239181284901129263294730820084699342273118705275037`49.69897000433602+ 43.3805336688080347438883835122070454916446850520664725816761`49.48947787186823 w-25.300564401143263572258110575675749326469297829596969968829`49.024121242478294 w^2-17.6880027648275758106254577121125874094887989251380187397616`49.12154447703124 w^3)/(1+1.44867036064691451590335772511206462222475083232790656983994599621658479932981`49.52287874528033 w-0.59770395810892324850888755228447369607589012911298927343338292116540776861084`48.90553136678347 w^2-0.25145444080890999458365001922629004294226210601973767476254715205260027118707`48.74020572165862 w^3-0.40523575702091373565909259658655698687237544214209060995613186892441885442759`49.314390669914474 w^4)+72.46214259408106097146759688027866468203067850585138947022629229143313248679137`50.185802935007885 THRSub[2,1])/(1+1.87293697878388598917799245901859963802920510262272891929477596585314742586435`50. z),((20.19088267893152246825076458074344851388520826686801136023240611246415656934279`49.69897000433602+ 12.70044683438545015911972562104979759649641137779030113920058282759471193604951`49.39493430602047 w-32.7633241505059678642908025926481838053886662641920501281753`49.44577862607543 w^2+25.62932180656694182845496042858455268109867826766233409270781088477027231862731`49.49261161763076 w^3)/(1+0.95226528676407737464238700324937970346287773763020496377818492773347068697191`49.52287874528033 w-1.43952044162223158619787835253966668393835189265079964077166862139493962917583`49.36260245111102 w^2+0.93428102131233534746785327173342956004269821631590960199659583952821752245099`49.26596936778727 w^3+0.15516296592026443014114321936730543929449212445336371919769312437965941236868`49.055626301182464 w^4)+39.93613546311885042934487997556357693353336846897048751054430634283865498561981`50.43364080147076 THRSub[2,1])/(1+0.58336472334849945378510172048806653852363690701839978277104409029378674201385`50. z),((33.2011001912545010200008222540075135184710801352374198348536759072094199880279`49.69897000433602+ 42.8013911628812450680742350134409554411660956231438758662629`49.48883516716819 w-25.1380208966612409370564691973451448495905815575842821584452`49.026384136482214 w^2-16.8113054779557961796198892074118777251280370838943677930439`49.10735898780779 w^3)/(1+1.44683723248019317104253255942134257780283258024026670162154305717982758585953`49.52287874528033 w-0.59785386584177247970705575946860434812708273647860731666407377883712106804244`48.90606555452182 w^2-0.23638082180843874453758535774700753725904586521751679537687449846707573274599`48.7145182833223 w^3-0.40071203328609923772532941867760322993519432855018708167897296575026818789205`49.31167058963029 w^4)+71.64607967506692966455492754148132574432444204899921684076134129522429598063488`50.1884521444307 THRSub[2,1])/(1+1.84058218974344263568141561812983528035066508729958256756633715576860111000629`50. z),((33.22169258829387846918468929895373481999280582153190665748030533169916822183326`49.69897000433602+ 42.8371572015000682853485482041864047079980788598887379938126`49.488875281415524 w-25.1477668041252162158042683885722228190754256415143846244052`49.02623892387323 w^2-16.865325748701827808773716028687539754224021458246468389068`49.108262254025604 w^3)/(1+1.44695547236080766580114226858109393766496904167079056418856804256945391692415`49.52287874528033 w-0.59783603306253006270041180901124079093790579872870179363569016886411866269928`48.906025631142256 w^2-0.23731873133406241832731379022155432531711312177391559139159508462932919695128`48.716165340214985 w^3-0.40099435740550846611751710423454087937489346326715911162591900332478928663713`49.311841553982724 w^4)+71.69626974765337585731339534730515439590696628316397736586109458331240803467478`50.18828699853543 THRSub[2,1])/(1+1.84257209661535490509486194312530125712814891886221025790393182988583690119363`50. z),((20.06147938115199149516860193724269956706012883508744624215466412337606978709984`49.69897000433602+ 12.28691768806208902521000749419047178878187630514539364217614150882528647124393`49.39099699645722 w-33.1478608698637015567803967322583654037340079349049293379116`49.455503017532436 w^2+26.21952434423094903205985032702924134119272679495553867468484193240754877932092`49.5019671855604 w^3)/(1+0.93843490495268760656385270073565754096864692553642730733368075368002887956242`49.52287874528033 w-1.47198691411894860751277065158942331785951032965641048295016930692496288106816`49.374093129321764 w^2+0.9547067820742366428368639827736686687310789257299770004012551620324931716347`49.27450593808635 w^3+0.17143793278618722375454295538492193639086218694147976277448278142917926217349`49.094665967209224 w^4)+39.6207394023270602059046717176988204269841040531771632899162337060783820848105`50.43960782751874 THRSub[2,1])/(1+0.57086008335893449098328616281149628637153153774903708647411275334922604351586`50. z),((18.06441050011187213783629157258901053077733930211583967814403181982994396989832`49.69897000433602+ 42.6459661433405226493423284750302571814182684870837939200228`49.479387645165616 w-6.7197638438183221403809412310663404443695039364012245189973`48.66969009944245 w^2)/(1+2.73375519120941792899181050069255594010792456110738163228950682995727978842336`49.52287874528033 w+0.50623120253608567816361600963503172075644907425107489812132069098314712270549`48.69864553849484 w^2-0.01339763047601030695381283643289037718121784919925249005444275602075383103374`47.67516748230534 w^3+0.01807361615842498680780062083535576315473688341326001266468594207035850548953`48.40232151062926 w^4-0.33239218445079696640338720921148807408790557985341585774426427715337363774666`49.551210383842644 w^5)+34.75326176444606878677916163512611801427471419208341122133316564174354417991641`50.561859863025646 THRSub[2,1])/(1+0.37787715463700355096535744385172172281769357784232152794615792278128785665062`50. z),((16.58618245629367081475670404399892728923966947929350573681151844906000156687218`49.69897000433602+ 51.1543080386248465252908983995005877344003259880890914523817`49.485563322873304 w-9.8864435245216098516826752984473968499687161698755838691774`48.81040407575912 w^2)/(1+3.49922300476595922629251083709676709929475752413266232580017556582094757972873`49.52287874528033 w+0.70075108245500934735262662247730848465857512839556430727272756450435655838314`48.75803411106898 w^2-0.12387859470147838605023951345664183833398014845485495539595167976335650479849`48.510760717565624 w^3+0.01444460676072145233890793382235457905388175202631307742047177487764018952304`48.33824332956481 w^4-0.40955822153066289452783508964287640015143709887979328623315228589785231244221`49.54295186499055 w^5)+31.15036052489232343276222750574564609772432068403592618959949819625019858024255`50.72055208631465 THRSub[2,1])/(1+0.23503141710473038493606008060381998858108683064752989923095516967124033744083`50. z),((19.5749966612847225564284252540326231549596480075167920855878627231671958575963`49.69897000433602+ 39.1606458458150005925946698684436400513747917066363626065119`49.476715612499284 w-6.8607551969973396372454348191185756049157327330474292691349`48.688530734280036 w^2)/(1+2.33708394311374906484826850554191224721530997935197888239876944725588832914943`49.52287874528033 w+0.30689747533646670503025027178109440612981630492354099495177388170383103190935`48.54698992353358 w^2+0.0331782320232135384556961720657706316543391790884456549626134299234563812019`48.16723674924637 w^3-0.00918031551120356338261747433686683939234630222544584546803083161452417190586`48.084551760683546 w^4-0.26941092883357384049866133070614453865149819483412954466801466813159326778852`49.527627472160795 w^5)+38.43502979428581189711332577942002439945233373202100917100659134506631237393863`50.463735403388945 THRSub[2,1])/(1+0.52384975690304384194542974684382055672926609192467320987254326242899578048564`50. z),((17.3205298711581002024652395004660866239400237091160876222209074684906621719115`49.69897000433602+ 45.7922663829707943542752741965238125441525107746900496416508`49.48181548322836 w-7.6392826080562809784701211777363850755351111059590574264038`48.71506429686275 w^2)/(1+3.03707891314666883246869964609688906010123166062905021571512075519628160642945`49.52287874528033 w+0.60506240294263507329229177409328673973792437906478220003684667327070994665435`48.73832315834065 w^2-0.05424858421743557472491742191960723884710730943848188841052720868368243352966`48.22084194199905 w^3+0.02237047131994484693626580218662866246291170433569721692475237811539626757984`48.507538579298625 w^4-0.36810002904585221056333042532170055067018473532348349745346268443727520729566`49.5517118295409 w^5)+32.94019344163512768671200725882443185640146488027513615235785698632855834998126`50.63022862525213 THRSub[2,1])/(1+0.30599367392288640609718446392361839194754470890053623790247696328624931832414`50. z),((18.45995183813331724257554737650933558230649547043184613925957900236151991357308`49.69897000433602+ 41.4696305155546020213866782120603695064012664309247553668945`49.47846271344043 w-6.5549847181418466489618347970095959350928796548881059641824`48.66261092375564 w^2)/(1+2.60932846192315109385180143639393936973599657037848563779954433103545713595111`49.52287874528033 w+0.45372667835337628829477307362117255785768329301228433091550845967443012759175`48.66938267181409 w^2+0.00205834420193475462353052793341489550584878922504952216336366819196159464944`46.8915606367536 w^3+0.01280232474864945173473796736820616452239652055377989152450302575648453950674`48.247792113684085 w^4-0.31495669783114120332237947576699849879621574201090083801177658916621543188588`49.547748982119415 w^5)+35.71731895644145747436310261423825899996007908570636966426305946211296414326132`50.53189654991662 THRSub[2,1])/(1+0.41609953472947882686076007919874146865077348859289181250148672289438097475214`50. z),((23.14202584734279063237049444961604886910597979803748662127030549669461692467745`49.69897000433602+ 35.2962391954819118691917457957812949654425299482041389535846`49.474537792578396 w-12.2748727755447794229063691392099382999092089618462639912814`48.94190373611593 w^2)/(1+1.79456759849645143811241843529648669030341048749640795076344653511139812894289`49.52287874528033 w-0.15351393342253812502626742576073411903129347634623235585071490664707306624752`48.36311512536816 w^2+0.08642400719988960255004887246054630382538267082284157104270036743444508751481`48.773770369556786 w^3-0.11819897132499262815584158550963772050606701195344946218196851358548800456055`49.09985868503157 w^4-0.1398292901973389095774169015594898581920606712918491299437519429741054097914`49.35873997638039 w^5)+47.12898870659119301707673184919185222398023974244793044027468831553561092729502`50.332711827041734 THRSub[2,1])/(1+0.86854279463320445002625801349020408610528357274248549630820780188056664118984`50. z),((20.71647821802259819991828986498950621229546745022735773389472582548409761623308`49.69897000433602+ 37.6209099902732771490806953900284239149820294463542335046244`49.47570845436736 w-7.9896122249867836918892402238378305855368110809034753616147`48.75684026915676 w^2)/(1+2.12851659394589991341992194855777364818979980049323902538287709444770833318551`49.52287874528033 w+0.15850988652891039897541759200119226908032887178483194748552382397697697421075`48.30494861649069 w^2+0.05476371799340353057329678992656119388106377233710667929167873729922498955232`48.44965878067327 w^3-0.03908096398246178958189149504663114074987183962996002026998417848244013416773`48.6796236327282 w^4-0.22621856976435989368829317805788151546844108906837444162339139002483312523208`49.49224849090133 w^5)+41.21717516955270232225596814640340974925886026781746019570077757520201665751649`50.41109797602325 THRSub[2,1])/(1+0.63415464222408193103664280376157874188274069077621491961499437053914122920693`50. z),((20.2965290821861816231996368262983164238574525547675754831025751823298258636208`49.69897000433602+ 38.1271040622683071053386540547477144738225872516892554741128`49.476018038820904 w-7.4962975005235293299444117334302190794838733933329343255698`48.728706159338834 w^2)/(1+2.19955081745577117926119667372352277364405669994316374221626412761070620274899`49.52287874528033 w+0.21290436032889669249252294965204416570808106944149352074442952516471908833076`48.41682364391477 w^2+0.04760329862343672547388335867319901503169753548962045570221554223737934614521`48.365482955115525 w^3-0.02739369029495064968524231408209761762859154599834333139686530753523986494794`48.53750266638238 w^4-0.24182118400055829556068325207775409189462900943614023319857928636329563553283`49.50699781619744 w^5)+40.1936285872903048684471905712506504402522307316047887118479129492714215399754`50.42889752137593 THRSub[2,1])/(1+0.59357366130881845218883022884033306906045637757496533240444877079566300482435`50. z),((16.62367998108918738479256014373001572899352645690893080067996138908401150181464`49.69897000433602+ 50.7907794063198754098283216421575433003679646937045965464493`49.485326929867846 w-9.7206866917327025640598654107910323982056795309043235566293`48.80412246341009 w^2)/(1+3.46923789011600396852788011641282509619619451347305350061080643877405274153084`49.52287874528033 w+0.69598695674181452694221088363962923716011972239714125929754938533800755827939`48.75755162174715 w^2-0.11913498376298229366558936376864161784570219522237557650712709310638366189991`48.49756332493032 w^3+0.01530784693960755612386929461866662484916728783715816541911185256753789216036`48.36204436697289 w^4-0.40721331536222729919451219671481341734490714806722187363000213095577577557164`49.54366358451459 w^5)+31.24175364866029539321740955430349343888776312625756039695745484571216232961308`50.71517994202036 THRSub[2,1])/(1+0.23865491863918579049758435111070804168031293572197954771619546778784577416875`50. z),((18.68521621301365700952448652121910937754588497855508249487734184079826670214877`49.69897000433602+ 40.9024141101693641490531010431721091658333436422670675232468`49.47802033900437 w-6.5349110718704572038314967457487041865490275345810522981416`48.662968907029054 w^2)/(1+2.54631792181007177855718724897519047815798695547987464045915799423005947233322`49.52287874528033 w+0.42390935033869029653448373172128164302793789627106826454170551887262073852021`48.64986877151694 w^2+0.00958631922260295143357224477217063232921530281122991325297917659638294607673`47.57398406578156 w^3+0.00911703300279111288456201382365044086111148217170540126109424377394712303003`48.09811213145076 w^4-0.30537870812586215368867436984824589984553607305669588301359931053562657897592`49.5448804268244 w^5)+36.26635825986810139686000929081757146081699631896381317988344030386649301311138`50.51637613768824 THRSub[2,1])/(1+0.43786752641661664368284075741897279112287250124160680214578528988738173210662`50. z),((17.25731968890173302846906885457402190735074812639883069978708892685707819955882`49.69897000433602+ 46.1404405115973800068199658986559155613008925325886912819906`49.48207540517766 w-7.7670359018260055513022896381900915464760640936132895765591`48.721131223490524 w^2)/(1+3.06874216571554826335691684496026544404892649559813577050931225744062414361471`49.52287874528033 w+0.61342410216708468945224176022923907520722273004001351517717601155788425371585`48.74080880228148 w^2-0.05875560308172483312571209406651120711228814625515015210601800070987267217615`48.24994608320403 w^3+0.02228173075439770413406441639059130551743989286835170380248832375464967029899`48.50717144557443 w^4-0.37136899397446033483356972085679962274055201482695063593988809662585532282898`49.55135245606523 w^5)+32.78613057903671531606716956755352008151168260070097398585875956541187637406175`50.63694965539812 THRSub[2,1])/(1+0.29988547895140023565137210962148223362389917605312117642196101724416193024575`50. z),((18.84364610472869591950434860718064882090888007188869815603254211833134826294147`49.69897000433602+ 40.5396904672943818310303796894102798255798405364741752422239`49.47774039019946 w-6.5484973577005465443659437767704253709769904952461428190534`48.66490293822787 w^2)/(1+2.50482580632545412892757144089651565140270616011009847653722292597539584771669`49.52287874528033 w+0.40298300627015061279824189577904185506087309172339740492978557657254730374936`48.634770058802296 w^2+0.01443429504185766303355532910854540143380078109121453405331089728848475415157`47.761621032547716 w^3+0.00626858803659207350202075522666989959077924238359742754888197128932731226223`47.934040395835666 w^4-0.29877267047853092982301479575748777117931495005027306975170014708979004257152`49.54248953261036 w^5)+36.6525011527928682924407066211640014460326592090149999718054600829515580894159`50.506050592259925 THRSub[2,1])/(1+0.45317709575122207387575160851467298388687348520769787256522951868088963788454`50. z),((24.39127881537432786381937668774055875888792884389612791269792783800031487818831`49.69897000433602+ 34.1763721533384153781628691499378568326328713060238197799435`49.4739789869534 w-15.3260404555689538156917655248235012504980002720452495617679`49.036576024820974 w^2)/(1+1.65165830076237299207755245009930994085233601076385518036057075361302289304067`49.52287874528033 w-0.31475462006391211420060300130982767907089795260444275798686642686023761062726`48.69933901129303 w^2+0.09916979307300655508590646733720823938139381023845086061137020972802908432737`48.89426909163399 w^3-0.16499400975938437382497276810744369799845260298218275466623074025638973389491`49.220479877925236 w^4-0.09648966073101851138826824084663008907308811945958881235434106722218106436876`49.23725254530564 w^5)+50.17380651116435856151031680781496484541890119625015257874157753879460204151714`50.30338066744615 THRSub[2,1])/(1+0.98926196399892431239717995829306300838140245588551625773460463286831864784948`50. z),((17.09885578860048616087319897080770798958533636208900757587043609962002616449524`49.69897000433602+ 47.0892602847873389216793837625169614157515991592470828234418`49.48277264508862 w-8.1321952869453159242356019686600366771250727388371195698341`48.73801838720304 w^2)/(1+3.15359195007238271880729779372926949757702859424369072451190558920268380699811`49.52287874528033 w+0.63432183014237759197548389167765538232254247112340267393758621313255632576523`48.746417733964336 w^2-0.07104103723893783269183627697734976639618719373044653361715099986059907315467`48.318213464893745 w^3+0.02165153147515028003789360640828591650492708072634151221960932649388902514386`48.49838900891765 w^4-0.37977258620471647551277749207294990956274299807344997770318153711457000011448`49.55014564809353 w^5)+32.3999047966160302994095649476576862291267558024805969083140050860167055091149`50.65456554478849 THRSub[2,1])/(1+0.28457262326216256777260896735403222751957982608203590621060122235660792261764`50. z),((16.85702837085659250393434481341156309756824087354285203402704960467456701151881`49.69897000433602+ 48.786379435592549120746199796710344924896266191699661689675`49.483977100732154 w-8.8342371386262402875957312187636992974289137767680802113232`48.76863488064477 w^2)/(1+3.3009339730390582883518702868707649201301777100540739205297516237935364316541`49.52287874528033 w+0.66595054902478629555212604743291711642000500435626279711608075980406063791871`48.753199121805785 w^2-0.09304972148924680939260198489635194383921083895181850487239117764866519134879`48.41296174158515 w^3+0.01938010834922784755764323309477968550679500474031569930091879892747577853972`48.45677897971289 w^4-0.39326045419089669985515564632031543820869496025208720030808774875655612267323`49.54741206433586 w^5)+31.81049620922576864390013200595797242920739174608328007567966941451312810784296`50.68380539272914 THRSub[2,1])/(1+0.26120409363129055346873507011890634916851108123180615518348436352333730341515`50. z),((20.31305760699025560661130116543526213119810684281646738181917667142526646130053`49.69897000433602+ 38.1060798587150738862167787214464286348846874989076208126057`49.47600472141418 w-7.514102963181275585159955898506449891793945854703083209308`48.729760855272104 w^2)/(1+2.19664528714422713308968757310688214602098939381653973705836289845966951221313`49.52287874528033 w+0.21075954758462207473917113944870319092282023811978296236850787920934005704833`48.41307068792917 w^2+0.04789980812259437148487540526752741230375878943873748518719098810731473334579`48.36910809062701 w^3-0.02783971922630749129044171546663699646217137182405638538219378935924790779338`48.544028849987136 w^4-0.24120152547391585567729576329940302518126815165414152053292101393394336191078`49.50645600151009 w^5)+40.23391374001327456497199358864476914546227880675131423555893637741959980284369`50.42816554614644 THRSub[2,1])/(1+0.59517086366594596198563607497379455111922320896251451270695357287138075938728`50. z),((17.01105422576498753096774589834298903369793285650009180611219112213810304100988`49.69897000433602+ 47.6673371240118657495729915913093683892160536586978935823037`49.483189174144414 w-8.3651149079244701241820586449832952249393117842641928133853`48.74844033814016 w^2)/(1+3.20436379379338827040710950813579812352642117530546660442233383165294060247287`49.52287874528033 w+0.64584932819715863979372725453435153936969045029430461899305882861866740958404`48.74913405702542 w^2-0.07853141079018892745161664981332115413138908144474910962697955688405494121321`48.353711367338654 w^3+0.02102521679255433889078724155298690019679947030056899231457538545088499651683`48.487867765577036 w^4-0.38456972519974120444902726466975536273286526057387496691272859907330442976882`49.54928163275852 w^5)+32.18590509548894294394128323103527599002263211075086144133847597328103036059965`50.66483298638373 THRSub[2,1])/(1+0.27608808729887008352008042946607091802303725508862122739842114898490852846835`50. z),((19.23967608976229165294319740032891145283524905938805341510421261476212237821434`49.69897000433602+ 39.74052762246653784247914963677652230677157754140641182838`49.4771368068395 w-6.6706482631416569993684971083846186526368565891300723445552`48.675020274880254 w^2)/(1+2.40968594619977517485321046949061864445470849666890522421653298678222887655735`49.52287874528033 w+0.35084578259350334110502755515952956387388258782225592066779312940945710200259`48.59135415595858 w^2+0.0252298093802976561069333314822803211368607186604693142915968327383776442934`48.02834395734718 w^3-0.00166618258804558151562742132246873705422561451296821484720151959455947354043`47.35381278534872 w^4-0.28266480493985382383520723160439602590423313857004091196473464053518169318454`49.53520871612509 w^5)+37.61774932944934777830255120881124448999020947274263572605435449654738280017078`50.48213131713847 THRSub[2,1])/(1+0.49144669531239536253918225143687386653193220629558371504041034532989720413859`50. z),((16.17287147246834691661242471864306063464423904478442446989370736705518196497079`49.69897000433602+ 56.210703062811613174863852851008327039086757129493020406906`49.488596489806724 w-12.2951074051993318696132689140909661964153841099928427159617`48.891439558510584 w^2)/(1+3.90383197122520269472704926482144779597311682352706424735597844765508157875407`49.52287874528033 w+0.75140943612752297855402523827614092496395674293966076089518794862891326844868`48.7587448080853 w^2-0.19029321919144229447135551071264113890962746211570985176384302497754941322347`48.65341118207145 w^3-0.00025318954258032393181506010115832397411429128286649971275737816855963924333`46.60192372727603 w^4-0.43789930022223529321397773115973807276872114523922407860962748202875912985719`49.53287119088534 w^5)+30.14299318250372542610930111853996631413787736837855012487262870058448442399934`50.78716206211195 THRSub[2,1])/(1+0.19509190130294603687837455194734772039443932444960952516624425534449466977981`50. z),((17.36223471575279570074303033050637919337981381742053259901836381941272001580104`49.69897000433602+ 45.5711596056997760533224586963509991411147598724577065114432`49.48164933752682 w-7.5601349380944666484213927470446433090448851978386056871503`48.71126504931235 w^2)/(1+3.01681035701216891835421129970809152160247139026932938670207069181472448894485`49.52287874528033 w+0.59953922443197114904573573544866378559714563562519547360505642907390469677029`48.73660671319632 w^2-0.05138631499217372655149718643679793945663802531163934695916384231801565393454`48.200936326102365 w^3+0.02238221599876495724336145454174705195382360717924567687620364173812468869976`48.50690031711625 w^4-0.36596727344733238530555006486660795946595981433867507756469188047722896171302`49.5519119672229 w^5)+33.04184111156940484984583034204909419567428539236130231046529382985332118845798`50.62588421294184 THRSub[2,1])/(1+0.31002374175288813173935168490709841357023916660916315187966720311101230279222`50. z)} /. {w->w[z],pi1->pi1full[z]};

(* Sample Pades for the nl^0-part of the 3-loop triangle form factor with LME to z^6 and THR to (1-z) *)
(* Mean and weighted standard deviation *)
Ftri3LoopNl061[z_] := Module[{const,ls},
const = Ftri3LoopConstNl0Pade61[z];
ls = Ftri3LoopLsNl0Pade61[z];
{Mean[const] + Mean[ls]*(Log[4*z]-I*Pi),
  Sqrt[(StandardDeviation[Re[const]]*80/Length[const])^2 + (StandardDeviation[Re[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2] + 
I*Sqrt[(StandardDeviation[Im[const]]*80/Length[const])^2 + (StandardDeviation[Im[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2]}
];
(* from 20 each of [5/2], [4/3], [3/4] and [2/5] Pades for the non-logarithmic part *)
Ftri3LoopConstNl0Pade61[z_] = {((73.6743917437372041903357206275304416730357315243461576151293`49.69897000433602+ 187.5851767951147380295816599761510574538283254972583641202637`49.66498370791431 w+120.1566415492356500081339045841774200154754930253408350179101`49.256801036156915 w^2+9.8556598178018301316845499321545674277517462255539475732802`48.342255681318775 w^3-55.4697619280180549499218402532918161706348056466865325852998`49.490230562836196 w^4+2.6079020875935984250131284273646505834886261890950915435606`48.33550901113746 w^5)/(1+1.48032426278974640564353285541774513394251274524407775727394214841341190596798`49.52287874528033 w-0.42901686329584439308848448261568417468096395847092401369216379088002570715222`48.96302682040291 w^2)+80.95231228072549526370331654851103603604098081507911364903065314036386931551469`50.77158478225287 THRSub[2,1]-21.77949063545627426428292119548938061059877325747592606695644223079039797980065`50.77158478225287 THRSub[2,2])/(1+0.20366751107907687155895942546611040876739678099953803596005875045202187454283`50. z),((290.0311649987691432130005995818299520456287824485867361879094`49.69897000433602+ 2531.7422541599261495979927137356279557843962499138268862971643`49.678919241937905 w+6904.4449747967429580642728828252583016527808664399967566978085`49.48699627719475 w^2+5889.0028633333107238778817753845571107795677971881689309660019`49.40921474000168 w^3-171.3193737043729732502521777113700334633491854921555358738947`49.08838541617079 w^4-1618.6601538931995898955904675489124527714438030498616455743108`49.375798618929025 w^5)/(1+4.77706714755217582195567503556400731286701785430719156633969365826870971242288`49.52287874528033 w+5.38848357440901555398405916213546878693768848974509308247526717316327508236457`49.4012097909495 w^2)+608.28102168131027794597255930038455247094221610986156934121`50.050885882024176 THRSub[2,1]-163.6525312518861010647113972116123148918489260706349448227987`50.050885882024176 THRSub[2,2])/(1+8.04443718500314888542934931700979235456054589696649808504233233314344997929624`50. z),((72.601957121496130802842622598309069597564568712838601708755`49.69897000433602+ 187.1580135173166135586082187484350860641285084533259424012086`49.65414714844201 w+123.3178983689334947703795642487455753930806289363023606583246`49.26813511219605 w^2+18.0224457061249973238396210935844165805981662080383019067714`48.605687985547995 w^3-52.3614315065372064542567349654424935019790876103661874214582`49.47696389698143 w^4-0.0972548999765454548337984804243654721903932822813410109074`46.93227048960699 w^5)/(1+1.56920413646207080094471460029765177069743394356902052450905130493966019717677`49.52287874528033 w-0.38512877269313173276469992205151185988254614177012154435934452005214768418605`48.91517564668802 w^2)+78.33845574758025369404243722817506581662258359206893232620307802888975924796778`50.84928854535507 THRSub[2,1]-21.07625607325319449842236579541092458297650241682677890262799021077719045090389`50.84928854535507 THRSub[2,2])/(1+0.16480247932237655359085416785213438452173174367519250972938131322928861500755`50. z),((71.2543558512326468601076285254966495417354904507252853241653`49.69897000433602+ 191.3798416972110889459721828027024145874367157507760144410764`49.63747837533685 w+128.5531235873701899891299555618370944869667849711338650715498`49.285392973122946 w^2+28.6392657549592104671605312355025464181847270492768917948496`48.80928818849769 w^3-50.7612090764803220150150881980554486970627890913265257050671`49.48846632176674 w^4-2.9933969900450571031545090042765816142977936338738572558028`48.43650722954391 w^5)/(1+1.7514653054240721684646218287562685774378654306032643927434462995808460433414`49.52287874528033 w-0.35761108787133613277264438671553853436070606625332436881619380494221655917228`48.88766572415386 w^2)+75.05393255959124943043298941584331017535484536558871204926808059800923737333965`50.983322272608824 THRSub[2,1]-20.1925846869847403166220752818439726485425981956138500782601313769240422453672`50.98332227260882 THRSub[2,2])/(1+0.11596540797278460328592419407641848008260559615045348293882241909333468998271`50. z),((73.6682227501576794597099359737013596252208329930929688863311`49.69897000433602+ 187.5784446094099719739910746434227561167383523683596532718098`49.664924565125794 w+120.1748517961979770781088403370046525710447744887507026304954`49.25686537715248 w^2+9.9035604801422221544203318208518403584289493613545463253132`48.34436415236298 w^3-55.4495262941473821321697751754240026969650906770175025915834`49.49012949997449 w^4+2.5914830876680819188132044887626045422974111942923286793666`48.332905078731855 w^5)/(1+1.48077009829959603078420152674397684192467634155908100498678310378419463280234`49.52287874528033 w-0.42873451383654982744157501083714945490379726504382507732200320133945837205142`48.96272883712808 w^2)+80.93727652578401870429144350287502000868909850141324231551753995499272122520703`50.77198109436759 THRSub[2,1]-21.77544540098774785978477799174317596184495322502162015377259139333663401507567`50.77198109436759 THRSub[2,2])/(1+0.20344394674573402876043054863079905192621807565393064201284231017111149103507`50. z),((72.888758012992519607817786875817179104773967268516718268596`49.69897000433602+ 187.0920547805600129191826511465367267000653995610215902677816`49.657174999847676 w+122.4566086650359648154864200926350435202720912775146893791127`49.265037237046364 w^2+15.8591626261055809524642558665510905917032277911523355298884`48.549664540711746 w^3-53.0975692518178119820799409509242848262021847822463526777076`49.479457382943934 w^4+0.595949203134011132854231027842578857774954243073560308907`47.71301795343109 w^5)/(1+1.54270663000902837751430684596016064442013220018066563396766855408218868836475`49.52287874528033 w-0.39568022781590198733308848362910396630181073579493072123628291361870946568171`48.92692090189308 w^2)+79.0374786701926864839677574582108673987796640823044352063627561057455073096128`50.82658581470476 THRSub[2,1]-21.26432189581070075806873176438029295041897160447974197092502143277874061728021`50.82658581470476 THRSub[2,2])/(1+0.17519614391012004510192159046938897974972171841022775895918185143008457302317`50. z),((72.6762692474724300451041025891776043457628775022025078933922`49.69897000433602+ 187.1244383181582026752441732315684924052382022503469635455061`49.654943053130225 w+123.0917314438621803079636700684619793078751137388148554159409`49.26732369140747 w^2+17.462166697257220155205420925101968730771151089194504446116`48.59183771644823 w^3-52.5438474416270305519951029279257407584643784331871005698163`49.477512486397124 w^4+0.0801349834277345178035882299957434263937241151661850854241`46.84700550681756 w^5)/(1+1.56209154722588875025059859067221537076651660605323409854321525007627369393148`49.52287874528033 w-0.38776104615314853390098997938507194419487007178559112399483215149351827832559`48.91811359684288 w^2)+78.51957749798509874897108953876076452802563828943996040415348163147306572199801`50.843251958781174 THRSub[2,1]-21.12498524918013095800087520722196785431829677005302047851947420214182078945203`50.843251958781174 THRSub[2,2])/(1+0.16749555084028541572878036407325512073673647573366157347283224757704950358789`50. z),((72.0816268424910166516888057049705632402919563554215695575261`49.69897000433602+ 187.8094123772370592795939175906285465508144139059682588781587`49.648299477834136 w+125.0052133737239608390928945393788335614140025794935420549877`49.27407870062309 w^2+21.9692480792471299171378341070340874957547723237898219499037`48.692731089509245 w^3-51.2875125796820091120502080326300587425717185665212034083906`49.47559901144505 w^4-1.2929392732602219479795210731598526534197207756967787228682`48.06067135670484 w^5)/(1+1.62519251364127901451520488434954850216487472510495700019499385542472320701566`49.52287874528033 w-0.36914400988606911369319872988758121374829326666766687874482821220274538440963`48.89743661767214 w^2)+77.07024911664487805274004400901092973987484113222891095648600513382180478272833`50.89497271074969 THRSub[2,1]-20.7350564995276516652593810516450118897969840847370109699188381563941759293743`50.89497271074969 THRSub[2,2])/(1+0.14594570950339486760301121572435302507130444521230574297980532627894758578043`50. z),((289.139551563400955690265526082925022973605812625501803052793`49.69897000433602+ 2525.061841725193579155274115800434936587016072058508009436985`49.67869338741469 w+6890.4190266271873688320897352839977385332154474200602404640889`49.4870434280976 w^2+5879.1957417653925291741804759275128987538942434351605588308521`49.40942758705004 w^3-169.2224892143004874754197895775474202604957931730025620743641`49.08408885891259 w^4-1616.3052096281560898014820990956741352037854007715331608253954`49.37609889795146 w^5)/(1+4.7839115840089998472760112541191778812675937217344832502985963413469008552524`49.52287874528033 w+5.39984126852453965925768061308036049299971966730299123575574491909634005726383`49.40143328853628 w^2)+606.107882587565761043634907414757529190235273980342178271067`50.051079489908545 THRSub[2,1]-163.0678677480491422299717240666214302280753510398599079149718`50.05107948990854 THRSub[2,2])/(1+8.01212511323520134341626165101849392097724010769197578936339522440146483998502`50. z),((71.3752220737953785290326856257524154295795346151452925184445`49.69897000433602+ 190.5570823031754635851732044355422330622904132354703458442488`49.6392280609202 w+127.9179868329358640331003989561858723363630224098506153077639`49.283507670118524 w^2+27.6028459577982310355808193009798261560601960444753931324925`48.793156856483236 w^3-50.7012012874805686193450002859751100513301041988914318562816`49.484817736809404 w^4-2.7638769609712409042605675993884402532792819795119456884068`48.399841137017724 w^5)/(1+1.72861525784076643126451984767237174916304521453396874764169872122625556859686`49.52287874528033 w-0.35770754520797998826738784229837118082728931236251172212791677218840218264334`48.886866285021156 w^2)+75.34852111439003838095206892094231916673135813778120925637135007802242318361928`50.968921796378595 THRSub[2,1]-20.27184108485393928265816276187727833800838627136132974758979207530138987769058`50.968921796378595 THRSub[2,2])/(1+0.12034559999642203773017359675443949162096750619446623208277984799204620704324`50. z),((283.158033792124404582910291778350435407563244585768437552529`49.69897000433602+ 2480.5707641836892771777271828011321570473968467595472597830682`49.67712559857967 w+6797.8256059260354157068013410368565083040603582849565049509516`49.487372452057926 w^2+5814.9572605351608387133981126376201340080379885620545183227375`49.410903228521214 w^3-154.9836234795567216712265836035487196581986167517850838641978`49.05298537184073 w^4-1600.972356492515084555421917282792983976980464810143521084886`49.378177517394285 w^5)/(1+4.8320923322792519836255798631400225669713681376351852225788772993538761306647`49.52287874528033 w+5.47979604585144921855448697097209456792092541023308962629546262990385882125204`49.402983560351586 w^2)+591.529064466323669307445211584526796960832123561962683210009`50.052417476126216 THRSub[2,1]-159.1455680162450297511936199980470428274721245553396344095504`50.052417476126216 THRSub[2,2])/(1+7.79535490336624679653798549657619372677272181499115464595010257419615230935177`50. z),((72.2752196877863242466373438248095004031932575454471492641992`49.69897000433602+ 187.4706604903521012049997329885623509083006619920780635192147`49.650537484860436 w+124.3508286871498377021518898628036398162898089621695435920799`49.27180308537692 w^2+20.4925334016029317085092773938364909405117819772193589710565`48.66211022336917 w^3-51.6406211979812936219004208782855440858208826435710574028979`49.475532481570106 w^4-0.85790918567374523849969173254879072583025792091346654228475468338961701555033`47.880603317566255 w^5)/(1+1.60293373304062005913851680575642878936695213004616492302548809238294630830986`49.52287874528033 w-0.37453610800376701475111188089766617850708211981660423791080503567082600873738`48.90336493900434 w^2)+77.54209505760104973876137406665326845840635664706294816268807935087507778880041`50.87723263616995 THRSub[2,1]-20.86200240092199410602987258752519414552438534015583866991881024625722481722072`50.87723263616995 THRSub[2,2])/(1+0.15296151440584119833112941275508746479106136682624411136500124351085988450104`50. z),((302.6850312465738908046076437465548238558237206894469331051619`49.69897000433602+ 2627.7412953016209746975342069345571618717429016643567783761721`49.68192549981335 w+7108.9933484060432750921888411703324545013011575838032100029527`49.486374774766965 w^2+6033.8685436668295175645340079664725381963281673749348147714578`49.40637563453822 w^3-200.4510888620137541581432154491010692091715337165951984361581`49.14173946788871 w^4-1653.7842678592781106333169532279429524410942225633510264912436`49.37178212859485 w^5)/(1+4.68820857461497945916709216889640056706910614815444716748178681899886094678836`49.52287874528033 w+5.24104253881986037537405698039013864539864362559094758768463495090682426001229`49.3982314308697 w^2)+639.1224270923484360551212762856674227319455809200226167159351`50.048288478650534 THRSub[2,1]-171.9501336477839166532213462302094332863552183603712288314727`50.04828847865053 THRSub[2,2])/(1+8.50301331017362040571229492508907703387584039207475954214587427495730868115663`50. z),((79.0630944419495687248134528042574409910330337378871216063415`49.69897000433602+ 198.3351371173132754807345546804791070738336316960629429104116`49.69897000433602 w+96.3107006704927026343882683769377782562358755816501900927774`49.181054738103455 w^2-41.4682561029313904259822089983389486004614554062431348614191`48.917336110764516 w^3-77.8007997555865894573778414801959505167849213774258875369255`49.605930788962176 w^4+20.6866985280439991293326915604900820301916782504814665592172`49.14203167799964 w^5)/(1+1.17904190052252292999298522722921090674323652541388083230140348170069390807675`49.52287874528033 w-0.74530923910819027948143170375514048324971811598939757275938181124371117355051`49.226841543337336 w^2)+94.08625579652289539990482624749947329616629264997511085733873224594138913253887`50.544880531154035 THRSub[2,1]-25.3130598659059019286786914250868429019787255418101692145870695655666950647387`50.544880531154035 THRSub[2,2])/(1+0.39895410212160462515666000445518461536604992277469290867502780541850081623621`50. z),((275.7264888882882106156821266049966020263767195450222076088184`49.69897000433602+ 2426.1689196607451345598400758859003565914771764941408221287537`49.67504025884538 w+6686.822045910452186540983171872915812777736706686950647855669`49.48781465677667 w^2+5739.3230548825079700879845443586871733708328107536295334175264`49.41286071188195 w^3-136.8317450307103755832363314596051859581996646998068398451741`49.007683224981754 w^4-1583.1740598932466959823253690713903544845851696393287927830569`49.38092636731924 w^5)/(1+4.89803718292797715416932919142629489612891805214745318466653094226793544686267`49.52287874528033 w+5.58923919991954667231335722823379257145311706838380417320630914632842325299162`49.40504214254147 w^2)+573.4160794923194423489479489172118638383437640508192830279733`50.05418087264319 THRSub[2,1]-154.2724325182314351274972987514831270328211394901019507851384`50.05418087264318 THRSub[2,2])/(1+7.52603570879812104030518740453667778813473207884240884794037923169709514920882`50. z),((79.1263636219710083771789996110873771586051565811186553129477`49.69897000433602+ 198.4664866580966838015175509265027091255854352444847792431406`49.69897000433602 w+95.8958498399745753060280754453321652559832531066934929196077`49.179719901344214 w^2-42.2152793972445967444430807035740050116972197994476605027188`48.92448948890288 w^3-78.0998951705236420565868803672387005829652950989557337932598`49.607361687701925 w^4+20.9469083700994279347544944668668965200395368521473006244383`49.14663941114186 w^5)/(1+1.17581312976712239271902444225912813815766931669955507089426908651213134863873`49.52287874528033 w-0.74967988507092444537315449424926675146603015603595738492207075159044252527032`49.22977334572048 w^2)+94.24046245501382885363847811640660723067175666973419956098729544185835467280986`50.54310291502128 THRSub[2,1]-25.35454777872649652817119251218779865135054228520908133691755504433640479524365`50.54310291502128 THRSub[2,2])/(1+0.40124697726733158790958551364373185061488995013836269286309336415191767547876`50. z),((71.0295070276281017295686959699479686620405550726765602867937`49.69897000433602+ 193.3352761429832007735368984161190298488606163691004452504841`49.63400241066354 w+129.9118152769655196331440242014905830435387849377705951778827`49.28922827715787 w^2+30.6679478286259754211895044001507356033010052305901848169136`48.83907142141043 w^3-51.0629968494855170937795063661230613955199592955737945776566`49.49770103548673 w^4-3.39801785518545199134438144279278660663187809069740922696019359767185920319845`48.495795286064066 w^5)/(1+1.800161664036608571676041797888859257686100722052871490962165601231261803613`49.52287874528033 w-0.35961971833430827887396153608979188377043641002651498133400911916956436197142`48.89224515272421 w^2)+74.50590608379490228949452456599245491140812268816187541800548210448375859237697`51.011781194982404 THRSub[2,1]-20.0451430987049882298869932514829845125046559958600996094670436892513408262512`51.0117811949824 THRSub[2,2])/(1+0.10781688638590603004493559854661783275758052418068602955679309333816378050884`50. z),((75.3806660516337316192779637590609648372035902171798583241933`49.69897000433602+ 190.3967640143825106008671952747993828301894226109034871449409`49.6805377297333 w+114.6163135843681447768255362185059056588566887650597845801543`49.23816219660148 w^2-4.1298912875555629171597100925533522748431887318441520486905`47.95844025756689 w^3-61.7127555681401949049507479556301895944489471188977847527133`49.523436221223015 w^4+7.5138186759314519504040115144560154805780219198050373016543`48.760078592826694 w^5)/(1+1.37240911032550265306737408838900460781827292916921804228618551755797655937739`49.52287874528033 w-0.51595322248752697224834632384390127661259902561912022457690724214340225763799`49.04831972093532 w^2)+85.11103315241202753487944780973982599900646461572558211020129475457970913980064`50.678193883809335 THRSub[2,1]-22.89835703628592640633627408233117587361897429218657011030781128389683455349895`50.678193883809335 THRSub[2,2])/(1+0.26550289366255106444824100109167468627116391669392243593800778541796320458753`50. z),((326.7237070329641669811630029288884351474478726059990357692927`49.69897000433602+ 2814.9765114809976259649193805719649509663865916018011125518507`49.686774735808534 w+7520.0218899640252454527832926989574739617806320377316639426701`49.48539718346354 w^2+6332.2991542500573951543133187376518829880881822329962918642287`49.401775411961594 w^3-253.2278191090306072104948168701086446787711521106822354037568`49.21563892927145 w^4-1727.4696173356452808244984925720504716813999564708633940286497`49.365229392844526 w^5)/(1+4.55325057075039845194312494294624869124603004834456754349612303822911140865182`49.52287874528033 w+5.01715306191951665395745363375124114343547610545467072602422738695154451200235`49.393417057624426 w^2)+697.7121522367238359036946690107006560729815359683817437058003`50.04402051319682 THRSub[2,1]-187.7131715915401665555052029474951694481461469340138756403988`50.04402051319682 THRSub[2,2])/(1+9.37417494413387424265087847871396474810853720893903942686979264958926769046778`50. z),((71.0714715814112007179261576646214166214809117594872526965831`49.69897000433602+ 192.9219105035474019428422673771974642919734629147227536103224`49.63467569244495 w+129.6377133376531614244031216526205089319277264702058918002053`49.28847534036641 w^2+30.2774983488154725997098099348231746127187721901304516810838`48.83351623393633 w^3-50.9850850838188060367467277427918762747775527652652728481248`49.49570097410956 w^4-3.32493131229189222715184001763439692962850435304516768434304820338471908951454`48.48551202455684 w^5)/(1+1.79036865306085413025943247617287070814014171692721068290320778431749766885559`49.52287874528033 w-0.35899693824234363468278959762945722484428162477664760560919567089373951156054`48.89104219719147 w^2)+74.60818674575008952860330117136437530157218722521665701272285785158307829293269`51.00629390343042 THRSub[2,1]-20.07266078975643530713284166441650611670693257580911749016887259027232438098185`51.00629390343041 THRSub[2,2])/(1+0.10933768185596245772150438557880735216916120563348698740357086745689851723119`50. z),((164.0938763140805967031766377025783962341983627524686975583574`49.69897000433602+ 812.9475049528922977730512175762475753477882108243590659658164`49.69897000433602 w+926.3442486381817711425227680814237669550532528163742168823298`48.93139313832683 w^2+167.1104299474027503959249814317522955575618202615328471333033`47.520603433270026 w^3-380.3892191219054810320556897759255530906900095025951692342567`47.690683885970536 w^4)/(1+1.7563369872339292426649213669408837002369626849583660068067028563199655272192`49.52287874528033 w+0.24418436596118094060244224065807163823282385268115994288810130203885274922678`47.69329635723222 w^2-0.250885587669864010607844632122334054165431917269923455395`47.22435690738245 w^3)+301.3327024381495580311360823654859589718785194752981580400386`50.109685686845665 THRSub[2,1]-81.07085005984456365469304516720089535667972312622305921695478836005989156479201`50.10968568684566 THRSub[2,2])/(1+3.4804697201566951684256882922671777728918737389409287270306753711200398766364`50. z),((85.3732732778589414518010433071949209593026839913495614978091`49.69897000433602+ 268.1697318884163305151544542399214228250114322522873542904545`49.69897000433602 w+225.504058419518431993561666285886903352066402846231227960075`49.29217068634206 w^2+21.0253410570906564167500994008803552242045982045987984307505`48.12567945510737 w^3-93.239659564310263901535092358146939123105216668667701258999`48.840537759920785 w^4)/(1+1.54512714682161725230393669338485897212277791676941682665881270022068628046169`49.52287874528033 w-0.133353438586994286946612601935278299011958183114533463029062540005842199244`48.34403969943464 w^2-0.14118817139966575728039322128756468793585841802642850130107247465591948549865`48.2491770912305 w^3)+109.46612309425069336415156097245421487165563956890074569571629182469357395513804`50.4138498707484 THRSub[2,1]-29.45087466511549907224054894696007990364279232795234515900273351842960233158607`50.4138498707484 THRSub[2,2])/(1+0.62763498929362203478078969939967092965328361576168065198222500919314967060604`50. z),((78.6469131993880907682580756224887159408488542795223480225142`49.69897000433602+ 221.4851281388982461260777170265019532358923276612883611098424`49.68416607557695 w+167.8503044432290999850568952853810406898211052885915132089999`49.30030254469128 w^2+15.3795911619248210648022266016272283291471916471222865499824`48.19324472803992 w^3-69.7618442481047042749122766358321486230496416667027876517074`48.975834839669325 w^4)/(1+1.50574945470684507824510741270955046884880865671519551290162824901913053009402`49.52287874528033 w-0.24111332728185549884016259883233306145173117069220351362827953456050939666823`48.69652434519618 w^2-0.08477963446525169823810746107776969789062040303270238117744358701467359365178`48.214708931698 w^3)+93.07189274139459156008047312501641578291351051870530628532727511764017882907588`50.55690973747654 THRSub[2,1]-25.04015462036444970005183338437443497237641152169261425107177722536419225062261`50.55690973747654 THRSub[2,2])/(1+0.38387169348498857284089589420322436931936524683987248611049329187512984094683`50. z),((336.0346098321229694644801861973426748967232644212340537363124`49.69897000433602+ 1984.7206478250863616587238117373126349911813170642096845119289`49.69897000433602 w+2447.6714881988063555443534010505986154173251178247126291406217`49.69897000433602 w^2+518.7555818841970833171205075018703468290352194791839401981336`48.06974228690476 w^3-1007.539366830100229916510770298073517413682080713476227183999`48.05393788954277 w^4)/(1+1.81960344828919275426696452171799936786824467236119223863832546511448443838001`49.52287874528033 w+0.35410098740544199558195829508132694637339664840011670730044361179184974095548`48.364763779031215 w^2-0.26145711006126280774196137079910752000405981003136358706922292244385147712427`47.589281457638144 w^3)+720.4057165867852035427777002672561308786391388645498472504402`50.042563551496 THRSub[2,1]-193.8186707221062786177301893031886098864225903617412906548979`50.042563551496 THRSub[2,2])/(1+9.71160207066272295479756136777215047461703227064241739487605479414868539414113`50. z),((215.389992392444990848598853040515047598497299776559707906875`49.69897000433602+ 1163.2453474388145901990167225209659162126931412796494853514173`49.69897000433602 w+1380.9789053893126956151783165373372032473191222832769053830533`49.10917824927763 w^2+271.489276146834455766439595318460952746811813966689347066361`47.48572598950094 w^3-567.6032927634856760686712956284045279382689500118546865270986`47.56210191564885 w^4)/(1+1.78910654115161855650125409797213667063562805167862411625574547430572739576925`49.52287874528033 w+0.30090070603571200829364871227442136711417088719891135751490205447885505008214`47.72502559359918 w^2-0.2574367466315008781754188746988788715025152789021672994376`47.09669705805488 w^3)+426.3572823572687125107678569765726111809474563154552688431019`50.07455517209473 THRSub[2,1]-114.70758742823029208037328693220638652501592895479541046270818196123488715325382`50.07455517209473 THRSub[2,2])/(1+5.33944101690103829074856171102615623102947951705659035364780603903823538116424`50. z),((75.6237336000176408838948933253576390695378634701700288145923`49.69897000433602+ 201.8969994719100965292917594359037867229818982064200102185862`49.67226315266394 w+143.6092628686706988454696376501444557592956671976242458524071`49.309914390186854 w^2+15.0025942917038104852549468390708694397901506618200261141311`48.296863947334565 w^3-60.0184816374446737893831449129735956899594113310191276438075`49.0616347829878 w^4)/(1+1.50420779928178484715165642377442996374703487653414713437333408930263084448612`49.52287874528033 w-0.30377809226382155127837384622614281129295442655997602771039036665470765775882`48.859199208804824 w^2-0.04729030834388591912665810834403966353162834758458965221837631069913007097952`48.07610502013889 w^3)+85.70346432365787616652717488122972423842649080843127277199055182695621793219204`50.66703138634346 THRSub[2,1]-23.0577453080076408044882837829734921416463586896073921440846580031447954768927`50.66703138634346 THRSub[2,2])/(1+0.27431166185321505909964764254506627143805454825526418625080011955596280346937`50. z),((319.7569659817347975802382866653849624292427949556751694832104`49.69897000433602+ 1873.9697182995146640897558429079674260434976369760615825869766`49.69897000433602 w+2303.8505564450136037960424099561507397619054359213445373305594`49.69897000433602 w^2+485.3457695926515543017443271067371114645740487828762207694837`48.03751387124752 w^3-948.1974784838338021442521590410411515582809389245107890850058`48.02947255378392 w^4)/(1+1.81709561499432605114034328267694484080578943094441180702521446364829480995649`49.52287874528033 w+0.34970789126468077013966312847268520408400476959794259837944521147554294130525`48.327957603276005 w^2-0.26120253768069287171343294096656974294149126879525145869800002194659206790623`47.564850577567796 w^3)+680.7320387325240602521920035342125508270847308149287182036855`50.04517767504731 THRSub[2,1]-183.1448249608565084367274180397576414957785548785083863347808`50.0451776750473 THRSub[2,2])/(1+9.12170024163786300630617879146099138696036114308675020019709507242888787937864`50. z),((258.7949806199305898338346312085817109790296033599950973470787`49.69897000433602+ 1459.0067362867756539510458177613606175940074762691688321881989`49.69897000433602 w+1764.9974172447572663452447923940761097368575241069548274325368`49.576413128241214 w^2+360.3197379930473454711099387753041164823367833669058671375261`47.84245589315549 w^3-725.9193606185490447063009632643180152661508973294354629319137`47.87382918692346 w^4)/(1+1.80418262713879044809085717909084569760665147596927854561091149843624499525003`49.52287874528033 w+0.32714163251966152261888887952545503038522103449051025372975375342633682681713`48.10943822673601 w^2-0.2596754005799661413913172724515362231128552359399390731539`47.40911382542412 w^3)+532.1487308023208984964218497347312358222609022568965708793841`50.05867907234273 THRSub[2,1]-143.1698239697918704899556075568004773837599453198860379169995`50.05867907234273 THRSub[2,2])/(1+6.91243783262788413559657335151996713574042077266560779296513964993352403101695`50. z),((154.8660352200480386164995664982194207895018671671028096247808`49.69897000433602+ 749.7597129743451684448108484621230900218918437936031620320933`49.69897000433602 w+844.3974488301163871177785393420437943478176209384119774546486`49.03478617628026 w^2+148.4974595140409536345685002140094723560200469429374840322327`47.67144101173443 w^3-346.6888710857295614224830796241592325634009936409206915306916`47.867097567518094 w^4)/(1+1.74703090661616387920559229052714379428612127936141953200466429952892823232504`49.52287874528033 w+0.22813999021202602266216628525883400181593865517397955653198474196844772370124`47.82301634410466 w^2-0.24860293352001102065097821126227512270153811044361956125729156145488680593479`47.40054310842654 w^3)+278.8415852826264630359288000317641029696383132004655698690254`50.119868823118594 THRSub[2,1]-75.01981752391172830342053519959603554774154938845389110732872061850375408901226`50.119868823118594 THRSub[2,2])/(1+3.14605274990268881911623999892652355559609351654613145546945837391983355253531`50. z),((71.038965101733432670441184518609743208385351381991156717798`49.69897000433602+ 188.586201628091286949520878574536373015220229712733625531713`49.63729640356027 w+118.0038158143457905436052145643378730112995067273554420570291`49.37809938899292 w^2+23.1861580236921043181009514356170338752435399440538997628222`48.7301098298485 w^3-52.2827018125875386784147225782679722913550571416034644585644`49.38726380363717 w^4)/(1+1.73241326471916306535889701092921152991657617119473147297388478392945770683401`49.52287874528033 w-0.46579401329536559631491451811485818742200756345858538613565237193985658733634`49.259240518446994 w^2+0.02865262484881137770862089753984538690696312356977991881102423499904521136376`48.15405308100569 w^3)+74.52895835036526841057645475542646066604195720494517328590985043764493959556506`51.01053707032842 THRSub[2,1]-20.05134510343777794697814188885379676327401684264524248549998747057873119595071`51.01053707032842 THRSub[2,2])/(1+0.10815964700071419454918380152129744170342876121434780866747254627111369623231`50. z),((94.1077911858543668344720629568193809066054857815803823336351`49.69897000433602+ 329.6360030026286474995576212588283519551706407079370927983349`49.69897000433602 w+302.7805933478885236462263833942321753787771765375746818105317`49.28261418271177 w^2+33.1222497438370884027653263735367948411093542223283080522262`48.11263079015573 w^3-124.7553439887074343241462960288633748565445354627209826173437`48.70108983837164 w^4)/(1+1.59682831620591951831152630222052147364234103366363724441139038051969170467101`49.52287874528033 w-0.03333847852653860346953632258028864626358771936464864045195001461775189983466`47.64714266075912 w^2-0.18266991727124573730147886017531915914439125047428647013733003077464068444543`48.179987020944935 w^3)+130.75485829936588513241610027959177597559223184919988530255573613314166075427542`50.3136831112414 THRSub[2,1]-35.17841716486087287109443585160674874093115933237395317449041891908807238357494`50.3136831112414 THRSub[2,2])/(1+0.94417392680416495689731506075012268040907752146500002452602124300701622107848`50. z),((232.1635098648401209405835808043529562048078836281220463760457`49.69897000433602+ 1277.5846995557903915883844073123873923054584130085741276452951`49.69897000433602 w+1529.4296989902269608145756003564930480439227164404497358598049`49.338886096416395 w^2+305.7871090351918588409261615298470644042526337260387369366056`47.67234736679042 w^3-628.790754319887659860858260414328670135785868387398927870753`47.728883288610255 w^4)/(1+1.79579333870948281840745464997513477533799562151014267777314888055126585576694`49.52287874528033 w+0.31252635251916153318587829634022505612989792802172373360865669837361323078279`47.92401188269634 w^2-0.2584900585857542518827559078875761148523878417652498012419`47.263862218404164 w^3)+467.2395583671812693888565894755968100294334232559186495788249`50.06749606703025 THRSub[2,1]-125.70659563971074000787020864802444504441823699190572878130950085604858294702646`50.06749606703025 THRSub[2,2])/(1+5.94731330647139733876992592721870831636914265266472661126158060000053456488637`50. z),((71.9235414195670134859690395231855809574007318995540619410636`49.69897000433602+ 185.9159133518688007237639141519194301812401522802682897947173`49.64815871559237 w+119.7639950304442981035663576828375478995678729405704482745186`49.35174462535917 w^2+19.4502237359434495720844229461975738063529063315100589730623`48.59515820211685 w^3-51.6174777894042842582873179292441347424525626531842774880094`49.269401455170886 w^4)/(1+1.61328503285559465403201000988223266193609885403088405539979606094938292549447`49.52287874528033 w-0.41535233386874248330501213307944478977287026102543572677702608062682046544828`49.13792941522377 w^2+0.01285532560103239136333881085737270603795464942083023040829423001596711428746`47.72486707891806 w^3)+76.68494580123956112448985057137520000625224780967153720474693461492543970495769`50.91018767308758 THRSub[2,1]-20.6313941122127633611970519749190718337773541290127950180047672186360448258815`50.91018767308758 THRSub[2,2])/(1+0.14021669362233944396799856792203945187719634518191349225087472464770549186676`50. z),((165.3855181472359980278170275758747227083374843115509546179954`49.69897000433602+ 821.7861560699884571208887073661096934748107282271788013941527`49.69897000433602 w+937.8093600657642427358269251476681751108073382046561900574952`48.91302818078181 w^2+169.7219588857260818727639391685729580735089104093163832259002`47.495339943496454 w^3-385.1056706433573209422139754608524549527146640865643381347795`47.66214231813901 w^4)/(1+1.75752113021443045180636219694091456911137073727028828197811443127653112988619`49.52287874528033 w+0.24622755502431908429512774565098582063170866623619782553148331484483533761973`47.67064345147186 w^2-0.251162583495226294288533684507604053837581539937957656734`47.195825959135576 w^3)+304.4808350833095450824390174488534428606821348200078308531539`50.10839745142713 THRSub[2,1]-81.91782679877535742194116938078343626002692234064291611139999527927244705197436`50.10839745142713 THRSub[2,2])/(1+3.52727882145087443964907947688192703852249775581099669096446595826800014574285`50. z),((71.6158637087703953296070692271852474228017639149729148955406`49.69897000433602+ 186.1117463862746625787907700678725817603879559168755271005897`49.644866448025354 w+118.7256551249832807271670088893454007495922551633379008627788`49.35951343239986 w^2+20.476430915411842114851551711153293832076405878507110637433`48.637086317969185 w^3-51.5509744172716703729516545675701081080831116244850852180713`49.30344420223007 w^4)/(1+1.64415241791054703775781312562739989214042023840848875804096513745282593412176`49.52287874528033 w-0.43026442058247949139071549195416705989453073376599723638116989783058007116269`49.17461922648446 w^2+0.01841667596209226352811394466605337671653853346491469728203766528864245021772`47.906390242351776 w^3)+75.93503958058033089398499170802380697293846713942845583451671191920622273014882`50.94190612856992 THRSub[2,1]-20.42963859652495701198421368435492061700228723855096459273712114917555790212605`50.94190612856992 THRSub[2,2])/(1+0.12906645308278010598586833885452038458809460567463244200026365316142369127772`50. z),((294.1558880556463627181527815142573568916326168353017837491351`49.69897000433602+ 1699.7471757641784562957245053575241157860807017165099336391255`49.69897000433602 w+2077.6082947838353902566122811935167591080942719200865366694535`49.69897000433602 w^2+432.8179833166473530886582876443044789371434397761073995099682`47.97392771825744 w^3-854.8591403668070201807068922431099678167698341212852571730257`47.98011885971902 w^4)/(1+1.81246673709149224451498854024373919209565947206849166480504796791313229318197`49.52287874528033 w+0.34160841567048082399046692886753067782084299856186193729567972925839129461254`48.25595159007966 w^2-0.2606966976181070786245252994171515573145709807536154761449`47.5155156553548 w^3)+618.3342539120110183072852359554619950199145603436990531185491`50.05000901739993 THRSub[2,1]-166.3572628531938789944385801511030707797128580372579158058322`50.05000901739993 THRSub[2,2])/(1+8.19391715261006143601796165210731471966989955589133566033293149675252761373097`50. z),((305.8840882227257703731057067975392609049120620046022652441016`49.69897000433602+ 1779.5670175643961272936962284897955589801830080043101155642498`49.69897000433602 w+2181.2603827037417184355522915287767702713456276234630759142588`49.69897000433602 w^2+456.8784817604159276895203198881999270257463403290443300010603`48.005374172698765 w^3-897.6198502390400419185709805262333724820842831542011939949315`48.00470306020925 w^4)/(1+1.81470352905091860320458693616213796660258924455489426165144494133509830103707`49.52287874528033 w+0.34552082363871432628093051361479420027657940331936572740664280983157823304142`48.29146305000507 w^2-0.2609469492997131507198763867191092461789873109573340728082`47.540098052855946 w^3)+646.9195233475444747187713109708484538183276742320280767765374`50.04767332093567 THRSub[2,1]-174.0478721816123837102054045677766553359297719109715376411887`50.04767332093567 THRSub[2,2])/(1+8.61894713811160722181128504308009630820999494330788712416644621514908858736627`50. z),((72.6197749892764276848426758935480780391661839340820775510379`49.69897000433602+ 187.0728398020688915694418800853439445126016928656499469179296`49.65440112121889 w+123.067752737596994506369423335144840536223046532691822798189`49.33803440825836 w^2+17.7593662940005153776388979034562614139352575177282769835513`48.51437728181564 w^3-52.4231418059804787752223810956124935110514323771837302159856`49.208910487346685 w^4)/(1+1.56643540345558079569185671495887278292370895227107549008512014798056931484482`49.52287874528033 w-0.38739122919710086531570375565195277712614960291760323339950329533189299047499`49.068186140114996 w^2+0.00040509712677529655262240144682939812782038017778546605462930649070068635874`46.1733937387385 w^3)+78.38188342991945539345130263662219367380483108666618149896364520741084189964472`50.84783093140182 THRSub[2,1]-21.0879399001159314781499256615490678077458405545445591236700138620226312403892`50.847830931401816 THRSub[2,2])/(1+0.16544819886812454597964870711794077979498511493955858256757612605328745465947`50. z),((71.6613645087932264209106508862626418852097242848496597893281`49.69897000433602+ 186.0453592882180628521590346016007331072302144473431655831183`49.64537978197198 w+118.857221586857572569684974968142164872114977344151240506984`49.35828384478208 w^2+20.3103882974180700420670972045724316282848188252802936758744`48.63059670339049 w^3-51.5455523310803458782949654311495642459815393287156106850201`49.29803899878733 w^4)/(1+1.63904863838227470442880496958030049030745667907775428077706068916234939778439`49.52287874528033 w-0.42792447427667301560744758056815531766584603795956435790585572627970583375034`49.16889756065816 w^2+0.0175949765925461306184303923264627631874625405548793238315736213709440177102`47.88265329661924 w^3)+76.04593917383896523165659146876045133057905411307076408698610275420064231449471`50.937026544720126 THRSub[2,1]-20.45947513342925765408468678962636692308424619489483225937017003977106117566027`50.93702654472012 THRSub[2,2])/(1+0.13071540212001576060477256465357019886964821310431945166519083436537284189124`50. z),((117.8495978096662431433292347774937641306586799396235353421289`49.69897000433602+ 495.091885190934142548713073630247958713036718209014760919694`49.69897000433602 w+514.8053257578750540051683768245433231507796365790477736180342`49.23195114994967 w^2+75.4132107904884507732513601447802204805901387682869727768033`48.02219350204704 w^3-211.4137294818518967620197752019780936261858584551697456818009`48.382952192535 w^4)/(1+1.6848937242194912700303111655766330787288215333115433503273223055840457049156`49.52287874528033 w+0.12125490980183203311152445891323848114963600710548122719125594258985614625116`47.973738887549274 w^2-0.22841303710866538407810377318333725918151347238240959124525647490826343291022`47.90755417521586 w^3)+188.6210210148508871137051428665239041081122050927496026391683`50.19149194840341 THRSub[2,1]-50.74678715287623969125562106365879931283704597391847504927281059358387033070774`50.19149194840341 THRSub[2,2])/(1+1.80457702202283670499544961713609075153968579153414184265919294253200404886616`50. z),((87.8634894636177727549718081596797725937791179367571700398043`49.69897000433602+ 584.8281627511752012483138304075877348195782235437296883863224`49.603451982123076 w+1256.1114738456295230777624650036986099668997209867492940747703`49.478028665388166 w^2+801.503075298136685129266659009074033164205142560709975120009`49.45026089869199 w^3)/(1+4.96545013558133967687905132857485600410812435475684138983441273108818340183343`49.52287874528033 w+5.62360468600794864730615937990034574125936999583611343811574089256127398543276`49.40577583096445 w^2-1.93170540334581400582539733234499890793045695235745826330177025253938382498387`49.317110827641 w^3+2.00607336310868528885088002496757376045372268725672815284489926177355686895844`49.38636118876665 w^4)+115.53555400509512841263115063159515580930676103972635741248803543899512892614502`50.378940819283294 THRSub[2,1]-31.08380039584547913402890483459447733979191092674213664635922521780942665079889`50.37894081928329 THRSub[2,2])/(1+0.7178804262959443483647568485313888315696999708943616869357280188070922082408`50. z),((87.6562318192760040517444233836534099442757512785433487540191`49.69897000433602+ 577.0208541094306946083436807240067170379944969324646580158357`49.604032405508775 w+1231.5032598578850808634691238435691406558144736772491603432584`49.477185353201 w^2+782.820583167736430443711779372387666260130438971663295032513`49.449210593157034 w^3)/(1+4.89979177324842946581019157433730263066637641997275984688349589338666240253903`49.52287874528033 w+5.52275346715115393844854913479964649045681431717709819893079232149102590027881`49.403601417364996 w^2-1.90090387084312762635357712576567559623345535518726738882944981789273259277733`49.31349035481344 w^3+1.97255890778473576389453186626625573830807626947989308691925467515616355516926`49.38387846022864 w^4)+115.03040270125625766487077028335538999365444585011282742476787623035263400336023`50.38160566936151 THRSub[2,1]-30.94789398648567211008263558703842698879993663798627559448623693299125515958522`50.38160566936151 THRSub[2,2])/(1+0.71036940906271758085690409941279879237098778215199413588109637427866149079695`50. z),((87.515035145527667928074179664954019294085465479743653737124`49.69897000433602+ 571.7720797676769714085123178631742345193830756306249598759262`49.60442637257981 w+1215.0163029219831158652517563265444560552241581336570841573779`49.47659997308524 w^2+770.3257559993410089674529139899099344146540452573379688905915`49.44848783783675 w^3)/(1+4.85568353032487045842927497552134093110385728053162130343215256566117391189415`49.52287874528033 w+5.45502377024568577531206011187813367893955083221017974236566468884830930530925`49.402093590239176 w^2-1.88019984472351064897729389097873843932574803933463286860259911614836879144326`49.31098371907439 w^3+1.95005858602007524718512722980341041965072884234323284456875657323814714961819`49.38215807374226 w^4)+114.68626251734068974566157287032240213811812065907690383534831075566836051378796`50.38344408171164 THRSub[2,1]-30.85530616901998255049466044759596249309168281845751614369640661396603892398335`50.38344408171163 THRSub[2,2])/(1+0.70525244146827155517219517299295736350014273372015736586598661839539805382958`50. z),((85.3606014317318523793109320650565203036197246821233255926171`49.69897000433602+ 498.040566684411905720730156667464700644816482944861339541058`49.61028861593227 w+988.6947120350868757151303042985533418919657309630503235293674`49.46637476029638 w^2+600.8546680522597712239763993304169598309982338392501898909838`49.436662443619284 w^3)/(1+4.23902744878221141810684055389812914712337975970362531727809150169426953439411`49.52287874528033 w+4.51025126379199444226217342260318259251120015637455243206897851661629887691273`49.37598239825466 w^2-1.5895309129678015065831240356578260952429975636654100632695361995560708343973`49.26807942227995 w^3+1.63688455947236516583058528506858217631254835986184766108309757089449239639772`49.352525181851775 w^4)+109.43523786628492055390562135281106779109034563699991182686672970921930837719041`50.41404520052394 THRSub[2,1]-29.44256527265587638916772568138557133669246801737655996483243902974244033664803`50.41404520052394 THRSub[2,2])/(1+0.62717576157760875117144107822046435615907483900418949835653818925112436942239`50. z),((88.4232492112683749459994187514889658101185851002179569279633`49.69897000433602+ 606.5497230940111846138835257541515541789107274492248687126302`49.60187179117271 w+1325.0915301174608280161982148393578134679625351015937218156827`49.480216581009465 w^2+854.0719002496048091015491459584953188428512682460890007215119`49.45303645843537 w^3)/(1+5.1484301426698046537176937453771900297757192919827344892207733460512034518905`49.52287874528033 w+5.90484113647184520933814892793203026397675037818315072003337298440021169060389`49.41142881902365 w^2-2.01743887293619249220087047046921068269138236033730579346694660884991593475819`49.3265549007101 w^3+2.09959867418694306291016093824065619809991378856449155539522161553369035729106`49.39282561428246 w^4)+116.89986250749198580402273443771578880190377842412673357941871099681147556607482`50.371937172178434 THRSub[2,1]-31.45085531268076428499366953288092889721539751564005287986057342810027104761984`50.37193717217842 THRSub[2,2])/(1+0.73816612009712122740961819108800577365626036190797709599170513656568287941101`50. z),((89.6757815256943676628340673818816411145894691521746650949383`49.69897000433602+ 658.8301320755541280668609916626351332154731793869170375771816`49.59827041616684 w+1493.9892889098718533919782853513840414449669716453686274703186`49.48469058947891 w^2+983.8909228642843117564843902579852806632419873149493860603417`49.45894478370615 w^3)/(1+5.59058504755203972118075378941044613939527761438398584437167945115795645131144`49.52287874528033 w+6.58534635789258800497795845997496500042870442432691472262241497142998216127222`49.42303577869565 w^2-2.22405499928589372707256260757034012845317913243415021823531239356158493322767`49.34609107949384 w^3+2.32626375569353471841835415076201103172867840587156028414696676917456794160807`49.406143445957845 w^4)+119.95267309859015306995797063358297914781043549437534355403717602838169692450792`50.35721612123542 THRSub[2,1]-32.27218651135086106639695342619382059796946881251326510747258586673898239592477`50.35721612123542 THRSub[2,2])/(1+0.78355789239437629162090181290214340870624585997183464592220498970194439941591`50. z),((86.883155846143156954327066084644179842287120684335929195183`49.69897000433602+ 548.9502536163792728617944298289787956555739338523849497577717`49.6061749008382 w+1143.8815643528009831977827380003351369350058679293371357680438`49.47386548476556 w^2+716.6295465547207172847119024648236779146908593798918512789619`49.44517912969321 w^3)/(1+4.66421608625978095934348468216314091328883278975650761912658171391931849118167`49.52287874528033 w+5.16122646153718159848091984883190656792355710588151871572105241162280480993877`49.39506743578972 w^2-1.79020605873013061419543337988509360911834594919853885534751940842732365245712`49.299345672772546 w^3+1.85252824638079441476022943590023997859512351275254106900847476660856687644885`49.37415477935974 w^4)+113.14617624951394271305662322148151881476224490579156950622999291222895673457402`50.39190797055918 THRSub[2,1]-30.44095982729215322629117293465708472784600560622736123298949730750692082691934`50.39190797055917 THRSub[2,2])/(1+0.68235313504186997140759559332219590502182607373119724895809422621569511446209`50. z),((88.3087491544637051773009009005074075951948431318807198736083`49.69897000433602+ 602.0288998857518403752946238470638074452541220460712961244097`49.60219650961332 w+1310.6740587963275457356220072607892772458874098583583312095329`49.47977927509433 w^2+843.0611167616221096602295673203408766754093475242016492304505`49.45247580775346 w^3)/(1+5.11031081820063680558633275335836364487364085989695021362748479486649491250925`49.52287874528033 w+5.84623190992129371795116953052826241484561921834124122481524230311267807897948`49.410297638691965 w^2-1.99959066678113116827243296503951561105929399755012160218602119897619276431887`49.32466143715097 w^3+2.08010038795430681081878275590446139756596673781460967299243809435809234351968`49.391530918951354 w^4)+116.62079027752335051320591288257905282969281298686670252550012860973379651804477`50.37334735606116 THRSub[2,1]-31.37577344228106035951215729085143479787479557910900696526854835324155653587836`50.37334735606116 THRSub[2,2])/(1+0.73401663792676926056166473806530127065826452385625087102560860770852290173771`50. z),((90.1059036184476104583038600320360921851307407661764007605354`49.69897000433602+ 678.0795102692887319407781406377872291498559071588437212825881`49.59701317253893 w+1557.1130606413240863951868428890856527513268691030528926374955`49.486108517574614 w^2+1032.7630908384572265066800536460572357422090309808378711931837`49.46088394260003 w^3)/(1+5.75397158331813276763729003195079164283327572915029039347951154132674326868644`49.52287874528033 w+6.83708329953869539954659751560724215138852071844019126219836975883430007750702`49.426726042165576 w^2-2.30023859057221942893910600075687876452514596667161902726827757830944976767442`49.35234382953184 w^3+2.41022885761317347363018353600849824329695932338694352433502106955291256389418`49.41039024404675 w^4)+121.00101433905081405716417782787721362650352174032707691615073347150303162233183`50.352440423356526 THRSub[2,1]-32.55423328167902489817329978425805159618139659460346952826540906015924457501825`50.352440423356526 THRSub[2,2])/(1+0.7991455174555480106475902861691340251681452070237158629790536716174620318396`50. z),((83.2609264192385084688538014939862408529711950157940355290906`49.69897000433602+ 435.8387402113868325044666681694167108800073708516444118070305`49.615723299690465 w+806.6292413805028303055367139588769334708830435351958977110198`49.45315561010941 w^2+468.0399144600240062970474261936003000943800769673873620933767`49.423401177997434 w^3)/(1+3.72330714966347484417116513193828817965264170285198895125180982853179947917419`49.52287874528033 w+3.7244999499425283893279279491297399310815502120051497464946196812590962346811`49.34298168361627 w^2-1.3440709692397779558672504884331162647697750238084149092480208493095375110541`49.21516949802576 w^3+1.37758501528616809745344252668369688856598497750636490653614560140103561721302`49.31548812727657 w^4)+104.31767719165963229421437917028588213102073516219933166259002979254563727023204`50.44941775112455 THRSub[2,1]-28.06573165729392773414153582638645885357531252451470026270201730928661273698794`50.44941775112455 THRSub[2,2])/(1+0.55108353707559138005155412795152817701559203185833943790464660195408992359318`50. z),((85.1317297901235748001407124703563403705035991033670601620066`49.69897000433602+ 490.840490066811695194920955641921282319041289934965144522399`49.61089460457253 w+967.1697838770558779241347722860134152716806852563112508940064`49.4651185675209 w^2+584.9653978581216960032056811532101550503351601687205856119113`49.43530908781546 w^3)/(1+4.1791155702789593898574795542155553005094253131744851358966698191575009818829`49.52287874528033 w+4.41872075467915912552049049049352720621502720371505933587980764055989783984462`49.37280726241785 w^2-1.56114592490699184904979572292155210050167726673217756808747630811576064530841`49.26292595336557 w^3+1.6066197534191851310970943191170451754736172870118079700451351044764095472114`49.34894201154702 w^4)+108.87740653254885401688551645251612311346126030316678345130945010543038823256656`50.41760757979764 THRSub[2,1]-29.29248577564116971028028854307684798929196532580756968081443606337982498453575`50.41760757979763 THRSub[2,2])/(1+0.61888145306234869003250218534740025303938382094367032339271437575424288699571`50. z),((84.1001593910579079668730721056022693566281729679441821132605`49.69897000433602+ 459.7037406305265533699322129376941175705988002480816772787881`49.613584881318154 w+875.4076672998771237800719879826174985546131243493309417014731`49.45893579508563 w^2+517.7668274905625860053907802577812980232464560727990564245868`49.42894124693414 w^3)/(1+3.92067494944514034305161796556038787287398223019247484804191207909434925170971`49.52287874528033 w+4.02458595710924161386249586946552370841297901410653779947664914096740432638962`49.357296353326035 w^2-1.43833041618211559245119817897393798095326653423282914565924772671078216261627`49.23794427592453 w^3+1.47647273726913158062234957626785254355798830709430684885379446046048813200796`49.331498823252645 w^4)+106.36314881363783901350613770527433446455749591596789785160020657619414852142726`50.43452073298251 THRSub[2,1]-28.61604737751051965022089715695230797570699101032318329892914795776504369891678`50.43452073298251 THRSub[2,2])/(1+0.58149734079340811594965780811918493448045403220661499971340091071607472132129`50. z),((85.0207523947546176057883714649310017753507778896441537953599`49.69897000433602+ 487.3887750769191369532656466488001468151560462670606515752593`49.611187259533445 w+956.8902990639799617688760942563768153296479104159741849952576`49.464495435795584 w^2+577.393402999619288290330267728650656438352854156317101431521`49.434645418279146 w^3)/(1+4.15041370522729626908196563422202920509063229925778747170997034627396192112278`49.52287874528033 w+4.3748914164839269157514895214466021578765106463904612433963401547278254552215`49.371235123338295 w^2-1.54753678078243138669110586791765589239735846102805239015482413093463319437182`49.260379284772014 w^3+1.59213271024777164236754284931538561070017335934528134952989647436572127084647`49.34716942721107 w^4)+108.60692012349352965040523533319480248591798987411989006379198052471778121788097`50.41935879737734 THRSub[2,1]-29.21971384304201558848398381803530678252129469797098911849840392111468945374569`50.419358797377335 THRSub[2,2])/(1+0.61485963214586502379842989013177484370870482848649649135234134635565603853872`50. z),((85.1821045009896425599451192789782045235398940324441967972303`49.69897000433602+ 492.4157464331881596019024666108958512631893821482616052368665`49.610761507864694 w+971.8695942029912578503773113750096300053659407904644978888451`49.465398356188075 w^2+588.430839985956687287643845620613361486471728616011655404502`49.43560872314429 w^3)/(1+4.19221850342126895521522655374068338434786259044150800528509685670232713825286`49.52287874528033 w+4.43873403112787575442382575625343422053883135037238363310218948577260281656926`49.37351378411927 w^2-1.56735639606812554735641592789288981653573499255655054741757998698239107291194`49.264071512306806 w^3+1.6132359387908984355027088036066905900884064914082039777526261079789455632033`49.349738955815276 w^4)+109.00018536155329014543330304172338371235482827607798421159210794483303292314629`50.41681785064592 THRSub[2,1]-29.32551831394917168777420600341070843739419685197638950339504433365732603718187`50.41681785064591 THRSub[2,2])/(1+0.62070703263330012226954927231741558343579522697859058784329721352836239352744`50. z),((84.1448975684550757236879018669338407737363501774172362727369`49.69897000433602+ 461.0114946659056325597125887768624943757837060413306339937022`49.61346961194195 w+879.2167797552996015365326767370225251375882728033090509686898`49.45922343961036 w^2+520.5377517491384939046903906295722971726839246038384341799862`49.42922705919269 w^3)/(1+3.93150825361925738572859310621640741734083081825759099286387165015399997090769`49.52287874528033 w+4.04108210156657562750410422584278512836507340952413072149605756812004290654115`49.35801352215606 w^2-1.44349173477516529929575877204922467628037667040610471958454381109035220312556`49.239092320014905 w^3+1.48191399343846075568160318713697109482344898203073250687972676013720235769721`49.33230313467549 w^4)+106.47218965850186362358614477115609950362158643518334765484763972572616879479797`50.43375653225986 THRSub[2,1]-28.64538383489746584201936196333885348020585489846230953468932963373920265067815`50.433756532259856 THRSub[2,2])/(1+0.58311865238594542044257855578888011749268150695027081394107081509795854519926`50. z),((82.8179241711764948726050301458850536188528915592043867178671`49.69897000433602+ 423.7271161973706403949965239984923236929261268482500888415412`49.61683367456011 w+772.2776713278359288662825271931988613291742137191424532421318`49.44977219108246 w^2+443.4366148913100759435607289525726316997871109497365047662378`49.42032923137933 w^3)/(1+3.62337740038088111029566274419527472924210368665235895783409379497614067000761`49.52287874528033 w+3.57292725166945658897310030795928356362907735770209656372027641898335265109163`49.33469081532191 w^2-1.29616751103869650907037913731718138211366685580921099497512827521582609974656`49.202099277591174 w^3+1.32770847473109310358301990192147819051282747359922464167203917119255968872602`49.3062517687405 w^4)+103.23794300900599917367055399311978613390279588062930732499399991335070110980167`50.457739190588775 THRSub[2,1]-27.77523889856533066389582638762946020819697043261607542550268656311909854127644`50.45773919058877 THRSub[2,2])/(1+0.53502913517345892422431358965408426819288459757851996788740484632899841454948`50. z),((83.0808370826719947753605152614586340606643138482651903411055`49.69897000433602+ 430.8761475394706931955967639374350938501879566610394528769155`49.61617623234292 w+792.5075813714860113741348214723822984407568910780176353479269`49.45181056647583 w^2+457.9058388951826750664342671191325673086718258175251692589381`49.4221654241485 w^3)/(1+3.68234314440072074493380192673371687139903995683526736175495550449928655159653`49.52287874528033 w+3.66233376400558365887740029560876357548687162385762210111056459824253790786037`49.33967777553461 w^2-1.32444948287210916173277047108247008434896912352431204173210153401256787880849`49.2099505088494 w^3+1.35712265546654027585916553699330625672621055406448412999729027453036866429281`49.31180426694452 w^4)+103.87874349894604622303830901106114709038934242734558558252257090893832922290212`50.45276054370228 THRSub[2,1]-27.94764049991116402654517632251537202205713574117240866296093900980031678242168`50.45276054370228 THRSub[2,2])/(1+0.54455709934265580903868025264342115067368605526230175338149452174099023073842`50. z),((87.8928043323292537987051115749998903005925193358261301399947`49.69897000433602+ 585.9424751194442670684760619619980273987959562880757359502022`49.603369681867214 w+1259.6318663845174034526383373731744691113580557924226309301237`49.47814644905751 w^2+804.1788998358514162205921098959446520206195725756314599292394`49.45040845089357 w^3)/(1+4.97482612458381216735141781775607948881176200144099965102653000169068589150825`49.52287874528033 w+5.63800909611099161572102982626021963168696964098821623289236706527027657442135`49.406079730145144 w^2-1.93610214834053222073617866656409055250740777620060947985152197333958156244882`49.31761736706206 w^3+2.01086122284483302660701200975185805747988451992074305467552092585300649283442`49.38670834666285 w^4)+115.60700345246533388097154769366904426329927936562451338788516757735111757006051`50.37856708748579 THRSub[2,1]-31.1030232262510094582748022644474335810815947252220982061258786474684620307613`50.37856708748579 THRSub[2,2])/(1+0.71894279716665939504030225108420145963783266259841515395064429412003802761454`50. z),((90.0355807282645259061238980859292279550371026665456840648856`49.69897000433602+ 674.8835779360700230684662229660478155158062349951322708137801`49.597219434621124 w+1546.6000377744690785194923723860867390367784107915331466815858`49.48588048145417 w^2+1024.6114470122140818555432758816965689704531110338029567658647`49.46056988507472 w^3)/(1+5.72682394984561064965936928087884056733334933033187149992544050037867813438869`49.52287874528033 w+6.79524674873220553507900031784521874852734743016655831173695928675518878228629`49.42613221682665 w^2-2.28758570357575080338917569759117913418851985023433840059889751745175487686896`49.35133629113056 w^3+2.39627059762905952682357552629111037851637360950455324366473272008860083884326`49.40970645462247 w^4)+120.82961559629986317054386135320111768120402592963852463767548278612593109185484`50.35321199882689 THRSub[2,1]-32.50811999340471176776270248254252880701371409795172034617357573893272988492871`50.353211998826886 THRSub[2,2])/(1+0.79659701584667869698775039413107713928620782192690355743157958972898553937986`50. z),((86.2142629821487907996185326751281722636343437242662596221057`49.69897000433602+ 525.9113286012141893355920039049262823631716374731057057658379`49.60799964724872 w+1073.0264914101570907651740985667718462211777286410666588713484`49.470745901356224 w^2+663.5187493098434128321943860807946729330988872899576876792659`49.44153711403621 w^3)/(1+4.47146285525348231501288888585378687900473155026281090950958456748232011982776`49.52287874528033 w+4.86583944275922796060134976264981322615068656033631427770591362528638193391817`49.38708900350067 w^2-1.69938798043005512424406490201025195867240092697417415649863551533017804710407`49.28621395801116 w^3+1.75459498098597275520002393594295721560847231051169032760223654263897660017316`49.365093251999944 w^4)+111.51587641932729326013736311108310172475560029444852788048212372683596548567387`50.40131387069748 THRSub[2,1]-30.00234233899354880491881529940131492649689656743450102234900489413003861518945`50.40131387069748 THRSub[2,2])/(1+0.65811245699788242385895093834111649081931520391276548518728489908858823679044`50. z),((232.954419579654334880995927553343586617007223759039800317396`49.69897000433602+ 1094.8854897292729941433316686481514048383338868673311835339133`49.69897000433602 w+670.8089978975580467077644180399070343387362757594474480930216`49.42875540194758 w^2)/(1+0.98867124093883861975211532249700362680745370992902625847986168734640732442931`49.52287874528033 w-0.4062558044450239884631232323257064698383893214940244766560260684513041399288`49.64621891567151 w^2+0.78174312664157618819029128931928529954261722128672348250362301289317361590521`49.60960080971552 w^3-0.53275224215843726752687528649071937127482530738657516216797150423138818412802`49.283938812743884 w^4+0.25066855525369166453132193718605806827700063372650032526866210086311354375597`49.01778356625012 w^5)+469.1672511908939838024980959167362753038035074774142264465451`50.06719613443925 THRSub[2,1]-126.22522403486386562879202830980588496640501594934224643287615478408242270552032`50.06719613443925 THRSub[2,2])/(1+5.97597587530818320873878923302752280690859694222012348945726958355199717204261`50. z),((136.3688314147961308332113368343746426392377167083143397614372`49.69897000433602+ 515.1274284492923077365893640645535464212352038504487324049395`49.69897000433602 w+278.0388005994350739369317983431926167143179549146432524343383`49.41512864967891 w^2)/(1+0.93281703998295918881373116021694340119579506263040125086594174441678528881011`49.52287874528033 w-0.51478829294690272444141522454309678848059273528245639576870281227183623033035`49.69897000433602 w^2+0.85468885950487517758977985628782442777439059740074909406482955790738861179559`49.61562232513487 w^3-0.58697604950133013939914487772041228134002351427899511472317734755820993819181`49.323796695980334 w^4+0.25702900338144469512007322675706780816541845322277435153483249810748963034412`49.064071778383145 w^5)+233.7581498837940060083985242257187796506259763057145081621346`50.147343557308716 THRSub[2,1]-62.89052521070308508073705647473404722935959347478636093698607984279158853149066`50.14734355730871 THRSub[2,2])/(1+2.47571406594730217322258181402541152111730381923297352413463250135825621686068`50. z),((98.3675728116109119730206659008359713687033827051657798520159`49.69897000433602+ 281.0622358727060991046371257081560423319017631644966692254548`49.69897000433602 w+107.3899422436462382568857122683070249530324664913079201462464`49.343505477440644 w^2)/(1+0.82017064339999483953961870858966202575921796633688874119342965356508844041856`49.52287874528033 w-0.74341350667619967238437443294968523558662719837648880717481264475980673368802`49.69897000433602 w^2+1.0515466426483492882089022520526625783496685256089542819450693330753823758088`49.64637391221545 w^3-0.73046977566469312891370636004285202829436236869360748578105924649276375656488`49.41627443067986 w^4+0.28525591543119636882641803498854452508605099578922711583691346727291583706555`49.17670189488609 w^5)+141.1372702444297780152931615718527732223401149012416821122139`50.28109979093761 THRSub[2,1]-37.97171160402178839924122855634566138658318257809355563947935513929275101323046`50.2810997909376 THRSub[2,2])/(1+1.09854841707907987346755494879220231215320334160550061470193861743134004152842`50. z),((226.5530611249921108335740621086952488857092143180544058954491`49.69897000433602+ 1056.5925541423614942624673400504623943599016388601933349783941`49.69897000433602 w+645.099763068501981907033522740464434564759351037171347749039`49.42850414963381 w^2)/(1+0.98702309990859246679627640353151257907428451075213417839733187611039819511466`49.52287874528033 w-0.40944204604787428344419683275185609457610600009783783104727106054925424775521`49.64854167929274 w^2+0.78366077612371133336784893785802736164952387209601063011036922107282705449363`49.60966050273327 w^3-0.53421254781380413266774544169426817562678548820324787308666504668899324425772`49.285037588585084 w^4+0.25078168716946372594014103058939723767609988149752371924511968938190590045956`49.01903409261807 w^5)+453.5651508197236367898714657435406849314222518328204395417831`50.069703235334465 THRSub[2,1]-122.02761942847561569752654351429341721881401757329169877791220498158957259700937`50.069703235334465 THRSub[2,2])/(1+5.74399063866357221131761891987837326779718989483498903709175498002605877468848`50. z),((208.3694934715328969241685195500620040499063068803434734567475`49.69897000433602+ 947.7679946912455799670454805878232556036627726431666731548677`49.69897000433602 w+571.9501004433954476361324962474170494242989716246164494522649`49.42760837736834 w^2)/(1+0.98154701840073637472845756169202253071625335458173265850746066190618890538129`49.52287874528033 w-0.42003154865452055516535989796919045068393405164128686428675638574239463429833`49.6560071774919 w^2+0.79013521772272837951105713002754253269921566624437188103285024266447633370902`49.60991475163022 w^3-0.53912210648836613137945511951187119846898883516648176729409374946320516986937`49.288724281435044 w^4+0.25119066272100672513645852876123707435072074005768380265850567578392718597116`49.02324265811916 w^5)+409.2461442143972347283271181931244255930938282434817957179865`50.07796937085353 THRSub[2,1]-110.10398979840199527138157583621907665328660815844091197368671921690635683021975`50.07796937085353 THRSub[2,2])/(1+5.08501812915525805707743501909039182200415554661347292529233278601899690972786`50. z),((223.5221911668140748057471407413431821372288041605507809781517`49.69897000433602+ 1038.4589690544549861558412247261986111063756014508994180514988`49.69897000433602 w+632.9201810103110234007069854159175620652216567933878662485391`49.42837500619553 w^2)/(1+0.9861967720677438509883470677674803775894823521730183116535334237649638165738`49.52287874528033 w-0.41103966424872587009284751667016331044498396276216556957121355527176023991624`49.64969281928447 w^2+0.78462762293175948930739668767263318628783379068154144977151880738332742329889`49.609693384318454 w^3-0.53494769982102580856444897136728707123891405886832759759175624177238433868791`49.28559037363327 w^4+0.25084014564335608317241125986771477464953781316546175948905470782479001306207`49.01966389392568 w^5)+446.1779786070790006963237295428811177848827767856458921349695`50.07095685945929 THRSub[2,1]-120.04016726688857955982582975212681626624622964948305061663501591676688860238113`50.07095685945928 THRSub[2,2])/(1+5.63415190842110607426631435688501362822369143214080569160099440583518767707383`50. z),((249.8232786021662515757960530221719712234075471792499905242031`49.69897000433602+ 1195.760679192965296016111960738855829988340505698106242902225`49.69897000433602 w+738.4763012885420662145980716896058291445341050735431146855859`49.42930302154384 w^2)/(1+0.9924723727626518057520630699571040893657471422053120888458046311188603476651`49.52287874528033 w-0.39890838366005093641672832962646343056099798260507521141542949871091382531462`49.6407229242727 w^2+0.77737512135125632034823895651379829074334344787663433483733257922043482282367`49.609493370208 w^3-0.529414442826712951292977602483618350014164862260009025238327921396645502382`49.28142398480514 w^4+0.25042529013581036663095355397246115693783925610654169385675546511747869974187`49.01492830951413 w^5)+510.2819041946900309713710166913916158879449653104242657372018`50.06137978464627 THRSub[2,1]-137.286751183970582920685523137008058208145591050858507771926`50.06137978464627 THRSub[2,2])/(1+6.58730334274782685618481652331325763378475385752871714133212970138842412430545`50. z),((319.626470820863844461500576076811807077524576236005636812534`49.69897000433602+ 1612.8452913912563258509422843010303085277722455153246146716078`49.69897000433602 w+1017.6899304112837982998637609804962958348652715943863121355951`49.4305807896661 w^2)/(1+1.00288485700632113833346704265733919570044184747492745643656297503117519823825`49.52287874528033 w-0.37878361860922943446424237874807212504376685299142668873867208592260322416837`49.62461794476588 w^2+0.76580141244202355889214831570775446255012512129959411638902185518822919416497`49.609420794220995 w^3-0.52048168015369657069595961009375788835256188009058883406373732864543721778813`49.274675122044705 w^4+0.24988604720690046376744046267725399411269801462546284863138229464370744378696`49.00731720860723 w^5)+680.4139814619805278020427042568033500244345864603209495009159`50.04519993128452 THRSub[2,1]-183.0592545163543200089015362137072086254774927459065262418246`50.04519993128452 THRSub[2,2])/(1+9.11697109688053789382296442039323652880259327335305228633692130414643330473182`50. z),((94.7153138567648217579640304919119042062438848691370319339228`49.69897000433602+ 257.4350202458205311714039837121893364681369502496649975373763`49.69897000433602 w+87.5636461989807949102673031392464430205847529374380231301534`49.31207223060007 w^2)/(1+0.79263717166226852005711621934993325062986251392351318149082047764911190787421`49.52287874528033 w-0.80254423157624337714868035350988923046009368897408363050147905534181341227825`49.69897000433602 w^2+1.10973004803355309198296443051006449257876625432719011225893262729600368966052`49.6563787501698 w^3-0.77317127210189060448851058168761839900988058584482914110422921780581633278306`49.440212260514656 w^4+0.29521913486267538252394516714251883217079418430616927960672307899053446144017`49.20689835571726 w^5)+132.23557989251506326078171877505511191244276756380626308948224680714625484966315`50.30856281919843 THRSub[2,1]-35.57679197545153832801874495024436284487118881962931779026922362653179204352923`50.30856281919842 THRSub[2,2])/(1+0.96619054899089496101749261316122021260850822511819890631714001989072459204181`50. z),((342.73604409857722570241051276239368802252055979001418118476`49.69897000433602+ 1750.8562923831912614427602840390174415567531786085722089318216`49.69897000433602 w+1109.9594151228359527758523538684585877396607788618991147845917`49.43082036209843 w^2)/(1+1.00518695337991171889924723264239538013149459348525473043351544421620619185271`49.52287874528033 w-0.3743335182088708188523397380266414614348649599267244422776415513507597719288`49.6208373017894 w^2+0.76332021762644732153872422713600590115152217257631975597709949838542908040097`49.60944979519129 w^3-0.51854736995601673803042647360856056967722371709300170198158306521846737755832`49.27321113206887 w^4+0.24979219856795228544631099992448771018699455071303050976690447825352931386299`49.00567694883218 w^5)+736.7391949877438778118230243131134200371216588829283145742646`50.04157325988575 THRSub[2,1]-198.2130460012767313465610427287008199369019603551880451808417`50.04157325988575 THRSub[2,2])/(1+9.95446205501954772907454930464352588723378446232412562545034698310010590002231`50. z),((161.5273371952702087230599391240387212875095013286476076911378`49.69897000433602+ 666.8293519532292498373251273420533658218817013478630586123968`49.69897000433602 w+382.0577124849858898551753797179673106530387930181187538569104`49.422650642205205 w^2)/(1+0.95805369588268589781444222844996089555730949617737189252937606186354567227914`49.52287874528033 w-0.46556034292712221173280193800780694671608915099605334949819746671628988044166`49.68406700279208 w^2+0.81970203552795670229153418341560827560647528612807496878056424468699157811841`49.611931977139754 w^3-0.5612284023049687299421608619148849326819583365337289991946670786267824308181`49.305145133859625 w^4+0.25351582881683171211713270925917193748630489723160293653799129007183427990291`49.042197291382436 w^5)+295.0772488150126684939488037406220269858028551804954870711257`50.11233904293178 THRSub[2,1]-79.38787659352543804837627328078921132322402774647894675621853251973765640856855`50.11233904293177 THRSub[2,2])/(1+3.38745833998609413876447974186961758911933465895119449442140721140642648396515`50. z),((266.6731525703736622085661158631841283248215190211320816863786`49.69897000433602+ 1296.4825060799695307401865365316917354222085849418235133586966`49.69897000433602 w+805.9731280702863144635953933781210979602295432168375292838378`49.42972583303046 w^2)/(1+0.99563977548545378009341918398117247720060653049783893799948417917132566106073`49.52287874528033 w-0.39278662004432564851977623749185665646578845064780044556760255269120656368674`49.63599064786179 w^2+0.77379370225944721534005673688613417752871245691236825058158418761473264515623`49.60943651951327 w^3-0.52666484632047567845357853134457316096926973712961639739516366490482832722903`49.279349172325 w^4+0.25024147139265673272763448128987117821345292305259931564903838026548353456514`49.01258016530978 w^5)+551.3502847197756740131826175891394241547340501977092777242618`50.05649649270623 THRSub[2,1]-148.3358291393685672188374722755980969468359496000388747760499`50.05649649270622 THRSub[2,2])/(1+7.19794279180094600997620796563154219335339140605570376898959550538626671401971`50. z),((111.0786267657222354424383827974159062093279595153218497433059`49.69897000433602+ 360.7958868121443575896427337765629988216918768031713789076684`49.69897000433602 w+168.6138047610717797977798161420770695030575134187342870718524`49.390222744802884 w^2)/(1+0.87940223604682620020289433356166172436561171268880654754145550567059070685224`49.52287874528033 w-0.62094276261306521947714941602640925905382894924348605979603300796637523767175`49.69897000433602 w^2+0.93974819635249989451635515030857210986358529239185519289876029603796062073598`49.62774489245526 w^3-0.64893623362291194238753248541173543116583404905498299903915207401875232451189`49.36614266376298 w^4+0.26787704776120029566215117077501679019029572013615962494104715129246510850766`49.11483595985796 w^5)+172.1180598721325048537704525802290175651268648967152303034919`50.21520272478206 THRSub[2,1]-46.30681406824438707430143397808837095483133750997840370412206253931029911904815`50.21520272478206 THRSub[2,2])/(1+1.55919702478191624513108114766688380416167222220288443893644045949720605215151`50. z),((82.1635648008309014783454306679821095291688226099129440098564`49.69897000433602+ 166.6959216115486979997417211897208681142457182038227186507116`49.69897000433602 w-15.0586955302559628999032530370998779205396706141009803203389`48.871770401430304 w^2)/(1+0.56325043747865385862972799888253774077187292235120698011116010743584253898044`49.52287874528033 w-1.36013976166691181751341727502567080217724297810645791989827234397339221228164`49.69897000433602 w^2+1.73269566120981029494868990266513058591719782720285915180467943951228106628674`49.69897000433602 w^3-1.24102795889077158116479684349359072647740196488678473612334716545657405283726`49.63458623209957 w^4+0.41988141117083936242891537512354774453359806504969264962725631802302638499977`49.46692238864513 w^5)+101.64306582047547680030402531899563272982970902310135823060539906613207887462134`50.47066637453299 THRSub[2,1]-27.34615155301987440480125410247568641176515041924542107687010649469262519030346`50.47066637453299 THRSub[2,2])/(1+0.51131515095348742363959279725422766089026667960661277312735858702229523993378`50. z),((140.6152842136342166885450135613071355018030202468285646378072`49.69897000433602+ 540.809078931631907272875880963656081916613429180459274991235`49.69897000433602 w+295.7908510428007912063904529288448177613079361799514001967991`49.41695481182393 w^2)/(1+0.93825202232565629417591228389589167933507174670025163096105886366736248583176`49.52287874528033 w-0.50414872264183164218994959118116492596523610465471921248548624179942237464438`49.69897000433602 w^2+0.84687209840331160812757019929219137171676278887751696613803310001613082808313`49.61470440254507 w^3-0.58124840735043943471948244245382062634962645483648150748702805402681848754406`49.31969732129283 w^4+0.25618435180894297011401757422922852941366522713442323486626586706683897816788`49.05923611607755 w^5)+244.1080753344857083166382740639663015769765145409593205133592`50.139968824032465 THRSub[2,1]-65.67507945109729545352545889422093688307954994909660440137155361566519180687328`50.139968824032465 THRSub[2,2])/(1+2.62960551952168334407415288792850699692326338707668104375229037185665359583359`50. z),((78.2816016632696935860219384557724151831139688403341514040548`49.69897000433602+ 120.3362361580438886845537116948537486082546698120209330412831`49.69897000433602 w-119.470446170052076085637594629815276189428093078281503778274`49.69897000433602 w^2)/(1+0.24369030242105649716429734364352373069537315967215919514316410697739321797525`49.52287874528033 w-2.2490535946625430306582435503199722179077386120535008240010352068792335777633`49.69897000433602 w^2+2.82694535532913423382732893736132686416194720649101505364127016534854798440249`49.69897000433602 w^3-2.0914220016716441540833943553013650786762774745290680077828850004118916494306`49.69897000433602 w^4+0.67350827464803522732125845334786319100996985723971781917826648153367467896668`49.69897000433602 w^5)+92.18151497335779092375356581877790943341337300148291678911440454611390859024729`50.56797726732673 THRSub[2,1]-24.80060649981504904211177388814693760376092556238212131623025365215461495498104`50.56797726732673 THRSub[2,2])/(1+0.37063280305951801438049390706631213495023189376564273340173667855582351842603`50. z),((183.2556413822396100470139483168730673601350995359110605664907`49.69897000433602+ 797.2929177420578128359376635637443509926032717263153664172241`49.69897000433602 w+470.5007102867519568686798811723977095704455660443867262562193`49.42566251571616 w^2)/(1+0.97124564112054754932033507378698060530893707289403100812583576391839757603863`49.52287874528033 w-0.4399707661079232807428497329885978810073841150393039166714612643969906505612`49.669061245993525 w^2+0.80274263550163013741506509910908503280306688674283918383197133816842203030545`49.61061925769218 w^3-0.54860302758047059738996914049051679687335326256091142348313727643680976213807`49.29580623970375 w^4+0.25209688628553283489162102580242651408399981502870871929192739944766762983682`49.03137800466007 w^5)+348.0358802088713418302006151592781966341364351532148913469026`50.09325604315787 THRSub[2,1]-93.63591947226788507501127824375045281891197988917016330918615663188706600383828`50.09325604315787 THRSub[2,2])/(1+4.17489210492843944524907149261750347099006007140906648031559644869118244835909`50. z),((81.8928718085392682096524730084217413947961849015426888236918`49.69897000433602+ 164.2553442201518591712115596206645994195315136435334796194538`49.69897000433602 w-19.1667521683527215014309806033278385389649586718135468427587`48.9770024343955 w^2)/(1+0.55162256980362338474850161615457596578245863276959736778305849655430771801467`49.52287874528033 w-1.3912942222290179132046940613073314175219056997959135062350969027721498321324`49.69897000433602 w^2+1.76973814801967969853764322226901865983326870591062118718085816261860477728009`49.69897000433602 w^3-1.26928721817553925244043386652362210280046294728989388719755943652318837753985`49.64371384544547 w^4+0.42787473687335422473316375971466467044488886060504480252997014525089049987355`49.47971104942301 w^5)+100.98330285525197169535512199437838167384397749426860793619077560498257868255449`50.476251378959475 THRSub[2,1]-27.16864826845801413937603042935070796884361045800589679208879347154795346046848`50.47625137895946 THRSub[2,2])/(1+0.50150523664864539654704092937607307885858328807982003288037154286340862000892`50. z),((121.4540524258683012409244460697649707314144777361578235784618`49.69897000433602+ 424.4997914150297212705426883039835639914350390336641254962241`49.69897000433602 w+214.5658699015428504242855341302683361371290239634064552965618`49.404857691449806 w^2)/(1+0.90720702654259694113055635827258779793822207127253223219497880080914112630044`49.52287874528033 w-0.56528277507485345632791177827249373795105948739148773439839778489522883248178`49.69897000433602 w^2+0.89360478028002417393010956098546620899530547923158384776419067198834998327255`49.6207744897622 w^3-0.61537179674400933903423454686716507517563853186115169003679979070955484245199`49.343666397354845 w^4+0.26165496029155307386393364224501730896999526443892584981374896389419227229229`49.087713352522826 w^5)+197.4061973338483556957372870666608145224768987577353413771785`50.18091165524492 THRSub[2,1]-53.11035973011063056445007768692263288762942942024161820375077474686532623012972`50.18091165524492 THRSub[2,2])/(1+1.935202460831905410520760874762517186694963797368562628593862426764290723662`50. z),((294.6529972231510775051243852363946594852609735755811927386392`49.69897000433602+ 1463.6705192096046199190111370426712350225587373860244886466439`49.69897000433602 w+917.9025661525240146667586178103293075539957428064857951355578`49.4302450365246 w^2)/(1+0.99988079200541232966782548233693913543010582426991356091579341142538133985743`49.52287874528033 w-0.38459000072060793561420921487604520825258755129703559579642075991410072876689`49.629428466517 w^2+0.7690815158388274524384763585140125936019992877270377844764250567158499556708`49.60940777558664 w^3-0.52302769288424382139476257464768404478643760345652407796724281747073998058892`49.27660093092149 w^4+0.25002238941280500420035586041038028598193842660764619833515444462388417358353`49.00948097655241 w^5)+619.5458634761010744637102210255711099010644354541340982988203`50.049905376744086 THRSub[2,1]-166.6832354957469391849222002601822738090515605786166761089257`50.049905376744086 THRSub[2,2])/(1+8.21193238932560511213025841128336196887086756288921384134582569757985151446617`50. z)} /. {w->w[z],pi1->pi1full[z]};
(* 20 each of [5/2], [4/3], [3/4] and [2/5] Pades for the non-fermionic Ls part *)
Ftri3LoopLsNl0Pade61[z_] = {((74.8962831659377864263525058346359752665652888081412845128207`49.69897000433602+ 45.9970672304247027598696784236882464281196063481277169990182`49.23322887182772 w+48.8243598191548560720190700119075234479811655905291623334231`49.577657646641775 w^2-18.8859668462621001969215799472656510533930840343194029870178`49.071100931032305 w^3-13.7929895957884250397231672516390229674738426153982685592979`49.05917079620093 w^4+15.65024992438212643515804188437173981670911416994781587339065864546628760753624`49.69897000433602 w^5)/(1+1.48770735961207174866507484670254144793261459354907306078336174372695963954074`49.52287874528033 w+0.2388929134016877047238565909895175241786466312301749744286200959456793371155`48.786010876292956 w^2)+178.6864475557988343468948167663755757761271353116021828239809`50.09828315642902 THRSub[2,1])/(1+3.93765155469037752261742209473850942066944711207826189088465335726549911897897`50. z),((159.4396796940115689534138533762589896716467757832063291428959`49.69897000433602+ 55.1457640550102720920744567292410062751018513497504098295297`49.08244834917591 w+117.4348691965591082666924714694942810730643775418503259025885`49.67549696740195 w^2-84.1150091424011978527073469630694817083218596843904622079421`49.324834258071455 w^3-5.008679571439067931803908788638656640785171959577694057636`48.31510861070984 w^4+25.3879107758477556064332814365846944196265914258835324184562522253452063096566`49.6375804666324 w^5)/(1+1.2573976605877384581839603973023736719154674939439718937977015558413223653071`49.52287874528033 w-0.02800141192931572429068219235929375008933333547054938072203757674991545878253`47.95043589893357 w^2)+384.744984613658908198715801914334849783813978508700051767488`50.04289986203755 THRSub[2,1])/(1+9.63167742950244214403535653282453838420459160624146765339529319582494639099428`50. z),((119.8893552595849403870563827630213753743874247319813012538813`49.69897000433602+ 50.6269048922351241407829077903130966483009598880958960503384`49.13878741585334 w+85.1160963200289673951993923093130922127203711694308476360529`49.64765142585169 w^2-52.9644048405871920097511160535617264953082726802592692996388`49.265217297073306 w^3-9.614879383649367796389139336435736204792055684086023632019`48.711438549483574 w^4+20.91142526014379313977873241665251038582761955766592283167621598707405089571453`49.66316447180167 w^5)/(1+1.32271147446040779272346172255073826301798303699026191101989595466932120618348`49.52287874528033 w+0.04815907689431735627932381781716892588730323671638292887149077620936165075782`48.161770921829955 w^2)+288.3485500273636241204887830349675386316994043491031722618818`50.05824157511633 THRSub[2,1])/(1+6.96794992463390812473799917167799174500447455927701528862146187074310012618886`50. z),((131.2691088492193322516561391406758121279495572039958423094617`49.69897000433602+ 51.9041767793055415687647717237998678492444490770231198597801`49.12066828722004 w+94.3927305696485927382469633342450739146300858313109461553005`49.65746727109851 w^2-61.8631971517921323011523705256153552761955868653653473973928`49.287008969525125 w^3-8.3395626217282295096539367006687868683824513681193047390093`48.61364046526391 w^4+22.20739721809590994433178323789994094755048275292215410212303062310986554218725`49.654516310779 w^5)/(1+1.2997112012974163513466719823039793886404937900101104376163291238891025750413`49.52287874528033 w+0.02137899374416893628977049688055885686437025169175974501190106739005914541702`47.820065591257915 w^2)+316.0845468415008488165008948659068776521444433676815858003917`50.05280657607789 THRSub[2,1])/(1+7.73438011373622442825732866163642526249771130836224537511132705463392782082291`50. z),((57.41956182373838073903626744420357092428303344879925035564508182389707351917115`49.69897000433602+ 44.6628050054850196518219529993086179307029990701879905700084`49.28482252976131 w+35.1174034271187676464059503780819277733519366512983917000782`49.51936488001902 w^2-6.77586705431021545519259597191023489848961708016539208264358053534634802746243`48.790877417596334 w^3-14.5315627987073810959639460686679552879869629455631028099320003751943255961813`49.19940670566268 w^4+13.46693810737913527677385681649244301272172182546319912763143742352948529153063`49.69897000433602 w^5)/(1+1.62960622190599339832596804655203615366972687730685894515489639010494915808863`49.52287874528033 w+0.40074693382405953667517547125689940631799755838693568571776079083963690537933`48.95794445282025 w^2)+136.0902451292065485455740425532686476407441056930565115035964`50.13425413665291 THRSub[2,1])/(1+2.76058855963648185132644484172435358497804244125782288011571214195285830405056`50. z),((23.2222418137359930983154451213435991041936214755785471207828752755166767943936`49.69897000433602+ 48.838291151272075060621573717808397733527512636868383429238`49.43424074799194 w+11.00572554183388611339909483392517743076697117573551738329094765575186536309074`49.17248984979001 w^2+6.36195625572399731919694187665707629570930868330833734809837225486987176161371`49.69897000433602 w^3-7.37785687702928880916654442560751932273725942177593270948104902497047248597108`49.69897000433602 w^4+7.91575054296749140188821127319446709460664201928139563436124204675317680865873`49.69897000433602 w^5)/(1+2.81734152456751914499995659515706414054336638892573945177223016771933216497544`49.52287874528033 w+1.60492008496776238951505585684970136282336991051698438753360595462745854199913`49.28421144134373 w^2)+52.74074626893020371805150243351832479685083262879086842257228848606370090235268`50.50329062940692 THRSub[2,1])/(1+0.45738768313133212940428302785102399731680987210798010905099251647546624300653`50. z),((133.5926249060709185992257078994276412075858513853913314914704`49.69897000433602+ 52.1677278243492511738189915785359643902358829341106080676335`49.11717977494613 w+96.2894982417887611346998223926128501731832525894891139058749`49.659256377269585 w^2-63.6877800790962076092107854305620286378105066087572341682841`49.29088375517615 w^3-8.0732156441398520742468353073542184985488180193284468992314`48.592585144675624 w^4+22.47106152495104100471036345104205664477741511344930034044819774218277180691471`49.65289967342958 w^5)/(1+1.29551736580171713271155736634074027354051377766652364272300827238119088353928`49.52287874528033 w+0.0164912230301699985227172422997930425241916062561108467338633274022186320101`47.70936582152833 w^2)+321.7476777206381687233430177435732414067191898611453912568885`50.05181937349709 THRSub[2,1])/(1+7.89086969295322428481481347548805898377033311714253154503214598228706619856175`50. z),((17.98776684175915017159641121760740082730268344279597182971456545201823130892884`49.69897000433602+ 65.06986900570354649257934099150546367026362567637101186428`49.47395191696424 w+0.37546549978208661976345121447415094000219050818439821067310188724233130313905`47.760399844514374 w^2+7.00804490124162022234660019476871810062965363450385722569691389255919649417793`49.343683370620035 w^3-3.06220607705016346993281070074891831080783629311484887294421686627418871657222`49.07070534350374 w^4+7.1247083683488620783728680110861634873193286308001930712256006461955656495604`49.69897000433602 w^5)/(1+4.26451895835068152238904321506567073519731641698750289403994001938954406436245`49.52287874528033 w+2.24960205815311122247190960955003653181420317568711514158697059683858126769251`49.296282839830766 w^2)+39.98270366257046459625403843069925372138573549679608413385980949912118033774063`51.022757181766195 THRSub[2,1])/(1+0.10484405281249265290962525661823680738208206114174741191565667113080039909471`50. z),((93.9659041563592275015739940462767239880458292203719843064119`49.69897000433602+ 47.8408714760595897291279259766449822801118147904993629361868`49.18784450972586 w+64.0999658646304012242780278251312657980863107024899157785008`49.61588548822829 w^2-33.0254698651171709623715812063203715119580551372846123265593`49.187215267583305 w^3-12.2601518928152362251297189090492682414080338062124338398672`48.91451199290897 w^4+17.91785079986924561187508228642623394194625750148656817985170161298112480028245`49.68901154302377 w^5)/(1+1.39722284100843442442461001269819034580092627633267753611965346436254448621348`49.52287874528033 w+0.13460325744039500549039840604295824263890492113440634359497995126051430825959`48.57442861652107 w^2)+225.1650415667370263060647115305274598508992901052638977392152`50.07609318111165 THRSub[2,1])/(1+5.22199687084126726243971190500145341715497131389977838512404804785625783552369`50. z),((78.9451692414465645046508596684319224006161997398794030348786`49.69897000433602+ 46.3652797430123154593180444164568597202621018644219994500098`49.222768948839835 w+52.0476359015427634729843174789803158197723093434674762601742`49.58738595470981 w^2-21.8303817619671461419024498356189672081746450456154651280053`49.103726716447426 w^3-13.5127607194617983946077754021935193146600762355468274577542`49.02817605703776 w^4+16.13886599100955267436528938612841238794848435580027388069621297735568178477944`49.69897000433602 w^5)/(1+1.46454546957902609731949133680683185547069085671337318034910617782592284850108`49.52287874528033 w+0.21227255369422690246428167831485539364670124254683820110197111585598669115498`48.74399567575139 w^2)+188.5548414895135277662903815023514778260412231712730999422004`50.092548789487445 THRSub[2,1])/(1+4.21034537851206074684871366392155131467564759888877674110465270486538822335087`50. z),((18.1259249488392656567863228786750460022767971839828607477002934383477222382609`49.69897000433602+ 63.5452895830831197436940129281618153875204820627456922589231`49.47231329413806 w+1.43950912553520219938594199319267329593225429884538322036977677120996899957365`48.33509723376584 w^2+6.587149611885386125744010196586459501824824268294544859445519116602567748268`49.332281098958426 w^3-3.04263176623923360381739330743135969655278065496434451467399924449406633793939`49.081949978139306 w^4+7.07580127480944189891040722188197237472441399306716340636197244380882080073071`49.69897000433602 w^5)/(1+4.15510791089728946415412535846333100707128526014158983646414900784494595517715`49.52287874528033 w+2.23493403371265277384821125152827232699728825803578251184911233709880273950436`49.299157812226355 w^2)+40.3194379149985459872835921255443938107324813575357856975501239831833744503109`50.989471002164294 THRSub[2,1])/(1+0.11414904727492836879131830917905659050811023162634015313221231807488461173818`50. z),((19.1970440183068840744109601372353140277342733618868902469174444930803417166628`49.69897000433602+ 56.5670503104790920943613388698031714759559674615318962628429`49.46193764245515 w+6.07694619403178086734822112374132714419481853009543034854409886811739370080013`48.92943035276833 w^2+5.36046162692851480982229329502276665130662570475361315411882638694421608987524`49.36352155648362 w^3-3.66217065046412294215666623104542142638250230668821242079285349260864000094305`49.26515077871891 w^4+7.03812416777449424289568329284746098426868505534415858300053454884049081668934`49.69897000433602 w^5)/(1+3.61249932949267413778856799008267716767924030730365471155821323309624521680781`49.52287874528033 w+2.09323316660318007898849205764745620660655609322256465001694941749326828920558`49.30749570309791 w^2)+42.93008803710457025484690518581411886266375579037747031932264973266798320351133`50.804002755751924 THRSub[2,1])/(1+0.18628927285160000833754526423175756894108326688983153392016343826097100580906`50. z),((20.38211958769421676764616260751431920227841114293455464532015723919155525835304`49.69897000433602+ 52.9117278450038471059042633735954735323827431159100654429935`49.45278029516897 w+8.3335135640127703744960494012958836359358780033969459558179`49.05741416172581 w^2+5.44945883125659468239568554353271475881039627960516610641741291361881712106021`49.52144090328109 w^3-4.80567633969198753743904528417888517337692121937210771944785638429949401287183`49.49914271384475 w^4+7.24845648812705947438615369567244951672425604113530461186695981017565259906136`49.69897000433602 w^5)/(1+3.27807254004392902501262541555867486618073406584919376621650806692388390297772`49.52287874528033 w+1.9313567178535142115077010447267822425954513725266483259978082104810982016068`49.30464827280684 w^2)+45.81848557208976660683142734991526394384991440439265053099109039387932717242307`50.67741732504227 THRSub[2,1])/(1+0.26610450659913932221120219335531584427762026267547255859987421693110681765829`50. z),((135.8278894407970018149559702038191696778336645680028758906864`49.69897000433602+ 52.4220387197537975644753434046294044713950933481857732151347`49.11388661594164 w+98.1149736904385117653488958398660259723931606057416243254605`49.66091704493982 w^2-65.4452105010601496722481741084817223051362180395832304363429`49.29445501480281 w^3-7.8153089455255903820318369342782905794019918124673046419371`48.57190467974046 w^4+22.72444465226869555514694278768529741951464494697465653518975996702557711782094`49.65138729555183 w^5)/(1+1.29162390028068802641884541724010267638299380437647110729143422391888253603633`49.52287874528033 w+0.01195223098739132617231972017838390925597344408737873676447954647857788605525`47.57145974431133 w^2)+327.1957122079919863433074516764290496876683998303945991011658`50.050903925077236 THRSub[2,1])/(1+8.04141550280312401359043812625500505313569304047244699626030910326801735867405`50. z),((19.74033049415396624716474302663643816388270534602164409517852499395307520245133`49.69897000433602+ 54.6101785960074108081500309868913167457690644785296616328829`49.45755640039065 w+7.29598151215114344462397811774638662911838346142902631631026700836706469779546`49.003281740448 w^2+5.32501337422101013071994055378472324296769772273536278346077990787102897301305`49.42613545622918 w^3-4.17180971157234880943616977335184780040195541678930750100260807274148216176674`49.37365896042167 w^4+7.12024765915964442675135025707478255795546863893001161186472962303159137786969`49.69897000433602 w^5)/(1+3.43995897097731747836844961155136251554570085331810582904976175718563110563518`49.52287874528033 w+2.01771987486207881081745902242891931412794769935850922725030290958446046861282`49.30703244454169 w^2)+44.25424605551581375878268271057326470715434813434911260452480207141345259397264`50.739313065519184 THRSub[2,1])/(1+0.22287979769385083094817975484275345726815338112063831890461600657289842724738`50. z),((37.53103851524512755499024740095529627543181873829770394247118325497336649205783`49.69897000433602+ 44.4130715965831525953355173836409122589253170440385369376522`49.360918117196825 w+20.38003445311414812808992052024917260031681429807888258877210022781169300177685`49.38833652243203 w^2+4.3754288657338114100449228629730221353742229319612241747953649885446192285116`48.87947601768145 w^3-13.28758202063487122942421410324792756589770038471594150732997572491810894236191`49.40039538081124 w^4+10.65794103032537080855595148828918586422671601359101440775508705891149034129855`49.69897000433602 w^5)/(1+1.98565782641183712782199667011199984118656020566622430218182225299579531383438`49.52287874528033 w+0.79540990469637099966481271530124556570497086452384979190494283234748594086161`49.14783812159981 w^2)+87.61573161911344621178329721548391289764902793347164999239924885692909934892927`50.231389363148075 THRSub[2,1])/(1+1.42108990000126551991758040976500471034643346823900497477258112648389316308238`50. z),((18.0303553661619169179983473229970770487020813219977923876282804886837658838149`49.69897000433602+ 64.573985464936610471980473731291720726735019704315820807606`49.473435639354975 w+0.72314678089826390549372311612799703106053654572360002536017728976625369501024`48.042066259178334 w^2+6.86682981378790452402510651900146364969906460527723238795518339883133345497481`49.339631384864816 w^3-3.05163479017691603041415671755998729617926567579359874587826638759754207113035`49.07356583124892 w^4+7.10772928869446441131903100910218127939119089539475531527517187606413965716338`49.69897000433602 w^5)/(1+4.22917576450915640384025188630563135046903914096474298068658708964172291998039`49.52287874528033 w+2.24527004817195584855301868874505876052128018249593433704099277007723725995983`49.29724180596188 w^2)+40.08650513488265150636163053429241655734751595414971037033153702735201215126626`51.01216129967265 THRSub[2,1])/(1+0.10771240409571668821330332580052375910050048815007307058385770601589772354476`50. z),((25.2743920281796728329849579843520159640602171505694178088088917694821647489232`49.69897000433602+ 47.3386541880083374459386273018062958174270432183249681649061`49.42219658156054 w+12.37186842980820514805135677723217453725986810986870323870777675726118351112974`49.219717035700796 w^2+6.76817404273960312452804335974864110583636890190228929054343342041368679124791`49.54351585813718 w^3-8.84732953501539146190200498174911690423107336899151447208466714670469193578873`49.69897000433602 w^4+8.38660901751408074783325590236782658983400076626443103775544377499382542620017`49.69897000433602 w^5)/(1+2.6059954117547256376502034467714308775953247630111205513349585344718792437082`49.52287874528033 w+1.42056333348025640365009077451553338953608505007300415107351499206940880634076`49.265803573838056 w^2)+57.74247423795994402098844933102201809311620352095369594959990646236229457469994`50.427969026613916 THRSub[2,1])/(1+0.59560068260744470576921973120774386897633945886595559331789739667952089778688`50. z),((18.3323400595405737989205241171738030988491371517473285821239636343617776594043`49.69897000433602+ 61.6503916814193849048870089386251900217790004570976802651116`49.47003662603547 w+2.73992280998296315623461335822559603221249581663288846891190317844750932458316`48.60453002288054 w^2+6.12542999276903054819468492121524072488596642933081348724027326469293762234916`49.3237364687499 w^3-3.0787417185795566331733812733811526503403486011471195523437320540525415575352`49.10748428753554 w^4+7.03053782581332317489827054399916024253214041989042223325740732379784791141985`49.69897000433602 w^5)/(1+4.01560140843626230765997698489234024486631308264074075100971859585475768745687`49.52287874528033 w+2.2103826019595788247831834603136870194986979154140672583391780532017046149166`49.30236767817285 w^2)+40.82253570245997043370541641305205504946866802584694638855117062156110929309097`50.94494523842488 THRSub[2,1])/(1+0.12805117363313731517119937928859039717858656537544385933135399832619523947983`50. z),((55.04045332198991651177458340391463630336335702758912192303127884458380797721932`49.69897000433602+ 44.5302400321033829292664529170368606829497865309272546541424`49.292800621516044 w+33.2889057843602625509813736944422646023835092685753652986687`49.508520462209624 w^2-5.237573275585533233213419848213678874492806360298145976723`48.70777620903604 w^3-14.54521425568363636814104409763733693439290784109924476112783421750347840246541`49.219925433357275 w^4+13.15608153518175176568601323739682886636076118188892010607759811431637666180936`49.69897000433602 w^5)/(1+1.65678292842390345851913592943762227886764700774690087898408381222590634686305`49.52287874528033 w+0.43148560234426617958779287682085617597731823020436104060398685849573965857697`48.98068150050539 w^2)+130.2916181813358596457146640900632707544331094962404159938739`50.14131269187209 THRSub[2,1])/(1+2.60035481076595058546597111062950571555357421222400496747635195106946646825767`50. z),((88.3599293135382970772289702300417262084094427210822990727474`49.69897000433602- 1.7526915789451981775778170116868758751673706373103482985605`48.05463326490396 w+72.1674549712576849636694635601591408726535549211803453224551`49.68634940986722 w^2-50.8182267484518055201635433748178514262544245367707532241136`49.4940247566436 w^3+31.76409249000669705985442304229981337842431250495762052078851035051103951734859`49.52488588701445 w^4)/(1+0.86463659226963798741370689683271609235352001366000413439279812013625875152888`49.52287874528033 w-0.18803923819516160699071922840563234461749743231980109601025945813474594267177`48.86221766762909 w^2+0.42456310145290260960153198638317724403982575133003791142994322640631373517392`49.69897000433602 w^3)+211.5015382970137454903431509118292052969601165953137312234763`50.081499436557344 THRSub[2,1])/(1+4.84443260066236313463598663134704530727369583736781290375103913182368398112025`50. z),((62.44650571765527302098619052739421228033552318720180032897515353179038386442817`49.69897000433602- 0.89312152957007575439940254530475909008049427077671365018678753677322708254511`47.9238615813063 w+50.76952992219686610571703626682218468983823152625306341274517200259208651212429`49.68232373521305 w^2-25.24769822190706021860193833468919019016268552906088117288708742544990817500826`49.436303296743304 w^3+21.69824884030591550234443749121822031719177910535011862588865733326495702632894`49.56504953026175 w^4)/(1+0.84498868720611142685584437180033591926399643456091605433307816031583864771386`49.52287874528033 w-0.09902871850526841157574627803177983910358811202779365845204189917297442082316`48.61055659608995 w^2+0.58077003330491561346680502593057761047938040022041904173864459096141003247958`49.69897000433602 w^3)+148.3424699887612634070285474500389456327176625595671109932547`50.121451046356256 THRSub[2,1])/(1+3.0991549028243434989189701491565392417188281969207478682796433806277735302551`50. z),((160.7032944109421832113869181618884070435743886758481424958259`49.69897000433602- 8.777234423740392601474495466459312358859491314836967497806`48.48961441268758 w+135.1377413512519174611535616019044271195348616321932479606004`49.69897000433602 w^2-122.1221606290057161600024237569251075719083498474026464308142`49.53891537654955 w^3+61.5907235690472741839559347917560179566544223035668415060795`49.50412908728937 w^4)/(1+0.85717218375786242568638452686417796467340019600324967715311608982867480628649`49.52287874528033 w-0.2896030488552970575593199498022204166023419107469460550196600678395492796646`49.034825872840266 w^2+0.29517493075664727164819535085228007655971837466420676901244829779682503953773`49.67250117338097 w^3)+387.824806464547547342604281821074588496337266531042748194613`50.04254193589659 THRSub[2,1])/(1+9.7167823009586891686161366722114420486664568869819866054887945558913514489626`50. z),((119.9983371074153460149347943743152121156545773476261154063303`49.69897000433602- 4.5035236333827674919578149330719140213985280028647236329833`48.328022974582886 w+99.4499802229988696428845727848504601173905085142890444938883`49.69564142887233 w^2-81.9677877420591599374473243465452160962311878849644950541046`49.52161112645548 w^3+44.6551118014817776491459746495043489074747727705808667357921`49.5102911438625 w^4)/(1+0.86294197569208440035651768192241749108891001510704009443321374354418213642093`49.52287874528033 w-0.24720273593790750623095363264874036071206849800908116961072021494498148154198`48.970984605086805 w^2+0.34481099890301538414345282041150495094646131946335919064652605162395434650233`49.69897000433602 w^3)+288.6141726667656106889883309468622244792959936849178727506085`50.05818421658206 THRSub[2,1])/(1+6.97528988833202025544045316878009882042795518167216357405193344886841194897795`50. z),((81.2583781107995914957040308492291473224406922796747844996365`49.69897000433602- 1.3043169633189654820508633164206361992309331018697306273917`47.964395387237644 w+66.1664548308414913717605365804074821236435075476064039363933`49.68426192167706 w^2-43.8286296683897731223422182027489472014041740737651412977961`49.48372686916582 w^3+28.93821680164706484578741388734691571828544919476299055904186239578231966067835`49.53145072459287 w^4)/(1+0.86311757997335784969949455865173387986621754164690035283569353747306288480525`49.52287874528033 w-0.16875792271375341579965795721163312451588438439912068349408469783877439070068`48.81957068839797 w^2+0.45395036875941796986894975126376992695223999752979452987519574869532264425324`49.69897000433602 w^3)+194.1928505488002702157419394355442861854823554548024864202367`50.08956432761129 THRSub[2,1])/(1+4.36614076522292148931709520409165266057458099333732575271614574438297398486339`50. z),((50.90723213904483787276851318046756026058317032313133760879765525430284590759571`49.69897000433602- 2.0237638819938320835436429634263173760970462575612805750395`48.38456256426385 w+42.10521133672121601472453313350069346944244953741288889025396323328430803874258`49.69288709039076 w^2-13.6179139694342340665456161845345689263236699049089215776623528821703123094955`49.36066588281741 w^3+17.59092035560301399393717521214513460858403036431643123547536393113342847355397`49.61440897545539 w^4)/(1+0.80007382592401879500545990245739544354838733858595516483519250152498633509783`49.52287874528033 w-0.03754461837213255637703674399467591140602337057220824821561232938349853752998`48.22588808444142 w^2+0.73921067414137925309201719619627682669309696518350418916631872326280811693356`49.69897000433602 w^3)+120.21767337582515363882826905457088060444411289638851823885569972177033691535422`50.15553848305122 THRSub[2,1])/(1+2.32198098940906197424688156952705574925768026289381726065928865643442705382235`50. z),((130.2079646680026032103024852947930824484141989349572937408591`49.69897000433602- 5.5293810865813740555275145013243043942369621982835931166547`48.38117488880639 w+108.3620350790933564673012240353066685242486059895579241328476`49.698178634990484 w^2-92.0312455683294192642481749213160876888842240489416822639827`49.527125795086846 w^3+48.8783687354689154378562411822428485448047879298036885061067`49.508042904904826 w^4)/(1+0.8615097211884981612283553939858140404544883106138648555237677381497897036016`49.52287874528033 w-0.26029522357429519863449113065394692112791701908242775853348634000538804049916`48.99170913177855 w^2+0.3289049511384606915193014335447907725129265983840814494584653730316143020559`49.69710501123991 w^3)+313.4982086226859511895414690882772468929752558299162164686975`50.05327006651469 THRSub[2,1])/(1+7.66291170020084051554975164263711724915871683514268273082398403624637726020884`50. z),((163.0314803461928914076857945327943057850361946020773695571961`49.69897000433602- 9.0329067555818820403677947068380656132703374451364369835182`48.4957971195987 w+137.1887413206235970937101856870127876048156837484223477321718`49.69897000433602 w^2-124.4211579809055340888326735972111260070568111590035598372701`49.53961391651965 w^3+62.5656305360073054684368219898178144354002740811683956884704`49.503937347064664 w^4)/(1+0.85686039436602992925766602905768944277103734530280865761212477967435250879217`49.52287874528033 w-0.29139378349944467031824337760352998429706919189659661864822095379680770305442`49.037329230343296 w^2+0.29319173412101295151055265975648698549695458398261085190754920285463835752331`49.67094236880581 w^3)+393.4993192889423140032807644509715892797573587141686341004369`50.04189787880476 THRSub[2,1])/(1+9.8735863980390445155398137670368670470520496918805187699727337278144375758502`50. z),((86.4654986881965912376475731092047379158269624005083092937726`49.69897000433602- 1.6236217105063453870630119318805355929585447857898589363175`48.031222811877356 w+70.560061414429912036607779649430493581426840371821975795586`49.68577383789962 w^2-48.953932948471415653360279084889896162729007295107924418233`49.491508717340224 w^3+31.00680219638388700874185097810453792378918869245250928763398879951351591796972`49.52644537172402 w^4)/(1+0.86436518843257114046748521900023080112098965749244484953644774838033051727219`49.52287874528033 w-0.18318608410477468827259837043065875814668457001507731378400070675190716422563`48.851895435340666 w^2+0.43177865327491548292457546676774576738285854727727841141389962313182028283345`49.69897000433602 w^3)+206.8842219926481716221285213748500042984300244706815302838818`50.083504859480236 THRSub[2,1])/(1+4.7168420679688945872362417587407847321357959709876696899628743277219670588677`50. z),((133.3749050958468435958950519570861194298553049869097759527288`49.69897000433602- 5.8554826475911058598256140632902484624378025905036772561565`48.39549685732284 w+111.1330529892296948069886286156604964553050083739339536980556`49.69891434126417 w^2-95.1540437926300479152130588914016118350683224451015958977024`49.528637871411696 w^3+50.19244217951038818154699174713051768981435218842961043125`49.507471468478215 w^4)/(1+0.86105085466630329412343808477563041971981319974038546099940055931783891614339`49.52287874528033 w-0.26395512840724010196768560292787258262749155635980333867899696689387745155879`48.997330087553344 w^2+0.32455538524952320082908937946133063344940374514113743104531971157664426688669`49.69411938731719 w^3)+321.2170268664535909250642681920434401812150414949490579705344`50.05191030517696 THRSub[2,1])/(1+7.87620619132227910027785410908312833188881350105856970779555913467965206830688`50. z),((67.3980136410674476538012561688803079660829568555748630464144`49.69897000433602- 0.8367928443920931974071338917594909978944065824132111799619`47.8587499650161 w+54.72166582677477684601153213638620146777360794229469117006044503581273043595158`49.68179310045138 w^2-30.15825135194008969057451191553671870243042023077685515156046854946399248902244`49.45331072024383 w^3+23.55703611777975805635232189998756587198340477105847948413760313679482794035287`49.55273297323554 w^4)/(1+0.85318335036900218851461231828440581743502635246832740927724379146073068072537`49.52287874528033 w-0.12061267614252171722622455198949085181104735133905800644645021749712572282815`48.68780512776386 w^2+0.5373291609278573229240992522695633352536372144783197889519167813822065505074`49.69897000433602 w^3)+160.4108339394562268148879950012104681975115190483402576615477`50.11103418489229 THRSub[2,1])/(1+3.43264060830914350883417551248279236024339204986273683827299683662176126157916`50. z),((85.7733388044947132758729809371140407394764389390362647077109`49.69897000433602- 1.5780503431675222473916336770347693400387500247550731557812`48.02250372636967 w+69.973884595798276618744345763111592643035728435484295638403`49.6855660369 w^2-48.2727519981868884982356028746938629390430498026719425867361`49.49055084260409 w^3+30.73070460114254467950204344298108175461722211186345997984966661530141524064207`49.52704709327416 w^4)/(1+0.86424454202678976835072717984621958710613251732552221003717499642135275170115`49.52287874528033 w-0.18136263706333932168446286514288359480645423932460199639921197051887237482588`48.847948909944016 w^2+0.43452024898535799288487898072670480312470700471223543722120984613972683682104`49.69897000433602 w^3)+205.1972132030452270436773964397800975670357173601493126478909`50.08426249028326 THRSub[2,1])/(1+4.67022486959318606597481551211715961743147856490740243281703072937551247495158`50. z),((51.90747885600013328234310799322072230175147316902983652565314539219180589114856`49.69897000433602- 1.83844100575172098701169661188421283998562387567134763051224310669349556389847`48.33218424434714 w+42.81142331906363252216077106262567306818945456650887464707960524298019890701402`49.6910371877804 w^2-14.64495064309879209092877681120227251734920019795312656850771416473773918680469`49.37112974152554 w^3+17.92991228318876746450283154075993107199203014330035191036914813006993026262086`49.60837849081024 w^4)/(1+0.80643976898812542765828792939242608106064421730071298320717328297794994643899`49.52287874528033 w-0.04348539797040062435663303658244881890624216185553821140459533470215851064689`48.28491365595356 w^2+0.72065500771269330866320452182645734523529899103212493775686208132443346210573`49.69897000433602 w^3)+122.65558554468738049961114587704771667871538714108842983432782654659709691464097`50.151836757648525 THRSub[2,1])/(1+2.3893479384722927903573656436675819066866984423709104473580959435963213816592`50. z),((163.1218471334023445919757617180835085344389264934698594570384`49.69897000433602- 9.0428471758274301600044127696262528039021699687889218154641`48.496032604386635 w+137.2683644141832786346010695044086872491595215380827517519873`49.69897000433602 w^2-124.5103960305920178826744018398855648202641905458321843406492`49.53964058496156 w^3+62.6034807120205466851678548355389150677604011187518935078977`49.50393011866748 w^4)/(1+0.85684836960413679137648116367686589367753486811629558149082856442519890444252`49.52287874528033 w-0.29146226582778624221869251515972176043450596113576465329746028179151287314736`49.037424687747624 w^2+0.29311605997875418858265417759801109919947112776290123126023138472790918047815`49.67088261846579 w^3)+393.7195712392506454097715783940742557855518386652976375173088`50.04187327343834 THRSub[2,1])/(1+9.87967263121307365184315690063589040295694543733736419180812654193678616460472`50. z),((122.9459690446828436270383479458385925746768187307131881651624`49.69897000433602- 4.7952780830367234051583295403701859094038843321204912322253`48.3445804505078 w+102.0193412098276916381193628410054109901432710513489597212892`49.69640037103332 w^2-84.8725980588363445039233704438957043858443943451581481058098`49.52331390489984 w^3+45.8721808484646763117186064693558972510774537269248626850047`49.5095699582351 w^4)/(1+0.86254000974695809948192053948445705405226820546825137129832009231193041326257`49.52287874528033 w-0.25120212627891004005244699058181112135960953300006891337466523851310812251274`48.97742120343262 w^2+0.33989332732215600286820478256609507040112495413402596464020328041382790682199`49.69897000433602 w^3)+295.798467948499130749656292611573022590418646476180979211439`50.05667463949094 THRSub[2,1])/(1+7.17381387967237555470352509723912915622130458746215003849664271450759443068494`50. z),((164.5737443656054464130738634695275746021956911009781466934177`49.69897000433602- 9.2027232144779074120757856702122610662689242280892916137521`48.499771396598106 w+138.5477961913514950892105027207819734519872977458529070450875`49.69897000433602 w^2-125.9442004451267532804725671378728904333235824704074669119909`49.54006462182083 w^3+63.2117075362593267526102805789638551420376860191079900828169`49.503816093670444 w^4)/(1+0.85665597208238393900171649456255456059202472902153990847285912277249606429735`49.52287874528033 w-0.29255230723027993007523962395361070507531786653996995593955004816020116898383`49.038941361798884 w^2+0.2919132080005416729599669345764016168202348517676337149861133648394037616524`49.669930189566095 w^3)+397.2582961061511837251628544941197794289778231774580853706758`50.04148187430003 THRSub[2,1])/(1+9.97745839269460185099139379797538820075763662348608758451796115831195254046422`50. z),((50.98966781297724920225774216302874162616640984297749232227938929485749307549751`49.69897000433602- 2.007588941627776871938836762812199403948934852417710903446`48.38018363983844 w+42.16297288642672102380040159655300788730729274851959485437091018762656966437515`49.69272416490944 w^2-13.70277223472782859772152058897117951618983018835219207484202505236008282301116`49.361578080954764 w^3+17.61870141822679250128753857472751556254820022696967098810371462665349944682012`49.61389445428148 w^4)/(1+0.80062560088740172232488155611798716555681810864354803173532705320469570792983`49.52287874528033 w-0.03803783649050587022495644963662661880295262683612719927055443942769470776699`48.23114544696376 w^2+0.7376329653357599931752060452505114676161208812735567967101854011812889123247`49.69897000433602 w^3)+120.41859473774667079716604387295761058790998556736201319327993668223321050218642`50.15522652067509 THRSub[2,1])/(1+2.32753305946603978828953196940576059178448935472380992257786072899974012356758`50. z),((138.0960135300190820131192973723218197211907318711227408892731`49.69897000433602- 6.347417614867937850631371187053989847848716017893787608329`48.415255199070664 w+115.2688591975969391477547310627907708789622045618757077257059`49.69897000433602 w^2-99.8103469511504904931851180165543051338401085549410647489773`49.530744472510946 w^3+52.1544697528464946684915361113702589849480412605135607703186`49.506708630611556 w^4)/(1+0.86036387478542549396837569724578776703204043565841901552018489603388646283046`49.52287874528033 w-0.26910344284111270389347653776522922850888251333163715290709002204176831721425`49.00511667122461 w^2+0.31850574358849966335597741900030472545748531435338713955477516622255281556144`49.68987993477366 w^3)+332.7238356438134677515885302058081058146949351874711801718759`50.050007534353156 THRSub[2,1])/(1+8.19417441457722753026274646936646402224205871526686466059158042944427018181767`50. z),((94.8913197385542659569180324459828451149883965919202786377983`49.69897000433602- 2.2399398127408879237014511585963175716742339458624215001773`48.1290562626793 w+77.7393100304027944477282355987713047285073257116204943372284`49.68837035654973 w^2-57.245489367309465104406008343567147376225650437499602381405`49.50167493521518 w^3+34.3912413792724868240557156269770662203852722663200463143874`49.52034877121415 w^4)/(1+0.86504390349041342741497495580229154887465626776654355415876827727699484229162`49.52287874528033 w-0.20335971772417387600745416711587977024686112284083581644665410913936478712662`48.893203288781265 w^2+0.40252092530394098616094173787506934433110265529454683666722951550985048635192`49.69897000433602 w^3)+227.4205669994576806769109032941537791893473650047130764422404`50.07526913103456 THRSub[2,1])/(1+5.28432391808999075042435750675549649748951784141809355180465215299502516586663`50. z),((149.3769595733868846871527580419640607650588286808861127999263`49.69897000433602- 7.5465678628098135410213266695908129871314820002423397080344`48.45598371199602 w+125.1716465925264470912572542699331567514697561265873983388448`49.69897000433602 w^2-110.9409722556633487003731470379787400254415200901908332405571`49.53516923263685 w^3+56.8555934221582727518403220165260066025426909911141520328674`49.50523555433495 w^4)/(1+0.85873963659045723180125070589826964521304321741920770325032172127191024250108`49.52287874528033 w-0.280101259257076753895415981136017299359823248697416524708507602056921887153`49.02130253583219 w^2+0.30584262342029996707017560978186747529433077195311208529270675609541990674261`49.68065976093908 w^3)+360.2190077540696586148954812755806232294849488987370264708875`50.045980790569 THRSub[2,1])/(1+8.95394988257566878574781602111897637636066944829691200150942474428946322116469`50. z),((65.9360727667020076659437723628645255622541101140470328402479`49.69897000433602+ 2.5271356854986564491320218651140960075404066034615125532575`48.31806230231232 w+38.4758740563481881994939960751319912896293870436909169496033`49.46041629726697 w^2-52.0367804629433427449745043996288281078099241432409059943067`49.459238042497375 w^3)/(1+0.90216217140815329379024848236582198057297100152858375373648212804866751096136`49.52287874528033 w-0.29898855279126028442221281343619593037451259583897873548621176932956392169616`48.95773592520702 w^2-0.04874883013452506338423023001975223811769779609736741153291344637232950730987`48.48635497341575 w^3-0.43136896244619215667362179114480673697448862684097728828983719948161214384837`49.52395675202408 w^4)+156.8476295946106923639469645167806932361461214045017840427271`50.11391794964633 THRSub[2,1])/(1+3.33417840418752435222404010093572054091678180646155658428005678965536815211571`50. z),((78.1827697533013017968309492687036487060784475214212179202173`49.69897000433602- 1.084053939357016004976495935124672622452527638327063162841`47.9015701229358 w+42.8702018512788983101435170734494633897909029332932317609873`49.45315342514269 w^2-71.7562545195746203161398759806312025001054196103965664324679`49.50140290621455 w^3)/(1+0.86270760986541530991075754320837930143199627443272299042371478422406304591143`49.52287874528033 w-0.42375159660376300866293395820229904491800641822480363542702765321529119863302`49.106057643095504 w^2-0.16006854217200091244620748682545523858966489998487096730143346558028626246986`48.97605868516245 w^3-0.44709782324764061407517450377087196945089122784456259572139772821746049983138`49.534502351326324 w^4)+186.6966369503960659120020607167048723414855707079144901307591`50.09357665771766 THRSub[2,1])/(1+4.15899751941580275405485606216601625154574909858793254999937161345754646783864`50. z),((59.20246284080521616964269428679394807056468214384892965559173992550060404184851`49.69897000433602+ 3.94625644744673056146043431052013192520837127724281716453847424601822951507496`48.54300715334082 w+36.0128178705706901484438995770334268870216850767167329869982`49.468425237811665 w^2-41.7425390300862417980225793474449842832133447772158669991479`49.431229323271744 w^3)/(1+0.92124283717790814475510954952567888351915401714627051160726122311886473203221`49.52287874528033 w-0.21799602816468694538841246428988173339304604394802339656244826757821436980357`48.826173447614316 w^2+0.03135265733778544377481035269865062291213179484201572932999685137961082850638`48.303396355785345 w^3-0.42556036088363522021325025794609570820181095540158439196088918576946154024639`49.524124196254654 w^4)+140.4357291100135977669344980219143175740616641197538701949497`50.129413299195924 THRSub[2,1])/(1+2.88066753611853312894212159414937067104967232842443403468436127408438686009714`50. z),((59.35159685816066803801095530975869132931740326804137666801771996715941872460021`49.69897000433602+ 3.91991868505973205379581417064550034298833957215910913044091489358622325383349`48.539319990714304 w+36.0666543951040809022664544072873186740076231232411400250595`49.468195293739946 w^2-41.9665744544477840504427459627136457680602709687486193328801`49.43190454804249 w^3)/(1+0.92085916402885938233298236106735974769789520590688720431054815701842170072355`49.52287874528033 w-0.21992328947525607176646135310009689415626085114599880679625116080491937695124`48.829823464628056 w^2+0.02936182471570216907351957844434240592376132425142514762043092109109988787725`48.27530714425305 w^3-0.4256546587810151567703182933373834251895468549360103884720392506544401001376`49.52404878902589 w^4)+140.7992150675670241957377233068717282113440649253984659885573`50.12902426834163 THRSub[2,1])/(1+2.89071176178853723205007265528585421092686502054713630293137553706050840994886`50. z),((52.46361307800853793962101138354472914333239722434403521430948380268190544306185`49.69897000433602+ 4.8361419601968313096107050615351108110247404749675566426788`48.671842803843134 w+33.6732066341119796815783773073040512492717232535531755189128`49.48272260255301 w^2-31.79753065074727173872013994861983136268325622558128732929044819168827764023003`49.39708477949454 w^3)/(1+0.93513329530196608931694400639789644037766482955073008724591720314140769524997`49.52287874528033 w-0.12275855047152461766809319650272209928308099396412382441053502059271328885682`48.588059281637946 w^2+0.13588711254525067621905405652838782407614712475425916841938463675574693084523`48.922882669640806 w^3-0.42380190807855814244639048724504316751806951274845928078228444541404973779304`49.53262343575865 w^4)+124.01105751412510952730735543164580961358311661709139192220615916023986267189776`50.149854575426794 THRSub[2,1])/(1+2.42680376329159498872724660925758569341179948046442603614804832014713623089944`50. z),((72.6712453124811456396758873002149065092165548354192490184336`49.69897000433602+ 0.6949620375370982364356485665188803379164891432743908196736`47.732273746259615 w+40.930465684010279511162371924482055311856029055452360237263`49.455675966648094 w^2-62.7138835413447675709995270704846622006585946051143362789619`49.483445310830234 w^3)/(1+0.88093495693268635325282458442380405518192999959374306728971952144547882891466`49.52287874528033 w-0.37031948577309895124605257848506623357713571022643138663810847392426303310904`49.04811986971834 w^2-0.11398756238490155984615449163884091708986552556813654149735379247598723552175`48.83818571646183 w^3-0.43941664462889496794242324483629811760418409092227496347122729761677529796744`49.52850818163996 w^4)+173.2633386695904423234063435984349801931606357416545341319585`50.10174909203582 THRSub[2,1])/(1+3.7877945152253099751777274428914141579100950180174022233509420511754112385988`50. z),((63.40501017003948237041745685065074739567148204094757268935814986406693695532598`49.69897000433602+ 3.1129597267498877238290414204959007243654197666737835948695`48.41956447226106 w+37.5454329303158250863553833879262068726685979835196847836746`49.462927746543684 w^2-48.1239620556196341476550330061059166566915394046097066101283`49.44925111140031 w^3)/(1+0.90968533032647525301309073986063850375141375848235009227259818120713422811259`49.52287874528033 w-0.26988393276085517003339240892371140613938423556974378580187348898364118325839`48.91492234892406 w^2-0.02076603913139860520842686788536516838828907931213551087345069783849563227468`48.12431452939974 w^3-0.42885618938627163229206753460072632779085956850410208991434745715734492918049`49.52332807990365 w^4)+150.6786432835750133824467755580606480241312354683449013826971`50.1192837899138 THRSub[2,1])/(1+3.16371049648547511530250610163750876306767464965358540879708814463651135874847`50. z),((48.30911745829258629848931972995061148443761751125556107614912090948995549393955`49.69897000433602+ 5.0047418847719218044630753521992160761522203429088419925486`48.71888019127311 w+32.3984313429160778111479431960521784577079562107697020505387`49.497301501378196 w^2-25.82699970777261823476035227739449512366616328980118241908072029107825639116529`49.37106527491008 w^3)/(1+0.93776145180470390363515895087178774383382159748582421697930044413006548696599`49.52287874528033 w-0.05411210459355828171088483264500910629400960561021147921801146567598115678809`48.24446873125199 w^2+0.22028586912512179981893136121900935641577083888026568234859863305483253787575`49.12289348288879 w^3-0.42637909467604661214995905307081472273113944565101196400096855247089128314095`49.54510224946929 w^4)+113.885260293195059183107323670848533578921922768497878899340898185097187601961`50.166064884781306 THRSub[2,1])/(1+2.14699710154243305724304453835310382226118100200527703801933175025647417666735`50. z),((62.7663767045256345648330920250158971472060664066428105118859686027010023504407`49.69897000433602+ 3.2512122644294219149022250490394035282157370056631097238846`48.4413510899303 w+37.3110572103206561485126216473202183496546627099779341552695`49.46364568290882 w^2-47.1450206372482567507930445376311037175501592064586513740429`49.446636534885464 w^3)/(1+0.9115270852781082274371433729490952176473945750419063210344158877243929028073`49.52287874528033 w-0.26230236890447300207235773316953579252424083859621073330700539898656004916563`48.90304558301251 w^2-0.01333502114170687885231874842317769680409520843092048485853218818235354411562`47.93435738377766 w^3-0.42827842487616830102556469941168997623768174707417021720510764359337069521387`49.52328813373517 w^4)+149.1220950134061349188442915442018344600809339239373629599946`50.120719033440366 THRSub[2,1])/(1+3.12069832017730853637872543294868708613388972749839818465970469803596216781804`50. z),((69.100442436727842269905484503774984993463855752017160736235`49.69897000433602+ 1.7141268205479887604723617209992195410672693953664882388164`48.136994640952445 w+39.6361534346722514359747883463102443463112355944219958704408`49.457895605941495 w^2-57.0042391620160637812412257841370297810365015850194895021582`49.470988525729666 w^3)/(1+0.89236537457586812548144504323100889799253678947938752404893498523744038625303`49.52287874528033 w-0.33349157707261992203209667539577782319453878010397110797999109690527178532729`49.00367705546405 w^2-0.08086894578497265731588568615871619784363991753644322336695730648941485280859`48.6972619674684 w^3-0.43493540165891611567688565534798844882886069531205057042231463046249976188254`49.525642301882016 w^4)+164.5601821024729282000032552864873612653521907947314464184913`50.10785569467703 THRSub[2,1])/(1+3.54729975391487407749086273126865891169947808972845518892147018722844576874453`50. z),((56.85123064594000016080355430921252905530162540956663197783114573847018183228645`49.69897000433602+ 4.3267131124303896559848206927483585108498020239938295783644`48.59586138664496 w+35.1727996389561548156851261060899293549580570939841563521245`49.47247029419769 w^2-38.2334632991036184202869213569745002465617229224610725968136`49.42017746639404 w^3)/(1+0.9269460228249546939604240092315958572482817009087106123438061733656214029233`49.52287874528033 w-0.18666615677238605973609254043155385075608970992095699621538358488684360142947`48.76188647180705 w^2+0.06436204382082110280196439504313952276739329040725866918785272862223645721353`48.609499383972164 w^3-0.4243438498658167492328575079474397932488494343686644255784665870768251155061`49.5258688792906 w^4)+134.7050453871709056964592272854640425356456860991538386771841`50.13587490631803 THRSub[2,1])/(1+2.72231126578808759397873162337545580943411723240705364762171684355495858519755`50. z),((61.02820772446196618928092846848339108291427872106062492747252987214982358444782`49.69897000433602+ 3.6069036878713397518667712619240518371741615661368179727875887840073131250604`48.494706331291084 w+36.6752724005297366068666183607503549573128400352795538998529`49.46580020071076 w^2-44.4974168949882319626841873862645258194853189759857449794792`49.43930484492099 w^3)/(1+0.91639762089037725484658188397776403606196496443917730868495824155749054842388`49.52287874528033 w-0.24113571475473302132193195663242756685126940073422554045112551319544868192236`48.86804348643054 w^2+0.00773781071265919122924924582116375571540590002149311820223043017260468092855`47.700705168298626 w^3-0.42683779701757551141109438221510270517535622647774768979389618010072927922541`49.52345612383398 w^4)+144.8856369114142324000881892111684826510799585823610334441892`50.124807427029815 THRSub[2,1])/(1+3.00363206126503818846875432867002883402111134401819417837270808226469818010063`50. z),((43.21866265340563186343303117589427224998861062575551353861340425872009968657989`49.69897000433602+ 4.5657671171694252079036957264904444174565711314489576794825`48.731783508563026 w+31.21319377131135353473637285688726316334415014793894618389528163708027491525408`49.526432923173296 w^2-18.6304988156146245140683110155934164539036688009237016494586`49.32966125656338 w^3)/(1+0.92673352235141716969198958900587476474467304601761836828168369958044879803857`49.52287874528033 w+0.044358724199579938714297973858743153353143115107450860957935130451402673702`48.170873142324936 w^2+0.35978528850670761037096861176755488831906379033734185386059339059724677842808`49.3253589311218 w^3-0.43661993100896203374106346874787508028929972957172792872124417898414888131001`49.57376233462715 w^4)+101.4782396016872561872655828914656797207587329640067569839762787695574119507632`50.191528317251596 THRSub[2,1])/(1+1.80415327737737487328553951655828940042883380877456252722631318461678207866606`50. z),((48.75335002329983279658345196904667977102834566848825697586064841506237373387238`49.69897000433602+ 5.0049491538883059163291275166123921329469208063334714442855`48.71509762967265 w+32.5249617454586126499748416034734993182372737915846056356233`49.49543738277434 w^2-26.46032656231877155847060094175693583288643351267341980096266448279086463775463`49.37410096106045 w^3)/(1+0.93783307391002596863636780692225996317820176787138496884452746579090308989472`49.52287874528033 w-0.06189680055839586867670847284730398588697531470739886940677218403535273991146`48.30125846627561 w^2+0.21025775031638956018018830639141788424093158980904980930645677874864071470478`49.10366298199614 w^3-0.4259107214561787456291709075605832645982963994078824653663401150889548660055`49.54339613712432 w^4)+114.96799314067957596992895462187531790744440656486263857870782249772546747209345`50.16416404091161 THRSub[2,1])/(1+2.17691631254486124433752184824787782271615520993421186540523366824825920311543`50. z),((59.02253357237989370521357321895280921992889465024925543524264946003043543187589`49.69897000433602+ 3.97769529058364925047911352337560699595220424227017766059214212676097484343097`48.54739887994454 w+35.9479401235516264534425364780081014739653763360528208092193`49.46870658773683 w^2-41.4724755350421871760215910769327185278373517429671557779324`49.430410796421086 w^3)/(1+0.92170259899480391244032430284825353812066852637372623842545849020650207243828`49.52287874528033 w-0.21566167293256626989699065698658297573041641034371866039091819195861635338088`48.82170961551181 w^2+0.03376999973399009630761717381966643063602891853081493940850809867015910403326`48.335168767522646 w^3-0.42544912371192158752931676714762795133782702907161649649898602303423777274119`49.52422040794646 w^4)+139.9971855531161482412614958192073561310845915599945609440987`50.12988581989925 THRSub[2,1])/(1+2.86854924004665026894869686591062434602070992239761325446972783152309789166943`50. z),((70.4077139147407471334695487614857420790038737421948297883884`49.69897000433602+ 1.3532937646171557107228051629298985626757699868627757097991`48.02954722961234 w+40.112451297667482435210147525360856654800157034935800288661`49.4570161886381 w^2-59.0814996245465570737572323813363413840554205503743963005669`49.47563825644392 w^3)/(1+0.88822062405514176510329980584789605633999295890600148345725045253807736575422`49.52287874528033 w-0.34721108660564285495227310762647769664493305590540501805524712296080158560063`49.020731732345126 w^2-0.09334244141747442734314990309567877769165309039247540507625861301763300370092`48.75636544239444 w^3-0.43652498122101196299354390878355437483136209114604635141859557454318735022237`49.526584448327526 w^4)+167.7464090505155967382514112293667515614731247621038174496135`50.10553643300964 THRSub[2,1])/(1+3.63534492275000043055241140494485458015464005525315238061040378458303107255828`50. z),((49.27972638990309426695623113285256765482758668385426638729025363149756059978429`49.69897000433602+ 4.998955434009298778918205399681464198309621534038329562752`48.710199975482254 w+32.6783930513310229260151495623491315627744673133216010203354`49.49333554749147 w^2-27.21222889763167100960883426041383237331677495555137046732561803825421587057265`49.377609433554134 w^3)/(1+0.93778965808152083742598299511147680917044195812875086191841898784190388826692`49.52287874528033 w-0.07097390456942281496544420591381135162071153260030905178818229834764586763652`48.35891250015566 w^2+0.19872219107132823030160006886594585215366797816236678122299135788554265722455`49.080361673548374 w^3-0.42542319611459212960960932584889888837205990293215958851458822675055435078179`49.54150348889598 w^4)+116.25093596647535335596001406188289507353248336144741049213277969470158227489009`50.161967926802404 THRSub[2,1])/(1+2.21236793590533589436540026753968235590995109871856710546028474953124149478939`50. z),((55.48943216020965728534094305966072968355454981854471272069340052368193623518186`49.69897000433602+ 4.5149591790435929239929395702497362539415291324442542765391`48.62238460251785 w+34.6959053670537393830314276358015804996806104523552303353823`49.475225557848034 w^2-36.2205784609685006536763645991358330385169291289767151326086`49.413389987964024 w^3)/(1+0.92989160752195208821413402786871492057238361789829249334375112415895992461654`49.52287874528033 w-0.16764492986128621989789215355284992923942408187996452167817956526941189650072`48.71737150905824 w^2+0.0850301743526611232731297121246432203896055342328317871660049601400770081457`48.72690174418854 w^3-0.42390360169177990464426797300737142243171657058276044083368083534156350625198`49.5274187603822 w^4)+131.3859191719848010923361652159452283975957377851491973592306`50.139923874705154 THRSub[2,1])/(1+2.63059368484782337038188724043723872314405643179223525090362323632347254885299`50. z),((48.56917271845129457842746697918655845204930821008501778711119841975044230688108`49.69897000433602+ 5.0054624455763114388416490367230910679859870354090611603774`48.71670570332182 w+32.4721628389320819367121060392387591584292481445579411540006`49.4961999134101 w^2-26.19761684850768708722319450014429234413584218422395190855419552383574691002917`49.372850926477376 w^3)/(1+0.93781587617585719920391877615685724366279913598462342889595992841369425293536`49.52287874528033 w-0.05868328891236081033621118036343030524402156892518993330408439139021977139992`48.27875171430444 w^2+0.21438199342894139234483030564001862140078784900150451557000048998525686380193`49.11168158085155 w^3-0.42609839909865500913577528582166649196602105367177827113653463575295032836373`49.54409107179232 w^4)+114.51909579854656788901802325909169211286990182749341018502248621704332721066258`50.164946754726856 THRSub[2,1])/(1+2.16451190980700237875772574166916122612194620151073066274675922243491424820981`50. z),((51.82676520075558232929257912203288465098605132021047269197143414925108184399234`49.69897000433602+ 4.8845242119077961664524931103483393375802001916278205880817`48.680654938963656 w+33.4663331976734750116506267784564155700736513437478058524385`49.48459036787116 w^2-30.87496526782803779218136093444640719374485314882938827495691984555338286505116`49.39340304494246 w^3)/(1+0.93594368383455766962870508881015065753706116601382390522919056924102649902298`49.52287874528033 w-0.11280217491113379510775376900506668171016890503068795274462386415163333806503`48.55285372574404 w^2+0.14759913760327238434328407932228587931800535908328624919995847627485884284418`48.957231486420305 w^3-0.42396469204752138882983440250373763435191774360609393582079920573567425509217`49.53408439638699 w^4)+122.45886127758555131809209582281640732944862006473113064885980038952642676962511`50.15212884898208 THRSub[2,1])/(1+2.3839118469466758608697607335515496037110893766106197368035725927262955421036`50. z),((135.7890978171061759324229333843737797247901727130315450235097`49.69897000433602+ 82.2551180356839993131922229307827964473591267273446062883332`49.22255829197815 w+141.4083295175581228630362501034148910199005518449733468631189`49.38717453989159 w^2)/(1+1.51142445775371464873176601071460584494942925007328783660918711995892030296656`49.52287874528033 w+0.53009713003064064782406079741060514001215999510909288593781443076134627214476`48.91167680105443 w^2+0.53780502978247955320407044931922888090073020531776928685329232919990407536005`49.69897000433602 w^3+0.20772018098915847732146443087022129570577216030582384973404069309049029881992`48.85294394006325 w^4-0.29356374653537130271357106752265915343783716284158443484591280005381084880627`48.80600546439551 w^5)+327.1011649629546248612387369565872039485492880584613035247025`50.05091953592188 THRSub[2,1])/(1+8.03880287404567648325354013647528505352661085622686649786728101296064250669755`50. z),((152.6624137599021090191709525842954601979379314602739409982742`49.69897000433602+ 93.1410596663909404440928066885288599981429505241783422474182`49.22306875009313 w+161.5050142865205718540969455838920957845385159815151268311272`49.393748798429684 w^2)/(1+1.52014370752014638582807390201112077848618650624017407314552142959151031725992`49.52287874528033 w+0.53839458061888469681154380508215992188699518367040581500558582976250677588088`48.91685584218864 w^2+0.5385352193129417289340873491834481629150886463443782788186138752429806990923`49.69897000433602 w^3+0.21701915054181626337697488120005597286999786309335781392421916080278187046775`48.86399376980054 w^4-0.29754469771867326185905673723396948917734278851217510409499242997635149489786`48.79878462257063 w^5)+368.2266808668850776456892142956344711940959433317461357455948`50.044927292171586 THRSub[2,1])/(1+9.1752263147605910453599061746074824911582365146470427457334081689054050778134`50. z),((107.826553472505257225567030532710075527243309898104471297595`49.69897000433602+ 64.0754198583944046822548192617713256185046694211746026788666`49.22086082285635 w+108.2143080024112049471296170602100306848528451818002998176035`49.37199174864192 w^2)/(1+1.48967314355103134213793675967139279462005841205894571711756398581220681504924`49.52287874528033 w+0.51079250598489011778276234099818236527842246490960366409301907050026670194221`48.89959255473185 w^2+0.5373261712744266679567646476358325931242861098051463299692085113767077628849`49.69897000433602 w^3+0.18449383154355754322361943171446723133693272810979327285380701935309441039684`48.82107344747503 w^4-0.28354155446304465538766615471036517390463012059532072920019115010734245096411`48.82257196763705 w^5)+258.9477524353342097448839825620041170580873087273709874762128`50.06537649055576 THRSub[2,1])/(1+6.155516212255758732209752887873766173259457955997530195558457204974184155682`50. z),((58.41179851709228819104043767685937899774976259086774590430982118697687853497492`49.69897000433602+ 30.3040791794521705814312806501464380183113415845676833302374`49.2013672284747 w+51.0329950597372382517460757101407195577205726848835614998955`49.31986097946581 w^2)/(1+1.37216057537602344504579759835373947161007264922452613716234173949071148920001`49.52287874528033 w+0.43744378808252648077753551577260089217559423967704774865892624654211834159428`48.85639931292585 w^2+0.56545112025515135821548290279240926720250380693999436623399766998660893852381`49.69897000433602 w^3+0.06098794853327447571641125649631503628985132101601821710013366090056020842083`48.44033904060045 w^4-0.23014568005011189276636201776297514431233666185178186840513160601674139172328`48.88125384376077 w^5)+138.5086343806928115470529664857153165922337185355071292383134`50.13151595551728 THRSub[2,1])/(1+2.82741603094607151619257936681730296464888922105902019236044652735168400970743`50. z),((98.4630261528270255302945311795800759229455419692895169351752`49.69897000433602+ 57.9202133896778741917979727626703975412985534737001878491418`49.21980259750282 w+97.1552264188682132876839270559513467434559215149765744259196`49.365145937369746 w^2)/(1+1.47894223298326519637979336736969282566089747784730480148430452912258729648026`49.52287874528033 w+0.50198817927450527241453037893868390362493961258472927993441975971803747781004`48.8940862067021 w^2+0.53778878280479521061534767346052795686798785160278350550668700193360972999917`49.69897000433602 w^3+0.17303660257975617421782779071336549750633653628592654446646864656441021423042`48.80277827872471 w^4-0.2785703534314997219559616270920258014630753777275161857389878302899698973234`48.83001364033984 w^5)+236.1259257708056901525259512122628854027612105312857285542087`50.07224968492337 THRSub[2,1])/(1+5.52487953302022372612571260438967806243785108052588784887560918731278307762115`50. z),((109.4009574564438611075410717791498894570219404098129687594725`49.69897000433602+ 65.10599792553545750415349230939591841351573567180821393733`49.22100471911751 w+110.0775266672695391232541762559128223919956328454590487769706`49.373038396633895 w^2)/(1+1.49125710468147803430641594896325391429565885559714972850416899819292662793328`49.52287874528033 w+0.51213191416463775181080235344872936797089757268131729700546457045032549661981`48.900431202350575 w^2+0.5372967347873488164684359492411161222023341741678018250930385889733161421786`49.69897000433602 w^3+0.18618553748637719050070696649448607652319519751488165497347411683086578803617`48.8236206017515 w^4-0.28427439744318526697881336276074941862958817517233969997665327785887967326688`48.82143340289253 w^5)+262.7850643365745092722569564147426660338944343765457905184524`50.0643474520321 THRSub[2,1])/(1+6.26155284421171237503671852614562725555885019944143031168885344347561950636223`50. z),((152.7261368275421493306481389305346433062357857882670041601761`49.69897000433602+ 93.1820931117091952366238320011327448337416354096294036769255`49.22307027166663 w+161.5809694996949112612530037134418463179385783677996309405839`49.39377094760987 w^2)/(1+1.52017247413816455323674290332357433101052466475779324026299287934079760425213`49.52287874528033 w+0.53842249074461833248320048313900465717940447377608645920364476498659636528035`48.91687323638576 w^2+0.53853814034855650589600250852047248404303813421370707028089498800728267856531`49.69897000433602 w^3+0.2170498101524110058827083685195258055376918595922494950345777644391685937319`48.86402873120285 w^4-0.29755778517053208037755605758288222836159402033098670582652714371408165604919`48.7987602342661 w^5)+368.3819937905903081229150486308462265853818070049819112906353`50.044907336481565 THRSub[2,1])/(1+9.17951808456007269604974993351438977921709976345591676281160549071244004501655`50. z),((104.5239627170986147997637078053804089065635356326772248439894`49.69897000433602+ 61.9098240824017062723681946050978980953657010070135227616111`49.220530295631065 w+104.3090677736731794908604336551452401191906339531377247552789`49.369703089902835 w^2)/(1+1.48615934752694059116621621112554867813170691113740170071258062362746469789174`49.52287874528033 w+0.50785794930018741367336029758025788927744123696894385897750777961974377539727`48.897755776424596 w^2+0.53742724911501951649167612682832003293218507790778926244629863015569363274561`49.69897000433602 w^3+0.18074135923743560424204331489041115322536492259275898823504568610319183763858`48.81528554497306 w^4-0.28191480293501733259841752923853116439495989951091510581249761480874258869089`48.82506060816119 w^5)+250.8983121773487443976752650304153938536777403963970058702507`50.067645947814505 THRSub[2,1])/(1+5.93308562645647544244528298134906855994870819255558965468880568526169935337938`50. z),((99.7042370544304477980981281413594399169023342588784234798563`49.69897000433602+ 58.739028789146268749000674703937545051237544663678574518143`49.219966208375766 w+98.6187088901205138009618371435074983397249292716565170998702`49.36611920181438 w^2)/(1+1.48050959995604424354709085278684424543409968572260099783146562334685741665756`49.52287874528033 w+0.50324502177758037757262725628366460645702374149129129833195302904126950665452`48.89487129052752 w^2+0.53769273633581566754205664730582670640416790038509409889117460459723080674111`49.69897000433602 w^3+0.17470948263555163991264134048143632256363037039603029836721510471338151118266`48.80556758298524 w^4-0.27929693737601368789705242381955786137628135572724130059804206815159057628384`48.82895592677482 w^5)+239.1511425596738712753578276770528199271043202187124435173208`50.07125645720352 THRSub[2,1])/(1+5.60847550006280454959474643524122613631021818872163744212539790628634220639334`50. z),((58.86199956889902531453140429385128737688348538743533460926788869154347504987339`49.69897000433602+ 30.6434464542940322796518409463790137670641425866554960381287`49.20196568364385 w+51.5239421889814609564981821470002882758525075467839219654014`49.32046845829153 w^2)/(1+1.3746601338617953219152963398498950746429181245864407209528359271299946477809`49.52287874528033 w+0.43853670914930396677441227365234166756226199526727049426310460869456607934499`48.856933212240904 w^2+0.56437516997839305305879400908646835624190331639803076680024738509393510463413`49.69897000433602 w^3+0.0635420011769784083995220790127609421498583287584861555758260139851589883612`48.456124742485706 w^4-0.23123249444580649299581159914599771653356023963467381295492189655249741006511`48.880470316915506 w^5)+139.6059142857697423880015902386868676909875548096993033048664`50.13031034990318 THRSub[2,1])/(1+2.85773722151952969829022484573333227067147642714711682632153267544818539886179`50. z),((48.43119125670598456922411986505405842442306447135051306030047364633800160120662`49.69897000433602+ 22.2300906977259694387437737926259003924251565589001087375876`49.17810092359549 w+40.6728090903823095079603523452326051241584621998001974748047`49.31025657262631 w^2)/(1+1.29344651653651089615572399348704192623889295938367431297789213070804075733932`49.52287874528033 w+0.41064697907075256586482778894655225558494366841673738140658935253246489917005`48.847039533997034 w^2+0.60748176971955760554182571029521840018047349525712790008144205593687083934285`49.69154706339037 w^3-0.01703688487529348547526919474582923554362514457405822680981568426394860104121`47.94122751033754 w^4-0.19757834027008998625309364517615505736826556136565830852648584593883120192801`48.89774770136995 w^5)+114.18279208570836476126219566934720950827335310356486895291506799866220216419648`50.165538113413696 THRSub[2,1])/(1+2.15521881246661703168554909290691136284224076123565066504792434680509394340166`50. z),((103.360652351849157552144521594048818564698665824212891311541`49.69897000433602+ 61.1456986106501472055509496138808704725096585776174751232095`49.22040368242649 w+102.9345950135935417283120586737580808378555583447050371312644`49.36886547139031 w^2)/(1+1.48485546883998257729464828501834614389051586150011735805091469712256329104618`49.52287874528033 w+0.50678184388839914187853259328794173106200780766131800425291602341235555531949`48.89708252331564 w^2+0.53747727224324512117353015426312917085219211074786297194820148967428100295616`49.69897000433602 w^3+0.17934908026442546149343639256941785410058001745083495209191071826872501074571`48.813088583849314 w^4-0.28131084750528026851999895761301104641400119329691054611144503876405754745798`48.82597114803323 w^5)+248.0629632104078544152370495840411518182463738158565203575036`50.068483413366046 THRSub[2,1])/(1+5.85473628644660346041328124926659171597055870157533617776635054700121520012812`50. z),((54.70431143717389128881960803079615408182883768365433009788116481237649101694596`49.69897000433602+ 27.4457986962919375491896497447200658636603797513548627020069`49.195384049253796 w+47.0508051231136326540593569826665599942722466314859527669901`49.31514598524951 w^2)/(1+1.34885046367081996986571015362317617903634030699437788946777077531981636745095`49.52287874528033 w+0.42804118274881715969386960627355050198749749277386894789089906305266438132495`48.85216266313527 w^2+0.57631959903870322461177521506572366173847626209931359838136762189865355628886`49.69897000433602 w^3+0.03738351016833611342031022017103522315177812234822044167284042098295214521513`48.24655097428859 w^4-0.2201596878124387396930294179282696632659168857837867517246307065080470094381`48.88774072989966 w^5)+129.4723359207034575176067247205748594861650617313493057079921`50.14237081747861 THRSub[2,1])/(1+2.57771554302473824367604344553311126438037903468071203225254955630445356522713`50. z),((94.1445606955626547577041450774712497975043648721520529635863`49.69897000433602+ 55.0630985657480705337662431939100089601047282813871118769842`49.21916320135612 w+92.0706362064900362448696985890936220990644200564436052158749`49.361586102908106 w^2)/(1+1.47307918574676726441066868640105464326787021596571843701979130650950259983722`49.52287874528033 w+0.49737406498914304838772575231468569218109343728849323927077709910604307384595`48.89120816340469 w^2+0.53823377705904226884132988872868186931370802142655356971022530988179273218397`49.69897000433602 w^3+0.16678144234401798113608699709521754832005856098961133387889990479764655363844`48.79196795498372 w^4-0.27585189712982530325955403698520855618516111105441849159183214377998093923755`48.83388306163665 w^5)+225.6004830869018088482016973758414856160409631630346004655069`50.07593268767857 THRSub[2,1])/(1+5.23402944817675307819348870671438849800264985142263823816675061414377219877392`50. z),((113.6309666695740034963165060479940921581589894158319307803704`49.69897000433602+ 67.8697269561463126397681891893045137537055116592411129096628`49.22135336599884 w+115.0878253521834450808714107968069411186157489349452092662505`49.375718008371564 w^2)/(1+1.49524996860597217298953608914705222302500903462092182317869965766513030770935`49.52287874528033 w+0.51555420696474556475039029937734925277639501395211761243226869373155570483214`48.90257447411294 w^2+0.53726715051406402891560456539167852015459934451717701493791499046689551551393`49.69897000433602 w^3+0.19045019284981534284869190470985686617214283296202829756790495710867436303758`48.82987569019807 w^4-0.28612017658248137437141282497940365473595383309748129418232648922013130132592`48.818516755655196 w^5)+273.0949116575232313303164991377739522993254630056680943293771`50.06173688440016 THRSub[2,1])/(1+6.54644537159270588958007510245636485433277007429249302276954772390158009381024`50. z),((163.4056852454874398221126230622132538503763936772073911359825`49.69897000433602+ 100.0523765144226955626353374974862376101492644782770260724921`49.22329334882816 w+174.3154478381559198794675903043639230789093777330307413200772`49.397244138687114 w^2)/(1+1.52463595834905306625921143925515837515356176614654924253457579941776543658509`49.52287874528033 w+0.54279585858298163416517754142346741680681290506252326249352370698547799175675`48.91959628091138 w^2+0.53903219262638362315120974388315722009281403274942454249098656106977722535609`49.69897000433602 w^3+0.22180516022778428906764008295242116437698196353229672988984335150086019911557`48.869338615605116 w^4-0.2995843243157547075654304154355979696643412036861497686813368678228296234635`48.79493050801702 w^5)+394.4113729474786575886558541169708062040345690399798139724577`50.04179617680586 THRSub[2,1])/(1+9.89878922246492457781966945790405229646382030586516999436943382424622106242706`50. z),((57.79633300979053720087425188929309223334990890678435188846755945209392683261697`49.69897000433602+ 29.8376956662055146044898548229414673603391513651572944929904`49.20050985964227 w+50.3641639868233236141470728759476181787688021464098283855924`49.319039068704605 w^2)/(1+1.368638268177291636851381743108449529949212536791938949308965481080369392828`49.52287874528033 w+0.43593246222664030566545841090572265213512473827379510094906298518893979912856`48.85567359773319 w^2+0.56699760891648305747286033687681070868945330287737274300339653813920129607605`49.69897000433602 w^3+0.05739617852135292499369791075791147935242792284894949654769939522724913617798`48.41683417710334 w^4-0.22861930404223343592352766208861522392394103516201771963284689076800431721954`48.88232836915201 w^5)+137.0085536262833342154277623676502891816380800794860641452785`50.13320097058213 THRSub[2,1])/(1+2.785964224329018996622074060171347398199564263954706784968247415968521486467`50. z),((131.4706885391130766354218560030459258609713975672275669085995`49.69897000433602+ 79.4611414064758879755893932864140190357546859622744351772275`49.22238366561552 w+136.271056478619245381061340740506315119268724304886442861238`49.38523050389372 w^2)/(1+1.50877295982275650253070880227981257457540802952857421667317930936262923971627`49.52287874528033 w+0.52763779436807539664652669428925613688725956030778406012380330716459854740908`48.910139169274515 w^2+0.53764425956907111411402834581396929743586934415983955038239604986937067776315`49.69897000433602 w^3+0.20489042409303004137645282405424177601606371245630074463111268996267255097209`48.84939884494904 w^4-0.2923481213630335939939208991606155797004770465697839078529597070429587278395`48.808134294320396 w^5)+316.5758592053977626630851281283379059332763842448311703199627`50.05271944057744 THRSub[2,1])/(1+7.74795657289481087095551857226722837700001374967746508218393606091691381694512`50. z),((100.8721732655310068284642569901757721498112784622332032073815`49.69897000433602+ 59.5086236258918470828951221594672647013147298758379350825596`49.22011287212556 w+99.9965586436852516169693392482193004233186311685723764282145`49.36701566915344 w^2)/(1+1.4819404708793396637778808804848449964423403399513372910641709235849816004844`49.52287874528033 w+0.50440106643797589524637127185735229735726820275254362318152098478545462781544`48.89559375946828 w^2+0.53761353125153934761431942339766516748448862485587530450653970161900370009636`49.69897000433602 w^3+0.17623688786543928120381476057348754600067028442552238502605894503918214739921`48.8080780659425 w^4-0.27996014498153085075833410063451544810008261364270396953104542385604948911664`48.827981664097216 w^5)+241.9977661508654759026022739095313197731792115536046377602819`50.07034653736878 THRSub[2,1])/(1+5.6871363923292778989237290600367828803780877678277945066135936078752695294222`50. z),((71.5712455782171014174070021027795993698831491476341420914928`49.69897000433602+ 39.7913416144149447237037696307706159130578685860274043829198`49.21250192988751 w+65.7979391522628827806943264104994854635191731233398371310823`49.33769080558193 w^2)/(1+1.42620613391971508886837134839374859203459860015716855351389724506456827950154`49.52287874528033 w+0.46522162948080798990692189409399911114859834452554151938669884274529134471987`48.87158967772474 w^2+0.54649208984794696684629923207237671466406848318041444072573597041805122401733`49.69897000433602 w^3+0.11707068424694107662560952838893039759168155512288314494715691525223138551385`48.67875535463044 w^4-0.25424563047994348110932523840703759560837742759682207290743779253658044754932`48.86014368071834 w^5)+170.582297390024428907125867845335098138158882981199888882783`50.10355489362143 THRSub[2,1])/(1+3.71370916726905644246948489772046636554368216265935260691387590404486531211174`50. z)} /. {w->w[z],pi1->pi1full[z]};

(* Sample Pades for the nl^1-part of the 3-loop triangle form factor with LME to z^6 and THR to (1-z) *)
(* Mean and weighted standard deviation *)
Ftri3LoopNl161[z_] := Module[{const,ls},
const = Ftri3LoopConstNl1Pade61[z];
ls = Ftri3LoopLsNl1Pade61[z];
{Mean[const] + Mean[ls]*(Log[4*z]-I*Pi),
  Sqrt[(StandardDeviation[Re[const]]*80/Length[const])^2 + (StandardDeviation[Re[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2] + 
I*Sqrt[(StandardDeviation[Im[const]]*80/Length[const])^2 + (StandardDeviation[Im[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2]}
];
(* from 20 each of [5/2], [4/3], [3/4] and [2/5] Pades for the non-logarithmic CF part *)
Ftri3LoopConstNl1Pade61[z_] = {((-12.39189769303803524467004114764629236539548542124775456055609846221603378308972`49.69897000433602- 53.3200154231982365331227239764684977040746661960733836209689`49.60633590109211 w-51.2670181460108244798472084966284698226028929964580260697186`49.35717946414362 w^2+8.36515174703433564916961069736400974597670143954687522176830226490504908024752`49.2317028780295 w^3-6.3591613487071908845477205499883019782481760203223956432364350056955524228244`49.250119642855566 w^4+4.7934994069769870873503832935016423986385436036745112021519005450620430277753`49.34118287342525 w^5)/(1+3.17441443456544449660364705416335017855188959188907438621169024785884488719919`49.52287874528033 w+2.29451476218202417954995029959321134757968432768500044423785180956350877436897`49.39830699107404 w^2)-14.01947659668356176952115909725237025758100042602284841933278124651151137748615`50.41960433513523 THRSub[2,1]+1.77027653109635595275291787738401432281437799616633022945835853048328595499638`50.41960433513523 THRSub[2,2])/(1+0.61429862154441098551267350177305352398766527387448385415887677496446791099853`50. z),((-13.30893832993249024589866852232402041934752993564647787759872698978161536122071`49.69897000433602- 52.822174861036066665296588014687785835080198931793939418756`49.64739618203988 w-39.0281255853409725756519217090365702606203447140961914300635`49.27120099121465 w^2+6.0471632238720477049425997827821863574017278524102258911233596624437737143408`49.06548755177679 w^3-4.14741237797818362998992328767968300657954166240549826859036826357559604705296`49.070727743657855 w^4+3.79481163143743469081089787200094494328762219155997707484261343336456878775694`49.240978188275406 w^5)/(1+2.48491151709176815177590162118689804115611495237811650421430178918948097371091`49.52287874528033 w+1.55128472120958463267747887929940384016299113722224723443004320979761347219347`49.34880929142329 w^2)-16.25458968441397464917174275780215229453104526082934500266941866038465424049218`50.33187854795226 THRSub[2,1]+2.05251019483323689588380747364109805441085701780526149252361796735149398527185`50.33187854795227 THRSub[2,2])/(1+0.87166486140621986982697488535032822310875920614065240175483604504397156602393`50. z),((-10.56968397637114545643005397215208196729515058459496725052003964656820591980389`49.69897000433602- 6.04935936878200536701030975995888336030952979908333116278212599365950843256795`49.6643259809036 w+10.33277106112307073700856128642936693986248260165564756256362498659629515428853`49.69897000433602 w^2-1.89579197138324160200437283823154844591462813787889150693773580513474284995914`49.69897000433602 w^3+1.76199207616818623000842891382682817872538037154025716539124333599861238664576`49.69897000433602 w^4-0.53864921016570073386906084685479165001669779323169890640227617207729072299064`49.69394179842552 w^5)/(1+0.3336912772246311426697847398811701837802384281433461626364468669991975281266`49.52287874528033 w-0.7366718955814030487187803962786824915447433750768869513468319092111748435592`49.69897000433602 w^2)-9.5781753468755874601279450310616087428126124778674703233577696116470209348454`51.030133176208494 THRSub[2,1]+1.20946163077947258453995590178695147500466758984345000609047265741148451982097`51.03013317620851 THRSub[2,2])/(1+0.10289675600511436649080191220139749598724525433434314797709097057543930763699`50. z),((-10.58271978565466823031851302310185125753121933271381833999033040638996273960793`49.69897000433602- 5.87672197694413046252798224077253379097381137281012817159928122070787135454827`49.67496128331146 w+10.7961616061088059971387910456166102217651659919239886066851902259574191882496`49.69897000433602 w^2-1.97254706017164957480919150477088760766222657892522011410647887918484424931042`49.69897000433602 w^3+1.83297513325227480267262333994308750704478463022340289921562635639640013396144`49.69897000433602 w^4-0.57583554873753072759970063888907898308356535982677644013892385072936861320291`49.69897000433602 w^5)/(1+0.30921979188483132149718381119367685115324723184904836095520933215247372380512`49.52287874528033 w-0.76383471950016861301498967404027478946404539613724468607802971007858909266794`49.69897000433602 w^2)-9.60994766618897114585100762195689440767234059156676587953156629648868027801378`51.01639829259888 THRSub[2,1]+1.21347360589359974765962967929010553853523411037261318139116256017185430175454`51.01639829259888 THRSub[2,2])/(1+0.10655523861087707249334648495791060244327422985471982335016916964156485204507`50. z),((-13.51635015828056996550183566351193229895076382684839649077545804661944041441445`49.69897000433602- 53.6991661506548520346296551818772480554395903617159278211595`49.6544672200822 w-38.0376012978243871239003470039497526741816530011262767684199`49.25661008490653 w^2+5.83272193476626860904906977854766923251870844413977627899320948753190515592226`49.03668799610255 w^3-3.90684602772817987915624194808339458373060468175330504989040821871821238495113`49.03667591889996 w^4+3.72059158258271971673417492257118001367979958155849387812358662188997633714152`49.22370502861972 w^5)/(1+2.41515106472610715986601782010872918767858891112734831079469290312564691679794`49.52287874528033 w+1.47602169175196890069262227292829131399185920422786098223976457563047269849707`49.34148237752752 w^2)-16.76011678260323700830417023034856897711184188611212965294962575537927944705822`50.317104677167976 THRSub[2,1]+2.11634444367883193322262690677895703917285601753729170004265990748773774346577`50.317104677167976 THRSub[2,2])/(1+0.92987471625581687383332206053430522342680500277899216093468520287028307865792`50. z),((-10.62122181790196542064525389302910118357335386398613970449405841374647573703098`49.69897000433602- 5.24426248345788176826644132563686022739643581785411227922656201243376475673365`49.69897000433602 w+12.34667052448352426979581601832848731453110579595014575127211168754290944187945`49.69897000433602 w^2-2.22122088667557323899252908490081358754253094110959879550092411936817300745087`49.69897000433602 w^3+2.0655818066188644662068987051256020438729655935506112539225723491223466101932`49.69897000433602 w^4-0.69927781155752786656320319655833438089815029761514998741701012802255255118594`49.69897000433602 w^5)/(1+0.22575292231405440163487310425189476257389268903001369856146668909438988900189`49.52287874528033 w-0.85559009693144657641796026950349712766834499784572477313945710123025252291796`49.69897000433602 w^2)-9.70378908686099404046272025030454809587563425933191719983637700607337666584162`50.97867042628346 THRSub[2,1]+1.22532321122763347629884412800948584897560366550093398136375268931469472372141`50.97867042628346 THRSub[2,2])/(1+0.11736078295412678216675676750302363637066723386102439172526563337146752072468`50. z),((-10.58536858124218687456812890273330753336005776315059760066485042044566174262372`49.69897000433602- 5.83955696702843440966827796301524172406542211704984180072670829421720843185631`49.67729892669684 w+10.89344570864869557759153023152365400408368093135987452857384649419294972928816`49.69897000433602 w^2-1.98854067690104016040175526317248550258161715371324108365346928044729061748074`49.69897000433602 w^3+1.84780095659637324089296367106301115328339514323751753883420668285380527676562`49.69897000433602 w^4-0.58363030225961361915737450260294451582390152933981125636428030759838265024845`49.69897000433602 w^5)/(1+0.30405762582660513305375793046312278770345731929009789140663056443380730503275`49.52287874528033 w-0.7695478608220891409715036809719529405881910041003654450072634062395325644852`49.69897000433602 w^2)-9.61640360439519360578496451481107238102822587881164620830269766177955705561907`51.013670623778246 THRSub[2,1]+1.21428881435119562649276150161029910411827069182963469071180519171144705090899`51.013670623778246 THRSub[2,2])/(1+0.10729861958342680316225371953895593382532764802005922251341563258577723696149`50. z),((-12.85129771216550964408044750986854703668704783389796249699966339250309452154294`49.69897000433602- 51.7452290584344114067916585371428806850613428434618166106919`49.62932626295847 w-42.7551719844752856001726816161692213160648463285565969893419`49.30881092399082 w^2+6.78892929715268316157745400700347623805506742484522129785807411118694896048971`49.1390082889029 w^3-4.90336398387018792365291917619675916420108996689652423955349899050777159431932`49.15327716306322 w^4+4.09006772583295357998102305704521140872223028707223823117034716064658799432363`49.285190519258194 w^5)/(1+2.71356857663906654084698833303588585370420125767186895657629707280489941765896`49.52287874528033 w+1.79787058967434314839430330763403636272350034796574763977596499400102842259231`49.36911932966053 w^2)-15.13917724455528617791945608529367237648220837967812040822129773737952750765777`50.370231919703045 THRSub[2,1]+1.9116641046702225973697443782498111407125018185648328322230293528437627565678`50.37023191970305 THRSub[2,2])/(1+0.7432286283058115526376858882865485885698454256545909179299519571341271361219`50. z),((-10.57396655575206009650422194928455629470403446325468468431492524626014191092457`49.69897000433602- 5.99443625644722157450489162478492731715520306054919223239960952187431554257195`49.667672588161125 w+10.48231582145956149943641888547409488080015685067158980997268588723325225308924`49.69897000433602 w^2-1.9206618269596382091529901235121889800077285873763231914529377794193547847598`49.69897000433602 w^3+1.78496369160884903691182427286208517983593542043734362943848479164608611743836`49.69897000433602 w^4-0.55065936476018289750333641139416163346803231663785578976778037504346901402939`49.69897000433602 w^5)/(1+0.32581466183479973381871471099426730049262004022114282030420681830817141828352`49.52287874528033 w-0.74542962631317895714755889303951839264408103555661689188366743261462394156832`49.69897000433602 w^2)-9.58861332403649314143663165806736276470708994390663074941856369931392423036066`51.025562757888984 THRSub[2,1]+1.21077966186805418452997387633904604193789015054096571288760027529799208006785`51.025562757889 THRSub[2,2])/(1+0.10409865623486674638719389534899246029785741013820039114070899361938055250335`50. z),((-11.9909222574909914186445777355423900258737092358915159428360122598331103425971`49.69897000433602- 62.5100364768637079535354691144264835531920394122464921694554`49.57949904117653 w-72.7331767539123908543477413215303695636361027639943406259212`49.41354672949039 w^2+12.18921819521382908776975744594274676581502352847338093130914966765537585818303`49.33616218044495 w^3-9.68112102466807062805377725251423053128688952909653885793536355681735324516289`49.35209118306465 w^4+6.60557703228711857412692422044565379676363543538020185596902297656339998873251`49.40486335487169 w^5)/(1+4.25729878239357906348212863807026626251366767235217316388756230519824553224987`49.52287874528033 w+3.46067031039966199433544750243133260733719327047066566567009342582455586970005`49.43662591555679 w^2)-13.04217481986737298257599269195068917826540830354166941156517659336315709233671`50.476101385450654 THRSub[2,1]+1.64687004103482699697464778087854916832881371630175633898554696997122172433212`50.476101385450654 THRSub[2,2])/(1+0.50176539676478642794828847508481565427739906081892871774861000116336086065669`50. z),((-10.60686749192111568823042171428796540325670161147278344712424927585555857201636`49.69897000433602- 5.5065211618482250933983858693158707741976306768521993955533605998900250996786`49.69897000433602 w+11.72971624458109059672954760698782243337258683759915009779540680486359379464526`49.69897000433602 w^2-2.12402986846361930901103306694739700467947976838572300211680152165854909617962`49.69897000433602 w^3+1.97403962718559266487094653260054827242602268401967323479308815964153788660725`49.69897000433602 w^4-0.65039718991290221059305099178182362863895408927772456740197787715011518057579`49.69897000433602 w^5)/(1+0.25929528962573116120548893377531237737345970474499778893944546345628042584819`49.52287874528033 w-0.81886841839490121235047861099382172841335463013160050187793134666686732477529`49.69897000433602 w^2)-9.66880313250460217057275392798340656208225877169152541721818613074285163408591`50.99227124279995 THRSub[2,1]+1.22090544188453402697893973312908541398809369801100612767314593653978199099037`50.99227124279995 THRSub[2,2])/(1+0.11333226038401175930968911454872372974619861944037958026471460122945202651875`50. z),((-13.16300181844421195447729783351510157515493438627077306088605197130734408209023`49.69897000433602- 52.3235434340107595682995863889450922780187782938465099480594`49.64203829176223 w-39.9378278538862368710600734027095480473018153816363542958292`49.28230525374563 w^2+6.23511623517675177678280522826703446855231033667189549548774415816011573159978`49.08730640373639 w^3-4.34775123086836400066170051864664835082780159527981372885842571901582827884674`49.09584496928441 w^4+3.86518099528552181290438546694033959613973275148387802963847430225534763255087`49.2540824414378 w^5)/(1+2.5443100040170182835368917644630296888964978065532962447887013255201767631027`49.52287874528033 w+1.61535519136803798943661873110622652365680629489450213769486767771105258212559`49.3545907581441 w^2)-15.89889704258101284193891287101253943140803420086251532909505145047930296999746`50.3431706942449 THRSub[2,1]+2.00759594059713299149149204105724704083051381480272386188618972957834858964659`50.3431706942449 THRSub[2,2])/(1+0.83070797279168549194269498111045906903849724540809872131151547252597579294518`50. z),((-13.84530846362360271675570344471200269558487285747567719276067670554579278082247`49.69897000433602- 55.3783271329918377405436503461640274570875068979349482231242`49.66456847514464 w-36.9845099953074289350545314930394900963161157906947562926743`49.235890970650416 w^2+5.58283585847709607227878982734406700147003022691075752503714966419386149287788`48.99555534643824 w^3-3.60093754144518470375124561290916951762615003429127970837699157931468374045304`48.98606265105377 w^4+3.64704631285887817592107705908802608340565225086771105391096896771712568982961`49.19908926517494 w^5)/(1+2.32961475799414394915870345879198594134241838355593884554294317747257600836602`49.52287874528033 w+1.38371215165510854673921949315793647131754074384602004483833522691283995293221`49.33159536185726 w^2)-17.56189042709490756445915160545710057640043371196659761432293557569237224422396`50.29628897973088 THRSub[2,1]+2.2175865304505278609475723458281349792808553369445496550145757520639622591894`50.29628897973088 THRSub[2,2])/(1+1.02219642885097336219301907610420365211712596304271872493819691827435687960439`50. z),((-10.60362830435274957404471334983079957438847667157197522437240001613370342675997`49.69897000433602- 5.56072503192412781368985327539924168366126027474664996356687935224157853518389`49.695506457496386 w+11.59776427162838894384828430831698813393549765580606245613611991435217351652126`49.69897000433602 w^2-2.1029114019190404766065398096917997567762849855560580666747866309100325568087`49.69897000433602 w^3+1.95427407757358059272681530080116753614099941245401817025815168033785148469921`49.69897000433602 w^4-0.63989564333341733737019963234260856372347750660853803562476961473159171505888`49.69897000433602 w^5)/(1+0.26640760547327214613839817982643914062501802793194474936788862061740144615257`49.52287874528033 w-0.81105679470219523595180206743812384059788566702128235860134965471205696858209`49.69897000433602 w^2)-9.66090822552186829496245801574325416273296678046029628923120879671951687961305`50.995414141063534 THRSub[2,1]+1.21990853101911493445716522071479759427083175575982853618662985470057279515934`50.99541414106354 THRSub[2,2])/(1+0.11242318668418023157126189065534304797612076723725761238457762533694251329258`50. z),((-10.59793029521275918837459780485096202656437136377068806555194172107900807075696`49.69897000433602- 5.65234206515925585389858633910897849152980482981685962547934738647856978989597`49.689382390736874 w+11.37114897661757425949784963051251605309659969912278333845554799949524257827467`49.69897000433602 w^2-2.0664024691141644957460372513356373047447656653455074500037070162179237045316`49.69897000433602 w^3+1.92018920352350102976715536315319096881545633251449197068709009082757691730209`49.69897000433602 w^4-0.62182827574238898404187852478797134716502278194788886360804095684229103616966`49.69897000433602 w^5)/(1+0.27857716463744983674961469754169790565170044382475942128748331524201705322288`49.52287874528033 w-0.79766942784311155340470832502181971741836558428700903488679844248502866340521`49.69897000433602 w^2)-9.64702040606173043935123984301191735038229149397343364063730793741102331030011`51.00101126393155 THRSub[2,1]+1.21815487918419542056623831312584448443107414490767803333521853884800284618485`51.00101126393155 THRSub[2,2])/(1+0.11082404796768480755256303049416219449386922921897050551359925291652990159859`50. z),((-12.41676869911296662447085120608178121512371468251282161093170524502471664771063`49.69897000433602- 53.1015726004181583917133295386089820533152896248161572167013`49.607750308011035 w-50.5669908266577951415832671061038737206307955398153036515236`49.35419509019352 w^2+8.23810647756269158005842123058353068343055386325092881276700190195033677043746`49.226055516564955 w^3-6.24539456805536214720071039260011218307640058807379296947390913491378713807521`49.24441214599392 w^4+4.73500258942352803757765695053266280996974537030179767302381404310765627585378`49.337761396742955 w^5)/(1+3.1378656625376757682446072536917672543212014579958867486128151088441289138017`49.52287874528033 w+2.25513861448128199437779203236553486464872267878183511939927695522229727313314`49.39640605946817 w^2)-14.08009496946511572247592605551172067305998773358725980525146223691249226826647`50.41657124001485 THRSub[2,1]+1.77793097396719897557016629306712581117755718508266626750095786256139289120153`50.41657124001485 THRSub[2,2])/(1+0.62127863645057920700264610575016634323546384184623545781857087659646592885658`50. z),((-10.59390439752374986048488337702165319703394842841522129612939208753559569796997`49.69897000433602- 5.71443154453534493354143960500853697529152903214593397800320874925051287475174`49.68531433079594 w+11.21494406281886619208633855216395621721788669261074409933705474465131800410744`49.69897000433602 w^2-2.04107103325239463119962925045031501799120963380311709002508159831633249543674`49.69897000433602 w^3+1.89659663024075899771643476117150359132351420324985008593799421159362462191292`49.69897000433602 w^4-0.60935330123785343518028728267146912441840072883335460486857079145251707165911`49.69897000433602 w^5)/(1+0.28693400069143251202100164144382006279437937820412575875856729989142394673136`49.52287874528033 w-0.78846034060759608060790816367599533837881109910875115674135745966233573777937`49.69897000433602 w^2)-9.63720804197169282598928146318685399975513054595002436926600209442282202685276`51.005019704055435 THRSub[2,1]+1.2169158459190537379714735468985374353451346272192655186935382910111159380526`51.00501970405544 THRSub[2,2])/(1+0.10969418511471733526807087264667237867244589036800128420442495328136668261179`50. z),((-13.55660964092009879743076343068069130562011977018772823488971892032294279180351`49.69897000433602- 53.887949020671517823043145489075630484695664440423149054584`49.65577264102748 w-37.8786744999239025036814783582503060568258525346919382142334`49.25392432246851 w^2+5.79690605605910242245371132025424204698115341482492912072618449020860515034432`49.0313714572562 w^3-3.86501995896073968635996743710642789108765992183502334935128382689134806218883`49.030270409244444 w^4+3.7090285315858541529149635460426971831854827047145173962212947483581065266319`49.220519523225896 w^5)/(1+2.4032263841226687151515105195424778160056796885030991047396949446724152311964`49.52287874528033 w+1.46315457775175856620801478644730731395867107333508305218504809627396701877989`49.34016676343828 w^2)-16.85824165617219623215416820669167861552755550818281598190325856886642044630417`50.3143946665194 THRSub[2,1]+2.12873493198258343910009924952134120901605106645304843979162509945566969230285`50.314394666519405 THRSub[2,2])/(1+0.94117348672340067485235338656590517668965849425079321862891367654186503894328`50. z),((-10.59837502378284713942586116215729814154895756186459961186493079455661149298756`49.69897000433602- 5.64535334185859185538032002551788305687042991744838818052093571376527566607405`49.689844327262726 w+11.38859693304990445549098461153832907998636626741356728289163697290575030324859`49.69897000433602 w^2-2.06922376477926598204106682830043242883605227976529755305588689183732730295771`49.69897000433602 w^3+1.92281959568785328898094000076141084155382529971619378674285933060838575507555`49.69897000433602 w^4-0.62322068978238102699860648884985724648860097085579597335277670891429307120469`49.69897000433602 w^5)/(1+0.27764214444307160965869872153462958941948525879433146106967202891689310160947`49.52287874528033 w-0.79869898425526607507207461350671498539833384610238155909477021202641230491959`49.69897000433602 w^2)-9.64810434782777631660018940743401400063294334933223110568321929242757166458212`51.00057122183893 THRSub[2,1]+1.21829175138882252352219556593499104240775755346837694044638029948510049443345`51.00057122183893 THRSub[2,2])/(1+0.11094886045170979654284155789935514736824312096104122348455490630620957528594`50. z),((-10.58592015833638659964847447455996042300807501897488492495469544585175531491351`49.69897000433602- 5.83172261834936752032456710943478781585515987417584113967179562916249641246272`49.67779409917853 w+10.9138461703143028667113945833039625795151218137092677877824946261326870593537`49.69897000433602 w^2-1.99188893307249059496992518967959708232445422832597499599574010038244277295028`49.69897000433602 w^3+1.85090644280628904036665474301701701806732506682507247610992500082876765167191`49.69897000433602 w^4-0.58526425069653566403287362242987281810181775732316713719450521391307803880743`49.69897000433602 w^5)/(1+0.30297400210609128556216345575530800834812572644623501140005225166035119418732`49.52287874528033 w-0.7707464388433588616681575880307433127069830710601111237939780724604909139397`49.69897000433602 w^2)-9.6177479692276105222418433570591436309911769825868820153512517217008449414014`51.01310522977264 THRSub[2,1]+1.21445857086782777663786086406840619972055793461950747843056821270021962667485`51.01310522977264 THRSub[2,2])/(1+0.10745341896419233002230366169374207119841824859110279299701882083167487599254`50. z),((-10.6025761253423577458052342247169694253012722897005000858648859682233769950502`49.69897000433602- 12.30866637742469067786404147995538744019067903544106659782811801609183805107364`49.59234794956155 w+3.97395810964788804707370844490111876070361603041252901281152943304069910360735`48.9120281627783 w^2+0.14729134710238702781132473511629862186493186331785586953293495218306757078346`47.72874684833109 w^3+0.99031521916484481082050245820778663381679368610530631551275692286391494347449`49.55291971085481 w^4)/(1+0.90350175683173174928271075774078771037923389187407962963984245181214112775983`49.52287874528033 w-0.25690316281541310397337581263005678118709384513684533644076489443288367090062`48.80698871838044 w^2-0.13110138245981244153470750810964568228783998114143263835118127399470110549327`48.74110443016256 w^3)-9.65834373821111384449543150552942852556617399219500299643841566147062377982128`50.996441068315534 THRSub[2,1]+1.21958470639775945849467720821525755885779154096725411160891749160279006089077`50.996441068315534 THRSub[2,2])/(1+0.11212789403882581350825453845998347403199732776287486925904866042454195177783`50. z),((-42.88411623805130820073206277282588693557238348116409453599569320994072691837453`49.69897000433602- 266.4619736737612861666597923136360749702769464142221659147335`49.69897000433602 w+23.8659321285521892305622726854182759283454046142041148895951`48.44016885959115 w^2+3.8695473709341724487262405044971202407578757287191445028907`47.908009752061794 w^3+14.66499197677111581789067210612464954464055487216491573799195839209803239242734`49.176358088066415 w^4)/(1+1.41546403705353145239014816218650141752323253929361805097474437139645754721396`49.52287874528033 w+0.24311864442150983941348382100527236809765182782965876792377267117952749473246`48.58635218202044 w^2-0.17314214023544609540238182160395937841993892592101840653751389836986105423048`48.675537154206296 w^3)-88.33849148210480015458400547633390702091226459254887015698306383571551572815783`50.04494277392113 THRSub[2,1]+11.15473585513309863140507394332695762362582026963532222231271009277208982401662`50.04494277392113 THRSub[2,2])/(1+9.1718993605373931141887722188472711213678925180154861736341331861875618173846`50. z),((-10.71927514938280605327302684066719251766515461678068495810619639696876370762105`49.69897000433602- 13.66995708530790710188005383263918496965588696900130964578234555967768813997679`49.60322303072831 w+4.0632889518190797805016098126403008342717741213942920827932574585751797901893`48.88151737892694 w^2+0.33906455822475117712198229712682137466768629229317450996456853498882253202001`48.049279596574294 w^3+1.0665830207330144999052059229788539953024729852987231301257956208780186981426`49.58940830182541 w^4)/(1+0.95218834823989927867402301408346461893816618739335532668015199471120401651514`49.52287874528033 w-0.23150024180716539771886240768457319252252324488919403970632280276645753853955`48.73957104465709 w^2-0.15589895940613785765505312122791497952168979526785112121985229454567269855832`48.79017055549433 w^3)-9.94277553486680823462159580403615748738492187220200304939324811142771684088402`50.89775331044052 THRSub[2,1]+1.25550066451821167421460181106298027052266740645262985578591100328857215917446`50.89775331044052 THRSub[2,2])/(1+0.14487932053454147691894699306046363851866865040604984944441932195353456638734`50. z),((-42.04327829460166505370093952293952422145740879717664298589626271524673083646587`49.69897000433602- 259.9554415929740046441873918302419718960563790603961903062462`49.69897000433602 w+23.3502712945161453273229477239368491473803859108753467158435`48.44132531809178 w^2+3.8098314012981069877561890394713420940699407136387512145941`47.911843662528206 w^3+14.30216844295238816524863854053309659399297398466746814252161825938975984857473`49.17735664410809 w^4)/(1+1.41479848584616125296245158538938222762293754474932422771917753736819877924972`49.52287874528033 w+0.24208342116903257632171515607425134163661598628551665196918323197773075296692`48.58476873406916 w^2-0.17350296399240144104657385988369118123251467089585546158230614574364510385998`48.67658636518671 w^3)-86.28910804536957032930424692820715702134100143707416845663514397869010936940463`50.04606881743345 THRSub[2,1]+10.89595476753328036098350980599956596211962745998296144069182865520530721335042`50.04606881743345 THRSub[2,2])/(1+8.93591930563860735058541557218510289018535209100556401642383100501687859613639`50. z),((-10.97029478515902238492886547755282096724608657781464258237228693533603729824821`49.69897000433602- 16.31093354534898815067692391571335129345036184760363779685176221134030758393328`49.62310016311807 w+4.2351023317624665398227794242421674142229253806559715724210960877843966470577`48.83320229146388 w^2+0.63593809049923668346090755393770812351333954205508763677821949762057179329953`48.254531222417654 w^3+1.20067645438762745734510357792635669366214290174958581288311375254573088661663`49.67575659862416 w^4)/(1+1.02722673052583354158994043602663175468088344461552094716480192214768069722044`49.52287874528033 w-0.18527020059286312759354669984535191582290015297725049516280929549773892746067`48.61236301256501 w^2-0.18954429018501661797931177016066208161987072487164258164207043561621274403404`48.83896027415494 w^3)-10.55458841493802834012567831800171733598126237958389394730059456112430934936201`50.75159358001519 THRSub[2,1]+1.33275590122717430373254589113725764547942241410289890826610286766472952985692`50.7515935800152 THRSub[2,2])/(1+0.21532764876783116906892631585554428509260655902420957135398412895000604260518`50. z),((-14.54501822785217131185297598682869546091960532014216810499569027605440112234941`49.69897000433602- 46.31937029661474411051512141796892012248596726867373585001138796033297642231053`49.69897000433602 w+6.4626836792567709105501858265780225832074703356924466064256`48.611948032492094 w^2+1.67587334646455393285378125009246999138316261985188766397326489508480863231087`48.27527004897704 w^3+2.61000654337446191865934078015794669492085319195765948667412708093755936771192`49.43299242711588 w^4)/(1+1.2921617881703084041279475288231458756392563774109089211373742998730255989769`49.52287874528033 w+0.06806336562020905229833001253124283804862038832242188783422582504919590429532`48.08540759384892 w^2-0.22103437712063331248315712987524456943280793323604729030000517837479847451846`48.81164792787226 w^3)-19.26730062236854696693394101654568292586383859061356584247388702433249221898051`50.260222807108015 THRSub[2,1]+2.4329332036137443337396477075115127208310018322237508394896212296805552833044`50.260222807108015 THRSub[2,2])/(1+1.21856904721600408731606816024531519603133982482564494885760161622123285048817`50. z),((-11.85228969516767118169656811524132651926780565682160202523645658672125650585066`49.69897000433602- 24.35176189046652615387166587503463685904279517980673670392069766524464256208933`49.671556170614956 w+4.7939870419282618433660035820527099494517872763517479315986`48.73620190999802 w^2+1.14888581741472416227332346117163311901073490666457309677877827693764066628635`48.36062825425398 w^3+1.56598904922953832964138716707332236619718963592242313895976644259611395206347`49.69897000433602 w^4)/(1+1.16117488403001290810725753634667676384252207589123039360407257142858785917855`49.52287874528033 w-0.07721489016523822047016334947763886815933032434717542453130865268159315902695`48.18675363303944 w^2-0.22655296007928931282949683925482298577302354207443027793483163446365185681797`48.86303081156238 w^3)-12.70428417253053324783654118959581237849252246521859596566774903277691770710558`50.499754171002394 THRSub[2,1]+1.60420369190743781036485745586606202687746419780783474059903650250392608947652`50.499754171002394 THRSub[2,2])/(1+0.46285835180722774862267990715685750379951646896096113014517116301055870482033`50. z),((-24.67582076956918615972725421268109644533581564176439527858874582555284433632214`49.69897000433602- 125.4365839350312349059577382573559847485148189982975165806731`49.69897000433602 w+12.6948392163202173224803412747822925609238061318050724596166`48.48882876088037 w^2+2.553626398174853285543068876767427569843960092844579364231`48.047966108072494 w^3+6.83901074552079234023286425109917175217133413403703505579596728710267907011713`49.22491139240504 w^4)/(1+1.38576802310611718354528892118570155749400982584551911478084160856119193348217`49.52287874528033 w+0.19781844987765863753779634814152615142049014570178864852233854536575579257037`48.508948231934625 w^2-0.18822952770796199254271018996604249438380124108415961033811880990251622396124`48.718459560482835 w^3)-43.95921550510055409900706151024354664792271775554519334069066206766634684800939`50.095587177944225 THRSub[2,1]+5.55084685204978297980852452262385603388626025247684532775724946826703639749419`50.095587177944225 THRSub[2,2])/(1+4.06176535940325724681456507503172215722118746597351956913600083451079567129798`50. z),((-11.23299764073289091994941357614908407110852658609139175486857977195068106459522`49.69897000433602- 18.83866136851924219040758392343157733630200760379090304073403482866219114081763`49.640294896105175 w+4.40467915506593176960804335505547870672289502214386531063456206639704010158322`48.79642971704822 w^2+0.84574926966399232460456965188411921305824956809707345821599459734438774593711`48.32405143798708 w^3+1.31881405694269665541107406159434823979156313668577737604468285692266267610354`49.69897000433602 w^4)/(1+1.08114168521940586278208806519292505042947715431441860629026920906698656382648`49.52287874528033 w-0.14610877907517367551748047062067227518645623577121974954090970863485992610368`48.48968893303798 w^2-0.20869747194196338781963154670684984006985523513979623155266630088042592835257`48.85769281863613 w^3)-11.19487693330265699284502809108065098057518153738802631371650428816213338659506`50.649291128150914 THRSub[2,1]+1.41360683238529595099330024203873108562382707890231215984238908353949698828103`50.649291128150914 THRSub[2,2])/(1+0.2890548571595656397476747569443079014367590336074564033476017331164029661416`50. z),((-10.57257781572950162011854594598484882469433296523921975164063831903486613712738`49.69897000433602- 11.93764008060432312253333248779368915481277520633635834916763188929444407172194`49.58933015597826 w+3.94886478860127724848329552765815946063105933922454752330907386426352514452823`48.92119987211754 w^2+0.09022905362748490685506952191223497044343592510210711782540386634914458726437`47.528292120910514 w^3+0.96844039815455006907798958527633374858983856476262630041404579075532148386985`49.54392788214035 w^4)/(1+0.88881743699804762136889621924338319623615096660910224447260796493285884283883`49.52287874528033 w-0.26389323240766877775233361065837594045715465661741276484021506862302026145647`48.825787615822854 w^2-0.12333317415960900610884734394364668256913031852617552483658330276667867603541`48.722942047719634 w^3)-9.5852285329214700378689275869426013170016536706320890905299003450592557523751`51.02703848563662 THRSub[2,1]+1.21035225530745502963720312498384308225304779824063214212587834114578507675944`51.02703848563663 THRSub[2,2])/(1+0.10370890818731908392565016811604571141129254132909511770665970048418019796468`50. z),((-13.95745593790098882464179308951168958939454398686572203108133723580007977407696`49.69897000433602- 41.63516089762406648682924660869554860254332246989859382449499020343772951497896`49.69897000433602 w+6.0996380763478343546471096942615025199931455477149718442309`48.630016240819096 w^2+1.59884341640283128867249341859727137941176279577950462435824835693058560114893`48.29716718676743 w^3+2.37737349199203521318590611945403321787984949788570132247152784708651157705846`49.47853245465355 w^4)/(1+1.27571438271676603542917860689707578480620198501350808216449357769904416244067`49.52287874528033 w+0.04746400318370986892524147353640598550278320648957199612639547512913835959709`47.93610434072324 w^2-0.22432665872527794775473056765324096782361829383373038989721556116157803892457`48.82262892482953 w^3)-17.83522868216085509816237482048620703781180547370049702886487144311816784036499`50.28982594983397 THRSub[2,1]+2.25210167762146745920555258495759937094845148059548737052808329299900217482584`50.28982594983397 THRSub[2,2])/(1+1.05367046893551513647995851195275700650362647888269827444676918178098235872606`50. z),((-11.10692253272670496701748185206122339596225198890921947703958167671078396738488`49.69897000433602- 17.64706727907851718807527223861355156125658644766245974884669255541704877198072`49.632422198434185 w+4.32396506242124138003594384810539700632559132290793614472449684268217676980089`48.81282725582231 w^2+0.75437418775084510891105513384792654355765920987314685390041060635878803581592`48.29896096791619 w^3+1.2639328959118739226730940667069456446183523262639876414555416883744811294667`49.69897000433602 w^4)/(1+1.05752118764914373100059188955122288711538633431538387914872642561020754062232`49.52287874528033 w-0.16392773594747646456987027648372651705614821963661094854194497317543421775943`48.548008424998905 w^2-0.2009200706856120522328596716786316990992176360951795561938631443653486538692`48.85103162557628 w^3)-10.88759270553284236413167640064368160689449258716381243898239485865312865994304`50.69391133167021 THRSub[2,1]+1.37480523711563709183729623484640058126521116927992104716690449632450991841425`50.69391133167021 THRSub[2,2])/(1+0.25367204512017071109680396768527045314354852537716561620455744305205490204064`50. z),((-28.78398172004489709534097127084254126355015870812862249369591154701335661588691`49.69897000433602- 157.2931931920650713579264548865498891350081283083023957542587`49.69897000433602 w+15.2165646023683502247471334669311925447165338188669153648811`48.47096381776305 w^2+2.8576510006949855994830351303620245736503632472196396931659`48.00113900529053 w^3+8.59561420025923898108135192340392682243707564418908108159985189117835031786377`49.2054380930505 w^4)/(1+1.39708487809833397064994009147226386181172238649697117862371804537339321011267`49.52287874528033 w+0.21486386486793342373401274122634553603535570445521514267226128230042670896835`48.54018873196676 w^2-0.18272765859813094626184932340573844272288777365679610230861506658525339919645`48.70300640356005 w^3)-53.97208073428677379979950899426546788465415484003997249378006397087783839628886`50.07619063541123 THRSub[2,1]+6.81519792835545921169258275734047089546421059074107269444682449566046032187602`50.07619063541123 THRSub[2,2])/(1+5.21471528772005078977156713013074441805690821997298433992512716510580366091303`50. z),((-10.68747432049397782938710245743797526148445119665205760294068782667071145488168`49.69897000433602- 13.31015129350722834964904288851819844604318420095312427840347183644568066376143`49.600383289878536 w+4.03992428240478606684790251722882291022381376904309813802819646027116748947166`48.889142814189704 w^2+0.29108928900916482826813406102321978030682464536393307741915939413782938853063`47.99348363630362 w^3+1.04699400263642816135163699127864428330758073913935109197509141830856179067793`49.57924005778342 w^4)/(1+0.9400697718740583600089718386703621226256145605374226904780367297546747345926`49.52287874528033 w-0.23814702659584263151785445420825387389931923317112911356942279874209094373739`48.75719277123833 w^2-0.1498946367780538537233767962277814657528536111378643790858666824349400229013`48.77941150974137 w^3)-9.86526702980120774326814686148295176637071072544099654845581825583390984881164`50.92196746168263 THRSub[2,1]+1.2457134598011358433657980462351247642575251426194948716311860413050610770103`50.92196746168263 THRSub[2,2])/(1+0.13595446003618552417848514276175779586655348190897992479204378970888926909211`50. z),((-10.70466549124849933076874908555013052113353980230458268843038214445191156681632`49.69897000433602- 13.50557267134553542151010198020791989670628517235625266285960190668049782049641`49.60192904059157 w+4.0526260507183938709744818075100768178447812554124742395327387691567258606063`48.88496493334905 w^2+0.31738617074269164258751668026341470901000661338033335234386616380691579696763`48.02532107865691 w^3+1.05768078461671671619612053922112982528345976414842663645385552471691138308892`49.58471638159627 w^4)/(1+0.94671530069375541893190894501207182290534083870647245242158734230669257975137`49.52287874528033 w-0.23452907136102101452272795698128127429882012158443849797729748227156542932256`48.74760718125412 w^2-0.15320311960829462782090441675482474077475491400062134936827082490447471585981`48.78542216921127 w^3)-9.90716725668424137277051309704292373361904410923124199758958701676281176881239`50.908663265151084 THRSub[2,1]+1.25100431269333253489401008639951421097051277205348905184645968924692322290932`50.908663265151084 THRSub[2,2])/(1+0.14077913933381921836970508246409874593775038911682915067448750455741040315199`50. z),((-29.56307401562696761695178013043795162632745073528782081296447031594065233093751`49.69897000433602- 163.3305161596137113091141092215241577983903811897107634231236`49.69897000433602 w+15.6946636503115011829375502152785507281634904482960938690033`48.46828905844537 w^2+2.914519562093355022241695859980994251992421535417142149045`47.99371661035776 w^3+8.92969375610968766185847373996498474048880343164197713679429333298631380094363`49.20269605592188 w^4)/(1+1.39873674686636392554309609229634867570441072288992975301915195331239814771829`49.52287874528033 w+0.21737467790712980860977569125584807049147022261757265712009660386140087735263`48.54455743831078 w^2-0.1818987103116853476601940487978979948491838025799468724312574209502284638892`48.7006608679482 w^3)-55.87097083396927620757108563098080993376121639490891558546682873541784351781755`50.073369292420374 THRSub[2,1]+7.05497582273094270900713840615523845421317920244284755748792874487099927967322`50.073369292420374 THRSub[2,2])/(1+5.43336650834457368190744595106132852341492705508134691682057219652356932630613`50. z),((-24.1943374623710903354413291785252082977759594075102459744648613105351440140633`49.69897000433602- 121.6997199124585070778525504358721084089404964985791437850298`49.69897000433602 w+12.3991885706346804758202932487805845979473734142158354996117`48.4914621625929 w^2+2.5173633782166001431537286587153778273771137728953427896207`48.05449197784511 w^3+6.63385390500732974303838437468643618427587389842869187946787776860916798071186`49.227960211651244 w^4)/(1+1.3840571225960843329430537575189664043998762214187705581416238300905602334717`49.52287874528033 w+0.19526547144667945030542275027345968603427099518620485809825850893416258007257`48.504013691516576 w^2-0.18903409146826855189261400705477590219659408006846900013778749960412209518965`48.720704893868145 w^3)-42.7856910197662727484865461820092338029410358267792793822189285548506892343597`50.098529793740454 THRSub[2,1]+5.40266279961906304187095302898062058698810154781276910785335803324366378500789`50.098529793740454 THRSub[2,2])/(1+3.92663770710046819391602844950122278520418819311943314130039086624747662993204`50. z),((-42.14585107649112535039676966668419926559653955607119521037708264988412224560139`49.69897000433602- 260.7491800140749781234826901042307107129289801217783433003075`49.69897000433602 w+23.4131766774856659685746725766426640735497733816124283219357`48.44118134659322 w^2+3.8171185618546165924081405678425228822509174827221224785161`47.91136797413598 w^3+14.34642510124923883300485790740335077101222762332965484588138378852964089512177`49.17723195557416 w^4)/(1+1.41488144449166702485290662015991675146808720957669188567919269717623109892443`49.52287874528033 w+0.24221240951920461812548783812368284109248185387367177169195475950556846337672`48.58496644385271 w^2-0.17345804391117065265780438748505019281870780395101925739925643573349750439834`48.676455817014954 w^3)-86.53910979886049683038409556646670275542545703037240115386491421544734548253264`50.04592843734478 THRSub[2,1]+10.92752315269272477725168795460586154262726072525866265531353616389948999662608`50.04592843734478 THRSub[2,2])/(1+8.96470622098889641303933794385658820502259983323214791975793852192494836983015`50. z),((-10.73712785546271449498397389940490671245137508895642807082458506875103511498809`49.69897000433602- 13.86883682977948183988294664999100004436049581796643954073734765994631446192201`49.60478062302097 w+4.07617135648797466279417910540565155841655984320498205952977816258905717291205`48.87742525280502 w^2+0.36475692641357193363104458119567317338109208111043240588715977177022669383656`48.07536423924147 w^3+1.07725043719296933261973030902887942863506925317632172847525176836636447036592`49.595189091037994 w^4)/(1+0.95867030740151436847702925164485589759303163564687364641194702183960192166105`49.52287874528033 w-0.22785510823308186204024358813257068121450804416962397473471241947587973132011`48.72987872835177 w^2-0.15905608775760010244119140296614342229038415732444554378459024812479963526421`48.79556528100675 w^3)-9.98628812897140319705683689470724280044282078006170960361869153985214317559591`50.88488449717651 THRSub[2,1]+1.26099511530025500137780603587743911169965793126550352354960537714007319185417`50.88488449717651 THRSub[2,2])/(1+0.14988965884485226194364609135247210366212124050324174408937394489307082413804`50. z),((-18.11064168111824016966024477998367351121365933367254804911702998259393380293254`49.69897000433602- 74.3595663683959115321662324192625678799769481514407339538136`49.69897000433602 w+8.6601828508651573637076479724922454773764513167590057926814`48.54356842066207 w^2+2.0327627777122223597689047401900527665599617032631712111386`48.166999806873285 w^3+4.06673704389843208030905508504787561287539926947758100402894825316222617044321`49.29916018716833 w^4)/(1+1.34777368968379492767738732779103132462660174717509849631432543374846358454981`49.52287874528033 w+0.1426618876886296239561640317045214251129580488503135689629241002726445530845`48.38286559244827 w^2-0.20435390535600486334116760954672876881257012797967648071551076895628492943944`48.76317174463469 w^3)-27.95783332689769528100150926391693689533783211939085267959835391111722573536052`50.161548077910815 THRSub[2,1]+3.53030984128313315092904402529137308826783700273946982170533481538378600688393`50.161548077910815 THRSub[2,2])/(1+2.2192565456870058027936666957051363287228358319323124896099484037896507488052`50. z),((-45.13496974700782665397733063768852186370277244494473057814116395093398734876811`49.69897000433602- 273.8176445231329004781271324322949660950585975974498561327431`49.69897000433602 w+88.0314657150054338883948828743123583925468789611534174946377`48.984829730830185 w^2-7.1242674942186878574300486512894109451869527027702943092943`47.91040672755853 w^3)/(1+1.19419722045360538769424983594529785710806482959149463220865215114431084906306`49.52287874528033 w-0.05932998107899475646335914912941201488514725626108558905313365883382095801113`47.949214233179205 w^2-0.15757914836167187371796351010034235451538827251179487602553983925966948057345`48.44859296544315 w^3+0.11050384381623753323832072878881632596259970908796959170203586430374208718383`49.01294600304098 w^4)-93.8245211453809560355847761323783257559310798358338873014588395407685850236429`50.04218291954207 THRSub[2,1]+11.84747138593698310317187952685844538689862185553788811498847171810733118822674`50.04218291954207 THRSub[2,2])/(1+9.80359841592676752877049838319863887965794421573120405565127007017812091898839`50. z),((-25.16367185568576894809606635612141618414948486537437295571727131888663536746898`49.69897000433602- 124.1307971931395337747066531373939393347032703299916043564958`49.69897000433602 w+38.9288102706697424755965949691066236889445196562922030511726`48.96991659558034 w^2-2.4365759101901188673926465919124737740688388574195233508313`47.84394970769306 w^3)/(1+1.18507670414606015632344109350304021921038417111402582804039402641974172485889`49.52287874528033 w-0.07208349869127716678277991773836828393754363084272932967372567038910871542144`48.0639125818911 w^2-0.16402224666568540875000860476506818706698580662278955672366609823899685639011`48.52375417048064 w^3+0.10693668851899472012690016216657975776484271132565311138185516126687800865512`49.11260438071058 w^4)-45.14826024703838453833588801240948365690232887153429717688918767073275481466618`50.09278030686691 THRSub[2,1]+5.70099068848758601348309123054474383102096911725583274013445178844902070289696`50.09278030686691 THRSub[2,2])/(1+4.19868012042357514609206321455074302456958411099890913881648206729129378130049`50. z),((-10.56620583056828857557134999375892458837499860205386811872889105754648161180593`49.69897000433602- 11.79003214152232916138842215869888142003489719072667986868955992836374653972408`49.589082333150216 w+4.2829596440717926544622094303567249055202684002624578015545364296675919891733`48.955723110200765 w^2-0.13512827167602977717697264154108680178343248209488273957949337466379893763403`47.71806390316019 w^3)/(1+0.87917647558007393344618983121138659522743028560468694881781851560021576145254`49.52287874528033 w-0.29603089547431591459343646056380490221388116942540967903156259897866624129509`48.873304103856626 w^2-0.09623743005930535354757875529978957482751569339787406826647300989924908065567`48.636712425010046 w^3+0.07840311863826034452308510576087092851828947532392280172797106713304727496366`49.54597980890824 w^4)-9.56969802439691658539593008265627392594073809600257583888391183524408486522076`51.03388825700702 THRSub[2,1]+1.20839117676308821162267739262604947618976518723215858387247478024763568969472`51.03388825700703 THRSub[2,2])/(1+0.10192061899334153464471814180555960852905104331948969928370142472345537172733`50. z),((-32.55043191624240990332587351474214951050136064765514324149493252456852869235846`49.69897000433602- 179.5185158159261839456611309732353021263899526193094021913938`49.69897000433602 w+57.0443690100699585661814806731141888252708545637127154583974`48.97788262860241 w^2-4.1610160833102192001738184487420167254536670831542987713395`47.886369944019826 w^3)/(1+1.19046776991526581589902528361912339292347951847539748606507907384363649440969`49.52287874528033 w-0.06465297124688096418948969035623775352360561937767467914825418823746212588906`48.00062177021399 w^2-0.16047948954443963312948571919644887555255932506143423730321716552721869498658`48.48319382277699 w^3+0.1088725891897128538438148658055828238299404573744563771422479751119082306946`49.05728835316602 w^4)-63.15209063691745338410744828674966041061445511405753434861311142811690661204364`50.0642500625937 THRSub[2,1]+7.97438215137442688859703980754766846010373661045484862652678419857231381459699`50.06425006259371 THRSub[2,2])/(1+6.27176454554229981249823735763621261617974404269973671417862598148508605963049`50. z),((-19.34834802615952573373839753479621092724236840188420272112712310029821831823416`49.69897000433602- 80.4543101023657537021774672885143765774512359817581368896592`49.69897000433602 w+24.7808596418217659330299753054670502589076789930448503367849`48.95840881187464 w^2-1.1069717533531432671864944901549643594140823173915249579866`47.73271662160241 w^3)/(1+1.17422675375434493680955372339499247131141912907840876185037965691430185964776`49.52287874528033 w-0.08630689039755982835053280500455895977046661839427328542547710004582467345352`48.16572645961343 w^2-0.16955116849899335777316525794463060768678998688590578411593902604199928911635`48.585166878883534 w^3+0.10397912398066780899575917823891721674571708070453752823957419902344308945541`49.20610104969386 w^4)-30.9745084220572422231190867426704311929046800773274199512105439132841155446355`50.14289539968405 THRSub[2,1]+3.91123341471861516863830051707101985213853321724173392371507534504237027665765`50.14289539968405 THRSub[2,2])/(1+2.56661719172677390593830440168080289007268859760125481328846471557207084659585`50. z),((-25.00955847275583530667704449658225393046549198887954832657494069734809867512613`49.69897000433602- 122.9745362451772100583517984876149900566336453212508452150604`49.69897000433602 w+38.5520583737919861356438991816545994546194536120788766316834`48.96969105330007 w^2-2.400867874176165305497652308464723975633279660423789035387`47.842443923961156 w^3)/(1+1.18490306758136003976723484704255797000232927885441346234877763765488018012497`49.52287874528033 w-0.07231834048094063527462157636275827792791130424135407986779689918582430525673`48.065780228262305 w^2-0.16412599220335994864494615329125839277271386651204813485471611398637450832339`48.52492099076596 w^3+0.1068807226387850506955622995422329348576310541275898828336784440818398434016`49.11425967991965 w^4)-44.77263802777925204204502588531358876834874224910101901115757588885364505763956`50.0936489559486 THRSub[2,1]+5.65355987359752989896172714031789303188751934990347191248145120777675784302041`50.0936489559486 THRSub[2,2])/(1+4.15542840367154520654665804511506741346719462374971855481364383175866340159606`50. z),((-37.29647594337794444069058725234874169731823881466852262747581846088129374057686`49.69897000433602- 215.0869595578113198027497928480882272038661959699163420338455`49.69897000433602 w+68.719505530922651890756369536157777696077286458825316088932`48.98112741085073 w^2-5.2764406336452310568301445187314778046540932361391064874788`47.898823280606265 w^3)/(1+1.19230752279228508900346201592613821167173089724782279380352830029113772126503`49.52287874528033 w-0.06204830012098324279343162402075964286890490056952004152435416790776756847351`47.976203754422464 w^2-0.15910331214663884403559293808489925128903763977083485521399323107084830143611`48.466963265678295 w^3+0.10964057638534390675281098676203854432036394334181332054644638573884045370009`49.03620486391436 w^4)-74.71967520538220807204963840116805136977662017381991258450994835123391113721166`50.053660049254255 THRSub[2,1]+9.43505176637772480844779991616566964558132671976847330304790615679821735036724`50.053660049254255 THRSub[2,2])/(1+7.60373551426508744761777122960834782167748933696825485761753024931088370359998`50. z),((-10.58021549921564144251772276447031543785442522861281066195711606131478794581491`49.69897000433602- 11.94730635669832304069839955148342700199053786899915542435704624287843289356282`49.59063058733251 w+4.3156345167726199063281844990708537898881525766110378026708371724173306119612`48.95433452920444 w^2-0.1196157630238583901474056340198451380174422302673559600597370300326478980699`47.66154273916292 w^3)/(1+0.88454921106113621901930155219712631604533670898822102136152850340056127687102`49.52287874528033 w-0.29416285503209377588783584897974857691948355427518731602547133222236106664742`48.86819672470761 w^2-0.09896563583286235488039593730242131767246377466478510990087393961265680545767`48.64651249861413 w^3+0.07886654218191755926460469736073320851656374320015003099530546764138059174443`49.55110084787652 w^4)-9.60384394169727364038866819446241021557119132218976798262822052475102395362458`51.0189964038363 THRSub[2,1]+1.21270287239685235706916453233140542806211671506144630876859923756605546682558`51.0189964038363 THRSub[2,2])/(1+0.10585241393940788096214470353195377638322373419119519547129150012239361597078`50. z),((-28.58703964981821399454403147098325301857421974076885213092239120927735457036347`49.69897000433602- 149.8064658502571964278072190181903450404491541193650794856518`49.69897000433602 w+47.3126430028374937653750946599387690955948782560786740388947`48.97420359032809 w^2-3.2332015286968349803334937453835431741889736463855721333491`47.86914770747792 w^3)/(1+1.18814637749212910977874519281324186231888551351421603076178352315688015052151`49.52287874528033 w-0.06788709098657941242698091175105067333835316029737802317886568226382836688063`48.02923049254379 w^2-0.16208640677642553142338141553897265979124809000439214582438012291439530735623`48.50178217435164 w^3+0.1079879484671017851102197721636363440702020668396133849468875530482006445516`49.08213275076063 w^4)-53.49207169108987560857348187058076088864826409534830028594672893654223194082075`50.07693861138043 THRSub[2,1]+6.75458591206331733410860039554372196728218536988837403708073468147150301798376`50.07693861138043 THRSub[2,2])/(1+5.1594437566170345047953839079255312699501319154027099779119058606596885905668`50. z),((-10.99136288980068897225720196533764630177663118012324229492559347485597391317166`49.69897000433602- 15.99533817553850677557416197253467614242728330825127881168470740400223272631055`49.628377323726454 w+5.23959503300832441673203650600135841996344065495449786851677347352354801752966`48.93553992242285 w^2+0.15231065360775940913518776303674035968338081046469796137994048477727501327217`47.67294803017228 w^3)/(1+0.98448926157645443757015280329235411425564511183124929269948841644113085692254`49.52287874528033 w-0.24945934884795204066830298065949183157594053954184561584534912075159960281625`48.7559649621774 w^2-0.14690469007290962012505818329090236607056475040481017094476421578851742714296`48.77028280954258 w^3+0.08689135489374098651671121898779102969150247149927950818804023379389700695139`49.69897000433602 w^4)-10.60593793482160852090376941388124915133645258364132867584751185378064653999775`50.74193675285029 THRSub[2,1]+1.33923994143410125826879396629905550748744176988035340093261912994542825107402`50.74193675285029 THRSub[2,2])/(1+0.22124038442478429895095489727535736401095774323317324138754857222797901717882`50. z),((-10.72572999968800417310947428530109808511798050621276398633984521919272969063642`49.69897000433602- 13.48029593821076529427154186269003586335923747648164978093381796331351203098665`49.605519959805555 w+4.64722150295062420327012209794736207022754100469312215547324367015402047825227`48.944112959596566 w^2+0.0110690994840945857025191805917623966928887227312625706844069632097761787749`46.59340145152181 w^3)/(1+0.9301474635631346775608241638314206724199281694414240932318531935085398898641`49.52287874528033 w-0.27620748164215262867751617560741671465544421040381662800311486434304339358356`48.82182583791168 w^2-0.12181563952583164353105144161143494875584960956759565527960592377198286671652`48.7163922577736 w^3+0.08268983102446354181452708959181104215732975090916745334845309030010984422841`49.60347667796744 w^4)-9.95850801150529928526502697084339954238516333167039482062536297557017349709138`50.893043281384394 THRSub[2,1]+1.25748724611254385999182778400784380683742187967057519329897987567555234079482`50.893043281384394 THRSub[2,2])/(1+0.14669086572139985288711867035110131000096068754088909487376508735953322646377`50. z),((-31.95249240272985346061574478917106336776204103747974386158919096862185646185538`49.69897000433602- 175.0366476132134579637461977281143842037967608051992968637136`49.69897000433602 w+55.5749080402670958183215092542823241081496415645080430989585`48.97739482018979 w^2-4.0207758723147363164837558967102117306362997789545714219143`47.884288437653474 w^3)/(1+1.19017502433547244758243000986439187847943587047955637640387441995223776992407`49.52287874528033 w-0.06506392365734077297007081920768039467932659322901290511681667156841571231991`48.004357202128396 w^2-0.16068968906300813741302503994460526139688426553743771452137224985433354460259`48.485646250656195 w^3+0.1087561654267853290774715137105651071960268350970942731926489189790896555541`49.060521555780355 w^4)-61.69472617720388837231063710299356238493932435041556017515663807166107534566189`50.065888892407614 THRSub[2,1]+7.79035687179336511512628374384535051987462139505335141207290770356854388376361`50.065888892407614 THRSub[2,2])/(1+6.1039536132169120111620974938097654702054836668125489257883035313658103232673`50. z),((-17.33318670541005490668291352578019379833031961797341613241524403424425272738538`49.69897000433602- 65.2751775213112685871127887297699271722244569571112092983723`49.69897000433602 w+19.9331688341067484650331036704267093404057869389639105136531`48.95232744273082 w^2-0.6629872617342832249309567309152121026506507767526765080786`47.6239928966761 w^3)/(1+1.16622469175996065243095217342249287738533344792958788086173493579286447049652`49.52287874528033 w-0.09628632344450937425138495525309993907880407569387254918189033048566298097928`48.22640345040278 w^2-0.17263872479089137611500518479806985998064634664158089860091323199632948549224`48.619790781903454 w^3+0.10230517023191434515172536997092502210702166245107187977756762181369049466273`49.26638521749384 w^4)-26.06293388469719412566853528590513734625980677762566766549892952804481644832176`50.176014217785664 THRSub[2,1]+3.29103585782296171919707582598792792276569900331216606589241648409439347217531`50.176014217785664 THRSub[2,2])/(1+2.00106483671599032147793015518438536270571468002101847991553333923138342559816`50. z),((-39.54632298191403746188444303891358135387098572708307634135867896784560394756838`49.69897000433602- 231.9454791493542106697097510761544008154296745428488226294386`49.69897000433602 w+74.2595724682145995260644762856818386260392234396097185863389`48.98235951784718 w^2-5.8062659914945089967658170337003488436013380632712410079952`47.90296751492498 w^3)/(1+1.19295993285592849639693205955513265464169266013401910897641651967098179834431`49.52287874528033 w-0.061114992333651578208000792641001092951122805197194104522250773978567306639`47.96712129481204 w^2-0.1585906816172924632405163688658164839219576447338247936163527897010981960954`48.460833907783396 w^3+0.1099293631170297226482109027796232517184751420284808282472996630000680427216`49.02837680205036 w^4)-80.20325178738955064450418217465780373669743792007660241671031566461643413933629`50.049772427670355 THRSub[2,1]+10.12747754009694896118668878169819468822432221493139503893446768385779944780522`50.049772427670355 THRSub[2,2])/(1+8.2351521050643274120268570450964768234800627129187036686246350039905636340322`50. z),((-44.78540432821844485680626133411207948454820115015211829764192278730131073749794`49.69897000433602- 271.198724136679378236363103502164461030020187313457076869564`49.69897000433602 w+87.1696989446764644274360448395579816335682016810425237226959`48.98469533972882 w^2-7.0417647342447163390313489076330139059307306648739772450378`47.910030298399704 w^3)/(1+1.19413223890796044626136560641297738756494977286046992002095606597823557420016`49.52287874528033 w-0.05942423853633559361288431171756868988626541840643442170633715062302492086881`47.95017828414677 w^2-0.15763362805851263205701871482264660829855206963658807172514870452015282215521`48.449257431860225 w^3+0.11047274073651309055957691549320082160291993954287137615049243074492428015676`49.013776971729726 w^4)-92.97252155984455812035313053080370580727511121344210306812274030927587766849048`50.04258906970447 THRSub[2,1]+11.73988713624140573574653964000975789241230194344987711376803387534962510296308`50.04258906970447 THRSub[2,2])/(1+9.7054933442429090854231771657926672886910259240852410376288794260217415698141`50. z),((-10.74503618035727558044776698379726749262775876729944894482869589001739805330487`49.69897000433602- 13.67297596153965421998446209874492047716361410681344050268774533956512256585023`49.607351175670715 w+4.69058932430454904462651440747121269817208714257368409452489791348881409850582`48.943167743804985 w^2+0.02490387031339534774127498793238395085074110673898151069678908832422672599964`46.94088637840199 w^3)/(1+0.93510770277436190287920037500938508960770232081507766756087365572200801463111`49.52287874528033 w-0.27401962912247124460140310719620493587339718798086833792993217575971457953751`48.81637949950315 w^2-0.12423458253603822137263955692075816491787822559496173846075803864384826400417`48.722620242456365 w^3+0.08309121491088303399761706424318127900527062765533731891780564474364169575875`49.61036352222971 w^4)-10.0055631749865037299555551932526381785824833790969835681876197944662910312663`50.87933836128847 THRSub[2,1]+1.26342902653517276761512826201240703192003926275013052720040418794078281539787`50.87933836128848 THRSub[2,2])/(1+0.15210911974967253085635629860089266190342624636140587649900478875126236691342`50. z),((-37.7486988273813877921183137308763771578514079438209195376746859552115833651165`49.69897000433602- 218.4756575336252828628409965817653402319879595083999634884776`49.69897000433602 w+69.8328311915333531987230965195926558553743014766049517939579`48.98138843433751 w^2-5.3828916607129942069841688624507447880954043982141347232584`47.89972661708902 w^3)/(1+1.19244777316479074896717020015652714903196261320549562337077297613756745388136`49.52287874528033 w-0.06184810770841749250087605123894191350934624355654153750805219956040108487975`47.97427109344923 w^2-0.15899425763863025561871334695343684526101886566583534597030402972530768357826`48.46566332381396 w^3+0.10970188346726927023043595691958574295644678792161251210483763072319750132304`49.03453876799341 w^4)-75.82188294399480035263116072504248249164979144298898323460115167452260947556621`50.05283055880782 THRSub[2,1]+9.5742304638563622381331059735148001723950899893579871418231373870512255976905`50.05283055880782 THRSub[2,2])/(1+7.73065126756209701138993064669194398445062396044151271850926847361947996333723`50. z),((-10.62343759636023188863226583444983844668032540663194626538283895726709453410307`49.69897000433602- 12.42016998628326266658171726455300847280500998949560427013550095563294143068806`49.59527057595021 w+4.41534814187072912230537231547074709253008284256558100285921228297405586223684`48.95058921705072 w^2-0.07532227525837940656871943836048681593335743484539945158340017318569598845961`47.45006146967227 w^3)/(1+0.89987288405321118156240011718815537774117464137324444932071447400601496100646`49.52287874528033 w-0.28855225353033328900760541349908894526524075725264643825022347702146479574024`48.8532647504811 w^2-0.10672807966439083267799714993248705650899922530688013586624389781801841747776`48.672598073210516 w^3+0.08017521196021352211683678761834097177586501523865928178388479312026402340989`49.56679392572982 w^4)-9.70918962772290624723229042946025284266587691317813700970697988395414926783639`50.976616955885945 THRSub[2,1]+1.22600515186051927744726499240352899370793507443209326361352924108531991696382`50.976616955885945 THRSub[2,2])/(1+0.11798263824300693089056766080723624858545929556722570391845752893271951196512`50. z),((-11.1431944543489917459231301713188260330586228667913001219871919525777776442736`49.69897000433602- 17.34269825068695762841830610839737446073051534354349811051818418643843310076467`49.63956856738592 w+5.57664935484603772002115413174016313196260119611681992689027077399302218445426`48.93322517668859 w^2+0.19896952831403718589485464690075263724204711293240586996637173427002766968323`47.758739155035435 w^3)/(1+1.00629204241608601051266694123375817619173531642962108153519792894744470137995`49.52287874528033 w-0.23683157829077866449525363568198922227239257591114805598460364915284178715225`48.72455454809033 w^2-0.15575334189188187915127163656377296883623608695785669093674329329643669917698`48.782782539281214 w^3+0.08844834273016319250975093179594229775739684993030715020016657955819378367102`49.69897000433602 w^4)-10.97599865339754504336577770201206625413291664073150514321153568694814257936267`50.680336204797236 THRSub[2,1]+1.38596849086729522415266485421148497487495441610313140868051029230059877855514`50.680336204797236 THRSub[2,2])/(1+0.26385171187093063852880056817752643195076995291139900616488907135768081817353`50. z),((-24.59905272544223363285590084027953613072790907258998183254256958016209611289268`49.69897000433602- 119.8944399542351369604506786772777467305472989679940872105916`49.69897000433602 w+37.5488635027336280577635956881765554129103184286627622647148`48.969074090063714 w^2-2.305835829520710606070997061815414395772856450978165141618`47.83822224465873 w^3)/(1+1.18442142413103421441700906105241415559307083207812468244233749568953910460767`49.52287874528033 w-0.07296840468625730445244173519999911107232720136666678930815792259999262126946`48.070912146933644 w^2-0.16441075433746822483833077099450442665254489927575540131808494643829537666108`48.52811888470039 w^3+0.10672727515562563515165430963082847858232490965966007987554429401269546756357`49.11881684387468 w^4)-43.77210791875771930445208416558447482193395382700458935418984085616125732092801`50.09604446829785 THRSub[2,1]+5.52722028035800088059848547067993635041845136727304478543811578570808067985203`50.09604446829785 THRSub[2,2])/(1+4.04022050952026002911667911180050905705001482243796757879809044889931444812306`50. z),((-27.56680885693977337053148392961139577686235416903218373286655885608491308310836`49.69897000433602- 144.0498112311174156054781686937343631644359781544393348679089`49.69897000433602 w+35.0238962427994197701738009693871612224016862897412932824257`48.928402405372125 w^2)/(1+1.25606059570115071063233139111913287765176925233468435413275426173102563730733`49.52287874528033 w+0.01340604140107969633119954784331482046244747222536267347160580690450604998137`47.55287195709205 w^2-0.16750631823500007568898667786310686480254366977578976829836317891073040083165`49.19378079484648 w^3+0.0947862751647303584068772255456636819203275071609622505969974878424588252428`49.48938850781811 w^4+0.00687166464916004032397596688025082612342236296352285500939734114803655110627`48.520545978938465 w^5)-51.00545211729379201137667605065204222262643592284823841013513788718593886393708`50.08106180892758 THRSub[2,1]+6.44059385658976525964400447443948278802275929828987682263486202448261792132652`50.08106180892758 THRSub[2,2])/(1+4.87311733618319659774799162883862072742672689954003205473168666187062778776091`50. z),((-12.17149161687197104887564253996296366804627993768035543725716149652226401716718`49.69897000433602- 25.41466343044621281893792202574785372479418668574246568802032289141628303132183`49.69708482665137 w+8.70008889521679298333602048492831673000332647081216952777309652142674357563569`49.09518835807387 w^2)/(1+1.05310765651673245019749141683463712683539053574623783077692683908744074570068`49.52287874528033 w-0.21434785131849625283964758566271220504039068018483665325137856258427478666274`48.845284163412614 w^2-0.1721226514939407706009590396424348266362398088819789148431288198980932917166`49.475544046421405 w^3+0.09907224548008489152996481110572929260756251630382276992542852014359300132193`49.45524088603177 w^4-0.00305641354550032481983597023386250529746129391957587411778923875950155825156`48.29916197426159 w^5)-13.48227847739152119124982386485068934664939969408691980323282556323443903848352`50.448728721027095 THRSub[2,1]+1.7024430983306302053920112341193733039057334322446361283534473464999391112153`50.448728721027095 THRSub[2,2])/(1+0.55244194825929455003805721501232522393991184334089137626771243436671923421697`50. z),((-10.69666907834373522881239134909727545261765154484086849633511450839639235574612`49.69897000433602- 13.21221942327264898036268796592519667881593983185696314944607382424634254062019`49.60253238902078 w+4.54973536945125970632545536787645272419893010920124980564268359564560674857881`49.12236598163506 w^2)/(1+0.92470001690807830801609588489186112511008577686544427953913213570171165935446`49.52287874528033 w-0.27734400969997295564496007149430654967158768744083301850057373525932612807815`49.04737254730903 w^2-0.11861831435658131002911769096864662383056723756729538867106669512953448613023`49.69886912625355 w^3+0.0817576751256319391929752368873808119039766929947608021314005955359268960217`49.465430576929194 w^4+0.00019913800514391245846453366403231367411384244356157701962884865327060939007`47.232830618955305 w^5)-9.88767751280673896618882235092888593445836039274110278848518376462386539201476`50.914786996246626 THRSub[2,1]+1.24854329098931376798989754802146027799939480295343542067666133389718024763063`50.914786996246626 THRSub[2,2])/(1+0.13853495664563323774586181166717079148625997114899328483413809678913749269481`50. z),((-10.71433586995545200208340968379133874382399240772267373278522413417732884944108`49.69897000433602- 13.35964909056458402077350021058508409994304286467655222896948118854379996720191`49.60446470105205 w+4.62901071402119172310437782961151915186294841571988085043415761086120118661021`49.12396234638339 w^2)/(1+0.92656476109687474265468754345377403533561507189954055625427102460074152308699`49.52287874528033 w-0.27803443880860110312803608130251805217400247054292932584560267281570006568614`49.046164155174395 w^2-0.12017632644911864226172590596835173677968343093188033523987741188152647917505`49.692721803498706 w^3+0.08251008381743787081132507949907635332564907881516196136484783111753785410671`49.465858480996104 w^4-0.00004582469370633353512971923589361983483991313903449325008344161736698154679`46.59262510322157 w^5)-9.93073697556214873060298253939490989153197210844455541214086083119832065521349`50.90140248178636 THRSub[2,1]+1.25398052367284717330469598224331811362402148956060462311016439611560655066994`50.90140248178636 THRSub[2,2])/(1+0.14349311830674292028735064161407104452651130358200399180244101259824783924533`50. z),((-19.91824480624312490922234290317271897991117530744136968968002107983856692657438`49.69897000433602- 85.6941935164259691616128157374683902799524732256727969820716`49.69897000433602 w+22.0962093340959218506008132401026529011524689958487734157335`48.957419129958225 w^2)/(1+1.22374823933668831413750249164596719198992311082191889566700550759018723940218`49.52287874528033 w-0.0275733369734649398030559304950383736233782349479195390740044191939642477669`47.88181425258643 w^2-0.17300937174083916491066562246547765528065453379792109014586198693752423444535`49.24566510959809 w^3+0.09543930428043408240042021919796193352711749368247941595814884685833349275596`49.46901882464949 w^4+0.00476764433481588924707722043456234526733314317583419469972012740134620548764`48.387500244342654 w^5)-32.36352402351839870334240326721010627563046577381565815205262353872967874772883`50.135693145787634 THRSub[2,1]+4.08662810250425334251424610834804085174195869088097298601531113969385045372986`50.135693145787634 THRSub[2,2])/(1+2.72655796806594619349983557720421262949911125201816913103832138412875196240869`50. z),((-17.79025656014780025818338095142245765014579663205334055967126976600135297047967`49.69897000433602- 69.37214427218148479020489574055791685561372232724888227606`49.69897000433602 w+18.5133618583306672705316135948544549620443297756150120034668`48.97425270895888 w^2)/(1+1.20496618227878960012669427487122731694473831691089242145619648170713317935612`49.52287874528033 w-0.05070915365711543103327801881581182559090228199768450708214082316526422291404`48.15380526563641 w^2-0.1754039631604017157089706487696561039417721029788692569772922772581758051209`49.273894115205664 w^3+0.09595130008376582919043814481487561692132860033138875084645858419759066193068`49.461238390559835 w^4+0.0036313987416333681373444968339619898194613345833427616363631570786620019461`48.28350509918899 w^5)-27.176955197635971423187561751758935908558466306327172746619913537541010935737`50.16720768121236 THRSub[2,1]+3.43170628669640421724600789042559292336005712538575801455441429504413724756089`50.16720768121236 THRSub[2,2])/(1+2.12934088592838265025666334084473168323848454382055549625212589009404776183094`50. z),((-29.41074992096500370927234114622928306437370679560350491235495696599263605752484`49.69897000433602- 158.0860320153241806178893935868209188987853250906436747876013`49.69897000433602 w+38.1507802418078812257847118767680753959940925496127866894795`48.924685711998144 w^2)/(1+1.26023656515661773525016317760020262444248970453305639668618055214664914048637`49.52287874528033 w+0.01880677719749710985672124729515417381505480570831168475981542066688730972173`47.69702062321164 w^2-0.16666502164901337106871289111705120953543110719831301639968060141080854214944`49.18671023602725 w^3+0.09473118535768759462579480359715632395833428040476735912528311516013477709205`49.49282311458835 w^4+0.00715837145870957465325626350847534521380575300929434300917950233819022650917`48.534831476139075 w^5)-55.49970966640683304915255258111622240020935142965866564032945748650489579022257`50.07390431438074 THRSub[2,1]+7.00809568941707135590237615676212856539618886474148666196688611888933439412315`50.07390431438074 THRSub[2,2])/(1+5.39061695297452535642956197397941279767047133976109245755604755217260952136811`50. z),((-42.77168762013946890490210183954722474929080400208265340780786694470521982020669`49.69897000433602- 259.6661630845159605079861312657947069167493404764713141035999`49.69897000433602 w+60.8669442037678228031816860478791340982741252516024659999516`48.9101037287608 w^2)/(1+1.27683115577280232728944816840377463976308750313477188354197544723652433564386`49.52287874528033 w+0.04049856838258829837899648787762822140746617838295969126765749970155133968655`48.018815371135794 w^2-0.16301869127016704270170352551857299447155798694986804263680902812323234429963`49.15762856849086 w^3+0.09459934407882142284566594449206229574915544097716951565141469833908686339041`49.508753111768875 w^4+0.00833465622315224495658026211564103624791898436128546685175777660860737016776`48.586718103666406 w^5)-88.06446799261017294781108511036866638489604005528381328051632626652870764589145`50.045090136015794 THRSub[2,1]+11.12013418159157556897328712248885201479327423126911557858184503188001579412798`50.045090136015794 THRSub[2,2])/(1+9.14034641786429721058441359211946240904126666016702492663240887636551394081514`50. z),((-10.58201333401253596943109448578852921444149882540431070852797754724362826479609`49.69897000433602- 12.25411141130268443502775073721294599136367365304470607975061820938299781892587`49.58910974894211 w+3.99462314367651087417646445262799312902052073381008228118413561013388629248003`49.10774153036529 w^2)/(1+0.91232345897568700385041362670027214238915331511061173776463387611849748248705`49.52287874528033 w-0.26985260544828028469409566243333881449970315037742675798646668348854112783627`49.052799427025334 w^2-0.10735025585213495941706269679383949180569553086405548812199023061817660239668`49.69897000433602 w^3+0.07597825830074150675109923525178799739934031290824436633003063795783367128069`49.461363326639734 w^4+0.00213663006570056443841224787000795425961230218911224533823321231446455226653`48.27605919287754 w^5)-9.60822582394158097909385397218393914459939009116068793712859227417941508210111`51.017129305629176 THRSub[2,1]+1.21325618430158923827724102338076879731721794723421082233680559163903103736898`51.017129305629176 THRSub[2,2])/(1+0.10635697389340991615395822425199564131134887627522395096076064216619001904252`50. z),((-30.57209271376436771734524071731141509918019539608502316003275582254415064071536`49.69897000433602- 166.9229356040067153577408993286508532103872794164447879491888`49.69897000433602 w+40.1215728504530433288850427971440871182594112838410744519127`48.922678265890305 w^2)/(1+1.26249929528682294109774417566948110391069718369919813126554848569201900223938`49.52287874528033 w+0.02174293384476474526803131427690836387321810818863504997599877662917189784399`47.75847447354541 w^2-0.16619648187984844512286095734047370088650330293053129727036918250703864779096`49.182839519455726 w^3+0.09470475594067906277702051544304451196552250602457870089277317171560474730498`49.494774237118904 w^4+0.00731523496709660845866249169825933361503292891051923262710959813060932703821`48.542350833463054 w^5)-58.33026304768081725364905773904865695078911382929988119496806558329123459454637`50.070012287898265 THRSub[2,1]+7.36551717989340883068128268584153319736413355439926570826098264585547972920274`50.070012287898265 THRSub[2,2])/(1+5.71654626924296498742452884086373636147266518232102246141252174487959687732403`50. z),((-11.19974756619757021590985144957313853282543459900488366835052229061669523814697`49.69897000433602- 17.41408012460072968282162922292642294686990900840983668776595165244942016601255`49.646816542663046 w+6.36902650372481380179922821235044279648549357690392665225023995091660590932032`49.1323233965749 w^2)/(1+0.97582593087300138438765684220289940872285540133477954648103744924045393653445`49.52287874528033 w-0.27036262139919365097180481871901720483332544585035831482110823542070536461593`48.99028816801354 w^2-0.14988969202669352331983713121331069149968246655688839727450027679537048041351`49.58414988076547 w^3+0.09438103623898448938260039123932648107942426692001024035582396328581216817826`49.46642439416346 w^4-0.00336605118500693005190387177312496529870497176855267269905872485516767023006`48.39442666756863 w^5)-11.11383616610875947780532083667291576545722348930910677058335625815431925968333`50.66038747319159 THRSub[2,1]+1.40337359955124434722507905419240511021906486866615319434996543100645243891548`50.6603874731916 THRSub[2,2])/(1+0.27972326779046195139646452227341271342623347605151290263399995486051360590111`50. z),((-10.58908904848373288129438860501004365972979252457495489881291993331268910626993`49.69897000433602- 12.31341201435178779429080514862339802524291872196602968480972230257717364330513`49.58998484074547 w+4.03110499526308853602796229461988685135666997374759738175195436724622615665292`49.10889074730799 w^2)/(1+0.91311136395951695207577311859628124042553627565903337906651044985125717106564`49.52287874528033 w-0.27048689850134913530411158675933964744634864096765776594083223217195091680174`49.052595142502994 w^2-0.10810849848683685992056500817148579406682166392388505069646445817723653233918`49.69897000433602 w^3+0.07638510242210692192505296009473056461099875612501965887303539039870069163028`49.461684922188624 w^4+0.00199777712217593704153371010599014938977786008501833818052057035399423552441`48.246036355764694 w^5)-9.62547153954386120200853446069587966951790322375414053419748203083939470620451`51.009874180083536 THRSub[2,1]+1.21543384659747701903506370969175424385986409483193074978161191186699484986173`51.009874180083536 THRSub[2,2])/(1+0.10834276378594368270348457614500342043500673364402339614113568251240815317124`50. z),((-10.85617082612400903789016107930493562531461613354385499853381531792527176149115`49.69897000433602- 14.54395428069188886968268311601422516887610598824721603226880203160648336142122`49.618819237273875 w+5.21544067739480195978565237698067417045997704277635138609519846213735799520982`49.132174462619766 w^2)/(1+0.94137917233497030113911318124990969439470454979252631404646314198840843488312`49.52287874528033 w-0.28020964808188861258952900553432994814667314554570686712523694852042825068283`49.033609227944005 w^2-0.13122719400201972212276689500190741034475088158673857182542691717170950553173`49.651540057078954 w^3+0.087498159608745553664032956429784864095545829999771750754229291143534871657`49.467823209014064 w^4-0.00160165369608471669598916800341429688110743971965849430054864758453346851955`48.111373052250904 w^5)-10.2764328521413866889276275996750861217374173272491919471066009696873097593151`50.809934580346216 THRSub[2,1]+1.29763245981929192181317549186279507873739516488301588079932404926675612380336`50.80993458034621 THRSub[2,2])/(1+0.18329891085448069520616093247429215977707771761193549430302683677877542768958`50. z),((-36.69129758705633710301191622903168088511164048017901133946738061506876783192017`49.69897000433602- 213.4566231872412600914052012905846906153943502324960331164037`49.69897000433602 w+50.5195293777727798535067738747752356933016645651221285613532`48.91494526808479 w^2)/(1+1.27127548269292787420818189499545681523772687025126395809704472891809249897795`49.52287874528033 w+0.03319572356581930930258236982438018096993061406134033394813359118155454172372`47.936242414501784 w^2-0.16429397919883625940482257078560549166881542978883707008345725426683611783951`49.16754936924364 w^3+0.09462679959048803226085977628030897287996936938565055784073207422835260505848`49.502984383074946 w^4+0.00793404077145299318079809703347333574231656093210732430994644145447939190508`48.57015261301978 w^5)-73.24466743559971859605343350379100265399751529072979365795156025620267517200305`50.05481178101779 THRSub[2,1]+9.24879861919187231157497932446533130836371735708653673332591164091332817895916`50.05481178101779 THRSub[2,2])/(1+7.43389301029525730160792512039734761826974672393704447322172193627420147569321`50. z),((-10.82967263127119883831165915455751930013142226577025249537083259094723631197478`49.69897000433602- 14.32257430713441231497109210176655819564432019069374357034304949071493594092258`49.616284298885326 w+5.11203789399206624140690404781254575278871380035117869789231515628891812220112`49.131169782179846 w^2)/(1+0.93862958571041575815328120540703683781248119433409323812845424903830734712338`49.52287874528033 w-0.28019764101683022259570589253015961845139919751385527303299487053635193015441`49.03629217328775 w^2-0.12934429127541303375153989489257221733360660912321451803604780478273255670425`49.65833949464401 w^3+0.08669282398798293782829830101593939753218023005233859607802575064721284829135`49.46762633402157 w^4-0.00136031747243878482200677402989102939184758993580760611916132916559696388302`48.044544225531574 w^5)-10.21184851450797896410818446664206805703777516927001153844094727426619043120873`50.825183869790045 THRSub[2,1]+1.28947722403710364825707370946294365599955363346795161652152808567614240452203`50.82518386979005 THRSub[2,2])/(1+0.1758622275734777355559024979464380244035923206177877790262896533738564303412`50. z),((-10.98908043759412069732485065515589772108179370251501986537230070758574081635892`49.69897000433602- 15.65482702766153185115748032320722828718510048747153310383557910846390501490249`49.63064216631604 w+5.69868059434630703040635953383748444614369023414931697651710442206759948230129`49.134560237635995 w^2)/(1+0.95501374511736465179601188045546094293512810109168459421876556489197724390273`49.52287874528033 w-0.27823154351348535106906784046743617222296126785079336231508025084448313047585`49.01840338602327 w^2-0.13959966473492042575005684599688979912212059773174636208320615450619210800004`49.62169088755948 w^3+0.09084330688545395733209573812158125056395794217558726196926875922056546452547`49.46797148744646 w^4-0.00254372119225864920154174275437030630158818564174629091730707453424409534127`48.29441260172925 w^5)-10.60037488931002007121889191754879520865533388230820529806728368701599511654428`50.74296815229399 THRSub[2,1]+1.33853748090765652491094567598484364775128520552703723360967376691215329811941`50.74296815229399 THRSub[2,2])/(1+0.22059981723677169807776989786232153416450318931758677104186341594567181783733`50. z),((-11.68264224273210152193331449789656215983568813334704737966892179142464979990744`49.69897000433602- 21.41731176930877206813890612409209846916300891795482324378991482675744516541336`49.675554098901685 w+7.63136423790930526325833707935916989422868722382913550112781197078257489444342`49.11566688578055 w^2)/(1+1.01818690194419225446837599711351331104608755106900995597094246831550177662008`49.52287874528033 w-0.2433779862282715868521821577240253910475770200843124956950476660111260196409`48.918636207364955 w^2-0.16449588946548149168674028201058786161955988948407094958030568119146621976036`49.5215494071931 w^3+0.09806557621913132910058834385746449975249668361631833265236279024722794452472`49.460485817305596 w^4-0.0036502734429835869083014790508682863955531344354136481275575877055750879339`48.39709201613926 w^5)-12.29080059723014491996040413014226322917729231424694375507635190717729417356738`50.53252572536704 THRSub[2,1]+1.5519920230694408832554214260809637386652303322096694767791086921721697026771`50.53252572536704 THRSub[2,2])/(1+0.4152470190277592495339613019382441825830993712945315255405810328345159298361`50. z),((-10.62111206426039510148052269486923590068293936990140377175735803628234828139608`49.69897000433602- 12.58136124988003263913651263527618719461782721786023897001503808850128340456776`49.593865952845 w+4.19236154026979204193203443715431373269789355519619723879087029388197250432381`49.113651812941704 w^2)/(1+0.91662350016331687017791031946072048017587136987890955966768228928254329654128`49.52287874528033 w-0.27305250648832049614878545050669068018081931807120152439280442972527279046926`49.05144845898458 w^2-0.11143163586084424850858136548244986356511704693931227483644024695289548524105`49.69897000433602 w^3+0.07813836043002221370978216970480158498594478117270736948030697800155415502195`49.463019690813695 w^4+0.00140294194360085862231047897532198390703628978736405565735755084333300255882`48.08884122251882 w^5)-9.70352158312034124019730773504904897591482780562217916133444111186856829923124`50.97877245274118 THRSub[2,1]+1.22528943282008792195844637819803184305037932375479816309376493848254999663779`50.97877245274118 THRSub[2,2])/(1+0.11732998074002016261408619471369392142220529120004301684097419776372777889898`50. z),((-28.78272501633554198419280607417341519617522038708619261897737571207732915193823`49.69897000433602- 153.3062508211350731283885969635829029857526525281803997717519`49.69897000433602 w+37.0854674406958033648329573961459335358722617453000738301324`48.925872008979574 w^2)/(1+1.25890189776842053777954884131153077896855301865063515917306282926889836005668`49.52287874528033 w+0.01707811306010221814991065445830741935567405174173232043590241682331593083291`47.6560611711169 w^2-0.16693720046626991130382356182730814363071349694424328688154791242492025071315`49.18898020664048 w^3+0.09474791820200455857651203625232079377098849046166675902370182929984595608992`49.49170231822461 w^4+0.00706634723712822944743752932269086588423038689770075682871689715878588257556`48.53032438265593 w^5)-53.96901775670958465741972322920698509364350944176715183242773126228129732508904`50.076195362082245 THRSub[2,1]+6.8148111580446863390683134283679694896440299959724339501814579071008710600196`50.076195362082245 THRSub[2,2])/(1+5.2143625954888837892688310506517116342568307804786588351763503051674286204328`50. z),((-10.7909178019602106286430138098911830068625150521228219937335213644760666775654`49.69897000433602- 13.99889842672949277511755597088635541362591115502215007951084427709120081849546`49.61245982777898 w+4.95598311420444924753745382357339368967035476907922129241846814593341178320764`49.12930252479445 w^2)/(1+0.93459337162135017601530183670026845993545809767030394867774271965404511181736`49.52287874528033 w-0.2798805509887310581251383848271033643503103110607697222310453684977344485624`49.03995894857899 w^2-0.12644702865824990630939237113902246300368986069223414581298377084894233919789`49.66893899289838 w^3+0.08541722453898399478993049872637203564592724223811370299676210349614293515914`49.467210493880046 w^4-0.00096930535224775210085024007695770247047753978478281090230862343988686957175`47.903752893490704 w^5)-10.11739094881155553454770060924619891038533201064961902010549286644539453807845`50.84887420927734 THRSub[2,1]+1.27754981643499479868069264983410289756233789988370500199906658686488692653201`50.84887420927734 THRSub[2,2])/(1+0.1649857360692051583870982359813774008654720984801851078367170823817201246506`50. z)} /. {w->w[z],pi1->pi1full[z]};
(* and 20 each of [5/2], [4/3] and [3/4] for the Ls part *)
Ftri3LoopLsNl1Pade61[z_] = {((-2.2229477978828812264168371767532354747776183359917461239000333777788240483446`49.69897000433602+ 1.61501855361062150679808694317830868567844520789350333145188351919234304097616`49.149949352141455 w-1.2677983977691958823106177724051950895374326652954897363605831851411310753402`48.794728630032616 w^2-4.40169128061433652795732847768291082059768691919457452049784688625943698744601`49.123870941258325 w^3+3.40816007676266826818406336711257945102915727396537065029956305151789057404081`49.26354344873004 w^4-0.63693031531182588059524700184251858210770739359632376477550732007867489668242`49.26063769272893 w^5)/(1+2.20872723189776727190595817647074911758034280274464435440853618585005091989107`49.52287874528033 w+1.21641672779573619455565553516255200754154647168279507519524785742728260926848`49.336609651878085 w^2)-6.50126403463029359524059771894975042028605715489350596324614620101621362544752`50.17872023338293 THRSub[2,1])/(1+1.96422095222045794825895472843461686145256671789327139399561291004063013812439`50. z),((-0.65617869390551497902609302008746601815340643707301403730835636913914933183587`49.69897000433602+ 0.70527368449796335806181285808221460128843160901662483246209792778287981518381`49.57987608859786 w-0.94332624779342203069724007316592604959767615062870776155528985486673310426552`49.656087427861166 w^2+0.26503730950630405167489909264605349991301505224074559957336387184943081023046`49.16006148407853 w^3+0.07402590092986574338845373738100162450822536196113834273155330998029021272565`49.238578553368036 w^4-0.02730674811939035171016766451655114405940394652881304915515943415920014484747`49.255664860927915 w^5)/(1+0.87652531126943744567431406252523121491352748580701227058722573040589454692188`49.52287874528033 w-0.09075510006953707501431810639772904219560446141754648896542789049256104723093`48.70853426039254 w^2)-2.6825607091041550822319342592849345453113381064785146298868928238800887404421`50.73896077556599 THRSub[2,1])/(1+0.22310101807487868858235032262768708419791660461315329933654924185999917580907`50. z),((-0.78472598674118472272812197630770136945252963332306748617130496013710127511228`49.69897000433602+ 1.35356179329902078999024841247204925219661263105724411875972198831648223605784`49.69897000433602 w-1.83810984157197045489188054734448938300499399745180196315922180551711334145493`49.69897000433602 w^2+1.15733975140550927221280329506820163921737973618804756942514834321369971007837`49.686037118089686 w^3-0.21854423172336162380651089145010803004201127886389782461882294632209836973306`49.53500614388976 w^4-0.01419873775119494012142318186568744349428066484977726702002567367401614502158`49.69897000433602 w^5)/(1+0.45513679829155240245153117865346072942341720969671381712987119492267684171246`49.52287874528033 w-0.50808928956283294346563677789538632221269067054889162778982540476116369316074`49.56130988429851 w^2)-2.99587041976465186010422212973932734223123954211206139162726825844235663889781`50.57201034345208 THRSub[2,1])/(1+0.36595311636329826656829408647608886940685076629956943901048995405071495059478`50. z),((-0.58227474852273546747650727612235450768304391055089531318645276864584859651178`49.69897000433602+ 0.4429508638027671024138449947496556792111278740534605046550016293557905128683`49.4359966034052 w-0.59408538134970571473675202939816476300753386110780171160510871381031343314279`49.57646555329618 w^2-0.00603751959860622553855243721217275172526101559415458746319423507617301076987`47.66614483061005 w^3+0.13566851440323885343197946914561467974056416875130364238554660642471646303239`49.69897000433602 w^4-0.02331626809189842716981390471866561028077124160700093261750746172863882055519`49.01188233104515 w^5)/(1+1.01343930500466232413002487545221780583033100230749182719635935883036236729496`49.52287874528033 w+0.04742845963468697956273187575912633291894541335964832484765168051723515843503`48.38418669384911 w^2)-2.50243382168577822749306847718971743889837340073418165937269888944966288217698`50.90813941035251 THRSub[2,1])/(1+0.14097300559919840821703323825182383551972410181646826682406424500614178494071`50. z),((-0.69872669561475265526472014680132644792630626855153270648436175578992566029645`49.69897000433602+ 0.88418209869135932097858071366691847041792164917562426087548398464910979054689`49.65394830342735 w-1.18613638331527461017231806659184122498955659084386152762652321632715727500581`49.69897000433602 w^2+0.48217893789868125012218384164508137071941221896148830902627705124782588931023`49.36267261976175 w^3+0.01158409750093286277398892614621028869293120983753169918238718913626955394333`48.40766805353195 w^4-0.02665701630298197902441085367268979036486697277921784857246110575227336370504`49.392879871843576 w^5)/(1+0.77093157548131889434915956715487346191361971988093567859978655191395876749969`49.52287874528033 w-0.19579298277484995379407253520390489537875747298944164607315861194001579898536`49.06474788596754 w^2)-2.78626341501601797100193568923565297040104415533864788310628086321381101795725`50.671954302148656 THRSub[2,1])/(1+0.27038378216944311842680028508866917764981291124095530888039848965593228462036`50. z),((-0.62934768362559820827678766561784632095424059378990122254477244741495240798588`49.69897000433602+ 0.60397426657397487560461129901905683194584435332373412235685983892947694062794`49.531266546685636 w-0.80749145589470406373525960630324838369300860087091851238596350901100115757338`49.62713622732326 w^2+0.15341900504355781234741202720110751183622411481005559343280641913751094697203`48.96919044199986 w^3+0.10222424516808188112374780632129920586951093723655241792020773183387657579904`49.430025662867735 w^4-0.02649291796008351358274572397591899740285545256076816375153370488692012926904`49.169291232317164 w^5)/(1+0.93214731429202450188665686259968485835490392935609364364249121847470316729606`49.52287874528033 w-0.03507165493785237907727158665439845413683842432148695856425587851592207188258`48.285511936496206 w^2)-2.61716519682155882873727094675237988357384685135156761909325620480643080709118`50.790547461056136 THRSub[2,1])/(1+0.19328423988271508206368629304178348776774602572078936624654158820912791785685`50. z),((-0.58279477396385060190421317289473250520729708893112616075545699967298374701369`49.69897000433602+ 0.44462816157332661270150237139975915031560199967407367203603180756039706815414`49.437155579917224 w-0.59629282741247686521972649463747037092348168889143425971727350017291499812732`49.577046063093185 w^2-0.00449424894041233350331011844804454401974331369276277436656181918304085699568`47.537608650791974 w^3+0.13539483998146977679569506417675126272765758112253742712534541169318520441946`49.69897000433602 w^4-0.02336170206876353349285640886333297836787569249009474751110809490882123657122`49.01369001748768 w^5)/(1+1.01264379005605212605569540780019021632690500119062772950957283840094522359858`49.52287874528033 w+0.04660889002068571267949146603980931417827707515423881632253447867834046906739`48.37704419735637 w^2)-2.50370128533201901296226401382769902172442574027033609382960418640847504586041`50.906582646506635 THRSub[2,1])/(1+0.14155089972507178168928567536624999435384081986401064221528735336609503638246`50. z),((-0.62140430925223555277022983116368160970516820983400826698993531577908260435345`49.69897000433602+ 0.57541138749101349170540017324940557292550752506095912505137731748280231911559`49.51628358566444 w-0.76941247512693221641102125002064496536104086931356098476611042468119532860275`49.618689340869516 w^2+0.12349675985514373145391784696774992820416786153057210424198596943311703686365`48.89050502456677 w^3+0.10919442687399058092903175044961807618080561215032935128423459813926452744989`49.47948417034117 w^4-0.02610112844829298802342317265965375524917717974163869280043147162836574379493`49.14341902868766 w^5)/(1+0.94723939101780246706732326282150273726585071770845796017614901410854842410029`49.52287874528033 w-0.01988800863284908244415002524057730636157787541713751488312775398350831577082`48.03669021476925 w^2)-2.59780472433173541482118501920854527202748034368983902415410359955529681968161`50.8076243110875 THRSub[2,1])/(1+0.18445692293426786275838040688768886200467625757468302728863171588473687766225`50. z),((-0.55571638490171872209352440530364756668051374236420416804405280915191029254163`49.69897000433602+ 0.36003132821324937498536947306842101911872381085844232522604917586164109475754`49.37213960667169 w-0.48532381688696634779292207888927117176716963848619614840003221451012165577165`49.54522189825827 w^2-0.07912194597637560361508180608258420603615491106010607741941320515443752515323`48.8058898112446 w^3+0.14715375587895414197754832892032255595971539603735544363696554484036260107807`49.69897000433602 w^4-0.02073407475928044709652486949728111807042393963139037190840270695052418779785`48.916634494517034 w^5)/(1+1.0511124090274252980244805735494601583889154430698638389637053684557664385105`49.52287874528033 w+0.08683147763843720877887798625576301473765834206059844709770660167956197454788`48.628367586825725 w^2)-2.43770283406121362631477806252536995849270539263935186705864499214077172388871`50.99877755325351 THRSub[2,1])/(1+0.11145921431913559208259038333286444528977822893826957215680327336074875818318`50. z),((-0.60525334959247175597964229976251657406802100475587149397624217130590837220111`49.69897000433602+ 0.51914730119370388618804196164262037526447782647870500214449596370897326682108`49.48464042105433 w-0.69468868167604670809865335266598386704492340778628519066540178580867878325828`49.60149530504858 w^2+0.06659971986912064287872797962951514079724610877421599678761531106611407406885`48.656681819049204 w^3+0.12162939478286831375726636001603972464018855644498351798609694574783249054599`49.57786499335133 w^4-0.02511498564929300559383558575240433175491677944248156151486126141517620314667`49.09009136217235 w^5)/(1+0.976153776182860501148189059410314943641128049458826163612388192086891404021`49.52287874528033 w+0.00933727030055557239865023101960214368303985466861038936388114182483109441598`47.69971061101512 w^2)-2.55843981522891365211171874982648764122972030790290166265857457742145369003962`50.84545110437172 THRSub[2,1])/(1+0.16650867660504864345908420202267466843839529339486489701834037914097049336467`50. z),((-0.57026762814738485803527147997200986055493726111881364303459544020224862137117`49.69897000433602+ 0.40480330772043725447388809059938552696351960402306066454419557090103411413451`49.40833542945756 w-0.54396265072793086983269977347978286100997205108651215707681610332082494041885`49.56278173837663 w^2-0.04044791066941824740580823127176958997374968197315265156420423424524687856144`48.501023167427924 w^3+0.14145444730433967602167818601855276780201508647354216173049230550259470386299`49.69897000433602 w^4-0.0222107466465541953054464796364012815379680760275497792846150053517903261931`48.96956850865753 w^5)/(1+1.03119308284314168501512956526946355927617449993725548024055651381295915645132`49.52287874528033 w+0.0658311633203620571774917858358083498750467895597859487703788327011587256322`48.517402992036594 w^2)-2.47316873700230695611890361321308849019007983671463614602620397836335309045376`50.946214676069076 THRSub[2,1])/(1+0.12762972701134689254224528795669998223254460877380239832929711805920805719966`50. z),((-0.57734303523933480141554430330969734086321811291440702843157900883622786397592`49.69897000433602+ 0.42714854978787971549374041677918503620009025806896205512694186842239941858495`49.424850325366336 w-0.57330353743335054093381878009354457179470493711841286113078708852668078257956`49.570914265375265 w^2-0.0204523536271217475435469136007517840749777312147946557097156058564894593879`48.19940484800218 w^3+0.13816752199362039156929864744139167672532511094821155139330129913347763197371`49.69897000433602 w^4-0.0228751429435975839031911100734859024153549870476625809584749417158981370131`48.994639378073344 w^5)/(1+1.02087387641507161521791554503759709916280119339655502482162534676462461391991`49.52287874528033 w+0.05510705246950408153928536834328714074696412457549148568001459944147142671405`48.44542317954941 w^2)-2.49041370342581564434606416363714964982017307371386550306193892758639022645774`50.923269045375335 THRSub[2,1])/(1+0.13549248885590711925599359315970939251415549438201616975005061320916968338936`50. z),((-0.7380626425046315882200288331061171079619805549780842716190280922529631022076`49.69897000433602+ 1.07611432315962642048436981026104287616096161919602169958104229731675509731171`49.69897000433602 w-1.45040786785756388812378953911434012834279958827835555951224842495765354954401`49.69897000433602 w^2+0.74125665002022417970965162097959275871521752970848775041261927904958838800397`49.51303700069791 w^3-0.0718682986472127848528707449248858364270446678755498498182627025235754245072`49.119463072188005 w^4-0.02326246770235300612342503474337248843075622583893147601243641160010416181672`49.526281001648 w^5)/(1+0.64819448496026114132087156952010665284743259122861468241082378926304517958226`49.52287874528033 w-0.31736503674622719543449601682780739440884227681883151308795087283014107385965`49.30397129049639 w^2)-2.88213734488850174289199522160251525920458566136793417923137071263414850413684`50.62156358028861 THRSub[2,1])/(1+0.31409705241749455459207472459506001784189607405338506875486555156662629364652`50. z),((-0.61068822930625123131147057969201225467567536281210309601605310345263006200266`49.69897000433602+ 0.53781873890982974660900484300412768049755568900663789228296192024234672679909`49.495486120542225 w-0.71944422810977759383790049017620883314037428394305579874930383272124386303252`49.60729610226357 w^2+0.08517790429370885182876463422985972487146626943239540699548571703062547456516`48.75154063853468 w^3+0.11769500420633767261109219116823187849426418342333732881071613698542808346245`49.544755610456605 w^4-0.02547404933367340636297661875896843564836150173773604809608009940384658741337`49.10816131635642 w^5)/(1+0.96668175733972801878942831824857148012071443961346321823203131074970971942126`49.52287874528033 w-0.00025959101075673765988969963852649904120087227909847063264120944276408109704`46.14946256427649 w^2)-2.57168630648544793216440868466318973345791989004586230898617883122634890280914`50.83221994406894 THRSub[2,1])/(1+0.17254835238453833479582629968822703301610874922259713436204464616873044643523`50. z),((-1.71358245833115639424479646382729235144506696973635564222336104576725879263584`49.69897000433602+ 0.52814471143751606371435270045667872650020563351551848775779937640092525974003`48.76315597901019 w+0.0392795815223639043323148513267064593284154406113722874619046176539787186069`47.39900673603276 w^2-4.64950339893708527612323246310663808921915217022596771993653248135861152789671`49.2196159357278 w^3+3.11066999524245914042062898116845457535918019541558733922218805359637674323529`49.31613185761141 w^4-0.52789425620126477274764587476089051227447427053564448513369221948928206831671`49.30946960151686 w^5)/(1+2.50454937841801020814468323340708809691932986034224716772700220342542418931609`49.52287874528033 w+1.50817334142246117191622522428838236545381725934168404460173642015893080997222`49.367279501473575 w^2)-5.25978236951697531697345226532478014854394239134710196262665732303707687370096`50.234319573378926 THRSub[2,1])/(1+1.39817318921251983445801314349100018933453326362469948861757871290494652249958`50. z),((-0.68704017065787399258961579596274140562699389404805037919152508732714133229386`49.69897000433602+ 0.8324785760191156827574769472884071763453635013512500405009618497361780745057`49.63369444019612 w-1.11559682903284298579637170286975714751216466083636769058946430721440636924301`49.69118043698028 w^2+0.41689846610765260217986838638710134201772210714368286707467373928911385716222`49.313345612838575 w^3+0.03122447329349237061783741178233763427882264386140555727544120180161898334927`48.8382254019506 w^4-0.02710743094079720962617560677926306484127247975594867308768885651216800692798`49.35482925988405 w^5)/(1+0.80236282241157955343374783043650746529856138735898569443602031430819024166968`49.52287874528033 w-0.16458753727577064263428188092948151815708046959258303420673002331541167826421`48.98237578239973 w^2)-2.75777972102218909184548327613336185502974533983962763229187663145701567729636`50.68886924090857 THRSub[2,1])/(1+0.25739677501461911676498462691591232424097339750156562527351651650760690407729`50. z),((-2.17415306973475450695011696459960942343406402119093339526218224475730515504983`49.69897000433602+ 1.52401545766868818863007114835677802913397817993119210177897843716226629263601`49.13380510656695 w-1.1625350308043839822535810970282584662107435327747812251646930331845255262917`48.7673354312718 w^2-4.39611853429641553647750086592663596788399557573583215055384581327595127971403`49.130893715242536 w^3+3.36658714387345513360759104611385030554274774474129394960650902968062686151865`49.26718607156273 w^4-0.6249970130243701016331872723786124109032235885096221741130557668146786122224`49.263922470401965 w^5)/(1+2.22503055233008837294461697508670840555768081809422822504222226973688178110944`49.52287874528033 w+1.23250023353660197490629252850714080891996353690127596713737110388643136815`49.33861760751152 w^2)-6.38233611463597184929754718629850093798188252256449303268762404793889561118619`50.18285990905531 THRSub[2,1])/(1+1.9099963229217012737296269316968220574442571211100683974702740300986456605764`50. z),((-2.53433573327091621237877183154464366996868815452673644850768476685682920876405`49.69897000433602+ 2.16749747996827352402636247570646762199928656938847554056173458481358029394882`49.223121146643216 w-1.89655302861312463874900377952722420142631709423891322724976246905064654586577`48.90857289485169 w^2-4.50042841134330515333689119774752952944430772613887342292632416220264066711458`49.085822861841365 w^3+3.70163868370763777043623391739823649586947725717527145790670119688671425440344`49.24439990746269 w^4-0.71628974102080843979130757470569144458768322712361087224894258909920853782918`49.24362419289038 w^5)/(1+2.13062558820811719356984729488685077930487658573681821541545173489049648287643`49.52287874528033 w+1.139358429971500520499699592272960752348862808749430914927708998916072392763`49.326335009682076 w^2)-7.26021322591597101541623931462028470634319113514077817153887645734566719216557`50.156201231021136 THRSub[2,1])/(1+2.3102602889550273152806778432866543222670330253810806577691346822150518704096`50. z),((-0.60330999316585487938225573548242559053088761271464086890768361788697167203166`49.69897000433602+ 0.51253330348963367226449604840047785694208888536971043975554704476321485072807`49.480708217503185 w-0.68592940110981228967953239097961383733246854160407278429986996297738230880253`49.599414300381895 w^2+0.06009161023963556732645902476472898820894218573341558300292563134931818754364`48.61642440170385 w^3+0.12297688589706820472384554205239258642511794302723178279906468813255509587987`49.58977863739194 w^4-0.02498015229485610078893887179169507875440871548988700598919314086598252666688`49.08359522993749 w^5)/(1+0.9794787373057227770238357002108636948373778568413610351929015989043922304994`49.52287874528033 w+0.01271229384935695061567033100377139741585134222179782709219662109579965472324`47.83171166485342 w^2)-2.55370325153859999244506416926032956671403542976861880036388523328093105111456`50.85031596670149 THRSub[2,1])/(1+0.16434906252729909614278114507117112118447724034904485399730232532014373421972`50. z),((-0.62188817466215727227339542681379913917393179283371580727233614104880295799099`49.69897000433602+ 0.5771339319737960644221937163155141329600655387057805911706872473272386231941`49.51720606251174 w-0.77170613658571653175199667793471621160029350781216310028713665318884365467219`49.61920341505863 w^2+0.12528162494742507965544299472961977619702092785311511305300354043160394373007`48.89576570096501 w^3+0.10878652196400593845611949193868476214852345761518282646534592808362926758209`49.47651066792781 w^4-0.02612681665354189237124484084605921227998895206602141507213326239074879890493`49.14500080114169 w^5)/(1+0.94633692987747194842709388280190285313017050720076700346289309658112956274146`49.52287874528033 w-0.02079712442240862185105076862211011302995139826502961720921710878773247518827`48.05624489228234 w^2)-2.59898405474186700952518413494197583515473506901033405229347208037997480530651`50.80655725414353 THRSub[2,1])/(1+0.18499463312303757848674583254155422630761627587771013808599019229907182656069`50. z),((-7.87800185580009288453429032239444626030618549187529460841039910636424586830875`49.69897000433602+ 21.29892449564669320705748406677926629306707119528114005671717106687336991261511`49.69897000433602 w-33.68922641748140292402914816479572449534669610035507355394119587405179934608577`49.69897000433602 w^2+24.89111845055461639763501266419238401605745385728554233434010027405556405251739`49.69897000433602 w^3-6.34092219904864170119365973941937036482642865371926883647508837386438815736621`49.615374494581346 w^4)/(1+0.52744826265120558663582017074474485682748027250581402210606421224421013717815`49.52287874528033 w-0.63763281439113928927154704407539839208373795392437476292136130745181757372555`49.511911029556664 w^2-0.1895645144961209487563440770386001600908752625073097954596825060506240612013`49.60125479337555 w^3)-20.28438860747131146251805345225838890274258538931753704605142911397843362554889`50.04969591121979 THRSub[2,1])/(1+8.24857218426565200125838055644138921305367259691628154742977126878289197678197`50. z),((-5.5482118080221201473082901744691496679982574416179616415604516921807973921215`49.69897000433602+ 14.93752508712722238962625591424717323548963471896709509421307202013500721380278`49.69897000433602 w-23.57937574483967043822409939104100591387861137904669924459098534174801810863059`49.69897000433602 w^2+17.62875124600387721149571633081973318316237314402899139525824141594848004568527`49.69897000433602 w^3-4.52327705830726497723141271592791876077571306205952528044947188998878914607329`49.643453575078404 w^4)/(1+0.48990411518963113249159175214309986337297750335998003013545954135478213687706`49.52287874528033 w-0.68038181940180072760119960007206564641898454288351828598303923657028473820163`49.55290808884895 w^2-0.19525635745397750054718194619300906592219679527145439837056070905257343230262`49.63311778194537 w^3)-14.60596606222052788830698658442646856042482758460294218290071229077913419758659`50.07066330591501 THRSub[2,1])/(1+5.65952196348799632223741392864025931093099035813947645692794369023313359474929`50. z),((-0.657161199546196283722996010748023315613246237851547738505256901754878758999`49.69897000433602+ 0.62713262060806543640376699843733968312457343863548821839621363978162290968596`49.50948900090142 w-0.91222739838865605083777694771081834506974162344360003780454865888726852690578`49.5522632323868 w^2+0.20351601588863051558697241994441213447907183028438757870462971116599031038595`48.93779215290204 w^3+0.0339063664522295399103345940542943397247427147191129803023878977862699381298`48.562023627378046 w^4)/(1+0.99912632725843929042870232598883555447237516123554344804563822476168228158141`49.52287874528033 w+0.09558307916511206102451658470076227936537527159638710912487868967325960245842`48.805678643016456 w^2+0.0637671448634242996789465726464373553744813441197345483431489310427210401072`49.0654783801855 w^3)-2.68495538075544907403249509028403284810059194489295921443135204583753213724958`50.737228069012716 THRSub[2,1])/(1+0.22419285742252605310070745706601981262508613931978367335460888795099285539987`50. z),((-0.66738447991790130794959732672453997920373827618681024685981681404231873331802`49.69897000433602+ 0.67163559167948057933865101305461926058355308347471827972381843777890976411409`49.533938072031454 w-0.97018992184701833061927072371507243221368369326232538765740116778225510923055`49.57569656278299 w^2+0.25496245024941647199340417516630091565507043784770888578728382116552340855964`49.03086696595571 w^3+0.01953314118240923537684898282459856801097161006951648914568323646273511544158`48.34235192716115 w^4)/(1+0.96841425748985245608201584770578362926435647258448088601972255556604776109701`49.52287874528033 w+0.06546611827970829893523720062263961926683653092172047018719823165383939543468`48.64509384431615 w^2+0.06413705819255077444995119029303923015976140638902669625130521027958404903823`49.123240224524146 w^3)-2.70987269285594352298605177523871370159002385202949595487364828291124997421417`50.71977156176508 THRSub[2,1])/(1+0.23555378942096044740130556582650860493830061484784371183430042518483606454726`50. z),((-0.76142151686015321817200256320021420056200384456566444286613112679128020676685`49.69897000433602+ 1.19608645936770467720629761987024181449647922176843207749063305974426845273761`49.69897000433602 w-1.65328168092902401435583686163002232491643352017830578994776515741182440362985`49.69897000433602 w^2+0.95340443662180001876487461287642507315384606884957948250747956997403491861803`49.58757754716744 w^3-0.1879989094863226238246191247685830463630350407611385980257318790714790728822`49.401280318721206 w^4)/(1+0.57343474999157567450995397046660620493506865810071708179818314909363567908747`49.52287874528033 w-0.34738571116220638375166911637883731938029635231710784037376291339489538789733`49.39562894025704 w^2+0.04255352655140735888932718106702294089031949209855913689941290916741737116338`49.60187183322988 w^3)-2.93907018263436674406377913836483684671754087395597142982189105123966487808238`50.595573159664006 THRSub[2,1])/(1+0.34005531370587148787711870209292096373430000409812386692344333380879838441493`50. z),((-6.42747308831289453044466788699532402577755793109945970730805640253649124381523`49.69897000433602+ 17.33415158903285060903200127754413391211011470714741258657255849842163543491139`49.69897000433602 w-27.38908561524922677907232432489970242269929691862497330963193696517655934068477`49.69897000433602 w^2+20.36110272054214085826484510325359446442328160122385799497842818152903184010027`49.69897000433602 w^3-5.20629888295046561944852358059070863953884195023595930769481150643859660982281`49.629997279666 w^4)/(1+0.50791836001919212393694859359310712721842729668245745689289653763559061202206`49.52287874528033 w-0.659881385674667146916295913496175821616659624649696675087999064075112168496`49.533459022500686 w^2-0.1925358707256273159094232805132614438830585325255181546870869087109242123379`49.61794561094479 w^3)-16.74899911446104182060358708703005207294927943107086808955880853187182675267401`50.06095416163019 THRSub[2,1])/(1+6.63662786795746968398500440490791343718268251794434947089633705415694054505538`50. z),((-0.64416266194710887949261577254336383888743513591311917549825141071523205987552`49.69897000433602+ 0.57376359038327893140934043140430418552894518025831145088419362670462399870854`49.478460798568776 w-0.84247969107293269773644223272174650542191215102744265656810943074042194532777`49.52166395983823 w^2+0.14400913131930428489982353042392815310933392677525575740771261549883200518803`48.794192562897045 w^3+0.05021377380424650598190858136029365140121807169101786635346769162335034204875`48.70928530365605 w^4)/(1+1.03459250043767941268814334636384763191759566257850161101717854135199147169613`49.52287874528033 w+0.12977681958361736071535114228107770133794862475124854825355667019813917307969`48.94092633232898 w^2+0.06270715942962730102229075712663204030533505731714919266046227058594542627154`48.98985946159156 w^3)-2.65327390412267479802899964238653849864826812907047619548446275346899241925855`50.76099736469772 THRSub[2,1])/(1+0.2097478362186621541922513691830979246172869117083311267166379630424382862877`50. z),((-0.64721746172865901300312931920560180365323510617488084722817216369469839759223`49.69897000433602+ 0.58599236456175490411625541790746596656581698654809120307560838991774120480017`49.48575100610499 w-0.85848959596271324372418397008540147895094225911394572741180974617940103541406`49.52895305255364 w^2+0.15742394120362234958916015255824523407702296905843712058034588855335995876253`48.83127956230053 w^3+0.04657117713324132876001432719377253628831549646437703727338396449637028621168`48.681896850603565 w^4)/(1+1.02661393996263720937397414257627790912329072017989638453849762226912420122708`49.52287874528033 w+0.12214506834650717096589716512773964398399075283179992192245315728212004023051`48.91327545387898 w^2+0.06301196389103359264215488391080131668737039069762248755447611440167268835487`49.00786020444849 w^3)-2.66071940075329417219951970847637653193720131882918193650937759665633403888707`50.75524163521552 THRSub[2,1])/(1+0.2131425756100494214623190147879324921695249884169023938443764327913759688398`50. z),((-4.41819321037988465373681176464450534328738639821470545406046094290942271604692`49.69897000433602+ 11.87326191070847284001723759854905574039323960436510297271536085377183060591936`49.69897000433602 w-18.70546073470070339820704273310527053152699413102319869308693151835210614111213`49.69897000433602 w^2+14.14994579304832908264064849230541161497747331866541235911995161471050096279315`49.69897000433602 w^3-3.65699016570284308019797544841666903358793626142819037542886518564596554053733`49.671198080954035 w^4)/(1+0.45263399154339807247074704665669067914962499585858114185428224816206856860636`49.52287874528033 w-0.72275409277724383198651189076266176136694915030882240308553419503411079414658`49.59197845698841 w^2-0.20084710359878193593240085236507469646303651402809891932594393454431943678442`49.66388546241015 w^3)-11.85175948144975582516704879005853217013003633383745253232209996497632198665358`50.08887251305427 THRSub[2,1])/(1+4.40375434507154864721667039089305548057394006752821064395311697118996714571455`50. z),((-0.5960877237472114096023537512655270299828589193176035895047041656134687989104`49.69897000433602+ 0.40396162564946987480279899049079557512602297680983275745259232497928669683808`49.36215873126086 w-0.61733816929476907063421685613467220751792214093942196788371059665589941298958`49.393283595141924 w^2-0.02719431999618697334373916142268798409840919549724105982225011862685591010885`48.08464909158363 w^3+0.09426248515240117692037682033490644937921500206203789441183037272120102230585`48.90254123969591 w^4)/(1+1.13293016365575622987993572673677747169713537963432896354281762684430747365875`49.52287874528033 w+0.21982238834650361456928264474991862091609132232634597087818968192928497221554`49.27357952143486 w^2+0.05427611546624488114202588186625213172493341480976839002383943203250266644547`48.68527470366129 w^3)-2.53610033597382002141583164887197304438439662987228605370535435534285272966657`50.869056053791795 THRSub[2,1])/(1+0.15632309544469072804895714126916037325839047588800735398469758819008489769777`50. z),((-8.11943800044360224973229514943028063880442405718037645462944860044851037733593`49.69897000433602+ 21.95967955204310291459470404370880736212779876226932281685852316491240745818738`49.69897000433602 w-34.73900204064407112200466707483450502197814513243587602342349559031885411428818`49.69897000433602 w^2+25.64680195726354923419883375219358836308176092729519079538232296736330143650886`49.69897000433602 w^3-6.53036064914755819275223296225014453375797845630175213311125663072698772929962`49.61352183242088 w^4)/(1+0.52991927081886536298538190856896742272667840120920002257305462540690924690622`49.52287874528033 w-0.634815806407080893227826936881487639257437888626630711535367498307232782401`49.50914834932415 w^2-0.18918663940159155688209811898578715631489132211309265922253165235150438304961`49.59912417224567 w^3)-20.87284354069145105882435241078494910826598159647882213810308148005684997226498`50.048214089348036 THRSub[2,1])/(1+8.51687546085882018301043165233944296598845295378732704272237076597937851788201`50. z),((-7.95526678115606784929419693598093358827283510244083646852660463199444378088734`49.69897000433602+ 21.51036087497280012774090491547232440486953385577052442894779439518891529354693`49.69897000433602 w-34.02515079635603905965709384657287052486594820204118510962508592909935657068542`49.69897000433602 w^2+25.13291391742139090268249063034907813930384923986133509323826316495785666628794`49.69897000433602 w^3-6.40153278521197483681823079792933162318168788766824595308684857348104676346157`49.614767552095714 w^4)/(1+0.52825786137485646405662274591279916572207055248052129948013856337313815579017`49.52287874528033 w-0.63670990613296740125349901432739608046765066006633839088226861928089744660326`49.51100679359103 w^2-0.18944075903567512866657250553712003501141162317803359553185936785155019462911`49.60055719592942 w^3)-20.47270724782130193373513482173529183731266918274896569750231451131732737775974`50.04921187091798 THRSub[2,1])/(1+8.33443518820544735081626458282027528330929388670643424270950470298342150329112`50. z),((-7.20672875413674749901854249503912800612194409773600249610679710727918284246424`49.69897000433602+ 19.46288702808946563324203385650784189315016622113356971710069693207901813814659`49.69897000433602 w-30.77197667112907355014895506763272671474085753816673800996205457445215144659346`49.69897000433602 w^2+22.79224543389291936934168129748029046062042928172503043474763049237767512052329`49.69897000433602 w^3-5.81497858004600908238301561105610969482870232992385406468310958095702173483641`49.62128668453635 w^4)/(1+0.51955777348421672942996390997937595273736936291935252752635513186985264686271`49.52287874528033 w-0.64662499577352450142691491028593142134421119243744575438770573827287841966018`49.52067732504796 w^2-0.19076813479466338818114806603549973865779983375005874317823482411027900552317`49.608029643777876 w^3)-18.64828739820525626729224103369611886173423322522996148217729076659999752718105`50.05433995920763 THRSub[2,1])/(1+7.50259948439891604692761810805415292143734336470967791488631230720913762953768`50. z),((-0.58394147972548268257180102125629860530189971343170289199875617829553942052184`49.69897000433602+ 0.36693565454515341209406209517597363616163953223961586571199883801939059103298`49.33151140631194 w-0.5672002313524904802265708651356531366296887854964267293071493043526241651172`49.35447036207559 w^2-0.06046058760610035496072407931020380446975961423441587833627054014482006160251`48.423637888605924 w^3+0.10207320441675734469894078992985522170866501462658791180031375109369610432319`48.91538914337719 w^4)/(1+1.15027691447672517990273007215961187675871392473739001368673892896961465363255`49.52287874528033 w+0.23455500863571652271878156786997063630604913844247812222547198332798051692525`49.368756378173664 w^2+0.0513171952829446979988854177001532965051091802534574270570857771046936675309`48.60119486847966 w^3)-2.50649616371852035191274317359827608459627579468246201260164892943621740898529`50.90317493689554 THRSub[2,1])/(1+0.14282521146322694450433375685341720009921477300565747559179281962358137526564`50. z),((-0.55240349074532273271304095778555814350500917500004080460232565163224926075271`49.69897000433602+ 0.27966055176906048716898143655820273233015106562785764340615610408225942740685`49.24620091568707 w-0.44668082342403812592432331974909910100980076151082977552047651206601905479101`49.23401298031346 w^2-0.13270582111503091254596301731841609856882451908655276761487241618388012091475`48.743607342172965 w^3+0.11767101515415745821542874799225218712751136025416897073201624630371408312506`48.913488245831196 w^4)/(1+1.18283441051638024741469677042993297403819653311757771007547291303139081778526`49.52287874528033 w+0.26032075480222321373606420966362367358662108034807120985474526897726452406207`49.69897000433602 w^2+0.04267915968526045205777194206063808435667118916014127830397800455751459900738`48.36908189820818 w^3)-2.42962828121227754383460471796487285140682137468330436784457118693851733965182`51.0119238536077 THRSub[2,1])/(1+0.10777765968496992705458362534401202227919464721803324288100904937832819106771`50. z),((-9.33852499451349840428071629715381086224574446061923852733181289274479561314155`49.69897000433602+ 25.29835689745468742823718319086949978934880388071267325547568366396679631479849`49.69897000433602 w-40.04279992079284276921083336433997638786076380959242271937426997091737136487408`49.69897000433602 w^2+29.46713695501350459461621057449313304749493380200255183282567227746963507689564`49.69897000433602 w^3-7.48851143981830073645914145677215568206014659785069643539604084505165889016744`49.6058102651477 w^4)/(1+0.54019666180010389397336722919480040766886247219987247246035320445623567100809`49.52287874528033 w-0.62309393481394081667589458453632162314378593194831916915891818274874537913189`49.49756604240646 w^2-0.18760980957777788165050622475655596045217076181578397033151865542607560915632`49.59021536107287 w^3)-23.84413748983970275822811250887264370415934382698343623198728161613696836798529`50.04190582238327 THRSub[2,1])/(1+9.87162305030539685475707649485537822953833492651134537714477939574716187567103`50. z),((-5.25728896463304376060472176609337548020465762960811908046551284216228498740853`49.69897000433602+ 14.14640423643590268599945078402928380263814323227791180397739623082474721153629`49.69897000433602 w-22.32143655568991107954552819600654229052482640784882017781081527238816006744273`49.69897000433602 w^2+16.7285009330933899252167622436558372569921914832241201532004890906469922449959`49.69897000433602 w^3-4.29861955946651076128375909912155584298205548950793292608555528743412840980787`49.649151359100195 w^4)/(1+0.48226408397743447097441559979905125659350908838409759740382413956947298149846`49.52287874528033 w-0.68907133947886496284894303341234504818928158767823639692969446588472993953536`49.561040822847175 w^2-0.19640557645337091802557474470268427545076833011885510237488770865019070104296`49.63949115573317 w^3)-13.89689666156592136231431352700725012448819042506980332459261681918851819803965`50.07459645645116 THRSub[2,1])/(1+5.33622508417300137420860086506413220284938324997610427850535396123590560295744`50. z),((-8.30625826833575284753275036213042376792049514271678233330640383736319099382999`49.69897000433602+ 22.47108286279507574841621962337181658492008036311588324354529795894663576621922`49.69897000433602 w-35.55146775379282623124416217869068379314075959479336119656693442454455429756812`49.69897000433602 w^2+26.23178020656757531133347271693041181021568425511156648828284087894224386187476`49.69897000433602 w^3-6.67702914040023992322520865079586371387123093569177109263699570600141089697988`49.61217259460133 w^4)/(1+0.53171836024751051004308444445356830049477405429050389920042092817443445793644`49.52287874528033 w-0.6327644928585176001271172785007125430389306548206927453636914721052101757169`49.5071315843045 w^2-0.18891122089444302764774988301901847419103876369741862185247988071465180553212`49.59757017470584 w^3)-21.32818260530817686765282239689655365022152006420223269288386893259239309448518`50.04712680954225 THRSub[2,1])/(1+8.72448517929384729550514483840408372989945268146422668843470166810407621799888`50. z),((-0.55352155976018983725087785581804655453896335067950305466782789421689763380999`49.69897000433602+ 0.28255675137517861988012617077690909034841084203356514261756131756152364773222`49.249421006500874 w-0.45074343686965032174238925086723815542282066989147155359999726619504977327742`49.23884979728384 w^2-0.13044838978770530580438021315221892576595361001256612063972544691841485687573`48.73698381684463 w^3+0.11721855234666911469587216837449012552732246102706102414358231449692963520172`48.9142464853102 w^4)/(1+1.18197417553656564416199389176747419795437903443860986445441808990115751039763`49.52287874528033 w+0.25968763479314278400540558301923674805481270604844206778801885657782939083664`49.69897000433602 w^2+0.04300305486402608184735969554534575223487126653690629432058497600501473954293`48.37759927024293 w^3)-2.43235336294538173742257750768207585345974452547370092325203517942453073295631`51.007432669075065 THRSub[2,1])/(1+0.10902014796521096243275908062706697905320774793499619120855436600510198848592`50. z),((-0.55057424394792998309237105491153490456531245448986915514158800735031965730372`49.69897000433602+ 0.27495135422126305883548792365370642080245356298340858530294187932460065466596`49.24089372207775 w-0.44006437841449499598916131261074066171221171463724219523312135985126153584735`49.22600370390243 w^2-0.13635584302331505823044508117192490378711310224832968339526770600607187116762`48.75402338588115 w^3+0.11839697357604404480909121996926139697254864348947184000905397106471171807971`48.912162147757016 w^4)/(1+1.18419630598709489018472303011766768780345203368117413037807950299260297722656`49.52287874528033 w+0.2613153235302733120807665284307879644967008612563750287519354892896581818609`49.69897000433602 w^2+0.04214711547043737880149924531725602783279442040740401026776980369386082661741`48.355115867827514 w^3)-2.4251698381585570750179365714044089633041809398454924696886919874040106905038`51.019395687157264 THRSub[2,1])/(1+0.10574485341164780133283307779040997778675728555352781023070694011522412677283`50. z),((-4.94797820102620111201408530412950605120954423170448297011011647482529516964867`49.69897000433602+ 8.84101204887404177083432533072252287136590008411639553370408845016246004062111`49.59524932197779 w-12.75455737986111119614381582095410404269572464309564711687633247220686834591962`49.6084011457858 w^2+3.94616599708509294692724382607169137735735151068974094837417194161331512242757`49.11152387095267 w^3)/(1+1.37539664846284012966157210999747167602359959374059669801046947606390518088023`49.52287874528033 w+0.49061749566747222018007358752363336837837880971063483990893913790159859065601`48.95706751770923 w^2+0.14784686437009722015874529162836833797519047790649608117103348622766365364208`48.639719414936245 w^3+0.05339259627847153390320627090085241528534520371740393646717191763104505409373`48.61818314263365 w^4)-13.14301018358521783155039129136188482468883816736960854528523603209095605984574`50.0792900552755 THRSub[2,1])/(1+4.99249406790868995527175028461952730385938680626912196061899009134608460318374`50. z),((-1.88699090757295377877897741896601422178564132102572961749274066031730161421715`49.69897000433602+ 2.92785336500004623163576950732139059393521792555148531104108956054411103133586`49.57041756895294 w-4.33207817415872698635033001186967608870524754073572120070008124697334695357302`49.63618261815749 w^2+1.30234391020188293075825109847312915152733081983699883389758261728776879767903`49.10823229586084 w^3)/(1+1.31028521662461259666375328560054758417553147144808712396009107563668397521545`49.52287874528033 w+0.40231610779233124909159674721168366403821921597470137065807396651049506438513`48.915069328231525 w^2+0.11629329786518117236957766176613425818653380078569132626645908575711306248368`48.60828034050035 w^3+0.04483005045645384546423856466228513313947035518584981324701834280822014254736`48.630289537839566 w^4)-5.68243266311349011466995498181411319741602009653736417731126496504987590785194`50.21181002236602 THRSub[2,1])/(1+1.59087861527543186696627216223509812146605567534719136103546935102783704118908`50. z),((-0.56449725853317897543459117744739048043944038044343791963239532604251532775849`49.69897000433602+ 0.6620809257833641655219618019116733066775644404302675669804205982069302051822`49.69897000433602 w-0.81408688263504006576100928410029371460098427127338439365074111230279906653427`49.69897000433602 w^2+0.34769614341645140579790653760147389687940799850645312719475982910274938762368`49.52892930503908 w^3)/(1+0.55175318217347494054402350056315100000383919440541611276046891273910118426863`49.52287874528033 w-0.24631949857361529317252903622693022732527151174617684610982779393565062616112`49.215591418038876 w^2+0.01870755160050167373160833199042931363850565565395663727947059146121880461607`48.59737551948639 w^3-0.09306208989910573875783068836615867716221954100165312299770167385176004761881`49.43147445072615 w^4)-2.45910455257376252518333367135128752583452033383681094815607759952081506825398`50.966125414415416 THRSub[2,1])/(1+0.12121722785165773337167220786455436012248786180375866522508524853687015267644`50. z),((-4.51833177709986048761761902019321717473207434082044358477869551738635087158749`49.69897000433602+ 8.00870679176951849041132737991561284608167592728381612185719653111004344363477`49.593764992428156 w-11.57222062134842799974616002041730441077877594539266117162427438032178832681901`49.60991120588395 w^2+3.57371748531257037498324244331912423027598107739303847476027548142836328248548`49.111069832417805 w^3)/(1+1.37209381405962774895672263631695148539226956714491037047273015599395726808839`49.52287874528033 w+0.48594742472774436153146639358167835778667940961705142522901775431232959875504`48.95514260241634 w^2+0.14599088479149400578707334619973954940880591131930897060646266589809780101445`48.63796213045309 w^3+0.05287940600771235976534374517154825570099700179488110304363390198954739607288`48.6186097387362 w^4)-12.09582829591401973786376721677457407321141458110839279719156255251570345256384`50.08688712760764 THRSub[2,1])/(1+4.51503638034420471870921381969642579326171066228376433680427047849080714463766`50. z),((-0.5602596015282323549173444612446953850191974304818988000174252815350035604795`49.69897000433602+ 0.66583437845915479631003856877820714045313566295499243263646913580712611436602`49.69897000433602 w-0.80951492526261126050678738966609214811978009681086165409761485977859012863734`49.69897000433602 w^2+0.35448552916147924214752131378556326525939562143829725609546919424604847646839`49.552767659419835 w^3)/(1+0.5239087801521650503881397611927600856624002312119898659842768692732780905439`49.52287874528033 w-0.26561083828173745178098383350957395555660669157887911722260665456665905882497`49.264612546198336 w^2+0.01348627375864077417113292484531399985261793366657578615080627753715901465497`48.487862861076025 w^3-0.10066533857541821474853398007620605981730542889435925744603721584048815494643`49.47098276694931 w^4)-2.44877606520689486182925969202889351241398253908819903996396284118756018457798`50.98150608438334 THRSub[2,1])/(1+0.11650800230805089441271968330393740194968738844710969474142783646547219749462`50. z),((-8.52235780381538197922390484420191797675017764824669270875856431373092303364499`49.69897000433602+ 15.7708900570337705958863364449289102370432141293024868977238332239197223387985`49.60179639310378 w-22.5912186808879925218614417764138609952883360538606872961186675285821377598011`49.601910631662165 w^2+7.04849042390849113044226028178151646354484296571118861028145005069145761556631`49.11384649711252 w^3)/(1+1.38930290996555242013256322256718448120665176502806959006615116510568430658372`49.52287874528033 w+0.51050533220118796583349473819204697666981651485270961659072030214212384759768`48.9649437686656 w^2+0.15597740904364505751827788526657952656413068800361914563679279402040432037212`48.64720606223854 w^3+0.05566368125197206573793566142073913793435163749739427069127339746162927827351`48.61661412455798 w^4)-21.85488434628955555082554492439156961803805681074154268922040434398891241636027`50.04592879635371 THRSub[2,1])/(1+8.96463237649605710800949181619389970282146266093261380624931048845414233025398`50. z),((-4.60638535150369844400455317789366733733921957906206955082105987669327327474572`49.69897000433602+ 8.17926031411162882777429172188327008260896574254310941212972115071671511522547`49.594091694461625 w-11.81453228613507414176807921544847162808830135028148023604670471922262833125005`49.60957754239654 w^2+3.65003387189616962500289933368609465170691381529478061117549599390790261079425`49.1111673718926 w^3)/(1+1.3728258296447154843819180424292708258796330816492052754710849338887929290043`49.52287874528033 w+0.48698069833778762679967336051266325065268356976761082428938764557437530478756`48.95557103804315 w^2+0.14639977326574193313161690142049080407408299847775201816086186377910336099621`48.638350752682484 w^3+0.05299230858542278194990162974069611115223638608923840476216504738689632018849`48.61851338768305 w^4)-12.31044222756916985892047263181060809088624386177218531298634781981062885700168`50.08521345615253 THRSub[2,1])/(1+4.61288859946066488670627936994585897701263883100040831738740387596097127853122`50. z),((-0.75120890673738571028313123724164904112585894351047249554186594469521497100923`49.69897000433602+ 0.83133845423317874064337379322548553737749929296536526223899720359520618135837`49.54581528259461 w-1.22595648516925835436073046567830632619041387917784505282969320386035095618974`49.69897000433602 w^2+0.36430145116795582476748144089743887603682497455652194363438196361506483405055`49.18000349132931 w^3)/(1+1.02127212708363021609796415001203790995561084228909648501154111572972557280171`49.52287874528033 w+0.10006580931169691542318005438992772999604465274060899377781518905814010573555`48.52319749220683 w^2+0.06785134135539137912183505160298968575428660003602618548379364583527051893344`48.68871210124192 w^3+0.01598235064291130604859136774658990787718317244499257287492613997573809423336`48.49812881552347 w^4)-2.91417887724730470015371555117648043604693508558428398047162948631231759913108`50.6066210266389 THRSub[2,1])/(1+0.32870623934688137621402846333713742527553531984624024031616610272891965524652`50. z),((-0.54638778672630852877921512654273586099248771374674437459111783694496613130835`49.69897000433602+ 0.68503913397480932491326255772103189949189870215763343842248697874645488151838`49.69897000433602 w-0.79880917573791942191316019982078551966136212189045863158600694656113707491622`49.69897000433602 w^2+0.38328129009960799817684735672541545177753086814344207806493918368697242149353`49.64402064226967 w^3)/(1+0.4170788804277365515346957832015473847292106197472306457117715258955967364082`49.52287874528033 w-0.33914630732636492549383508712957651991892021332361591836102304155373415258408`49.43468069990987 w^2-0.00829220798597824522358987692084404613701403578307346711504650994901626996812`48.398334145174786 w^3-0.12981850957944559066825147109327247678226979098450845195744073485638904444191`49.604162798947435 w^4)-2.41496614057874462945603866139598464497848800422538830682952297703498573983187`51.03710476950836 THRSub[2,1])/(1+0.10109252518823005713421924885618055284073710872161078508924059759459814049887`50. z),((-2.24959986885889376660299857420144942292247650796733037320875202499257095373323`49.69897000433602+ 3.62397853926264707161577232557774669161352152748151925509033272742173726767243`49.57672193005687 w-5.32955769350110093151411498350423997860320359581723244086210042794190235110078`49.628524683043615 w^2+1.61319022291288191295834536538911943983142759445585536703339992041941164201237`49.10808648951497 w^3)/(1+1.32918672525935747371510938699502790843993542597869271204879077540597688266161`49.52287874528033 w+0.4271341280766901885249058548193009708772459448953186661322206027217249801328`48.92817084511631 w^2+0.12439232015291407197008954590855395101869682871302418118866782284829778277493`48.61649770482162 w^3+0.04701265366894661753315578023482644365827842567971951468096752375484774717142`48.62602303059703 w^4)-6.56622341620725379423031076347623356112955494022732104380988077489189536512031`50.176538363706264 THRSub[2,1])/(1+1.99383887865569139611827128139154973980256916815272071474431256219924212348423`50. z),((-1.48545547208729371132151618951783023586596975187154805295793216707311389089954`49.69897000433602+ 2.1623603399175355913918042567321977372741827813506703081690114435718673930752`49.560396056075156 w-3.22790392559359836544046061980557293439787540578761720580628367814125607171439`49.64969668639072 w^2+0.96052296026233026385844343338572662556533520806588842785671407290006726498111`49.11040806181497 w^3)/(1+1.27497789875516398860505159720219951210151420924316504724833175518918875451264`49.52287874528033 w+0.35773900938160852628683252016628628520023728819330814661351199122545849396441`48.8883916546985 w^2+0.10332671329258646024740671608795275789272596540315732743065902802248514371268`48.596072999275144 w^3+0.0412468475853362525003159109487018045626665423403991121949712515312902784314`48.63932430543872 w^4)-4.70376599237485953871326633829269379107455746891151300476106681633722002711266`50.2726819237821 THRSub[2,1])/(1+1.14466012065798340785577027768063756394251821511335395161648596259566137959914`50. z),((-0.71444268638465387505642081304114564962355116152324999878378798788520038775098`49.69897000433602+ 0.77626855244367801892720598051600106455218532519044685799670041045734623943994`49.55262274377195 w-1.13119934019001095439784398463033700143145135730519662413538847333595067446676`49.69897000433602 w^2+0.34142500300192287060858820053174253609738077091874452417479818753332896969023`49.20158106313438 w^3)/(1+0.97865152247952385842265722908701313043158704608922310432016711598876799163603`49.52287874528033 w+0.06502685050157727875689593934944400802372587694653687497605768855768219145227`48.370212675350196 w^2+0.06622643431979665002854552141503346103314502362634773923874230096073516778327`48.72185881036335 w^3+0.0092907499675439094922136077232077744726869569187755032835691130257639834955`48.29929512179748 w^4)-2.82456816972723090432522942591904808251692663061239765810630383283722150664488`50.650700622983734 THRSub[2,1])/(1+0.28784865605855590688434569010212679660909877553422249736885957041912356302272`50. z),((-8.75994183091109714316493837179126078986686627932064171338017930018373308804516`49.69897000433602+ 16.23168680142532513971462622705579823245189824590337821183016486096438801747933`49.60204193203857 w-23.24506064351986506001029554108885431357403756408189725818874540185296418083158`49.60167227994367 w^2+7.25482087476014067545437582389392623430826962002447715568175537697515175553867`49.11394334049123 w^3)/(1+1.38980475640449408080466584218594950754512510001686356453094877876604564284248`49.52287874528033 w+0.51122985108869182521948318263197827129980596930137152627612842061113933976174`48.96522116282624 w^2+0.15628049575616930542400466581838317687280301373962217485670885806865778752799`48.6474782452862 w^3+0.05574910228999017134024813789033685277089705587547814502473647203015019140252`48.61656426200628 w^4)-22.43395047164213088214949279792814791810333839636303719888166432492754057498266`50.04468012041732 THRSub[2,1])/(1+9.2286548700216308191573781601155931643490023134524439067325144820173383536013`50. z),((-0.68631357952781599735934573535513927623967764595402207392629776607385855153921`49.69897000433602+ 0.73749546406139469029133597803667939177631090877625186762318555468946093778822`49.56131107694362 w-1.06074236838602441683866384116241944841783273993087612213656166966608440922052`49.69897000433602 w^2+0.32664849451186154586284144732595533393717423200599547495320632363654999060567`49.22500252561462 w^3)/(1+0.93806459715541051289253043439980838654855294845281963566940409977626934485996`49.52287874528033 w+0.03291906169304037375878635039437183562234019015545898525986852859561830200944`48.107969865401714 w^2+0.06449159679490913150753041867623444253260339552306680957695526170784195405042`48.75094684133865 w^3+0.00202683821777545979616775347830397588691639355554131658421419713983946746005`47.67197087369141 w^4)-2.75600879258250603299344141144388083257303751287354642448403652623889426344277`50.689954777028625 THRSub[2,1])/(1+0.2565893284691735702362241479785008115529344571653672278541813249564550154093`50. z),((-0.55239334408832919448987120820292613397401119189375714417889894296526280702034`49.69897000433602+ 0.67528077799069929120209231253307661176988384344721899597829227933160066514279`49.69897000433602 w-0.80255839221740712262631007322745527583534374826843377017438766007009612371326`49.69897000433602 w^2+0.36944510601496045516782123980658295078195394816745582074813041423438212857152`49.60177898925563 w^3)/(1+0.46660168845533934060016175493812929652983509846728209190321024193184952958966`49.52287874528033 w-0.30513717783702903048021822016823173808954668674234143337827050493941021577721`49.35882007647104 w^2+0.00213163414684473313066025974633578669180477309667229966041258696912620373202`47.75948141884488 w^3-0.11632639336392020582305126070905744126081215468896303705707884500208234923704`49.54552845073476 w^4)-2.42960355065516747893721379889481268705383578986364055818347352627681797705061`51.01196487161494 THRSub[2,1])/(1+0.10776638390303655912060382740843468241928987635754472950837857940614955744805`50. z),((-1.21660366993575703386078618265050662887581480719490268565911658687889071692177`49.69897000433602+ 1.65654239153441082972695442059328589920077715914916867353353624566118515575742`49.551174693378485 w-2.4893010277834676595067948087288460772490238830836624473813560048300932928106`49.66462081110151 w^2+0.73425876266556502344245028581047128753294063540342897452242062410895850291505`49.1157066628089 w^3)/(1+1.23278324276630031923727629005459066271264279549539134326870028370404919311738`49.52287874528033 w+0.30749357972291453456011981929677125181317568430293532711587184656723058759372`48.8522280267195 w^2+0.09123902940888788244362054271621625297871886428913075075984501200382611541955`48.58868276590932 w^3+0.03753473101357222700163221621844005975101159429334875893814596321711827764121`48.65013709937028 w^4)-4.04849057984374806674451070953851113464133427304422582422225665211992495100544`50.33889182643018 THRSub[2,1])/(1+0.84589035881580316720200171821984654336961736958091047430650941061527744018627`50. z),((-0.58128955687062254656689158633647945534635973878401598726330740556056578290816`49.69897000433602+ 0.65455772229597117642752316640549374871478796036099446614774691278281174735116`49.66828747158352 w-0.83677732233598652013077790580055133479218644362261991944430148494620434046597`49.69897000433602 w^2+0.32780159462591538914676725162664403263606831368554022940018649193620679891254`49.44895985057896 w^3)/(1+0.64545372387876183267094380594518864816850103063073009583784137095724284497921`49.52287874528033 w-0.1808829332638560111134317835330641741110768824757242317169214043193955723058`49.02746884923419 w^2+0.03468426839555631958783689504913319604884081887867342440542621588471810156054`48.76481420968447 w^3-0.06769989754100024554158282297273239987359336296674398260719725189590224636218`49.276014836482915 w^4)-2.50003260338969766461980607077759586276042292765797216507423933874288073800705`50.911108463723565 THRSub[2,1])/(1+0.13987818133945706775497555859648402888337842922796892164299414158873460717035`50. z),((-0.56639302324414541699449235231909105742154304426814438881795319474419969509723`49.69897000433602+ 0.6606714677525526218742331865578357263430955248069898809589450021689802385986`49.69897000433602 w-0.81629941482835612487450052397513252274919469785497531071855037263597530010355`49.69897000433602 w^2+0.34491567773412745433816894966634428530254391591547736604327896997732522486706`49.51878952923795 w^3)/(1+0.56359864835557542623464855962630064675913195231998845999974898414652377417012`49.52287874528033 w-0.23809314835089204120321514517548526910468572293431470947018039891381826165872`49.19395330787014 w^2+0.02086651824052410269557515597140319274376737462231947213098590687790556901809`48.63137718191799 w^3-0.08983277912306923274157527832940861621616400646060254960146101632055724742918`49.413888458097844 w^4)-2.46372512045948669374256685019611398557823144348117720660138428983299297306932`50.959457578809804 THRSub[2,1])/(1+0.12332395418442379419052580006191673911631841352359216369237049804671376360953`50. z),((-0.59533769995606123871709246581686336644771832310378435732367528312302174316165`49.69897000433602+ 0.65529030589796982215575590658572602950535711276705884501101085679902583410188`49.64084559138363 w-0.86016475221822044137762501112271057265529284010153222614761102691182911876532`49.69897000433602 w^2+0.31787063193430963822720537923388010785239531994612902498106984061542967069332`49.39639228135961 w^3)/(1+0.70797887444272719958683602756176396629427994056444170246043483501926248094164`49.52287874528033 w-0.13667515357001481530463856599153312149047218010512176208509463711824358030644`48.87005842586032 w^2+0.04379874834721705919214563223183148957729636911267216909361791874856952182759`48.804039068648976 w^3-0.05118475697683346232556633403600579517278642195042214373436053540327283781222`49.143056349175474 w^4)-2.53427229485517778466765204524648107360083412345875166165315994509328262960268`50.87106467374429 THRSub[2,1])/(1+0.1554896086401961021718908652141667593603455145467342894505210891317314501159`50. z),((-3.35095625790928706309041783908091505845077857411463523430426924707329330405345`49.69897000433602+ 5.74926933318306247652831607047214939593571718716433823510177954791732870437984`49.58782354976796 w-8.35986539375094468514460253009131298484219328933964528702000677360241062867575`49.61611538093088 w^2+2.56301516428343793589944283943455775874725468195264413834820737315285640552331`49.109541937317054 w^3)/(1+1.35825005858649339430879463669383392003156939949835786808755227306743715755136`49.52287874528033 w+0.46659543941225813705239825516961253352227029963515678305619609041404059942509`48.946843834170096 w^2+0.1385183878232944929364753547105801011291364567314109304219628979187913188135`48.630721915662235 w^3+0.05083063306259688934792413998491957163881739425920164123313746565029287144715`48.62062568717458 w^4)-9.25057128519417846380537337214787653311125494795438542571614118368148160349904`50.11752838330886 THRSub[2,1])/(1+3.21775474392663150761115031202741932562594143373409744318182511601511922411212`50. z),((-0.56063594059920732151566596408856913136859929237527888582536161444580386820457`49.69897000433602+ 0.35406921434963937423054682505890701721485593640360860662989652393950048249322`49.35397237826733 w-0.60873231797604026933649424904711759126227424989007145491601505288050445378939`49.614067793673186 w^2)/(1+1.08189605907891916265838644833627897120978988069075242224217885280897138413573`49.52287874528033 w+0.32904294670636310726915425748127802729231680758957278303305350193119690194852`48.76974433265952 w^2+0.21103991683397953707642868362600485877577164423616708834538744854052147570958`48.77061309817003 w^3+0.06273626125226191641041208980750904786167933173076483604143212768126326677602`48.36918980791214 w^4+0.05558121550962603328444615740839789683295133994802959460661250326750682603092`48.054534541032034 w^5)-2.449693320505208609627968936712670685852180794269611671080992710431099732908`50.98011257426909 THRSub[2,1])/(1+0.11692622057442398991603732899476661092638549411825959645543347149110010008028`50. z),((-0.56800347100418471213075424192187349134813384408973558648437662860069813934344`49.69897000433602+ 0.36117760148316505351223993805438543691855296441892260288635426446482911642225`49.35106129825434 w-0.62432734411467588454555232106869769435409593370109673561117670253937053771583`49.61685344863959 w^2)/(1+1.09876597547384884713413994932734870895323959799686887212501218568006800998166`49.52287874528033 w+0.33864046209754977111119454628843398866110498917119623342698493295684708093369`48.77330975739151 w^2+0.21360717200702024112042781957430085122028752294245749704941586456783806618267`48.765355544636115 w^3+0.06731125261455841880809799298635302600036595135021930502724738903716962101427`48.38465415570922 w^4+0.05503773510163178767927253884688935949961788517649460316583435439860687013684`48.033738401344685 w^5)-2.46765028224703814024983443120994362719260269061230478601241702017957504124883`50.95389181252061 THRSub[2,1])/(1+0.12511361335678453527945097920891124267193532369118370695319671098342554133329`50. z),((-5.8893684455941846094854988693770411370149984172998520308614277930510479775707`49.69897000433602+ 8.39573615161138828901641548373330620223247349137918303417111143574593347876376`49.45868460900302 w-12.15473606609614740883910247742864517863836846635944617459760994861804085983236`49.508988414924175 w^2)/(1+1.76620638798064071616146404558494531200502301858178843300816818419545849219955`49.52287874528033 w+1.18666331633071560223177305882856898335619554317655486477783382180189352723378`49.16410684501194 w^2+0.64605876113214798520863836950163288747805492371169098707415633445631145248344`49.637476104286456 w^3+0.37390953387530625422318174673778790474679335063391398126374468576496641712925`48.29941999514478 w^4+0.18763812558735752689469595890424239069665524031178330583688633811018852803971`47.855976915263575 w^5)-15.43747083411994760530839630941761498350176827973429545289416967701882713971651`50.06654958642665 THRSub[2,1])/(1+6.03864267810695210413861078624369358061575281434695013456889779240375447255376`50. z),((-4.14760813360507162032581048445586524779027984343050447787326957526613903676987`49.69897000433602+ 5.71452071962343723080029808801701804333274056221857689303570517396682601214853`49.45119471136474 w-8.40770918058092842828089467210878326665037388454693246098689394630570470857538`49.5369691456739 w^2)/(1+1.7486781148178452337093752028007038248990347107384855916405546619102629003123`49.52287874528033 w+1.15226640528430748609172545128010043971602387032136088242125874976538795111369`49.14633654977399 w^2+0.61646075734755112101327578311001234380588958343146063030094406688201927193459`49.69897000433602 w^3+0.35246104423158862715095829993570650026862105298065939337000860288228912418643`48.314840545393565 w^4+0.1747381710550804000230624410278306560148443080226349287910396536097520372904`47.85804729352431 w^5)-11.19225953988551944270150237996495100611978596331175036782393410894742384051524`50.09472283942898 THRSub[2,1])/(1+4.10305842896051404149011561458586244762060061869030039823533548804801816964176`50. z),((-2.86301608764939938869338552333882867635541797276240449754513669020671486050206`49.69897000433602+ 3.73986932785699710267046673717192918128838864528243616805828143743503438603288`49.43947844667536 w-5.63889819929817982723484934906926707392072535560746367442791453200837536937829`49.58090585839709 w^2)/(1+1.721103174240631547237951896132534148533258838787679131701789227709095728287`49.52287874528033 w+1.09963437500633171205019114595780487026247318176282043143320831276025912654398`49.12110677992124 w^2+0.57320861619162681343549925005304329316109761701480919985489767996088337596627`49.581303172605494 w^3+0.32222334004628024989379493966343424951663272515313038308517452896855988150677`48.335700783400696 w^4+0.15698156073293232618546462749165508801328643454318149034790024024907898018819`47.858916856192195 w^5)-8.06130941750793594081965842150734836040794479184035575769306060146895883598252`50.13791074955225 THRSub[2,1])/(1+2.67551635350062828408152141236891174552301783863383091835994833556728748869329`50. z),((-0.85492652247358686444433198998634945992894966841444212777886872338469063219702`49.69897000433602+ 0.71117426566202517579170924575560315661828770990656248656086128916110628654451`49.34951728839949 w-1.25875245291153002153168944222196993160321655041058781851053164502063171504505`49.69897000433602 w^2)/(1+1.44401725777492224133333022347824489707231907036498531025961471782025025896115`49.52287874528033 w+0.66297110866166530817638459922541026372694180582902726085353452256753001495796`48.93335679224227 w^2+0.30795235513648484310556062683334062541970219850370875736312489935246799581605`48.82940777650184 w^3+0.16050878598264195795917072836954997451966952300841226054089127720655336718593`48.4413251070137 w^4+0.0724889754177638022160685789884399155650762310418441028513262237186317818627`47.84245790589423 w^5)-3.16697094668627107866211324996091458128058983109112454989696480635839022949175`50.512207524941516 THRSub[2,1])/(1+0.4439656019561658905181677144817816406832382748081197337824351099103393508673`50. z),((-0.97492804514065045343771828209755557341265352757956331643577350230276439921379`49.69897000433602+ 0.87999822248741266937661356803400975790062817242321220381021148430861881907349`49.363012991711344 w-1.5263063892092041828306303587994926087895767125332925724709091106999668582458`49.69897000433602 w^2)/(1+1.5051242486046464540316274646382512832101206497751226066073870537623990692607`49.52287874528033 w+0.74547262860536507896592246060530737850870336777142151914317317387537180863198`48.970170682405744 w^2+0.34525775054780581392933363301065530691086729248583796078868357583650672999758`48.89489479816182 w^3+0.18237230323215075522573181263658028829916771963980348018585744196721045228052`48.42685897558091 w^4+0.08247771698691218886143004315638119289810526368578993126325330348317902392613`47.841630964825235 w^5)-3.45945195905344880215590336954049206794871301462541861467657653854523347894544`50.43650275282483 THRSub[2,1])/(1+0.57732095260294844596965949336755794667351283781326162818310971323347737383742`50. z),((-0.55722346578644443144528197783199166405580570099748780315900195705985173566676`49.69897000433602+ 0.35081955649795714003098739530130585809665486112564108120022817021538052014273`49.35543258618231 w-0.60153584567559980370727086359043482700793625121290124316452138433685574286377`49.61295232014831 w^2)/(1+1.07385434049679614390998695010990174575220305134016789919147238912253287559423`49.52287874528033 w+0.32467737195421263976473224343520994218150735669382807791743629877539951151003`48.768286656972094 w^2+0.20979377749628152983301376332244324833012762995540744930921110140677441064606`48.77322847928803 w^3+0.06055817108251390001263635003458119119750156435313951966732625011357250834294`48.36108444987108 w^4+0.05587577686045652326453744319110389544725284717647270185298504870175955056299`48.06478047224466 w^5)-2.441376058642761208431683648227803553974964703707025393239420662583137280157`50.99295429232074 THRSub[2,1])/(1+0.113134003899874985554284393048051712037625542724340768578968263364663721616`50. z),((-3.36222063336503873773990496383515924246716964504017797680754942913398321549202`49.69897000433602+ 4.50670316037735968988487594114436846502436245451226469006814887679764730442553`49.44514572569092 w-6.71580339371280490836612568913450636114483348975674929925442435234657939662447`49.55956393639418 w^2)/(1+1.73448110003322876520230525616019576159677642257642224974834601174273797583267`49.52287874528033 w+1.1249454418302455858521483609023656677341590540410005093142296554259033582671`49.13299116698638 w^2+0.59370233899669561541431587742044181270401324395014638202969561443107459693476`49.69897000433602 w^3+0.33638635029218348183426585751248364816245592121802324713820825478305856038239`48.32604812455364 w^4+0.16523413681427155801531516882987312374029738938509237804509924038855622205952`47.85880253693619 w^5)-9.27802606963156378060791314915025868480592323611927321744148202895281333794183`50.117129179933436 THRSub[2,1])/(1+3.23027262457791652410425414426193763377830285249128523835484596641973455441617`50. z),((-0.70637468925695745912399236058030717017215406164042588385299135802396493923608`49.69897000433602+ 0.51568113853184536056074645414487416885077160432836258499825601710609781005152`49.33558090057317 w-0.92692713266594983975171667604123493938118636296232456957256569843364094153349`49.69897000433602 w^2)/(1+1.32050554234311017077685570283602874924964775600546918039120615830838574067989`49.52287874528033 w+0.51925500546923402591171102070656089944727827940599517694169886964947309348155`48.86399451575447 w^2+0.25731246561635467156622645060998822743222751916884075185648986557783637788011`48.75626142458029 w^3+0.12522859404479008274532151949556679012367322705109602637590483382023749950764`48.45693128531777 w^4+0.05951800549188984633308793235935951003296748517184156300406239542602421023769`47.865615258098664 w^5)-2.80490395284699127959518116010629053125777271383988405841246760324293028548806`50.66140895756237 THRSub[2,1])/(1+0.27888284827488107881309516899854257173094559593882607145404299231373530222899`50. z),((-1.04797571625382453297276156566138390257808404481272848337881231179447685146401`49.69897000433602+ 0.98542676519533040361695485754758929610982945294756692039254366656508825822167`49.370543354699585 w-1.68853281662967064772072604607977483281296649641591934387314049291858308949441`49.69897000433602 w^2)/(1+1.53292961891627796058883592540820121095805440561003997812511052356677753657927`49.52287874528033 w+0.78553949833009954681547511127192930743849358407249093810167941274287179820919`48.98744427844345 w^2+0.36554656199850120349997907948900355802454950573384004416667445331592679676006`48.93293935776272 w^3+0.19396516318121355903476080217768165451580029312088726728588315538990244144082`48.419079686865786 w^4+0.08806974770563411820047757160542829012883984279231534022179208589682958301045`47.84282547332647 w^5)-3.63749183990997558014399137300793139487529247294256110101231004480216043972497`50.40116072881283 THRSub[2,1])/(1+0.65849740419060683618466948379138546490765742175072423952572800893287175556829`50. z),((-7.24089309155332401156924232524456628325513813865846124040925690099173975510535`49.69897000433602+ 10.47728560520350877954397492127173197443802866107062162269569041689295124057434`49.46195034518613 w-15.05994913754375581394923069997626179322896198416189584203462590802019263997668`49.49670022550967 w^2)/(1+1.77385193732540442066939873985806709795822642260564275875430632445770434257483`49.52287874528033 w+1.20190068039202902734531201744587777261968102216133145451470807898043204750479`49.1724024134402 w^2+0.659508415552984733754990158209272837386842885896297378861442516264974118426`49.54350627599271 w^3+0.38385709964763578903932134712250935621819920498505044851154861405932621406651`48.292071175940926 w^4+0.19370260137391512666504343850071200035071197948786534561406656708869228610003`47.85459664324543 w^5)-18.73155650823294705121575727128424488686741008142706290076590718188302555432341`50.05408271004268 THRSub[2,1])/(1+7.54056564594873964090545374253550125075151784006409754704174247500604451148994`50. z),((-0.55847757725515916793237907177619204797916622368522506733860225845833646956015`49.69897000433602+ 0.35201066854878936981725023575410696217514934297786484722599428939931682956585`49.35488745697408 w-0.60417858176189008559984171663144702548348550997766172459504639560418619044583`49.61334890367346 w^2)/(1+1.07682682086757250232677962747787358785633923642243848504851959480058901550804`49.52287874528033 w+0.32627526522696036590505704309911370358804550784495913451210499084084836573909`48.76880668494216 w^2+0.21025646183501617205192694701058432144527277326461596239553112966662911839542`48.77225443213498 w^3+0.06136281236047348061931560722137838877719187521925522196117730670244017595602`48.364137428499525 w^4+0.05576435493058838043337846949625220355475195411240961924999415662179982206418`48.06096945782456 w^5)-2.44443271812373002495589317797226650107183241294725911423964283551625965980302`50.98818041777207 THRSub[2,1])/(1+0.11452767350458998997363466970250610209879905040629451033496413350357732634635`50. z),((-8.96294091633555156707977002068894185757313472427887220681046164355107518886321`49.69897000433602+ 13.13006244994816291074016402920734391884147902951086326209940207674174881088378`49.46465362437118 w-18.7602602440244543356807735449871510707323481096246350960208366468714640167604`49.48645308199428 w^2)/(1+1.78018974210831137628519804421827265070905747320784101439150396113893035252085`49.52287874528033 w+1.21464095084066170504440003727799081404643046033172332190003501235824114524926`49.179574086083974 w^2+0.6709138133536610489773867437510594366912168205314052034564268357157178201211`49.4763338694966 w^3+0.39239027205094366704817720664721928332437340551323266837506012273015481192803`48.2856613412573 w^4+0.19894464056113219471307028687204963829009915809736663458287666336363351316422`47.85319768678182 w^5)-22.92872234365648184040725752817810419073529583954036779755529012823041053581563`50.0436658265315 THRSub[2,1])/(1+9.45424379269606264085541516018633935087014514329156437825378655006117674844313`50. z),((-7.75174094864849098761901933678724315000085018818250124113311746487076864269398`49.69897000433602+ 11.26418655822127679532769912059516395738605827274973323439353156372066378421121`49.46288077278925 w-16.15777399042851935658977409313491283900077271444716196805704215192126572281531`49.493182203709374 w^2)/(1+1.7760321365806078327370079012055299906139699046758633468999362287165409076505`49.52287874528033 w+1.20627210467161569698035577617668643660138899485254864747258412915884507460589`49.174837671726436 w^2+0.66340539648124085228337707615286681691227365974070015701133217252551228104362`49.51947192787315 w^3+0.38676266572207963630687114192107463092741233711600959529171235665116099755827`48.289899804236576 w^4+0.19548344324797473766105050160393932317301022138045361203258056728799606844027`47.8541426712458 w^5)-19.97665152942976334831704163640253240019022310222527705728490199659475096699075`50.050507747618276 THRSub[2,1])/(1+8.10826090177553342983881874469192112248570089509916424399525191879791902314414`50. z),((-8.29298345823118261487099401464222504482504669956527504694947187611779432594885`49.69897000433602+ 12.09795587782361598246046496196396861588899293947564045533844635655202878344774`49.463738531765934 w-17.3207960347702044202457243328272461382326380551685400252227900292628984556962`49.489930930568 w^2)/(1+1.77804309956288984083688615949165128832008614924636097034389771008523109652528`49.52287874528033 w+1.21031462091132627948620030428538773044212713121431669949156390167419220744252`49.177113106230365 w^2+0.66702443338797940477154048265366134640209723961715192326963310552030634579872`49.49819310937455 w^3+0.38947033615421500933912273913553938433399537132885195030030971067670725309186`48.287865963541826 w^4+0.19714680041115699454060192398129381687091700529194342975391185215750948134319`47.85369883877437 w^5)-21.29582776670217979316424857512862134889886782810160443515402920770041487958373`50.04720244527723 THRSub[2,1])/(1+8.70973314184532336317218694614966777084978512802291199638514673932383472939789`50. z),((-0.6798320622768561626365075319130939266195936081260581296600523402153403123169`49.69897000433602+ 0.48335899871045488202812227315442061360116342552112352097718966400337009580653`49.33482646721893 w-0.86796106884017844537489831383724948568945946102600314594719355377389661013036`49.6985750119686 w^2)/(1+1.28891720782353328385728077109852026997257828169856119826918160171518621293372`49.52287874528033 w+0.48742503538070954629643892630417861115576474730703049246194524376763909795869`48.84768085056411 w^2+0.24846072581194223627728593512739120402464796655126171913983856574467447054772`48.74814146861347 w^3+0.11707236506454864661968914348481187471074846654835586831242637191212717275644`48.45672944743585 w^4+0.05747300041502468638601478432011575198191894670276620760583702026991257896515`47.87804399578086 w^5)-2.74021132030796154323604935686099478919638082898552543513570368266209981296856`50.69982380629983 THRSub[2,1])/(1+0.2493865448168111929298993761656180983318349700059403288723801657921799832796`50. z),((-0.54865076367644987352073025048403531960146529126217142525400826079586252406469`49.69897000433602+ 0.34277667874129436083884529944740905686665774676636700149795368638926574208147`49.35943422548817 w-0.58353622060921404464104292810449167801905622654148758468868334902787842459716`49.61067781977822 w^2)/(1+1.05299072056483613179130720915004516365213624151192808559707433293782390631461`49.52287874528033 w+0.31398232655013309606378484211474210649979153124368382887589326641075869969597`48.76528146002483 w^2+0.20646144337340375504757973673235650046553096277503932907945999216424559887791`48.78026733404196 w^3+0.05493784184544504833690489832346823336606191593985495802017634540816372898137`48.33770223317821 w^4+0.05673524495162364434863988334763386664666534867402069554633514135201858833061`48.09225327857423 w^5)-2.42048171883667445262780213187233568364230101843741457253064518163910886275613`51.02742410461288 THRSub[2,1])/(1+0.10360732731727432590947004969948437193516493495445569288236824400852640633119`50. z),((-1.77841377879197374378019939032373581555289900536450299338620167587658011884906`49.69897000433602+ 2.08031725801987345498357657899175841904458439897331349271130888079135529961736`49.41539270682348 w-3.29013262735963002416111543581241368183767384665301178766927485146046458054078`49.67699212332955 w^2)/(1+1.66248729930667285197045321741022565192965788645599076697396365129492918473317`49.52287874528033 w+0.99355017796950177553422583350374929678423257480259942606582066359790632889023`49.07453709655398 w^2+0.49344556782081292632647530124426005643229696166569993025248911400474388828661`49.23419181829326 w^3+0.26988973103475063875441340321675224302826541518080812029795986282952451545539`48.36998941977785 w^4+0.12753218190429802702061952076270834588027238631098647761829322771302805153928`47.85518006786333 w^5)-5.4177964498390177479524595776155331134590702294063027788211870976969130849304`50.22535343039186 THRSub[2,1])/(1+1.47021897063925130978013011516159056332021855931512718451824970910613108440964`50. z),((-0.7485781452889258943339558709378452049647136895391523881266819711903010942203`49.69897000433602+ 0.56901663964315447915895844472412108941932064507102150630520759590841618519173`49.33841362683018 w-1.02104185655775998938702330293018452292586013453651981079111546788672041109317`49.69897000433602 w^2)/(1+1.36352436465007425119581065518443269169407848399030040244251377720058385541849`49.52287874528033 w+0.56582835002519111438670428683139745502186300761125065033059584561193981341858`48.88726798473506 w^2+0.2717584255684469975287673416223098840328834719470801959305610552071963849805`48.77383379150431 w^3+0.1366889052748407549841978115356768903743386428660819255245006581942078709005`48.45405749855679 w^4+0.06309599676208510760010503317326219101987994106978363315040526278928182186387`47.85346078066103 w^5)-2.90776689384375362562559044410387079847318186642894632535970326281694833124272`50.6095443037372 THRSub[2,1])/(1+0.32578272548113868440465522852696517441962847511286916868318761724287699262589`50. z)} /. {w->w[z],pi1->pi1full[z]};


(* Pade approximants for the spacelike region at three loops *)
(* In the construction Pade approximants with poles w0 in the region *)
(* Re[z[w0]]<=2 && Abs[w0]\[LessEqual]1.2 were excluded, for Ftri3LoopLsPade71Spacelike *)
(* this is relaxed to Re[z[w0]]<=2 && Abs[w0]\[LessEqual]1.2 to obtain a sufficient *)
(* number of Pade approximants . *)

(* Sample Pades for the 3-loop triangle form factor with LME to z^4 and THR to (1-z) *)
(* Mean and weighted standard deviation *)
Ftri3Loop41Spacelike[z_] := Module[{const,ls},
const = Ftri3LoopConstPade41Spacelike[z];
ls = Ftri3LoopLsPade41Spacelike[z];
{Mean[const] + Mean[ls]*(Log[4*z]-I*Pi),
  Sqrt[(StandardDeviation[Re[const]]*80/Length[const])^2 + (StandardDeviation[Re[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2] + 
I*Sqrt[(StandardDeviation[Im[const]]*80/Length[const])^2 + (StandardDeviation[Im[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2]}
];
(* from 20 each of [4/1], [3/2], [2/3] and [1/4] Pades for the non-logarithmic part *)
Ftri3LoopConstPade41Spacelike[z_] = {((16.26919360889307587881605115743075661165748053119501783292510835652766793663574`49.69897000433602+ 47.62228721752542652199250240982271748786415232886259327810635706101978780119066`49.69897000433602 w+21.97075488152000513909842763450321006598293780392911297552266429705801592037217`49.69897000433602 w^2+2.02392928171719592498578620403407609702345182480529224050173576297146681626068`49.69897000433602 w^3-10.23842085710506137829062567456416884584168559622602392031737662547301920090451`49.69897000433602 w^4)/(1+0.03557207925017423508952251979958559224691858824927151670237281269427665058966`49.52287874528033 w)+21.02709132616356910034574114360545783163218622014081370659158375821287888127695`50.46755646469976 THRSub[2,1]-11.12693556475626131622094648954720205071080681620472551555703622081588621981253`50.87487565082031 THRSub[2,2])/(1-0.11769143168711682852726768438446005843143611518029755808795652222335999291517`50. z),((3.80093599277933726705242418425545708803982070341630675221125815210294246658792`49.69897000433602+ 16.71480865347585880070272115840505966312614662995491851443672585815664611198471`49.69897000433602 w-167.5689376953319774002165756619922885340467302277968800698569`49.69897000433602 w^2+118.4298314759211652841186979756265114280821318131091842865708`49.543196558643274 w^3-23.6787292056486211587797124461048046184104302509830539247537`48.88362660912666 w^4)/(1+0.62488344347871896087388537330143964179366240254423164946252693936254660485917`49.52287874528033 w)-9.361928154308618769547649344362675111085797277648925560302`49.042988750445716 THRSub[2,1]+4.9540647215077959669194346425257040997434693425954825411474095356359914789429`49.45030793656626 THRSub[2,2])/(1-1.39283176633176216652493069054552316344049351993981377937841606004700248252144`50. z),((16.0606275467140289202382275705265410956968842694411333686839345453963719341568`49.69897000433602+ 48.39426053862667988824378930841227557341246752786128596132852724362245669380765`49.69897000433602 w+22.49899053800737241608788062784430709727736394672841131318622890054294574036476`49.69897000433602 w^2+7.11578225654403993603242804167154376751716287064446611438364741341072545795688`49.69897000433602 w^3-12.29639258303779413056751786392474414623808994156921417526857374385925848708055`49.69897000433602 w^4)/(1+0.11816258834612806588476082017189875486969623969579367167197146524049182635774`49.52287874528033 w)+20.5187510013427883268792439879674622082653682170031690726911568697328363125367`50.384590506740466 THRSub[2,1]-10.85793639832328361954997016004005895806621047618362996404768560123315934033258`50.79190969286101 THRSub[2,2])/(1-0.13902167738069279719989789593126913135929268360830997047896839502832996291327`50. z),((16.35940503225685616154861442811279443444798633212177037630570189148112867490181`49.69897000433602+ 47.14823138942316025854408730130943075387150512988252857135063140093393028474306`49.69897000433602 w+21.34007244702678195141666411957730858729481600857122546664294153448072602854306`49.69897000433602 w^2-0.51886684161809607832379147866359875646160249719945929938922167652462927464974`49.69897000433602 w^3-9.15086836356177008402399661190257292804415213778449228585396053574259967576513`49.69897000433602 w^4)/(1-0.00806562508522405390415278519463953799521186389010453547974548052090702601064`49.52287874528033 w)+21.24696460648623923120728427697005396465920531530605992564596339618912464874235`50.50752768071224 THRSub[2,1]-11.24328621852061687220164263955748385479914015413618360683730893595794023459981`50.91484686683278 THRSub[2,2])/(1-0.10846542528601431111104221594120380861628793971768037035117963993106617223914`50. z),((16.31209355077061581519376289773687076875307927825368228697135394154532893836001`49.69897000433602+ 47.40933377640101326121637169557127676826049446192636724886097385927899691358356`49.69897000433602 w+21.70665902779065306064338652070298539048696906270896319193671010280576688510192`49.69897000433602 w^2+0.84499328982644304353879331734376323329780575803669766052006901563602685849837`49.69897000433602 w^3-9.73877970575180175392968129613868150908175235829224570498071271824024683871405`49.69897000433602 w^4)/(1+0.0155253066150489798043485286578841087955637312389742531878615011836261148414`49.52287874528033 w)+21.13165181966370542026391015788067608108601971215459246682078842330248619949951`50.486210257841144 THRSub[2,1]-11.18226598852949576960643442113397193198876340351545995776671003886985666930305`50.893529443961675 THRSub[2,2])/(1-0.11330401462161888619019918579225472122284757983490105112830566097129540959255`50. z),((16.09058051323710666744574150711999588785025795688824565568593175218678055491244`49.69897000433602+ 48.30654328454490464081734410555997573056128092858550271894301344779911089190943`49.69897000433602 w+22.4895586296514313192407391216718398598893916952364977966319522294029048538809`49.69897000433602 w^2+6.4408090190511043446596180669789824684044276023100234494355468847398624231906`49.69897000433602 w^3-12.03352484554994929753117399192987351115186595476296005484372645478102051635801`49.69897000433602 w^4)/(1+0.1076084403087037680163379494305784163042025582756544300866027534156249866614`49.52287874528033 w)+20.59175569142806234812149515131681821203954799011929398356118357207757041889169`50.39580957080599 THRSub[2,1]-10.89656839311055566880192251215891107993275418043316322963774431545758827728577`50.80312875692653 THRSub[2,2])/(1-0.13595835955940590665205704689206901612292948372081977476994914162820661898347`50. z),((11.17174424665566664783677850960939021869698543898296598770781145330789196569906`49.69897000433602+ 39.78764167010591087089451534419293977310385376685344018562811922037380833421252`49.69897000433602 w-41.74217670465981887782607246292193217918251289287872111816916824376379790084053`49.69897000433602 w^2+61.35282527927789525838323907220123917401470744241961936166602718540024894760177`49.68327884977538 w^3-22.5926314694602024115816768728077244961624090001602384411667`49.25427617182322 w^4)/(1+0.54732284130733385277648027460083799251272274836028338053011018278964813219153`49.52287874528033 w)+8.6030227241838534009937683165160460867681818965109720628053600815112010236165`49.344663940283546 THRSub[2,1]-4.55247366501036951596566638744432394880350011920955974746939735237619690921176`49.751983126404085 THRSub[2,2])/(1-0.63901233198653919856692108929657468271693297960996336698867527391863853503014`50. z),((15.6171826497707498444882433943233609567090976388717428847674250693334866159749`49.69897000433602+ 49.0687355381393184376381623171990114011485423146171375542240159566597952723239`49.69897000433602 w+20.84754093755087925062694818320871269685995241728524857210099105108195830223412`49.69032282463609 w^2+15.58841897899852117387291847038991222365797282615726193217782894593889632208908`49.69897000433602 w^3-15.30364637648761770518707527717941205811380587891804872102006911219746559556204`49.69897000433602 w^4)/(1+0.23918423598063954799942366811951316953717526713561373201855606215016087932717`49.52287874528033 w)+19.43793794577122630495857881615955110597472831447635788532258485996918229155497`50.23847450631239 THRSub[2,1]-10.28600102978620838570225989765942064102912269402600077273430682388722372450136`50.64579369243293 THRSub[2,2])/(1-0.18437320056015698753080346281337783129663577812347597087684057835241526099024`50. z),((-3.06112196934071364691684684307548987686054062878832008488898453650115829837296`49.69897000433602- 5.64193082026026611630335072339814366915745085534089953050716136951767463812939`49.69897000433602 w-287.2256832142035180603238675189979112346457600934859170247789`49.69897000433602 w^2+169.4199119831808451237703260382649911635121813842595438182993`49.497853380529676 w^3-23.4318996275787058357041960979463873218604555741889381728376`48.6868742273134 w^4)/(1+0.64767465758310117574304361431242608330701761953908979472280406734594218985609`49.52287874528033 w)-26.086896430348547778174811579151818523888020903050596084515`49.310839104799115 THRSub[2,1]+13.80443976594066541726159758025726326238221846725183283396987401167268958715647`49.71815829091965 THRSub[2,2])/(1-2.09462083386436344595891892922527592776177061695202999025518888922383784926449`50. z),((14.28205080277727887502469168147216176441109927211711672496331963021528161308194`49.69897000433602+ 47.76154620620115246937822312561793064054501494384786735919887812470842141305662`49.69897000433602 w+6.29706153247263926358200659869077713977827252979089779508565756201017537740316`49.18597751245937 w^2+32.95274677276068579743872038522773524768838167396032706067560123234671044992891`49.69897000433602 w^3-19.60838755046171557136475570496365910859285313216924326047027545282328088347635`49.58664985421873 w^4)/(1+0.41522104877808521540075363010601209664371037902712702666774637614192942565225`49.52287874528033 w)+16.18380661832358196306927584015246262529469109138259766966613785382309139111616`49.918208199224956 THRSub[2,1]-8.56400776699425926360681116292455926357057860233769574377877533856520134920161`50.3255273853455 THRSub[2,2])/(1-0.32091837973336597406185548639704749780600904643287755246285430628985472085588`50. z),((-36.68158149569611811185213477780107431143176823709667337773213005302608625172439`49.69897000433602- 116.6515395419772591435950583389553606678703481044090627829367`49.69897000433602 w-877.7082080364379080798558212353352017231300304824937223544076`49.69897000433602 w^2+415.6333805438222122783941074020422233224172991011074261455317`49.43722079671173 w^3-20.1064129885020365983272451699287726594693037428917389304238`48.180044353178474 w^4)/(1+0.67627110141461994961749916841364402267900007434630952231201257103780615109474`49.52287874528033 w)-108.0304069789615972026700182357053212271826277496280217418874`49.50610614990256 THRSub[2,1]+57.16660278131851985525843190205201368991396634323819022112612039727968900011662`49.9134253360231 THRSub[2,2])/(1-5.53301658500269205808874198155127254269295899960632562897752154778316934790845`50. z),((16.32762159804003752863278280299158076024739531983110258813567250811547371973043`49.69897000433602+ 47.32680401596346813797168431750346123360013276717243394208837980353619487499614`49.69897000433602 w+21.59542890566502558273025687058591182244884367994132683964517954456137001181659`49.69897000433602 w^2+0.40504239896874574791102275275741371857342080067615930529497935656971465684433`49.69897000433602 w^3-9.55026881407799757666738721424525740233352489039229212101565129201720416730911`49.69897000433602 w^4)/(1+0.00796140812048946449814400426845159325029029460402380259626316671301665312644`49.52287874528033 w)+21.16949849764333730862894740535353770582611629499128481601578934811733413661113`50.493117509138145 THRSub[2,1]-11.20229336847887830572432005144561267635597206168408396946374600327587458255068`50.90043669525869 THRSub[2,2])/(1-0.11171594674548529040307261889344129749305221165789270010798641942443365650691`50. z),((-66.5151499882670588848527817746091865799204226769070974233956`49.69897000433602- 215.4964001635912648919919812316326891181448125402961498291208`49.69897000433602 w-1402.6535112657459285046656863773723441375541187347443674370986`49.69897000433602 w^2+633.2833316664560464716601600600496175654285165113137485144704`49.423286830440965 w^3-16.6684975513266120333267560081869703981808256620980918251365`47.90386641642141 w^4)/(1+0.68253529066073361414928100617234288040089171645404093723388447746183688548497`49.52287874528033 w)-180.7440869498542719770564396241466309366995072803607785780639`49.53889025283975 THRSub[2,1]+95.6446033360461680269056123250608839379735238269444477979226`49.946209438960295 THRSub[2,2])/(1-8.58412345835571920013158996798961749134349340212199929877882379220867163512691`50. z),((15.28462374695104654437080907885856511097280708629723062122787352619942104636149`49.69897000433602+ 49.06228578235733598201012350467874327757912608655054203449809365409521909041845`49.69897000433602 w+18.13905752853684089016365589584226527603538133068871945439184554452295005426106`49.606292508067284 w^2+20.69315837443918068934826114686919760487004263218739179338880758540038412092126`49.69897000433602 w^3-16.83099268411116930842547054291019139861121840228967449722625526696795860911825`49.69897000433602 w^4)/(1+0.30103631822717463733869796305325725771054388378488794840637718141334481285344`49.52287874528033 w)+18.62738852600856120626401414850911573420840518794912336838245452790670270115718`50.146452650459864 THRSub[2,1]-9.85708145047531801802947324480042561211632195283387703245647821302807235941055`50.55377183658041 THRSub[2,2])/(1-0.2183843097052332355179371977661838707938351930525338605947067402033557925235`50. z),((-52.52341199992139044354976875091882089572118042158338394630744275843059273485638`49.69897000433602- 169.1270923307337035866426984739813974376904726900159589076492`49.69897000433602 w-1156.4240690738166250801249553618169445804471413811041300967444`49.69897000433602 w^2+531.2358061756509601933075926204110706039664627239895457865261`49.42837805604498 w^3-18.2977385150114382614966429845489753513307019717504951032387`48.02501762008559 w^4)/(1+0.68025983070040338409975244177772450652125413107205915929498310875197589569466`49.52287874528033 w)-146.6418722391167358627771781790328626571859254502119891716757`49.52728123430142 THRSub[2,1]+77.5986862942671155175741418251948867528087647331774645493138`49.93460042042197 THRSub[2,2])/(1-7.15317536520264150880301691857248041086091442846595511716008227849587967281704`50. z),((14.0307724780551975397139225441366213786307831371441639461884136530743952006368`49.69897000433602+ 47.26352045655163200102021312980362828311681831941389725621705350591593684492507`49.69897000433602 w+2.83546650228521771199914554650313460591081264524540423056216447340583630835658`48.86621435448161 w^2+35.60486174819326844342793014945783148723384573310517844878390286260936937436848`49.69897000433602 w^3-20.05873661552021454514766398431856527832733580498686129548849988354743763704156`49.54916161204149 w^4)/(1+0.43413706554675833923549909043292875626809783043020958617061159147274163658948`49.52287874528033 w)+15.57136323287965327537058672442484357751662714538409809100645658805437917043763`49.867999076226276 THRSub[2,1]-8.239920237188532362939930267558461458057421460470673500011798153871414028056`50.27531826234682 THRSub[2,2])/(1-0.34661684835186502124341105715334735790659159466474371928249877103519040568159`50. z),((-78.7018937607624716825180089096802332531122784706599270384834`49.69897000433602- 255.8934111431813270860328470003341861213766128826496917157895`49.69897000433602 w-1617.1456805920371621145378917953559229843344427726092855348734`49.69897000433602 w^2+722.1428962850812268774257112094773134394527748610385811886029`49.420038121975075 w^3-15.2357236521733892992095565914650491330636686023208682072509`47.80503361178463 w^4)/(1+0.68397921696431734371616494616111938451800849113276998268983373806163328833838`49.52287874528033 w)-210.446969686834436058860178322010757246897966938000439171071`49.546090366687935 THRSub[2,1]+111.3625196743203351557044965064801254098754409403007203833304`49.95340955280848 THRSub[2,2])/(1-9.83047310966585861740827551022411055584051111812388944547954432275253495774819`50. z),((-25.8626313640782938992069827444176985909143703155134152927720769770529462446961`49.69897000433602- 80.843661746032914305701431622498246477803195694590302334661`49.69897000433602 w-687.4479988301939234907449808196301234472084647792703029744445`49.69897000433602 w^2+336.6119445719415591610895093934001099845200351686457370619806`49.446835822230696 w^3-21.2991704238837434924185618077628244262963472899496449144377`48.304785977009836 w^4)/(1+0.67188135280617925504427059518418403883573682740836480474484832964932292544383`49.52287874528033 w)-81.6612625138130988589091279440938840944045410996072638937072`49.48147258370844 THRSub[2,1]+43.21280542483986094941297574622308439084033569822176568094444742431677195744532`49.888791769828984 THRSub[2,2])/(1-4.42655246498758998977537595070090987373044029390423529326593419859273947902007`50. z),((14.38816664072709199735830401403742177052516604550657881876836554946439752454772`49.69897000433602+ 47.95671937595554992999883036343820419168585233979645978755215331892266113102614`49.69897000433602 w+7.7154490581087971125089373529316673932888465785705330170188983309985450197917`49.264728757791495 w^2+31.79570550084205821707833930640203401401095795434687331507685199067514377183061`49.69897000433602 w^3-19.39654586598022568320856136217464291763561434819170741099103507622112565783166`49.60339577587284 w^4)/(1+0.40637855743798589635986881542929093439217918461009158180733653318074415243649`49.52287874528033 w)+16.44244390076759300787473182279023456525032588016253700338069068691022983614899`49.94003459229278 THRSub[2,1]-8.70087122241747037752927123578018342192655257998133411366468267019674176630857`50.34735377841333 THRSub[2,2])/(1-0.31006581401964938762444415465626890574175761762410478921098791868004685656078`50. z),((-50.73303423490771816377429465967042708954741357680412246621857844839445400788923`49.69897000433602- 163.1948827856956459439297903054553582074413171309636867274156`49.69897000433602 w-1124.9200538538441711168681819991991144884730575209175378829892`49.69897000433602 w^2+518.1749234001591478629788579498212971441181690536566729057237`49.42917656384695 w^3-18.5045051133470410723072921678333791101488307247426993898597`48.04138830817842 w^4)/(1+0.67990155138130263103557655336679039892483537780605979041876799745018440342372`49.52287874528033 w)-142.2781650994688424944988138844215238983036231913434677362947`49.52542311587899 THRSub[2,1]+75.2895372344580975640116585233398483997963649632101763288998`49.93274230199954 THRSub[2,2])/(1-6.97007176141847020209051292194452233331546965594013945499638041220210779809878`50. z),((-74.6623870251137317074489821178256960221259790119509565932893`49.69897000433602- 244.2593992245692528402086187215810121242440058360856898551061`49.69897000433602 w-1551.7842777742986123726170908399071630119747785097617620027948`49.69897000433602 w^2+656.2279801689775077301526341534597541521893471964264665737255`49.343552598295545 w^3)/(1+0.70707572042618416281251711235453837777916043589235113785563157599244814398726`49.52287874528033 w+0.01650218318066824470443858685055747660440596825092560249597049106985129830198`47.99344174954134 w^2)-200.6014361198603448892016312477845345942260458676912965050133`49.54392748272606 THRSub[2,1]+106.152544794720414014779438470335309384328771839045545397999`49.95124666884661 THRSub[2,2])/(1-9.41734898845445061120702355508779238069191307443458374926111389443584790004578`50. z),((-30.60123580521154049151027091328965093943030407628151344319434139226063024961734`49.69897000433602- 98.4036770575243311456474446405455705796033713035794924612655`49.69897000433602 w-776.7868034387848782499277412803829997373649396023540252340571`49.69897000433602 w^2+323.6468098512164911462800951845724926680868348671014986013474`49.329643869828125 w^3)/(1+0.73550650378669393350735955641523135342946012146491075768191280775525860518362`49.52287874528033 w+0.04425285585811688302432098558966616709210576478074222502044111493188834437328`48.39196145018064 w^2)-93.2107144986474036228514220017844971144655370083424430981681`49.49380262902604 THRSub[2,1]+49.32444521610263575315767250620631598887605371286245394913924044700278923598874`49.90112181514659 THRSub[2,2])/(1-4.91117396053691089527878955457771706462391507462622064466439652029295439006501`50. z),((-52.65354219473783798654747252850690027477871840966170201724305399678027749095732`49.69897000433602- 171.4718710415693187808409857793838947426638484447024885158524`49.69897000433602 w-1164.9283960233738425184379415351486620566704343160576186992882`49.69897000433602 w^2+489.9411923955860279182000610985955606067158355837699694600235`49.33869268794673 w^3)/(1+0.71662829557905737584501283044302996518834511651213332663635196796047650845503`49.52287874528033 w+0.02571512428648528443119659891781965169206435710309183819806369916283109508863`48.175896815279124 w^2)-146.9590399739383124825170929022729377021007434550264479100848`49.527412286302805 THRSub[2,1]+77.7665223917014854553970419803930346374745422739929620486881`49.93473147242336 THRSub[2,2])/(1-7.16648390158956758061024763225270867706938314680988329551717643829430187055043`50. z),((-18.2323457769984274926604655783182847052615706968391818480846346104977006904999`49.69897000433602- 57.25776703042500808915721208119797587666255581592088538381579927835009888053456`49.69897000433602 w-558.4571990461705361338709905600258982852078281755697538041204`49.69897000433602 w^2+230.770752598509798739570506591351864862939182069527523201507`49.320232663268534 w^3)/(1+0.75715715267313241903003215127521054835534272647326865351249730316947148238321`49.52287874528033 w+0.06605078165931119164635836654878158825573241120298370318400423820380686003169`48.5440202461005 w^2)-63.0638847176033910830574906354651096635783251489545558274912`49.45346281408618 THRSub[2,1]+33.37160479456660548763304315070454688144875247147696645228723683567925529794487`49.86078200020672 THRSub[2,2])/(1-3.64619604177984558625579242964110114489345121072736822668985227160406328559866`50. z),((-41.9596331194931968879293814542845635216853022490533293105606831058176416062961`49.69897000433602- 136.0656293761149457220608176935609487419906800185656787873398`49.69897000433602 w-976.8085673623638811667296559253599101945935883872082723504994`49.69897000433602 w^2+409.2353245866199022132371110784450644060208081627019188574233`49.33509462629919 w^3)/(1+0.72394821167766969332294682031037802430732803276828476053465276044034051079399`49.52287874528033 w+0.03285098581146508359075595322241080251515809156394717130706876139215909262088`48.27455247063546 w^2)-120.8946594313023387826303300582734255625336414994080675631238`49.51453968626536 THRSub[2,1]+63.97399738980854005084535099295766997714665581098031530195114567963887333467685`49.92185887238591 THRSub[2,2])/(1-6.07280784702652652318490384330842727057624237527450445555965252685285084149846`50. z),((-60.60594256502312288388950651759888119500172272657666950420417365037452128760268`49.69897000433602- 197.7814817864150519677273909422865041481528922118754398210834`49.69897000433602 w-1304.7460312709914988026184974981131310167459969426962762432737`49.69897000433602 w^2+550.0033867327010847626691171617156632084529818365734270089588`49.34075396272687 w^3)/(1+0.71253251833072252582927467247611914097069949460061845959593487681559477724363`49.52287874528033 w+0.02175116250447937596604139960614769870171639340766442478220618166922352133192`48.10754124850498 w^2)-166.341511623929701902974782345719655097697947572359711799221`49.53453165553067 THRSub[2,1]+88.0231722435437418126125499615608008454291104879799355390834`49.94185084165121 THRSub[2,2])/(1-7.97978330408895816898712376228863041912360104109053781314448948275005744308028`50. z),((16.18775085822987617333709502652032273778419040050084049886295493213510179463865`49.69897000433602+ 37.29314804811718021471031847706442333285668950486623604383230377503965547913237`49.69897000433602 w+2.44731206013159785232291604127024672589603488083194781165928116350250324919197`48.64967822633305 w^2+23.48121981467211628631306575967377280283778868559135558599386584855089905985251`49.69897000433602 w^3)/(1-0.58913607876890367136263827929380376172742867913317872981240345072983284570791`49.52287874528033 w+0.68106273615305419150133974003055051966404478764552698082398122091286004683607`49.69897000433602 w^2)+20.8285900268923207266089157712837715218632011033062323259376427829841123916576`50.43374023941812 THRSub[2,1]-11.02189435233886306928409155858415617585901744525674865864076405285273823171793`50.84105942553867 THRSub[2,2])/(1-0.12602065775322232123174656681891035438226720635051568551680857840715414709903`50. z),((-77.5008258717940950278605208020766498401173863775385928114236`49.69897000433602- 253.6417845850923659937595129913797296171189368951447883912468`49.69897000433602 w-1601.657825131710110440941927977570677387587573204296534996231`49.69897000433602 w^2+677.6848417286908515410059107707746704751620082102732338951117`49.34401986379508 w^3)/(1+0.70617570873030492338891609175160306387190577032910586168626499075018092975758`49.52287874528033 w+0.01563998620320964784835616442439142485775628344147302622695098717468801532`47.97110521746535 w^2)-207.5195938979304085490621668286383249738635943112051045371403`49.54546761079706 THRSub[2,1]+109.8134361005769193830745770356434212789951680600347037002535`49.9527867969176 THRSub[2,2])/(1-9.70763877651166125777858003680694597423498064924982859678066566365376856244948`50. z),((-65.9475007305654049434243245636768578630797430288385546123476`49.69897000433602- 215.4467477643872928371999021709414947321515522213402391957858`49.69897000433602 w-1398.6349844493813325642308647745247867454077359484433706795743`49.69897000433602 w^2+590.3620188410179368557331700490696536961473929495208526286393`49.341925135760704 w^3)/(1+0.7102348453108135979841164886848992572696376982572332286057122941393738117008`49.52287874528033 w+0.01953650767421591342164840989751555968777882146264028141375915059090509171234`48.06335904156528 w^2)-179.3605492590644077991445272749083839993070159512842587138818`49.53850016952932 THRSub[2,1]+94.912474745456208775776257275972802815667403313001678771493`49.94581935564987 THRSub[2,2])/(1-8.52606943936504609762505877914691579177344017715943918826517703705806073144887`50. z),((-33.89543076323168554969487356263198171289031142721035373771756720843166283788791`49.69897000433602- 109.3346874086083318200422304190389864683476536608026037813714`49.69897000433602 w-834.8290326749890329691934232854160779882857592708317776949208`49.69897000433602 w^2+348.4497779794387491857685011133149349815932465398653059575583`49.33145477314428 w^3)/(1+0.73159822379093915167578673428371653858884620644238044867112879364072360963269`49.52287874528033 w+0.04037910885603581149126498210600980265031372916360043263540624113045359537285`48.356204689921036 w^2)-101.2396915886275313319597383057515843829155902604268836661381`49.500872943979545 THRSub[2,1]+53.57315034347095728866272991249690399811481336479076473778910982758115947507888`49.90819213010009 THRSub[2,2])/(1-5.24807435115169786742133786689050159700695032911689556376391772541594158220795`50. z),((-54.24837714237315857175415823695573359475458783757384362006201639946288817071594`49.69897000433602- 176.7493148861986842146000579354061193064463741761966904428861`49.69897000433602 w-1192.9727249694333370467390332536169573311651266671216044611842`49.69897000433602 w^2+501.9839424246986360330568579133782161613694082431473957646568`49.33914126547091 w^3)/(1+0.71573117141732738516266179743231898281606755006460310732633979407909595709126`49.52287874528033 w+0.02484510151867695222012111671966436670642937820567586127530851959636931437699`48.16189943220041 w^2)-150.8461484845285771897070597737741132921343797549259560747474`49.528976703545126 THRSub[2,1]+79.8234690829795363529140895388804908481050497881061874435571`49.93629588966567 THRSub[2,2])/(1-7.32958915907177123910810797336918554273791948933570179461439276930066858288151`50. z),((-3.43550375169203717669880426682005241051017839548213320101641389339614857700261`49.69897000433602- 7.46464973764675349099609485870680113239770037808256069457035235883095877559413`49.69897000433602 w-295.0421672088846751437930111399029350639052511385512562265612`49.69897000433602 w^2+121.1638910797809761308789314147683168833305567238030911168063`49.299085717093924 w^3)/(1+0.82181167189973125905051032248569763145444628179840376826394008009076760550324`49.52287874528033 w+0.13452699283675991840072448550631193583719138975197999295221554644126676805103`48.79160714493188 w^2)-26.9993812078771038367497635265604769314934156753518088233466`49.31790355137165 THRSub[2,1]+14.28730062224692171780801557092305300319507557365705153624613058466580899018104`49.725222737492196 THRSub[2,2])/(1-2.1329092079043220533735533121287360314832563388363117280260978330160552736561`50. z),((16.36283485749253829455106575610867460030768185245832435121847428733552308456091`49.69897000433602+ 38.71829286803594420767952044986685771878509030350858451235283627336709679057962`49.69897000433602 w+3.69152261268490619088969140010492775138072057219593595664159500791950589547157`48.83843283205159 w^2+7.51081543740223885808262599067683900947064977165028825755675767438357038862125`49.380876315416444 w^3)/(1-0.52380188148565360701974203033810543955654581398093214017852304211039583376738`49.52287874528033 w+0.40861633285980447775346986826835093381106570842517230731180744490597722954908`49.69897000433602 w^2)+21.25532415672259750514533666079106343867064197448441704551509769530142020000486`50.50910528009677 THRSub[2,1]-11.24770985350595425973551191879693692313807373768821771845750227911945625670986`50.91642446621731 THRSub[2,2])/(1-0.10811465386041045403495395901191219786315716097617009927504672038662954935115`50. z),((-56.4716585137481318304386723864503431086272698597984826402194776896959300885392`49.69897000433602- 184.1053542320270304293795363402011891860317418191971074146813`49.69897000433602 w-1232.0641987775120739076892583688992124092271361667166604723648`49.69897000433602 w^2+518.7744402156653579701044112870414603022710721644481867517125`49.3397355732388 w^3)/(1+0.71454761531868866572108631015897086358970143881505254893843895681706543063815`49.52287874528033 w+0.02369881916436589075323581946429629670054683400263760333635282356979261688921`48.1426414093221 w^2)-156.2649762779138701429738815780427298310884748304973499214549`49.53103627924634 THRSub[2,1]+82.6909578268213805200002761130024406633077893446235569564532`49.938355465366875 THRSub[2,2])/(1-7.5569662184164863267111874941140810228171718332666902366091963972071683359801`50. z),((-55.04487509936099239879906736682426972123914501502874488191123873639864722944558`49.69897000433602- 179.3847680777220321161968868233385463677294346651920458255737`49.69897000433602 w-1206.9778607841832672775547398694342197852712006818788586924489`49.69897000433602 w^2+507.9988985498500265846763156198921466057773039648815973086755`49.339358202538314 w^3)/(1+0.71529848591518657116010471217240020820905199845075612863578712360564060689795`49.52287874528033 w+0.02442584209205813798923345757199040567674180460150396427293666099099669715136`48.154967108831265 w^2)-152.787461591484096700122312226385469048993423551537451390759`49.52973021394553 THRSub[2,1]+80.8507564769917239108216602472271752834612007558612143064826`49.93704940006607 THRSub[2,2])/(1-7.41104774796911968221987287229103736882623156280534840167922235159606415636331`50. z),((-73.4653533872704930526361956261827363023837124735168965756307`49.69897000433602- 240.302380307894447504944430681766011074553827666158075857894`49.69897000433602 w-1530.7505111649563424763193153929035901477147100504978645208629`49.69897000433602 w^2+647.1797181221584977733862636108253976431937067535371377867432`49.34334703077212 w^3)/(1+0.70747264636473243053826088680048956242674319881275470053129883177036813619334`49.52287874528033 w+0.01688275051265114043619807111356404809351386205819469666711383317458563093601`48.00291687057531 w^2)-197.6838930549668073114425296168516938016881539808662371462459`49.543247400302306 THRSub[2,1]+104.6086644174055322759257112033314765725356109319058226961818`49.95056658642285 THRSub[2,2])/(1-9.2949272419252761972909189946071066821082918922824109763859847230755323930003`50. z),((-10.74719602974974420281555727981090349987843716821234158060874663120733132479536`49.69897000433602- 32.207585893848822949234377771162617217453865053179963133059558663936049719551`49.69897000433602 w-425.7494837306109921808408140046384517970382102330912932443078`49.69897000433602 w^2+174.9499956580283678003442048150340374442537000982039820450463`49.31134355036659 w^3)/(1+0.78047414261848117116802183393308569790465381122792288750923522243330857732953`49.52287874528033 w+0.09016459081059324485152501280177435771115758998133800721212043989731931533112`48.656398245851605 w^2)-44.8202480775151627432725890185387537789796605859696131057746`49.40750092672818 THRSub[2,1]+23.71759387064462913866128368951503393530391941223930818787732349194620463445207`49.81482011284873 THRSub[2,2])/(1-2.88068279626936719045711886498078618204870868359447812508403397376910306883615`50. z),((-76.4262148484570241027696899952544953403406682764067179693785`49.69897000433602- 250.089782967217139776157286660369131105492971418573629863369`49.69897000433602 w-1582.776452587930204711118075889062606840546173820027704424719`49.69897000433602 w^2+669.561219629543625278121584457962640014480992188886201606325`49.34384619827504 w^3)/(1+0.70650985171703226210015250414291243979864942068332158001460513675841933199107`49.52287874528033 w+0.01595997288416035166153883750187254791418597992675947664285008228972498317788`47.97954126099163 w^2)-204.9004327987952796834829555486995231188555526725164610837299`49.54489612654664 THRSub[2,1]+108.4274509287937709253342538208017115960062292094767488813229`49.952215312667185 THRSub[2,2])/(1-9.59773730494277629870876040529878044130228397321934612556094638936619384868651`50. z),((-67.2258114696752602556643576942474516529580262635356958404265`49.69897000433602- 219.673643271137480448050868400762323625351964353995863717297`49.69897000433602 w-1421.1014650532038412403541868130721170146319448453626451755665`49.69897000433602 w^2+600.0219109237364695596286469537341244480699160257149792316351`49.34218418741145 w^3)/(1+0.7097294041968374867335628243264887945906415777344299188462368790215788966328`49.52287874528033 w+0.01905020445880488591091637942232464003373867261622392766321161784530579212982`48.05295267007799 w^2)-182.4761898841587734407112795575544849264599193756799056987478`49.53937075581229 THRSub[2,1]+96.5611826880153321202275941791101064377907758421480669472211`49.94668994193284 THRSub[2,2])/(1-8.65680347084204821002434501919144692812903638580538784353220975825921654130661`50. z),((16.19821025959361178922157386965269424389360057917506774908348901423880174754732`49.69897000433602+ 37.38177348461817571220793316464609463585127502361811167786089687554901328362227`49.69897000433602 w+2.48839627804759171838303638252591840202603196063352528535802175138209472288066`48.65758888689122 w^2+22.39532499019437732495264965570565531670060298600307352166008807117194720421268`49.69897000433602 w^3)/(1-0.58497804349963088303305699687420382452481981447030637899051021163877883365913`49.52287874528033 w+0.66193557963271151600071800123911962109854331877522066199525726688579814571459`49.69897000433602 w^2)+20.85408283924693990646709061648521246883641725154641850545412823413256001517523`50.43797358945454 THRSub[2,1]-11.03538441979680584464844758103589681635553829695989267512010318303934343560689`50.84529277557509 THRSub[2,2])/(1-0.12495096502102373849052558105136569093549035937623493933427697347829929417766`50. z),((16.44015335573201017576672312078684642845240973093119391228127294397801832274556`49.69897000433602+ 30.65818225166083229688206382885475768725534837396114349117309062635203711392123`49.67816134474748 w-15.98924670810512509069529476990521678750681809381867880790366052275527902835033`49.23475270843027 w^2)/(1-1.02394413229073141635877581472838958789461829039993546480347712606317143445975`49.52287874528033 w+0.58659790475717317519281828944585569618663268402176942992029296412802675516616`49.51055004917722 w^2-0.15178165763806560710268187895851580810116554828207051435899563248321989061371`49.26596385753211 w^3)+21.44377337084242321216656174741137196617099224090228278597626904694198570995829`50.54592430915983 THRSub[2,1]-11.34743178985057719363955383264011428026334128511170086648209644970684274289255`50.953243495280375 THRSub[2,2])/(1-0.10020721893607240887235773799468007020749038679481498752298627548144508202906`50. z),((10.57130882067911028045928133623913672153638940059611759129808851902882821220409`49.69897000433602+ 50.61547589545202063038871275468872270358027713036381147337711373052401710326923`49.69897000433602 w-3.7142507001439192567251074451149082333323190661753406519644`48.29953005332369 w^2)/(1+1.75165731085860124793915894896218018486942341919732679392421271461372687404253`49.52287874528033 w+0.9186760008224702470550957962837547261140881370211132551617992298880720230584`49.08473113277216 w^2-1.20350647219347542415093553015665201054655142443228114327550279298604682395241`49.46501363246436 w^3)+7.13957494995872246605686360727940939504581931934935586020414966079508487713919`49.223836286021225 THRSub[2,1]-3.77805894289768492472399242212237373532485838150329884755964518555559925236508`49.63115547214178 THRSub[2,2])/(1-0.70041942298398125072266350724929599016608921647468068647385178382372891716097`50. z),((10.58003894172809856784858534458823384726496436099271409260739189148958006889146`49.69897000433602+ 50.70452408518549107971103009241927143760202318731900156354976890037465537310329`49.69897000433602 w-3.2999360446822486431326693611505724589294017649466574103776`48.2478730333403 w^2)/(1+1.7564642067473947581572384940535240986330646498605928849474674848871601435027`49.52287874528033 w+0.92566701142152297240397182999141661371178801717509667076306522843503869860705`49.087121135987836 w^2-1.20190942306334084398587618126361768455897370513916334560621283419506900238087`49.46732649287849 w^3)+7.16085296865170462946937572719028525492051599819071937007365921337730094241694`49.22568264188872 THRSub[2,1]-3.7893186620509421007937486199123319033053534924657643796952703160415696134698`49.633001828009256 THRSub[2,2])/(1-0.69952658536234691466913937542535500649074070541937209134179874017345228673426`50. z),((16.43735853761680916968640700681249222940598456576720908022039254956838944302055`49.69897000433602+ 28.94659959403831531963867503245892230001988564563834082720633120096244524898925`49.64190426913153 w-19.996196544540950398560631695912257724706426204814646417208`49.279727421734876 w^2)/(1-1.12779984983002964886871345149501015919822599003806575514014917303409244769363`49.52287874528033 w+0.64517516381512266792876459087253786509168391028097028743345388630412537050823`49.51096035377296 w^2-0.18159817009103410041749505277193682996337640241020897173461278236550696089621`49.29759618533223 w^3)+21.43696153034616528115612493011829392393623623926015456066494167914019170250376`50.54454932128554 THRSub[2,1]-11.34382715861064201085897752239163951778536126785331248394524701686595761518458`50.951868507406076 THRSub[2,2])/(1-0.10049304759123931524119909191031433976241196463505394610353561071052833181381`50. z),((10.04779294944745984099523155518590421611180930039979635884819754526641392035983`49.69897000433602+ 45.70550118869972760924978174442798777551895290076137923958568537868077968580078`49.69897000433602 w-27.0167362921185904984963145012662957937235425598559040401556`49.175929811090676 w^2)/(1+1.49092474917201858216863405887661448053921768147712128181084943442496443131174`49.52287874528033 w+0.50655844080701573411888298966576189903046830629994020422082986311875962380232`48.88300251155226 w^2-1.41197302029687720193809424644644659742155645294520923918155922005080195008197`49.386060179196605 w^3)+5.86360404054838649970152095096600951302856680029368316021733993280242427798637`49.10633850885695 THRSub[2,1]-3.1028516176768911451219601307233334771978767244801454929913788267689020601355`49.513657694977496 THRSub[2,2])/(1-0.75395987938034034415214519834054929408128690772003510487572114003065034068126`50. z),((9.9551429980049277549010266810005781881526681704680178999103730498060717680113`49.69897000433602+ 44.85713000868600499075305566434391845243619113963587133526180313709666654575726`49.69897000433602 w-31.1512024896591502736765281381950221360927045805599504962786`49.24054580366736 w^2)/(1+1.44399234051130030019642211769443591332117590494447669008690366412325854892778`49.52287874528033 w+0.42298105629333576900858803027523629884922216689665143740201352681622974931622`48.8177851254869 w^2-1.48178102270596378976228780296482895213119648195638014778500980931008381320034`49.385351802094604 w^3)+5.63778730929853182341249633285728454517673636937280344325195051759949004121747`49.08385857371599 THRSub[2,1]-2.98335585960527526250452635808903372506011752879815009496642407175446363734907`49.49117775983654 THRSub[2,2])/(1-0.76343527632229608588831530204692129609143204273542563808574435521811159916376`50. z),((10.13590958562510156307440561829781913456665506763751777135072540531299451668619`49.69897000433602+ 46.50211889614547389801644223436059471308899445646671608120992312336065994584898`49.69897000433602 w-23.1675511232746012210031877583733513394988922639755588286872`49.106782461920844 w^2)/(1+1.53375415234225231228899265886024845502642157146795768305694594174604856004332`49.52287874528033 w+0.57987132305420066290210888349524640911589314960153887116889646899013350803238`48.93080782407567 w^2-1.35783002468518115368187796643392597577258164931050823452634765679987970256482`49.3909621002349 w^3)+6.07837167334860432181755710778978936873252850723686258533478247825130299096235`49.12718334004609 THRSub[2,1]-3.21650050874295107277006871236625117367296651264210424130508340695292387041015`49.53450252616663 THRSub[2,2])/(1-0.74494810881842115407442543044586842315332420337867185276251129697453994332916`50. z),((9.95222345367826020906482905571113523931868813455820335966893846638329975290533`49.69897000433602+ 44.83001374200733228563322164944518366681926783486933552493589274275789688898053`49.69897000433602 w-31.2839948978201699569527534877801871785576573607264601317598`49.24248748634318 w^2)/(1+1.4424607647908059321358122302092541070782340511648561929971988576859791265578`49.52287874528033 w+0.42019401879895885030679585363903609004484834868943332192907075479429646790994`48.81536447179108 w^2-1.48424303625806782803797373403810925192213952966722071292546633271482132345776`49.385414068522806 w^3)+5.63067147225466617780794007103100289733949532023392566829258907163074422151788`49.083140252518085 THRSub[2,1]-2.97959036208361472461554031297589744959594975932614704239356985357777227371728`49.49045943863863 THRSub[2,2])/(1-0.76373386084343281771335212197355870960653099761091497551506276167198279844802`50. z),((16.43698227016716504204178308510760883436197759738511945135440384915724522372524`49.69897000433602+ 28.69399056496838638744795030565606145180440468944197318560726345968036512488027`49.63645212074841 w-20.5869582528643666777225790697071127345683275713152967026401`49.28518033326204 w^2)/(1-1.14313395680228374343590460632924818977753143982395101296911304155161779415441`49.52287874528033 w+0.65384022139696538870308366795771647837149645888192704627456061176809182783594`49.511023964817554 w^2-0.18601414939061752703902458861926484206025830300505477068168979394026808026986`49.30159904056374 w^3)+21.43604444961129777378780576432490483322129957984899121364478329774919653246003`50.544364471569594 THRSub[2,1]-11.34334186570511051298697116247150187070188048223170819771169738967814506490739`50.95168365769014 THRSub[2,2])/(1-0.10053152881423193481896540929691544907986686815430392808156418620502823126905`50. z),((10.84057970085914113640793796696719950993780072425396554496928249565008283647984`49.69897000433602+ 53.56920507959710369615178267838664077434496691011444800858818658280316801557285`49.69897000433602 w+9.8982508724971968044894762041267437367994014678967006037838`48.67172040670942 w^2)/(1+1.91546486813362300786901833864612862717927608889103636506958851534027355827091`49.52287874528033 w+1.14961928259382661771931579321028239709675422431413760813945355290476963332158`49.1527212479319 w^2-1.17783904638145164044879286032813598213381018508892865644867474173359612647574`49.55338711467821 w^3)+7.79587178591272572353455689009291117183266976304591327497512484888664408971965`49.27944863618395 THRSub[2,1]-4.1253524649421327252944048626271326154624604019365867333463013881428239144781`49.686767822304496 THRSub[2,2])/(1-0.67288083893843881676594888142331845084842609633723413001213206673944492169026`50. z),((10.42151777832804415511731054327180850003809653634385602613628645047210290907047`49.69897000433602+ 49.138937910044119396176451378413655464972715878489960176684898835460814134515`49.69897000433602 w-10.6235230455802951149852684810573978632990095706856372580264`48.760531634823174 w^2)/(1+1.67285327213924560760691761726017978762029566936153897751990417423412427743733`49.52287874528033 w+0.80158167220366131478477750852704514779830977261355040508839017012904422814858`49.0408168372632 w^2-1.2392301892182051911381661057468477602467278428810510348909947703318240392775`49.43051638749131 w^3)+6.77448761825939495444586479823436173143062476422717741592202963930444866947412`49.191644067397384 THRSub[2,1]-3.58486516481804275817806630437068615403969538942594012558174935595654462785893`49.59896325351792 THRSub[2,2])/(1-0.71573869258452736033975508680984646301145265624102335982047838801989647507109`50. z),((16.43744232138996597347259490469531169474942204888847737260003596394532335389261`49.69897000433602+ 29.00203608067230603641101765443881182028054715193959848030139457954029512539232`49.64309712228879 w-19.8665291950431382505402723240123245397211659898607511393638`49.278496399461616 w^2)/(1-1.12443489715780814999373822704730603601157595195495504748497321469705141375813`49.52287874528033 w+0.64327427028125507722488532641165467356373550844189633295668402904429356282758`49.510946480773406 w^2-0.18062963551511590591579869181703279202893148879134810576939121131444913133284`49.29669782744729 w^3)+21.43716573744494378515671575180696416960079743086147322674155935244750302671217`50.544590490478 THRSub[2,1]-11.34393521916902970289157909563271518581552756583846388816333364055794728660013`50.95190967659855 THRSub[2,2])/(1-0.10048447894661948600913410273062863433493659142882860529460283903684647569657`50. z),((9.85684430447347139661521800725408915189499688247399330114887648855181851116671`49.69897000433602+ 43.91979824858305767810304269090628936738642690850019107866439079186475934355752`49.69897000433602 w-35.766757032132991479392118582829146496594204937583015113714`49.30410676429385 w^2)/(1+1.38945617708159045052132596605351022141367142457923461524585449764989384037499`49.52287874528033 w+0.32136747483040754047439235025054110285903463460737939126459711532986446314985`48.715538347563125 w^2-1.57627040464829356037673692798178653064068944004088843491461309910807691570484`49.39095003798358 w^3)+5.39820283770630299708839653859625188437300566885493009064264304835718775091308`49.0593175177123 THRSub[2,1]-2.8565746069645043044505780027607787450380367780291952171708214936538223448224`49.46663670383285 THRSub[2,2])/(1-0.77348837538586048354551976328267938198493855735414227399449056303432627579608`50. z),((10.36018816545005642604637704647439355246271536171944142964592487337544306401121`49.69897000433602+ 48.55769806955212504378126929215488676610618247828003364447856893445412715971317`49.69897000433602 w-13.3648041032941507340744555298775558671887116889047745492319`48.86194215112157 w^2)/(1+1.64218022545521644682514421720853936999987826057600331038817714508557502071574`49.52287874528033 w+0.75454694400249372711721649921914523422302348280325174717165494757156678707089`49.02082920907374 w^2-1.25864527770817018053301538762899527242048881066961509161073748660401999031123`49.4191336371328 w^3)+6.62500828779783020442941399928343254320993831659442387443437685385754974800104`49.178164763947414 THRSub[2,1]-3.50576497675545534976063788981408825063746332695216628751291506843362625200626`49.585483950067946 THRSub[2,2])/(1-0.72201092929126613034358547149845054759760651842113011208742218512128102915644`50. z),((16.43879531348294449033040755561766043156747470701633121828602727804199853427271`49.69897000433602+ 29.85982741975476520942008759906184084537971696143978619218775463603741028804126`49.66139284265627 w-17.8591617811331172590861756845908168345895492673211489757286`49.2576826906252 w^2)/(1-1.07237732153762910986458576618396866040917572540539386678103744611100811645014`49.52287874528033 w+0.61389236839915471430440252743201611480120020489203885228010798242166629923182`49.51073633696897 w^2-0.1656679709779199641549525396364267157202364019154023473863709366563629468837`49.28179351909698 w^3)+21.44046339974358857078880868241664195247242069301419588443642727036671840152959`50.54525574819991 THRSub[2,1]-11.34568024777722765997709614677086702139520704178783405703015523611399474242097`50.95257493432045 THRSub[2,2])/(1-0.10034610718343242299379048602814896297025301392222541147531320857747842408609`50. z),((11.06990045691781160364450625643539345036258245835301837163777624462059844899632`49.69897000433602+ 56.5625530171182676242270808547578541392550461537722131937157374546605909713872`49.69897000433602 w+23.4536349858329060483344453637961101041591000654684362752526`48.98334394790845 w^2)/(1+2.09185219474910814124317720769670749575124866809184437264767066720376178767278`49.52287874528033 w+1.38693824382715201222778667585410394659605268658131291653811025016893855801709`49.20463147632831 w^2-1.19618872153627538468807015921084771219548438638177736872442177319316991479919`49.66242091542318 w^3)+8.35479775116846125017461122760930866421608227803929774208429627068098667556572`49.32492704741994 THRSub[2,1]-4.42112010604860516243878557314026039328712376870558423091819101947261606197033`49.73224623354049 THRSub[2,2])/(1-0.64942799134538755644619600272933557862847095224816378050819131756420622925704`50. z),((10.62458571851642216792280680237818073478692775453887094627708109272277649985865`49.69897000433602+ 51.16487964272338547417457201141145044137392854439436207248480002082098416362447`49.69897000433602 w-1.1621498307633644143333687763826605617272701701533768255002`47.793095642520605 w^2)/(1+1.78143137198822089677581672474062288471540271208848723268590164178856932743896`49.52287874528033 w+0.96173444604671256296133478828233203339979152106826290656988653535235722072384`49.099081311628346 w^2-1.19456490812901178694070707811619482375504400452079571939935850509871885282523`49.479668351884065 w^3)+7.26942731073644577233313997073235813295597829583116204624231828637229651514839`49.235055784774204 THRSub[2,1]-3.84677309973912132834775020319620716675273534824787971189788586333713511832727`49.64237497089475 THRSub[2,2])/(1-0.69497074495463897212619543816100531121215406948406670626184304258155207866164`50. z),((16.4343036280000382942498105851773654099429048110971177281565017520951601830824`49.69897000433602+ 26.68414788150870962659213644110529757393512187116904136338814747735576573818355`49.59202899332594 w-25.2813469237721945133712051901287299641004422880341504802813`49.321058808015344 w^2)/(1-1.26518833598942802471045726758136814735793471007321487756476546578453054797716`49.52287874528033 w+0.72298511789654598305205905022539796106005545677475881663300646945557426340939`49.51154919817579 w^2-0.22132838031767472502476948699730104080461928158581335021297977749666526075263`49.32897094597132 w^3)+21.42951576601297145466876039105085880201486448314708465634376117462560922720489`50.543050342391645 THRSub[2,1]-11.33988707300009817995595327150721724222036112672014766627353206660374476458358`50.95036952851219 THRSub[2,2])/(1-0.10080547604684035839575481122582815630127978830227959572949351088323853413212`50. z),((11.07204548291968280931502879099141173633382873864647294117415963685241597317513`49.69897000433602+ 56.59343401836904001986120782177145685077155074339626427132596274464637006071424`49.69897000433602 w+23.5923949143518676630716664988766062904036563602290912722438`48.98529427739071 w^2)/(1+2.09372787170872827857488313826730647271718691095984065193905690412093749821732`49.52287874528033 w+1.3894205497051886482811060800664850177511514559387813856685236936540632054663`49.205101663753055 w^2-1.19655589783484756825120595876045486139218396933653491908579794239603114996037`49.663627608230755 w^3)+8.36002584630123579939665509402952701434339210283311919700088408572730786689999`49.3253454538554 THRSub[2,1]-4.42388666452150318024800365340498007705496693257673559023760175940614795787`49.732664639975944 THRSub[2,2])/(1-0.64920861753566513118867253714544768020638979974868027163915471546118129961166`50. z),((16.43695841046531410287454918098199422802523747622915341808387613677724865060667`49.69897000433602+ 28.67776574416417548507025871867072391492838148626324016133637536151652672968104`49.636100992937216 w-20.6248968089354997454804871009012309851858984723978193856213`49.28552205588805 w^2)/(1-1.14411890255098926649145477920459137360408591380915500711236217185258701356609`49.52287874528033 w+0.65439695022891074295758918031279832055705996406647896068902645395664222490963`49.511028071947294 w^2-0.18629793345346057930876110019354309573858471990367428743791606454341489221313`49.30185118219407 w^3)+21.43598629610126687915733510687372040999432996817608895606951457493326673102192`50.544352752081906 THRSub[2,1]-11.3433110925302124216202077437786497112212959502536409060429966425236636989463`50.95167193820246 THRSub[2,2])/(1-0.10053396896819245357103163910883566519811961336077374709019175240558071386222`50. z),((16.37540715537371813943742240946118559139815673942482498149384236032334163507656`49.69897000433602+ 38.38014537394224293198115657742262713206751670152478980559530959005799659492726`49.69897000433602 w)/(1-0.54606324473304183640758372899934680997179298869455535278838863648281728201653`49.52287874528033 w+0.23613816701148332667057956180431269193630037184546062566192764722106061839635`48.842684896840254 w^2+0.08917118881524429212285957550623969897682701013552152927363751170015955535548`48.061251593790814 w^3-0.04902106639981072041935244244676126204992197302995798810129869936708305790977`47.437697373512336 w^4)+21.28596675466921890832310129782855140466964509897536582323447195004180918290451`50.51492684148881 THRSub[2,1]-11.26392504026669000243085428887443919824465642874822153658338544540916028661019`50.922246027609354 THRSub[2,2])/(1-0.10682887323082664595239596433018206616193920616453675153389699048208153862604`50. z),((12.80605406033106773641037853729809178785978287384581467479289432777582636676264`49.69897000433602+ 51.35999565834922207386904704919873573231871251206872546706600229019822853312963`49.69897000433602 w)/(1+1.04639225581968527653855474919485813949976633316152198979784553707060422606212`49.52287874528033 w-0.41763503418004923298950756247542580752776439024347725158056905834414290338338`48.79986750738409 w^2-0.98810870582216304488317358315015903418116492891444380387825273510841864788001`48.59697456361938 w^3+0.7335703447131955287792194702056429516446915188739414117593693693575633552214`47.8694633545264 w^4)+12.58634375379768183755119035085950511309720887308322296572238401948046141802415`49.64159938375567 THRSub[2,1]-6.66033327063744481078117515579868184423753853540343200744523381675063187844814`50.04891856987621 THRSub[2,2])/(1-0.47186994313905579807451571817462565852754407127145085369260007820087401953102`50. z),((13.84934482078002499025292026811405416614452122441834549678064886093528160532299`49.69897000433602+ 50.24896992749358336144526275594372273161201420427773150873817008247471317009745`49.69897000433602 w)/(1+0.68975158488238912104474518469348433025269240368739090824955907370656482697903`49.52287874528033 w-0.73414234783171286114225308812852003318558145026235620753130363319985977784082`49.18564258419422 w^2-0.23234110660664855731514037420577474480219970681490839927826481733679055919241`48.22225708936702 w^3+0.40383652285622127205585328639882262668589849423293446735213690699769611617327`47.90365954808956 w^4)+15.12916763659150584319850748873607341777739738888023151716273051675727256109433`49.83284012175177 THRSub[2,1]-8.00592297001563594766557287788778285280272012367141886139316412130828544272422`50.24015930787232 THRSub[2,2])/(1-0.36517162406588866655355727190936929637688750246399946007482491578441412712218`50. z),((16.14021060557939981577286918248630033536612223743762456271968112771549630672915`49.69897000433602+ 40.70597989646197622556668668254005815880873716274221453658986489388555292087524`49.69897000433602 w)/(1-0.37169647955980629375695856902763527924659833063782139970849845225022079140581`49.52287874528033 w-0.05582258846835175842315412469051309984480713840333107103504649784909360660489`48.40300898323913 w^2+0.35563825453049056965644450341979647429545994145323337273184800126464248931273`48.79213883894161 w^3-0.14438338440496497235822685870683774367524739747838220926071601178941801395286`48.03053414067535 w^4)+20.71271965363063974527069622808733712262314519175201404047651482317211047352404`50.41487717791718 THRSub[2,1]-10.96057906354555506308272134266345626796804742409519003605598651645618771413692`50.82219636403772 THRSub[2,2])/(1-0.13088264372915167955136652990987944249224765976526772440979033960345037759276`50. z),((16.28898729936351866484092776193518759426299008314395855246964419392401962850763`49.69897000433602+ 39.29193012198675938421015684880951137689261420507383784842115728814902867098344`49.69897000433602 w)/(1-0.47906884602470008459675165752670659095652983099746683942334260924383516704572`49.52287874528033 w+0.11984722742006895123057686232414729134499929938989466618602237849343619711474`48.617721220225505 w^2+0.20187853020629273755413332766795450066828733603145996347026292092904654886779`48.460057092271434 w^3-0.09149163827198819095341916784863930534253219011565391935300413827763920829873`47.74935866184101 w^4)+21.07533470256921389325782611198869331493838081202967825001195393235427803469149`50.4760866961416 THRSub[2,1]-11.15246458027083046513909193128992153661492092541326560325806955192059082853579`50.883405882262146 THRSub[2,2])/(1-0.11566711250255702352480958573143183374654394521162822861780038365847014117939`50. z),((12.37362454093981776544818058226516567048717892410485841396256347216852307187171`49.69897000433602+ 51.56447995981079449259206052263616432449631641236032797173884205420628395703689`49.69897000433602 w)/(1+1.19115386124193709680462253078091777475010245533306764625053560838214584454925`49.52287874528033 w-0.21544876891650182549572266774365675004609959578800907560294928871475627316907`48.46969285198365 w^2-1.24086907747568103031064827713011032556786623178701707293945592602635650420771`48.612656329743565 w^3+0.7881995461337228722014532724919790690832803813490682221683`47.80065219180282 w^4)+11.53237859737288980837268006253856224945296560270679146283676918028692379931616`49.564711422445356 THRSub[2,1]-6.10260504274675440570420354666233596962531160978634054344528757248541738403499`49.9720306085659 THRSub[2,2])/(1-0.51609491338302573559922733914917570454650448042995405350219778703152697977465`50. z),((16.38831154247017963812046717515330432327570589634610422119285680501326754314875`49.69897000433602+ 38.23771106049452665763057454519963330611091401209916633819011165664393177410601`49.69897000433602 w)/(1-0.55638984539944816465481638837513002613362282517574663262507652592039089826575`49.52287874528033 w+0.25448970006573840250040026023835929683455669143917543225046753014154066033046`48.86534064501457 w^2+0.07071019001330105638012781924323368739513605379857595720246199249056492159754`47.95425675460219 w^3-0.04185611886246790805734692683414470139510291500847277660706444847198999835712`47.363383869111544 w^4)+21.31741875726107368914048989478992200865303403566058897185633720908996645708161`50.520966686193745 THRSub[2,1]-11.28056854082478486804619353279176553120889989879002397167877665316404779745832`50.92828587231429 THRSub[2,2])/(1-0.10550912952748032163839993502789536474063948376906197548921001567450111364526`50. z),((16.22578824705155671609348599819399181989437518973058100454028668516097766183563`49.69897000433602+ 39.91527028342998302795280417040016749400632349513062958735945789217972090077659`49.69897000433602 w)/(1-0.43230176131322068112222492185293658940484486762398269667671150702109690077144`49.52287874528033 w+0.04164264220278762908962276218627779114643347954014311080215082130750116259549`48.214306707336014 w^2+0.27304604667843367251776251217296357920052693512913053094747037416739460435819`48.62595562969749 w^3-0.11688848814737037714676759695218036396853726463850458823450703702455425083977`47.88872573113273 w^4)+20.92129896710498183045108464844029378283369725877944653731283606001882385202712`50.44928648324015 THRSub[2,1]-11.07095327294856072562191330924407157693840649302423795996442320869334846758817`50.8566056693607 THRSub[2,2])/(1-0.12213053852369967689112408552356095370820186923980991663013932461253748928582`50. z),((16.42458614502236708766383861693887455231705512944005339864015449500568370183233`49.69897000433602+ 37.82807951030340639868198520389454337488571265975769679160364890985636029907685`49.69897000433602 w)/(1-0.58589415039433859333531515563332443474523186695249445089755794909476955551685`49.52287874528033 w+0.30752489499038567515756818204270793354966909872098266697563404663775872112976`48.920517631945415 w^2+0.01641257658175026605395347451006339400892549924612636833857489348618980527405`47.30276046941325 w^3-0.02049969833640507613033144021510018213226967176192359347083053264968848435386`47.03785494757921 w^4)+21.4058312393852924670015194112249066620885185173826937044733739521691093457792`50.538309448937156 THRSub[2,1]-11.32735389864991949248461106539805661456968725778735086263268522942728986435068`50.945628635057695 THRSub[2,2])/(1-0.10179929209376236095355962606683330709676684468220782996940673185815720563526`50. z),((16.25183165169276026445435667646807753825552226955895986899503304601729164040454`49.69897000433602+ 39.66263271669571302505361739051895854548775208399572550264575905674497523556793`49.69897000433602 w)/(1-0.45135746448942978737425400305006879627182962185111902285524104616114843231417`49.52287874528033 w+0.07320212599953626959247354823824991976507643375193573949908080236115312878869`48.43578533973051 w^2+0.24481334567048046999794797260458504882423842807883910679708752433168712064331`48.56393600925337 w^3-0.10697191677520652551038661830935957750592854102718608588402795565398594610487`47.836265834702644 w^4)+20.98477483962437225462830372051486752819875101024088674933393647127958930647079`50.460178264578026 THRSub[2,1]-11.10454288990909181309939675689996940569767313296760041735462574513339037139815`50.86749745069858 THRSub[2,2])/(1-0.11946705524223847827006446355087312763918861377186132469983250223882328650195`50. z),((13.39264323926053197283957382026350652906447470048452308794193847524098594955804`49.69897000433602+ 50.86143746969935175218964100573124511010413574523789862366984343244645607335716`49.69897000433602 w)/(1+0.84845018057062316339046801060494070866652318825344414667754037856497684229583`49.52287874528033 w-0.62720067230882463173183946686606617348171257580930963590961575788385164798331`49.04675862697825 w^2-0.5744906053374789329177066683030531136915372941547868760601288174897504903486`48.491729508345884 w^3+0.57253409704663699797806108519916528093032922901532357088475959472892725218145`47.91466122523345 w^4)+14.01604391996074376778952239726918258357862781306177002548458179094333993447822`49.74737799333758 THRSub[2,1]-7.41688972340861307568409336790105009943172926123585757850407125690313861703215`50.154697179458125 THRSub[2,2])/(1-0.4118789207405159159328757793041464907985627885630311347475052652885652965538`50. z),((16.19520233208526515125393450741573606909718571449395627687068463605246999824926`49.69897000433602+ 40.20466991351774010076600850285108230123887283384397410640088308253735778803591`49.69897000433602 w)/(1-0.41029504113975257469453904344742322177753493722742408785598271527931418212495`49.52287874528033 w+0.00573231176947276491119553969938982163577663685443891045191881111730199443046`47.38183765233715 w^2+0.3043169962052603023442430986705158087484186036161224289080872169984458749299`48.690794550408356 w^3-0.12759032012161675355511591381012927956934876165585007902201928618786371376546`47.94388418154766 w^4)+20.84675158491603321789422461319503541475154764669511343227373130790969599877752`50.43675298725735 THRSub[2,1]-11.03150492960562863261980343625750631171244612202997666850563190026686494768492`50.844072173377896 THRSub[2,2])/(1-0.12525858857257941060549157532017225638414765645476049600892851043193474956228`50. z),((16.35682726174370068419038389337284832226955384792035745349556478700806804193078`49.69897000433602+ 38.58227635943518919042343589828545817728907527246364421605544297157847047477448`49.69897000433602 w)/(1-0.5313464707097207484855791895701543468434125000161380812951201611683951917493`49.52287874528033 w+0.21017773337160082879591344616694973787561308598593371250448072650263536495924`48.8065139663075 w^2+0.11498585419629011853307774074786558942814735726167634395137753885243691852407`48.18080667803417 w^3-0.05895040470589170157239739077280310820901196003916010062898926712256593232692`47.52615830058846 w^4)+21.24068177846388358616665367033994992067702246702078628532823725554391938759882`50.506344943653744 THRSub[2,1]-11.23996152555739135752630827921276959965066494229492621090127567854388885829078`50.91366412977429 THRSub[2,2])/(1-0.10872905628049537585911173504978593751667788626201834264000285946793993302236`50. z),((16.19887064623657903234562005803816892212051414265073768901841345556427975055286`49.69897000433602+ 40.17036874534237122143043712835811702366452045809778818198635557135616632963564`49.69897000433602 w)/(1-0.41291361644415224335746493772367562251444487261775424014694087055448132853504`49.52287874528033 w+0.00997470601333430687225884874541497214170616531014571437664358211142016698279`47.61889207787005 w^2+0.30067178364872109192162124367456440054456642260028760137086649852804635834233`48.68339763239872 w^3-0.1263594398910113762625001248797512687058393721483818864057476087217478926947`47.93757860505021 w^4)+20.85569240677238460312444756603430457732743514386396519389461832512772514060005`50.43824191587754 THRSub[2,1]-11.036236156913696702533968487308042280179323761661174591911616157255989818294`50.845561101998086 THRSub[2,2])/(1-0.12488342666315248237580470369302878924470088995777452519989606818408107921697`50. z),((16.33341472433648502237657391947178601517368718597963866036811757118529523648299`49.69897000433602+ 38.8321374951997511298719187173746624890477288690392480549821681081259097266421`49.69897000433602 w)/(1-0.51305076198020852774815533490094471463682053735104444538143890894705882604301`49.52287874528033 w+0.17822540074668141468278192234497330055772040400132838817804947865762009284271`48.75346095416713 w^2+0.14625734325482610371596945698954336088647861048070149597989008761511158777743`48.297025292276224 w^3-0.07082765055400940178144458076420145170211653329622931259005521027659667079462`47.616694376965874 w^4)+21.18361814718025883038316000324148276585737431081352559485883577218646241245087`50.495716422053455 THRSub[2,1]-11.20976508333269546817471534516417350216983738977781340119704687219532348262154`50.903035608174 THRSub[2,2])/(1-0.11112347831631649695096996676028683115943462416666885564324078328423032289085`50. z),((16.07305486017543597784668644598827642581747074793768432167206096959187131764975`49.69897000433602+ 41.28688348057695102663025326701379978091689651793959130734202251467573172710439`49.69897000433602 w)/(1-0.32614884217017410383697631020144358946838427926153270249038923345518122419168`49.52287874528033 w-0.12602554173650509405248452458434066600051835510504594218853333514898358673624`48.79632798393699 w^2+0.41026388469670603329573896928907422523754215200578493737122145573934117241887`48.898855263009224 w^3-0.16088692478072201527937200634804536416460161098871513531718502152893345663794`48.122245799735936 w^4)+20.54904022719103841921559432336459106709961594938932542275580178437381137109643`50.38921976051238 THRSub[2,1]-10.873964590672478102350791438658492331361685613761306079819491568073575699125`50.79653894663293 THRSub[2,2])/(1-0.13775072444293566441426571365419336939368849384473958542119136623272505169985`50. z),((12.72259051707899310022727086658353708848736321350283216143135315540904071174551`49.69897000433602+ 51.40916258129404004906189012900488118015480715096708748818869399431199088033008`49.69897000433602 w)/(1+1.07432878891811447949952035379606559668814294851739438220603028935344067773566`49.52287874528033 w-0.38167958297296075247234943656903912030526814974851158046165169317152816450816`48.752037384291185 w^2-1.04137004693366149979278221812929992277272483457809030486578585434679029988897`48.60302079656764 w^3+0.7491072724610890579461066179900479931194857708431899652216`47.85857742780946 w^4)+12.38291715483821166268318354762314017681476847661445431269016529577995631771879`49.62673680108808 THRSub[2,1]-6.5526857304394767782569723926442115289277306558341835841278524912015291984533`50.034055987208625 THRSub[2,2])/(1-0.48040583754787304215394321858767605073351182029298483143591835876644632146816`50. z),((16.17809790274258368009015165535852384728472876474674826212300639292513541701327`49.69897000433602+ 40.36316646464488508455163070883158714053660046534115235222169606456668078350448`49.69897000433602 w)/(1-0.39815868677909615159658154996453016159397744146114631007470364212209388253684`49.52287874528033 w-0.01382081750421691844258517189767144584841664298301169719838277659606089984013`47.77548871442531 w^2+0.32094208074440797694593580736083404945571254346375651509226297570917776641168`48.72411293328795 w^3-0.13314396116536740962839906176265693461693749086964851130441216545230657822581`47.972321641021345 w^4)+20.80506277381661025428806473872850922155956143980994185847223541971484139686175`50.42986049206939 THRSub[2,1]-11.00944440265593146611047493305281223561187091405242200575453644269275319764721`50.837179678189926 THRSub[2,2])/(1-0.12700787451352315609088056641699218022816515716259531160311446206720657009405`50. z),((16.44052968244208628470949746768745410086416161471273796001713124211117516748435`49.69897000433602+ 37.6436039537418452341326334791408558920416562691515437242719547830148324815844`49.69897000433602 w)/(1-0.59909042744827976875228287125043197607069684923516756184465917955532603111975`49.52287874528033 w+0.33152902628657667852557425910418941208548053768109130490500009302372468633431`48.941561360117724 w^2-0.00860565058781008297358679659229437747138057356166177747031307103619900703746`47.014083636333204 w^3-0.01052915411533267746152747450488021088925863260550752269841071275938591261437`46.741892155985155 w^4)+21.44469059601338414556909202334964919369119526278945167764320336100170817348372`50.54610971959948 THRSub[2,1]-11.34791715918755990116501055080676665635936010621784176062553958106095074189124`50.95342890572002 THRSub[2,2])/(1-0.10016873165246014263606186956134689224269735384836820400428809525246953791055`50. z),((16.03079451539705697355315048567677473004725425231117589739728416663675481913133`49.69897000433602+ 41.635840867152528878157197160913743009553517545004352045094695530676141699891`49.69897000433602 w)/(1-0.29832602105802006958000984129079814506234076097017207334427277724482488503016`49.52287874528033 w-0.16756018889819362300829706142749999083043194176849864782359895308101299842715`48.946514345938134 w^2+0.44038357031963178452504444912387679817896329877245357275672213740110340883102`48.96010682485027 w^3-0.1691643696026390872264329557515433549629997773646726620924580602052629710998`48.175197163272266 w^4)+20.44603863063580764960141747626569933508640622545026656720010449358149223281141`50.37362056307459 THRSub[2,1]-10.81945909059358631354841880205062978265068216368630673220201351007933502793783`50.78093974919513 THRSub[2,2])/(1-0.14207272931659633027539344145506946915107265743478710654338087304995199020635`50. z)} /. {w->w[z],pi1->pi1full[z]};
(* and 20 each of [3/2] and [2/3] Pades for the Ls part *)
Ftri3LoopLsPade41Spacelike[z_] = {((-2.31653322800505403225522936941738718887772300559127156564228522067770244608918`49.69897000433602- 13.55028508270632423938137688437116312118774594760403076188733230314550044977102`49.69897000433602 w-18.39059650001545800563678203362081364966203809673593374413201695806920244610596`49.69897000433602 w^2+6.8703063840515768947044501822597422826000940676487913072883`48.58316283593496 w^3)/(1+2.06752994714629621298090617627111457490138099303688445215093349385627032726898`49.52287874528033 w+1.37884207703661810241469757112388404853659243712813140879410759084077349105829`48.84515549866577 w^2)-14.92143337368675856442280227646819932881014842569813423975999658783464197695671`49.57019254270381 THRSub[2,1])/(1-1.59159633128521797315934016573505769627410658418293886359938471289358401530338`50. z),((-13.14455563850126959953963065718925474041713807101244119521872455474697619176846`49.69897000433602- 36.7295640754208847408923030670049690731406312772366071801353`49.60828330994449 w-46.1556526744194953880816973077267517466135290571616531846784`49.08582472533271 w^2+6.1094139184219419168557228948156545647941514302762822014326`48.312006112639736 w^3)/(1+2.04601507039233512689381450512579004832402157209723611323152739636429685978645`49.52287874528033 w+2.21695587733522179885129987553553332825865292332149224726523466515395801063645`48.860250661828644 w^2)-41.31268980251584406931939191987174789207420279522951728166213665738566664056553`49.79303323151613 THRSub[2,1])/(1-2.63794155096333848595763398052637416566332100394593697017669999032770697672783`50. z),((-25.85051758124386253777784847139671513905946816440612040615517878367802259408882`49.69897000433602- 64.0328907455405835174256235514563667754729970261637655728132`49.57619695291524 w-95.9741768946662574152183469510385388700662180969263994203286`48.958302434371895 w^2+5.6376049445098791166407807368093383894894449447704503288967`48.09681172024314 w^3)/(1+2.0477753938457134353465164910126302166079333394004555789035486089476037229094`49.52287874528033 w+2.96261268085578778274738456372489533422872417095163771116309094718500926988847`48.849709841993146 w^2)-72.281068615697129408245965418471983011618463602569821650382`49.87000484476076 THRSub[2,1])/(1-3.86575786276866062964475762667659137544728954027731201174913622258305068579088`50. z),((-5.76615447804955174657495983290383484958767762540212857084923173922229155587538`49.69897000433602- 20.95434226098091022620697388684615724479842731572643149469328344520006934196366`49.671388176464546 w-25.3749736397076521197779166389263707137651367187667546241884`49.352570499430044 w^2+6.566810399648513315260352780169841653224005621074418740673`48.48348481835509 w^3)/(1+2.05529340648592981126862640491628027808880584661952074874686510466699154057013`49.52287874528033 w+1.67238160556101380246716312474801842547745319978509537425990703403094725056062`48.85593647580006 w^2)-23.32923265049765645368113663823857073427150867856602445587167964760800607851378`49.68169731008583 THRSub[2,1])/(1-1.92494387784969820032517838258044745564016662101247603855553665266290489917859`50. z),((-9.50525098407957159689651087286320240144043390177768684582023077530154811565512`49.69897000433602- 28.94831447458390878922217183299109612739436650760755329213977383954841721879361`49.62977762368259 w-35.005706312430937390922422232780924748601976991832335898777`49.17344228279237 w^2+6.309946480140694793134642481835705723506175889006463868424`48.39072894877808 w^3)/(1+2.04875785236419048630490629579063411127866187187245443057667291840200797639176`49.52287874528033 w+1.96096308855788515771621561346664188858253562010870584558651616798400001954906`48.86007046858815 w^2)-32.44257310748835744038178010636284540366050693849631441581696532503874213786301`49.750203782883915 THRSub[2,1])/(1-2.2862643116906160782260811805828836891105615475074206420510743802016277646874`50. z),((-9.83251175642684288800369420797079964797803137461996571947192177273840190043812`49.69897000433602- 29.64772014517567902601248094049186123602969758467251747773330855368506454644595`49.627331022951275 w-35.9403830829985838858918422360587557620860703559696517679952`49.16331645183363 w^2+6.2901670754782856667156543319187771338204985505734784615406`48.38322799557378 w^3)/(1+2.04839606388778475037255548937197675956773050140880804701079747319133977003346`49.52287874528033 w+1.98492736321542123627634882908022794486934591129640692530270062689345745033316`48.86020635410135 w^2)-33.24020933640318989117176074699843947463752152777291671598057696165111770126117`49.75478613180696 THRSub[2,1])/(1-2.31788853001526623347755740689431507732979651008720339045523105468225679562142`50. z),((-8.28551609880339873175217986909557240149724428265844047000853583889985600202044`49.69897000433602- 26.34159781585694584989237818986369578030518669353795732725903802509823018800683`49.64019353471194 w-31.6478287882558454754609165429417472868113324397317331904533`49.21701826377657 w^2+6.3871798765871278993120574364593824820754985950647132227706`48.41950646623409 w^3)/(1+2.05036297839406575235598476655053061127555262084838629309514363546149615510272`49.52287874528033 w+1.86988271731113718831798454227836877087111323246654208581175001734806517275809`48.85929183582148 w^2)-29.46970004607799429882208099941800188230665061507667258735698773516971030062843`49.73145173242117 THRSub[2,1])/(1-2.16839756575128283078570242902580491525603010101509164311655315454509559688368`50. z),((-1.91139544792414934815339837634800626581477319208299233835417191678725230252018`49.69897000433602- 12.6763618887739063464880037778095495027078340190186743080489883789823852394456`49.69897000433602 w-17.70428931995395564210326395647109973782691387796047320987948978945806649056736`49.69897000433602 w^2+6.9115920465210076690111819300928720040441273194894857067024`48.595970597153176 w^3)/(1+2.06958419850857684302239628038482487646537720020600189052037488422718595779333`49.52287874528033 w+1.34240259547628823950297072904170748678332383658220057136604301678140411581931`48.84316603146606 w^2)-13.93398666940608894778307535095711424104680016596657351612895414571208305643667`49.551273643341474 THRSub[2,1])/(1-1.55244661738291421988385835317572860124323563852444510779954391822056841487514`50. z),((-15.48382203350499847346408106745525489709244975142161426567422686496655333172483`49.69897000433602- 41.7381452081391680373311378280128608920098819797036044517111`49.599017957750625 w-54.1420194707913368556325272387205341194203023791436733994939`49.048893086719275 w^2+5.9998097326009525550944913167414647835706345522010478538`48.26622816825643 w^3)/(1+2.04538242665994301101818553295493193345556286691149879911771182860115325077653`49.52287874528033 w+2.37022199446566496051798286650456856480383936100262481206117612701711646837034`48.85921761218136 w^2)-47.01420915161154066105951131143013588964187081658474982937315313866960605766599`49.81347225019387 THRSub[2,1])/(1-2.86399208144553869129842458883548261134416700275535098727357395702171039980564`50. z),((-21.22969249995110188599526550623276248201850039991660015662403591418568237349734`49.69897000433602- 54.0741488666653564180769713969822733961567579156057792311222`49.583936547030795 w-76.1396685239856696072222151414670056584485382337827272258592`48.98927399071314 w^2+5.7783847044615476222641659286349196187542021052603184908059`48.166505302429 w^3)/(1+2.04600179009729783506526759182333019448576484095994231055987127584394131945371`49.52287874528033 w+2.71443517061430366263955173299465452506466664617160060063388055200684774766269`48.85458254307919 w^2)-61.01868154167797992203114375300487962614805624046603483429456040182157465121154`49.84974901607448 THRSub[2,1])/(1-3.41923327577735329730786698754555724408688849304605365297905742338409548237977`50. z),((-18.98507131967570690571868702587103874489420953422148883802754506589615275311974`49.69897000433602- 49.2489843293420568515160706862083009876589562794520167319737`49.58888005170921 w-67.168877955535619824842289123156583297388498949631922663902`49.00882338989357 w^2+5.8578517662420149757345069866667065469131065421614941944231`48.203534187670904 w^3)/(1+2.04548255193229169997462786538201569894786956174158322618941415110578006251922`49.52287874528033 w+2.58504365753978565316588248993820772984088452680987070019332063895989256513556`48.85665197019185 w^2)-55.54784200067316667823848033505384938245817092402091030182780015104738000316077`49.83741622490542 THRSub[2,1])/(1-3.20232860445964877177477768317338113004081107508580218656010871399363021033464`50. z),((-20.04888447056481674369573768275986975996434758484699850450317521467976257863993`49.69897000433602- 51.5348120080941444771516962843634082595499102799838122015576`49.586416036061856 w-71.3630685657272993026850001935630156429414030330412797885402`48.999089428820966 w^2+5.8191753532765898935075428992816480302248666407479803525099`48.185700807367056 w^3)/(1+2.04569299583279048469126622929564503327945299104073058359900979113899681846043`49.52287874528033 w+2.64713543741445100080841207466696930752392010737570802893239864276484436599169`48.855703437426754 w^2)-58.140685328210067921812569691919883707730366056616655749063519639325458431316`49.84350677135401 THRSub[2,1])/(1-3.30512815204689175585288875539925040495943920855692427868494078298660992260695`50. z),((-8.50289192542337740132696147095942377720457135201247334135539061176985440787847`49.69897000433602- 26.80617158715773759501337672503184057110332887665385238727421178337331324124654`49.63816932854352 w-32.231480765595386725296091109649453301282017147389474627494`49.20848937129321 w^2+6.372992528343775064530547264652520546924571538816340821348`48.41428001760564 w^3)/(1+2.05004509235888280060775057865202333936057116341745613991120242066564562129511`49.52287874528033 w+1.88632234080325468463937820230165173721311036985136902994549330025059147110329`48.85946454326563 w^2)-29.99951250529451041366076595723061205535154629575097689495072176105949648191648`49.735003364547126 THRSub[2,1])/(1-2.18940326267678183000627716229181070169434418287608824195553241695155027070948`50. z),((-16.34281275110738411378259628117929182079331690087212479491398230236373875149256`49.69897000433602- 43.5791548719292001890661312952617711218880768965997850421542`49.59618655140119 w-57.2231227484479658334179631707449957332515802874093886823257`49.03768034660295 w^2+5.9627177453806654506022099837022074253501881061562084713073`48.25023974622058 w^3)/(1+2.04530772458266629504525007735011865545185624668517041916890139538366204007033`49.52287874528033 w+2.4244794039036233645730661694442992462687002144615097044754066915061510055158`48.8586831510608 w^2)-49.10783654161890757673078228721017155026835417051068304406197943538348864900744`49.81998574037701 THRSub[2,1])/(1-2.94699900524354228777140942324757472658514422332127815390964860903111071674294`50. z),((-15.78083227977988641605292081942500512524999212594211881147226742979418721205447`49.69897000433602- 42.3745863499190406079110167701502147563973366154537568659873`49.59800923799308 w-55.1986100868122476418117238015882068590789827342899811620103`49.04489533186073 w^2+5.9868051999559411483215921588713500417452945261020478745301`48.2606525363439 w^3)/(1+2.04534817487141513373458236630423220603760741649331471469976201730924006004292`49.52287874528033 w+2.38910119226727840300645591810411777390621381621435324117301636768960898711331`48.85904099486143 w^2)-47.73811544532515265455591557084134816921982630117888313832714914079370562991075`49.815777839052984 THRSub[2,1])/(1-2.89269309808583472922886787875938875083606101004926263759996737576592850088835`50. z),((-23.27788747995671659121813376621001871530471320612154717913439819048667377071766`49.69897000433602- 58.4841468642785437346977064149144036002469561278876784615827`49.58016795496706 w-84.7141502336547546989057815207224189442051690651042946760883`48.97427903949437 w^2+5.712514310141653207604686931508075320552749743621345234834`48.13460165510927 w^3)/(1+2.04669246459750481474800693437899946896992240739674570146818347386335097689759`49.52287874528033 w+2.82731948277363812561284253661828283957249813382802905588449827740205055391171`48.85250227428671 w^2)-66.0107693749254073844869157353013146547569426407507058857173`49.85946240200141 THRSub[2,1])/(1-3.61715667721214824960207045540391087532570730743139546974351224485253111535442`50. z),((-6.19775170287683053473387104517694846941963077189506896327753336654480374719722`49.69897000433602- 21.87785764988691703334004883810493491633886706575956817270171119189982355074294`49.6647629272498 w-26.3832848857037834399809741145354117822277087018008736603147`49.32307567749268 w^2+6.533885332959637684223179773653474805147524174752201829658`48.47205228571919 w^3)/(1+2.05426316631915715630032751246942369667347332920184489926288766414389807552152`49.52287874528033 w+1.70716073621099349405903114151904895177688541024149827505657057939155936644127`48.856715165168886 w^2)-24.3811692463571515575653154139168496300730885353305046241178432913387168926056`49.691542281532335 THRSub[2,1])/(1-1.96665044954894080856587910815668020071671670635094363354380546031304158657425`50. z),((-14.42324438464543915023607323464766760888248005871932509580868720116705127367221`49.69897000433602- 39.4664933017232247216187251391632146016281651783393250986703`49.602905123039925 w-50.4462507497503980035368349340139709572956477287456781775334`49.06433705069155 w^2+6.047868859704330310918947954544532653110844984123498275844`48.286561998920035 w^3)/(1+2.04558425973082978668750332004781607272861428484595864561617136999190781838708`49.52287874528033 w+2.30175731180870615429671884157488833690614905082282209234241921219316831815614`48.85977032477633 w^2)-44.42925174825365591231876582279392438767935700454141343850964458573631139002991`49.8047380633583 THRSub[2,1])/(1-2.76150519040383419147959933563867307620298620927972008297293474325258669386246`50. z),((-8.31685197436439821691059625040721398886333127109991726981807338562388509530213`49.69897000433602- 26.40856955881964011993953966110299144936219034278382190937381020521588195700024`49.639896746518765 w-31.7315638252857049309857916605377116337244066457226604468681`49.21576590095078 w^2+6.3851229334681537319865846996245421810247632680088759390472`48.418750351341224 w^3)/(1+2.05031624569988265269075724355141749451668651524853879136938917650195774661308`49.52287874528033 w+1.87225823341075620169971704441734423396123291563123801599885967163972455595566`48.859317705658015 w^2)-29.54607531535621121483520786653514775529408037262046839308833664821419638442341`49.73196976532405 THRSub[2,1])/(1-2.17142564810599765378152500882116370597579115809011750333631292464128353217108`50. z),((-18.03588315283537975102557264681505932620424233889769897446326588002752739568831`49.69897000433602- 47.2109595630298710070301779021550115947113333018675972130179`49.59129115116746 w-63.5169441147673788910645326483795935054112009202544842845261`49.01834098431835 w^2+5.8940129701921039107721634004669322504071221879339223593011`48.219902348040115 w^3)/(1+2.0453573749961496405775679971392955743651734325973432070090865161473759962468`49.52287874528033 w+2.52842960490698169069262777347877891826819997646626579071113247821656182197855`48.85744049788141 w^2)-53.23437538963155723677143476978551579790200277605271566957739286361307767711137`49.831562138092465 THRSub[2,1])/(1-3.11060562280182818643924210757266413690388290894173907146034959577049894199973`50. z),((12.63925893729834070073238783999268529928067078219187346909578461353984669245559`49.69897000433602- 0.36982770404011348068528518188425853484045042152767065697856344732050910613824`48.416242805868826 w-7.92702967754213269856552097141972036156018992082128495884569002806680966328443`49.54464410570472 w^2)/(1+0.54642435410981708326820271136075817060219120240591636451044969398152229792857`49.52287874528033 w-0.52235654951005755988752169748945485259672522377288921171956423574933777418606`49.3536278358487 w^2-0.49401884609450193125915581069045906554807691190651585970659529660057796526204`49.58109096351366 w^3)+21.53048103574295722874964767350510422473707666441801078180606189074895448750521`50.76581070643877 THRSub[2,1])/(1-0.14637198233158929336772127049911617402232118236772585791827007253365515832045`50. z),((12.29382364376872135656207171893969148028148222841379550803095056650437391259347`49.69897000433602+ 0.2551166978018714080641308930190525720895840894694436125064464934450875522875`48.219602397308726 w-8.31813801307469460887861993766886722135124421614503986267744642794344854814706`49.524884418303756 w^2)/(1+0.61540107150971638914176073349059874090045172314709730137437675211445600063684`49.52287874528033 w-0.52680533531544043809510630144583028279235147992038184566510275248444406086991`49.306247610657245 w^2-0.54958796020918335805692502863336707441581466390032009448860238497459599861875`49.558790444610906 w^3)+20.68854784928492805976132165028369953213627322795313453543230572043935507812336`50.65927009181364 THRSub[2,1])/(1-0.17975246072277334717209036544180340812232230321929089757929637491685280981459`50. z),((13.0558292935109166083092078875258121377376361424631637581328570458771616116404`49.69897000433602- 1.56950821887006532254354830243700368051894366571635443398445758268666977075582`49.0851656373932 w-7.03206952993187388217322291320902282113944504717900197676529716885307687089402`49.582115292891 w^2)/(1+0.43393401060573632842062309358058115579512110398609831165440911904853686387405`49.52287874528033 w-0.50064142049903728525045181557253496393911998508552608256194611972614984020468`49.43170443282155 w^2-0.4160396449764183808373672430440369166730500985174923274451031976064434828624`49.62368043739833 w^3)+22.54579248179222272470168824626794734948082490540827068955546053835442881090218`50.92549340978435 THRSub[2,1])/(1-0.10611750331794032244732071182312870514173691041149969937908913471819073694972`50. z),((12.33175953066483044247580075454839471851850734533779633187084800401005985428407`49.69897000433602+ 0.19958490824517909532990361416346832445791337071844327225581081087236917203791`48.11793411457206 w-8.28685740502404908742141045851536368590647843095845970348487911401138911342289`49.526669300494234 w^2)/(1+0.60869941596943179534747405898080981809180341854696509704623026937220935105875`49.52287874528033 w-0.52675225687656739198973571370507463072128581738614118923299235171261860797804`49.31090571038521 w^2-0.54377477881429593374373280180590145510549369949715758850797471203721986319624`49.56081626541299 w^3)+20.781009397753813350517326292227564029155216342711890444333167728403345231566`50.67015526160492 THRSub[2,1])/(1-0.17608659890579780056139200025639186773595017832035437961242769319351228871479`50. z),((12.93394770065074643364734638610841774692374300491459706030304798362709473656816`49.69897000433602- 1.15711846052359031104620497755448439493975133429690859570125428292606986340603`48.93832516216675 w-7.35465310436497641432926256761320829805452799201698761386725079736202574242655`49.56915112927967 w^2)/(1+0.47084282369148322459417485221025108254169363655723538982401138273986987364076`49.52287874528033 w-0.50938123167245668209263089949815080924999379991001040251951216262171448471461`49.40560737027724 w^2-0.44046206828558209103560967683142764788364281401494686423251496178575498981026`49.608848875883254 w^3)+22.24872915395787556237141586293102065611204282298355515552386020501031222391206`50.874023653565274 THRSub[2,1])/(1-0.11789529774994775316424767822467702312998294663537315334693706154636533333862`50. z),((12.98016519046933975129236910681587541926535179328278553274652565143479064425679`49.69897000433602- 1.30681093103824037375861402750476663731564694729260997479458358660611904298296`48.99636445720369 w-7.2390714707449893246598243052204997093260207846543652452955849233338814314223`49.573835809987 w^2)/(1+0.45728049011619176187602454499711356520587704009304635391957088338549869617596`49.52287874528033 w-0.5063334192149627722781741720824961651044812491421777325527555148724117688639`49.4151166357172 w^2-0.4313806667506633208174215060756086074712891508799611402666889053576632640238`49.6141956646505 w^3)+22.36137554302675418941925184390902761833927959376542287957958348862790185210251`50.89298873093764 THRSub[2,1])/(1-0.11342915908640659084144524405238955717862653004995403535403132121252155225888`50. z),((12.85597824754961438691674300434688766143848144681313486165982143468423965116827`49.69897000433602- 0.92185781396461566083708079769864009616784291960552704437825293165113169332708`48.83152211535523 w-7.53241746869572205596617267106633255689556140585563078304275034071694560490609`49.56181980749722 w^2)/(1+0.49260013221455440206141523564743919615851912803365937168028828251104753900007`49.52287874528033 w-0.51384439083885760575100788437638928747689596695347639445174622828234526401575`49.39050502085417 w^2-0.4553253061374102647627654055867889044855837916368244887731531418617868738292`49.600509858602294 w^3)+22.05869336049545325042041956754956786533110997425228986649287125463305144029126`50.84339423594074 THRSub[2,1])/(1-0.12542972660873954293977920862024375593999828012635585464612135895355769271666`50. z),((12.48118207801921397695716845742180690535316615505326495841505467266490918126561`49.69897000433602- 0.049166626290382663034647751872175164096814022810193929204818483067421712273`47.52926526453391 w-8.13731507442264398006564162391581754796518602054051903371655826534213061227045`49.53458210043501 w^2)/(1+0.5802936865666720876060060760430041535259407924665663373685309602272235280807`49.52287874528033 w-0.52557092233221503875857021577719436567064202715742203173326247203480284798309`49.33048183938296 w^2-0.52023354585769067538974032826496107240979042890570941485105652414687274151727`49.569755104272076 w^3)+21.1451985926021528423225044592434901134383065821309366074331279840755895484296`50.714857873176015 THRSub[2,1])/(1-0.16164743705249112020124923045327449178122241158088235778285272436694132636789`50. z),((11.86118264131011149399845433218179209102862933567343414507716347398625603503853`49.69897000433602+ 0.70229447958206632561431418030974556304105748537488500676354740077713556500588`48.620853248069494 w-8.52143881568778379536553178453970802828143236514908113890211267030134557979325`49.51012685066742 w^2)/(1+0.67916965014502833261169463603518010692990095090573427899821825144968296667189`49.52287874528033 w-0.52204649881567080495110739104377859462698285224643641707178177276669644830358`49.26054712424692 w^2-0.61240094937880370952990593125837559725918469871043331431408946683097807189061`49.54154574002358 w^3)+19.63406724288695903016134878835972905186196597757368499559407925359007204892425`50.54573404969598 THRSub[2,1])/(1-0.22155989587552077424113557686101187243373929139635081598045228012731966065689`50. z),((12.5977431558913884161201467489214939603525982223330861908322510019184918410111`49.69897000433602- 0.27943543754894050019858927576282128790756441099105274887090961067766741379367`48.2915149640234 w-7.98797692952252091727660950652986589373886574315942687616370862603820584778314`49.54181890771764 w^2)/(1+0.55572748719445964481524850953159536234265673775789555279339784575948769837626`49.52287874528033 w-0.52341934616670422746102549789392900817607064575851854420606890780907796629089`49.347279014112495 w^2-0.50104990432418741944625301443282147566975056677261009608174031933865301881005`49.57790765288642 w^3)+21.42929417156616965960184440815181633310546749080825847275991096580617770040057`50.75202179663499 THRSub[2,1])/(1-0.15038378040233004303398900053502530526285205407200142978692145439137805732386`50. z),((-11.95426666888784778949467054279267274627393616855853168557531911556418466362079`49.69897000433602- 36.2657757271455151626883422401325716371187873729043038399772`49.608342049347456 w-46.05177835806982330471755649955371386383206990293785071138855553599528375339917`49.69897000433602 w^2)/(1+2.2208239919420564940443340096150738007484929918627671437149960002998771383885`49.52287874528033 w+2.30536319482631905911857310762867847834017327171009378732025756861050590635135`49.3795583042358 w^2+0.42325610329226860389823145210468123951257388901326229206219528236699046321265`48.75057899178976 w^3)-38.41158559063095258999730520842900042965979347967079667015314968061771298608563`49.78077363938265 THRSub[2,1])/(1-2.52292025472153248124888849757368218876374595266161503814177945633490773542282`50. z),((13.05928315060708766621713569087113476000701272222357978938555900187741632507535`49.69897000433602- 1.58204570073832955667800672487235446666511981357174187933368723617939922326947`49.089066461983855 w-7.02206616931755193410497842022380310204969524888916203394371739822276163292895`49.582512739670435 w^2)/(1+0.43283294954838648687428321744666057265264701533360650255405353083189651822322`49.52287874528033 w-0.50035967320016156162225267979147451074436206301280737834399821554600992274056`49.432494546146856 w^2-0.4153245804597111428891253101241954545586571244282444479756318262700532816807`49.6241368551187 w^3)+22.55421060514272696374867217256729155162369866997811527706364345395086861666278`50.92702361549951 THRSub[2,1])/(1-0.10578374644849325176666331937366685577344747156667610974566888618501585998366`50. z),((-13.83527815829207773902812807893973023947651896467898519212551462337365801468898`49.69897000433602- 40.1999110688031864000162053152323157061993802094473910863368`49.60080162956898 w-51.8930674035117317402486550639729110422764044333850975763268`49.61329551481175 w^2)/(1+2.18974583624971546204401817529863917845059913597900654394585131257127246667255`49.52287874528033 w+2.40882529964285780585632137099934049175051540173705063737827311970746440652834`49.34315997553337 w^2+0.3672917211407980701935679379661064495827029568967729843339522019641097728885`48.69251816134954 w^3)-42.99619528947307035431909693417073063240777945526917654034103016281549300105693`49.79952774860609 THRSub[2,1])/(1-2.70468819954863794694479127379998188554856605583919738920355407236732158082425`50. z),((12.97743956425723406076914587339540846771996728022144126019770766370302927078567`49.69897000433602- 1.29776256712247794009366927102133561016594059330203616793683476547941407612363`48.99303102500206 w-7.24610908009876482790801225849569253330650299037684984306923648263807541288461`49.57355205727031 w^2)/(1+0.45809461784626308406800895642331421410307831148399030178418093597526201747562`49.52287874528033 w-0.50652189471510936559859294830178596114023724707868429283239877575314273937957`49.41454341501587 w^2-0.43192212013716760832826206629289775227954911274114038393273284013924297568433`49.61387139797241 w^3)+22.35473234470615495128031101999925001113453952200052091830259928843218480549931`50.89185241509842 THRSub[2,1])/(1-0.11369254475828159725600379881955822203501376626704268927518212535411761165248`50. z),((-18.15534043557643449776877865519525532789688302765071791273454486296908831882594`49.69897000433602- 49.2776076564406515344073837050996255888259377300824671128543`49.58827573003714 w-66.9736904657527166609909640338915395382273733508372542145609`49.471387937597335 w^2)/(1+2.14507776186893138859854049216154580487855758617510426289281098953332479008402`49.52287874528033 w+2.64421734074606981164586773241196944546750244485967890627352094703340699068045`49.28063328290083 w^2+0.28014331846595737598251004454906543286697698770478472654308816564907647995355`48.57712664966913 w^3)-53.52552992012590624463840433639857658104334353253072135332163578675368286844749`49.83232225770733 THRSub[2,1])/(1-3.12214914866585640891747609221067618425726772629340737972115635372074015447473`50. z),((12.83419939726071100478015791021070561621464427700031196733942877276235988024654`49.69897000433602- 0.85983141746899854217173050670916260563037784145218074423357406456206130750877`48.79915592255955 w-7.57842646212737111104145735560579748410806419875271963228823312221004018015529`49.55989082293444 w^2)/(1+0.49843738723271873913548532029410861575970196147530294435540136387999624911431`49.52287874528033 w-0.51494781826038333668321715385611190186934273540273645443665300420150942101772`49.38647926379012 w^2-0.45938052391233038138013638112941392505521917087452646452301360098493603860962`49.59832129401669 w^3)+22.00561153253928193135873599508959630836373578095223465637047373602668681212395`50.835121421366225 THRSub[2,1])/(1-0.12753428411942493074168410438181277913302284226759909475268953124059199250441`50. z),((-9.39146586666973267667262628414359421737893420686812925522490434271336093180672`49.69897000433602- 30.91750105858119557320628342885707368972718703338078800737494210017241394917904`49.62199281813461 w-38.94037027977900332471191194031280672806843124298527589933794258303821483533464`49.69897000433602 w^2)/(1+2.28446114077760164055011630331936515185843174498520758618833530941387812207189`49.52287874528033 w+2.16843192293009521111171679554219605981508701423476284437135028675381089484526`49.44420562360974 w^2+0.53144383626754218782266259088067416414448293580642609306099689329974263611478`48.839911806945125 w^3)-32.16524340705879687848254037962967675705116132872033932844488114557131032609151`49.748569038755974 THRSub[2,1])/(1-2.27526890466625598108355574776520150907598661675595505128472904799946178267216`50. z),((12.58432772582846732510452849929553858630241643412053893883933209630304439643505`49.69897000433602- 0.25119557176390549120820680022684205464274742628861712005653423196330677473983`48.244306708069175 w-8.00676625776559184203643909223036798783955789599973282627093307851715254337591`49.540934744945034 w^2)/(1+0.55866978538761928922982051510388068889348575098114010187150326206879913885548`49.52287874528033 w-0.52372803141051906101903500410775897769962762650855662344376486888871710159639`49.345270432263796 w^2-0.50329864655880458265999417483719500594004047498759383483801344744955124605951`49.576911675754836 w^3)+21.39659659841094858710336324149382314031234737702086226102845283014926460845611`50.74763086355537 THRSub[2,1])/(1-0.15168015480793310180259792205906049451027815741332465451277058979621517948676`50. z),((13.04883080812396679079371094484927752309057652790354377212778550297440600977606`49.69897000433602- 1.54425355745271653474873666403102857355433752017668214960281589809006083610807`49.07722459098249 w-7.05218657482485955460268159245250730246886744891614646045661291367329612513`49.58131540883918 w^2)/(1+0.43615537689240765613135320557392179662753219389510573235580656326578821909748`49.52287874528033 w-0.50120628168597916212265853843858060842960881646965809851337502163598778061754`49.43011268946082 w^2-0.41748449248369355891206516889025100905307635301440102929903563484504393560194`49.62276217551585 w^3)+22.5287349974743691941092439050293325531499109483850274029467655954730726039298`50.92240574095992 THRSub[2,1])/(1-0.10679378855747987930956849432726361156773193414081613978588195130775778874252`50. z),((12.85052473438135925716473713868592084672448805891771265351143511320691765916996`49.69897000433602- 0.90617919806950597951933296052450657694157028593919144966759639649585857668048`48.8235368581453 w-7.5440827899516902333113374108706611747135768454940071708654197289091590454168`49.56133211185547 w^2)/(1+0.49407138335948348737187058236625396494800378806822325153458145143322105140518`49.52287874528033 w-0.51412636211934436452012422137955246785697234104287181258221570526928746669295`49.389489443720166 w^2-0.45634456507935919047560895957304332330534438673247664559813398532067428561661`49.599956322955734 w^3)+22.04540145371828380639555839820790756598743521120445821353647980060782842166324`50.84131160948436 THRSub[2,1])/(1-0.12595671641516292438055496101510653535761508550490309961641261454313417054072`50. z)} /. {w->w[z],pi1->pi1full[z]};

(* Sample Pades for the 3-loop triangle form factor with LME to z^6 and THR to (1-z) *)
(* Mean and weighted standard deviation *)
Ftri3Loop61Spacelike[z_] := Module[{const,ls},
const = Ftri3LoopConstPade61Spacelike[z];
ls = Ftri3LoopLsPade61Spacelike[z];
{Mean[const] + Mean[ls]*(Log[4*z]-I*Pi),
  Sqrt[(StandardDeviation[Re[const]]*80/Length[const])^2 + (StandardDeviation[Re[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2] + 
I*Sqrt[(StandardDeviation[Im[const]]*80/Length[const])^2 + (StandardDeviation[Im[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2]}
];
(* from 20 each of [5/2], [4/3], [3/4] and [2/5] Pades for the non-logarithmic part *)
Ftri3LoopConstPade61Spacelike[z_] = {((-70.7313603814045948150804173889857068801813953781933961492943`49.69897000433602- 335.3300991253587491746247279303660138087657031941807215276744`49.69897000433602 w-1848.5664611726821325310020771087992516296313532506886233229126`49.69897000433602 w^2-1618.6951021799653604999088211811914758069312480180084531653308`49.314802015920364 w^3+436.7257757570687806809824924290154564095670480825877416580554`48.945998922989844 w^4+309.4324718902846382760789161536031189148690571003618523048374`49.133682595406334 w^5)/(1+2.17970689744501362765202409158859972211361042351390585316633638479001092329924`49.52287874528033 w+1.42206195072908709414830530339923841223711319594523531533837500508459866333875`49.64680786466282 w^2)-191.0203022572150722324529412428521622411779556907667932522231`49.54162052817507 THRSub[2,1]+101.0824826794573630643621056094772832749549996203583673956052`49.94893971429562 THRSub[2,2])/(1-9.01531922741726420180084845340751844714355516443124055717502919248851963344481`50. z),((-31.55437341860713657763637683214627736215116276831169655419508425096397843739545`49.69897000433602- 147.7722152804391439867046973766380730403698426239583072157955`49.69897000433602 w-951.8995607096637278483935382633936729582406803737332063978112`49.69897000433602 w^2-853.059078251617821478627418282106557818435865789848645898675`49.305417786111455 w^3+266.061443554975358719177175908018746601648302430010234371713`48.97687989603568 w^4+147.4181512178062027304166441847979784044197269071889605595106`49.06089410351463 w^5)/(1+2.19861418010739425103131483014817085727722002088182989002990961432509041113577`49.52287874528033 w+1.42228861246884944654523759951145647614482683934373700994912901035180750238994`49.6486351182755 w^2)-95.5338071386018292400880278128687181554190800074000082818856`49.49595831668379 THRSub[2,1]+50.55375942389176365862741939314074346601976484450080298002924097331489756753671`49.903277502804336 THRSub[2,2])/(1-5.00865223318159218423571665154977457175441923711141428393753130875697056264706`50. z),((-60.72192140914536206861048153173748764044600799123305028218453287414170577474284`49.69897000433602- 287.4423499093173588385049878575586740663394741536302492382873`49.69897000433602 w-1619.5679164067903572281541643657290751263460727045108403038553`49.69897000433602 w^2-1423.1651222334065630495411118263318769687888667239011438814125`49.31336547488383 w^3+393.141600912500237290946674356643038074256538552217052361984`48.95119546485674 w^4+268.0559238150574759254519220927461933068283666990408302356561`49.12271504939667 w^5)/(1+2.18274324428303320566656955308667492081869391789705920741773528517132323173455`49.52287874528033 w+1.42212141383350323936226893887458579988791160448640584086916422156186334642211`49.64709688783928 w^2)-166.6241881182618689531410849339991936204581234940795698110296`49.534623995777906 THRSub[2,1]+88.1727565626165158776095513454719009527424912764841408085621`49.94194318189845 THRSub[2,2])/(1-7.99164456864244332599758799077534133794926338363798101656353107597448541443172`50. z),((-51.89410603661469512881734088992213815703058200014719572199860664206628134250517`49.69897000433602- 245.1949167420439210651285877571957425859716330937989332377206`49.69897000433602 w-1417.5651320114461135439833606856072506869961465083874775554769`49.69897000433602 w^2-1250.6834917114362655503028238645805421757455490060547486936872`49.31172514800514 w^3+354.6950438926900306284430737966534484061904780664295750294503`48.9569049030644 w^4+231.5569671674118119608413985292917433538716692703844683864552`49.11012235749271 w^5)/(1+2.18614506340103879089004210672309202647137654394339595898669129645683243521861`49.52287874528033 w+1.42217765492532407368864570946718878383481420343013291760538631791269656614881`49.64742266558619 w^2)-145.1080579912150083666700858895617991159614034531419618982062`49.526639956806974 THRSub[2,1]+76.7870356460639600665953557677113459354316396078767265804221`49.933959142927506 THRSub[2,2])/(1-7.0888156574269780628330362459193185636611689247131415719947886289196100118795`50. z),((-27.61657659916408884664342893383669006742681879983922208673883930524772245886797`49.69897000433602- 128.8880672211844064954262529669322699955639319087135216853406`49.69897000433602 w-861.6791793768365064398055866819373300258651039412872763978785`49.69897000433602 w^2-776.0179306594641258431772628339203631751703065781542857617358`49.30344981949203 w^3+248.8869689975410983934245120305621264257402918659021484501842`48.982543192667684 w^4+131.1170135242294808008117885090247575779985170244591876606686`49.04522900236522 w^5)/(1+2.20231771452462911711577442540660724903531098740207805588600423289954694845562`49.52287874528033 w+1.42229230300538268304718037804096870586263903537018942707218711254726981721413`49.64900097315847 w^2)-85.9361722532316055525408176252586761886475820473189851820908`49.486380774352845 THRSub[2,1]+45.47496543916730736253173304344130955920461791715991937359043803511958568404676`49.89369996047339 THRSub[2,2])/(1-4.60593007995804405758316813969271147564732947837017015561297825131675722955253`50. z),((-25.74493587709885897938925026606028178847361851129215063872484617612444113378911`49.69897000433602- 119.9082156180955278199784043718620342960082391474649770878888`49.69897000433602 w-818.785138424353153869845106957256021905953400144744930292109`49.69897000433602 w^2-739.3891602110995522802310279437239982493712088825787570648292`49.302370853796084 w^3+240.7210741497135895266003175368393705454420452732906861150752`48.985545512875866 w^4+123.3669734589668796621179956937773667571798752803866225946775`49.036570001236164 w^5)/(1+2.20431256329930605281841003154234505896478627185378563500175843326638576231223`49.52287874528033 w+1.42228865383739832553440378955933631767223413122125271185671912127669591622619`49.64919915749196 w^2)-81.3744020272316126358294252413927813950631384573486012311009`49.481126860334484 THRSub[2,1]+43.06100705668918676490103655282795234967794238537797661132114143081415097125095`49.888446046455016 THRSub[2,2])/(1-4.41451563776811043280482949467769025250602370399804030094569438532123902241516`50. z),((2.14636840534999850473017689186821015591539483378351896458090324694270458732912`49.69897000433602+ 14.91484501757449828163495430930108121482936674561364662216671493892827247508293`49.69897000433602 w-176.7062809614814544315947504913409523147347403414116260893027`49.69897000433602 w^2-190.9523158829874244558188665766434789526614194853787128858775`49.23869718610606 w^3+118.1826866944451105287919976352893295751388087435136004160202`49.08999902291353 w^4+7.4502555093340090966174736148393197304873218096442538682311`48.241951343389786 w^5)/(1+2.28994374570643393839955144083858019213326235446385541430534219122914598340598`49.52287874528033 w+1.41808618578620915602394531988106024368833975647280211144745298083536859887807`49.658581367289955 w^2)-13.39462367554698683040386966955343621594110318195178033129621681093522865645608`49.14875882478851 THRSub[2,1]+7.08805189648466809419810615117013361804991481595214342804791000517313460926948`49.55607801090906 THRSub[2,2])/(1-1.56204593659402540396498208323584668180180239395363992582966877137936430334545`50. z),((-67.228372428350052115342890719662819166834914303119906423088`49.69897000433602- 318.5723434693771070027587838108109749094633003010542636561575`49.69897000433602 w-1768.4284340339615464427891232180771019533916327711457542402911`49.69897000433602 w^2-1550.2696144633444472512898896896835088850673891205429846293803`49.31434054895231 w^3+421.4735227236351552546492049361471185680813656864927196025909`48.94768892747336 w^4+294.9527710785895820121426773563337785830834374472207981093731`49.13016533179361 w^5)/(1+2.18068819310523132819795697072507173014590844278349041599030803736496304177956`49.52287874528033 w+1.42208211986331300736702143103190467435889714030392623822012548046584507057589`49.646901092651134 w^2)-182.4824317365051954848928525567911035529667161522364617830282`49.5393724718232 THRSub[2,1]+96.5644856978223491391580097421512248886566642858046164693317`49.946691657943745 THRSub[2,2])/(1-8.65706538247414063838599173298544021922093087512521810123574472451359728325803`50. z),((-1.59848373722336114793321383102052693954734787697461576547858624758422009985435`49.69897000433602- 3.44234517101250269167651532330034921966454555179270858911685195231535385625238`49.50822970982437 w-263.6351818128487594808988900381695638173436005338439716449776`49.69897000433602 w^2-265.2384401964094863218632236933107644017297957639983475049794`49.262154573692385 w^3+134.8817048686002477357821268836450307198954529182230618385927`49.062917633115426 w^4+23.1081658104464549865188773022268318318796617928854798101467`48.64624988348008 w^5)/(1+2.2643237597271987782470589697169809007334706199797104829707118129350532845827`49.52287874528033 w+1.42022274891460374432049418558058866444799425210108524327805590433325243374153`49.65557419307618 w^2)-22.521992407892860371218064643759279871281120929463549278034`49.27920139456948 THRSub[2,1]+11.91799447794932539847475725820914329124909209276148899836673738993402769804416`49.68652058069003 THRSub[2,2])/(1-1.94503545776852519028230965901945615678388219870244877000086924199872572990707`50. z),((-27.90636160389130052873118341700638145354618655578366560080270276695360361347633`49.69897000433602- 130.278151728097731533042377623166718064334607939597006771519`49.69897000433602 w-868.3196819695686819162611327052849979734989288220051411286769`49.69897000433602 w^2-781.6884573988598815312175508673583999854063997174673815160966`49.30360785038002 w^3+250.1511113176843343965356501571910647552783787585794650094481`48.9820974798338 w^4+132.3168185343435887977915872151101478703634671462102877712434`49.04649295335982 w^5)/(1+2.20202344054211733473635451901579945169189249626653645512317388775682629500473`49.52287874528033 w+1.42229250632886077417693965640004737413897856448791489525508574412999563844379`49.648971804519185 w^2)-86.6424683873781193019055616872110316302750893997963101860121`49.487150095351595 THRSub[2,1]+45.84871716033408729111618548045096354062170544117883965338556607175649594415161`49.89446928147214 THRSub[2,2])/(1-4.63556666265307120304505883485642852387021576175629973434467565696695389433824`50. z),((-23.45557468690372436837472576164531140803091269109934625606468883570780623586132`49.69897000433602- 108.9198142117819542823163095696697064544364442137850477835303`49.69897000433602 w-766.3051022956786708012012164689520083675508637352855664772843`49.69897000433602 w^2-694.5739196037063639611809440966049234130787761117162061035766`49.30089667037685 w^3+230.7296403447695111140322348526156547070498808027576014645509`48.989535945232 w^4+113.8850901852832992107161848428688443204832828308643659459993`49.02465350784388 w^5)/(1+2.20699835072989538677531972500288038033391641472185141159362704221825292484834`49.52287874528033 w+1.42227746317739150562822115548106815884497454600667189364516631583831044404341`49.649467244483816 w^2)-75.7945171749356403994584943793955969299714990202540410595303`49.47394408372559 THRSub[2,1]+40.10829152189702011532778735412658186640169227047605347675974642145175482192492`49.88126326984612 THRSub[2,2])/(1-4.18038053372477597162689210071473960277913338972937294805039650025404605359626`50. z),((-4.55263722431096196817305337740414962288393418413486720430277858686706614496828`49.69897000433602- 17.81533449005003393916269242226033286162902704357247180963129287391578120329521`49.66756166242027 w-331.9072238212325084190775678870074369847056958245712219252739`49.69897000433602 w^2-323.566653408905334112269116403043041499694585548769719032381`49.27329276376927 w^3+147.9403276883954468828334934113323457779313767084900665218565`49.046521417312846 w^4+35.4245138280028935729492597032031336473411375359866615199604`48.77351966944551 w^5)/(1+2.25008306884625944001280816743688625163397466010567580311874043850114505387696`49.52287874528033 w+1.42107095245517852889307630387471322095470215382772333608556017176838112131765`49.65398271886827 w^2)-29.7221827337157692891312581276997826248290504651086319883158`49.33696891247122 THRSub[2,1]+15.72812934475927601433052557398043859407305415502515812974242322019397031828731`49.74428809859177 THRSub[2,2])/(1-2.24715949001888402040028362736354676567406001522081586100805875956788375957893`50. z),((-79.9854113214253799480781981035669926514584013048002739856432`49.69897000433602- 379.5940422900206830175899579300744460077133744461948455306369`49.69897000433602 w-2060.2541892673749441745262884783082334549819820277580022841882`49.69897000433602 w^2-1799.4427955528442279239783063845325877190913177531934688450591`49.315852051373575 w^3+477.0151415191203883306944471773532960032881745953435474380747`48.942077960986204 w^4+347.6810649576371989337252979632219753047250306958125739094456`49.14166603082596 w^5)/(1+2.17745282826390927652151505841140813900542503228888530320096237261602221363544`49.52287874528033 w+1.42201219392444219599620727502300520278366191958729924278352843361449302513272`49.646594359873795 w^2)-213.5753009545573735508965337253332907795266779955372406630526`49.54673794955677 THRSub[2,1]+113.0179431421327190830215524722773733312290861034173117064648`49.954057135677324 THRSub[2,2])/(1-9.96173964763911841254637115404182858116929674708414582402945407088267225248359`50. z),((-31.99597448470009159283512455966981701221209544370311773130385448686773936776317`49.69897000433602- 149.889311638078014232624886254429815412193810461692196565829`49.69897000433602 w-962.0153601893741154639725310120480979564939379046646859427254`49.69897000433602 w^2-861.6970837687453978187528180531769176582147992852588946264788`49.30561655979919 w^3+267.9870260302379783615696457211311829057138943913968918062282`48.9762939132674 w^4+149.2459019927267352104050674353527367505291820596847626887452`49.06246754198672 w^5)/(1+2.19823534273937257133148005021584623173035273856112282315019087475670128373224`49.52287874528033 w+1.42228747187254374268832756224433926493288147972417054499555375887490510560244`49.6485978458523 w^2)-96.6101262052493271239594958110007755459901151834188946097517`49.49692540307236 THRSub[2,1]+51.12331670197347616481628045847490050143832796595471211132862206581620396770605`49.904244589192906 THRSub[2,2])/(1-5.05381518606038567210966398499440077267003539301679577298751407781105423955217`50. z),((-54.44835028655513975053289318920517924557532113414640040045571345539260375319089`49.69897000433602- 257.4203299081423714608798895929018134456780781057955028163642`49.69897000433602 w-1476.0171654402887170813310362840393148665977108112236231990316`49.69897000433602 w^2-1300.5934373995385771800503305221386638882672810061358369894282`49.312244547821486 w^3+365.8200918343611006543363577639434565247788485268015130142442`48.955122055401056 w^4+242.1184073077730151631422607467466538563331037332002388937922`49.114118117314014 w^5)/(1+2.18507530427307950533528375974621039816506803113997336683019614606752881936823`49.52287874528033 w+1.42216115618244809494828568160447646563867022843090096553333541315917943249874`49.647319993343785 w^2)-151.333545197142512626250629515439536019322965274496371768213`49.529167577864904 THRSub[2,1]+80.0813854886110309567077810650227035053131838207457861213021`49.93648676398546 THRSub[2,2])/(1-7.35004059902779237830287206052125190252325101756147328753682646815142750327123`50. z),((-3.04564911057065940077852587213927564153080790653758847512674618718013735576019`49.69897000433602- 10.49230757081387458028726677631889980730172987641193476963370574219416557884535`49.63634819661495 w-297.105262402502976121647678855824589451163430342748125149821`49.69897000433602 w^2-293.8348281034731693666631711305352321374529759295803033548798`49.26814831945926 w^3+141.2876825662858887936112383457342879058525617893529137355032`49.05444293412232 w^4+29.1448698943522787653868688670871726213404040714961545455267`48.71752349923582 w^5)/(1+2.25684985391463883163377558129533818485284867738883188652384531139831717871328`49.52287874528033 w+1.42069711081375351259357652443242598852342608725108313973846562435375314076894`49.654732247046184 w^2)-26.0491842638968304644347064848018362123356475344215595404455`49.310539039202474 THRSub[2,1]+13.78448356564616743815298913099305503419561774269815271030328644122336720659785`49.717858225323006 THRSub[2,2])/(1-2.09303841016753049433088056848434490833844168567985302057916426388274012220788`50. z),((-36.34897134288602875526394167441959497448215218836228599316715476584567887975259`49.69897000433602- 170.7522842798358200737518361735743365252132765160443793869643`49.69897000433602 w-1061.7127403569426977663071971492516030227068020162215623918722`49.69897000433602 w^2-946.8290322012661527208677506232808946179454523211889469658778`49.30738196154839 w^3+286.9642173254456040450496046291216023790833930216683795155998`48.970971774169406 w^4+167.2596061521601688760610586902284886436827262698505187633204`49.07637495884739 w^5)/(1+2.19483144780345255702337391780674769420477512717462656732840798820117163018117`49.52287874528033 w+1.42227090909948156272152155412343832353459674812141037975140419997451052378008`49.6482641916531 w^2)-107.219732647041662985587781242328032890000783610442418279278`49.50551309147916 THRSub[2,1]+56.73761710206524426712821273241296635394339219138823188909460197522004820639437`49.912832277599705 THRSub[2,2])/(1-5.49900023447330185811784090783884608631704697037137259476959263774842045765349`50. z),((-23.5501779412055932258923427258499826293114747421218005526541373320936275754701`49.69897000433602- 109.3739929256637320574408438864057913505401024408294480959659`49.69897000433602 w-768.47403886480388097752808037578364122605629444300923850357`49.69897000433602 w^2-696.4260947816421810532140462292391757756597386888453478984471`49.3009613368191 w^3+231.1425899089826694262180979850284794154520240621744743345623`48.98936352935941 w^4+114.2769612550623518627409161170201022043436253062189359835588`49.02517838396469 w^5)/(1+2.20688148511096403082755117533760336435935022796721249104129579316944628184358`49.52287874528033 w+1.42227810060352462362440641366479724926403744682834129452772851681633112690699`49.64945554901152 w^2)-76.0250947124241256270823131996906993818425838023908867078261`49.47425928365519 THRSub[2,1]+40.23030656251855379579195798808948117184039933917474217116393484202452314824661`49.88157846977574 THRSub[2,2])/(1-4.19005569677186079366950054823919684272642329866098029188741715475998548244669`50. z),((-32.02561436499018431120953853983696715518807959875568189802259565653567962613275`49.69897000433602- 150.0314050210245592651653111720803759977189168650949665718734`49.69897000433602 w-962.6943114026852379829123190821759481440948043541194411047357`49.69897000433602 w^2-862.2768479232753267930401815185314988406009997579401207813637`49.305629758793835 w^3+268.1162666196385619680328400050259366632071786729614886085611`48.97625490972522 w^4+149.3685768710970629176032268325198995469367780043917850180059`49.062571966178695 w^5)/(1+2.19821015578689657854300686555856861807870817121535974247883980819267082978377`49.52287874528033 w+1.42228739103602655759528514378476058307146948197954702050441317566086062871969`49.64859536878781 w^2)-96.6823678068641677554449722802023384783054799337037393184924`49.49698961817044 THRSub[2,1]+51.16154489215891268717033936625882069605964673509926258701570003760256648535162`49.904308804290984 THRSub[2,2])/(1-5.05684648426063223339290637362259135053088155317305762026147647286699303119282`50. z),((-35.51652896592683652833219618725643230814989367445252317511880696723683959820734`49.69897000433602- 166.7633340467320222193767019792207373285218054470643053898397`49.69897000433602 w-1042.6494103980196869050969751209591694808472304717753861560746`49.69897000433602 w^2-930.5508999829956419563869197229225401237107973215856842513647`49.30706932821027 w^3+283.3356253431911519935226329049568580530674294575706907004221`48.97192999655395 w^4+163.8151587901585853113838505853626454238948529298138798253362`49.07392067642673 w^5)/(1+2.19543943455732754255472614369607255604977899771139896975912922251793350506678`49.52287874528033 w+1.42227469892745585172870795896095579105486239492713381499217558251893772414452`49.64832362413937 w^2)-105.1908118155463331971335479205047735889635520232916840006279`49.50399244827981 THRSub[2,1]+55.66397020493355226372125833416913909871294066804451212022849955245129903571104`49.91131163440035 THRSub[2,2])/(1-5.4138655762227143222758967217312780179968337725019816429803150361140099966245`50. z),((-33.34711724565743820853007673539267835602878587184038033168463426122953687322614`49.69897000433602- 154.4110566601970813213022228727974624446851385161610341775317`49.69897000433602 w-972.1051813367543803513527516215058431302482927400451142611627`49.69897000433602 w^2-792.9512599273276320719840977461812611217754739506663583021773`49.243737532186834 w^3+612.9308170694602702740352631680313986808041646100996756524193`49.69897000433602 w^4)/(1+2.13848821502557257223063078982954033311945223173683968519707202955353909082582`49.52287874528033 w+0.94287526181082806837313066264568547770774841999150670004360498093666932103704`49.21721233125332 w^2-0.3179841671123629155461671737374596818100248631410029531244327029698278874496`49.11401215969784 w^3)-99.903281106906696288543430945995827690090297237550581754159`49.49976736049013 THRSub[2,1]+52.86596012455228132540590743045964591036580258252935082579963099050107416289114`49.907086546610685 THRSub[2,2])/(1-5.19199781633690500069248602778239608416890018214160513393962427381829971376464`50. z),((-56.95171568790976730387823250668336484217738583047066374761337608324971510592492`49.69897000433602- 266.9738782243904835299438557793568473372264533312158408043925`49.69897000433602 w-1498.2189101590485619326041412836564109013792429870168965729531`49.69897000433602 w^2-1208.1374000986033803192129396277225026423887703935620102087609`49.24471121864734 w^3+945.3929795143518099780964127703423386676233957669720386795939`49.69897000433602 w^4)/(1+2.14148133876876159802898760384598300513886912308281257243735828028089161156059`49.52287874528033 w+0.91465673715421526807811799598524666058750631720828577955184353367625441938137`49.209027358781675 w^2-0.34031476547410250307003221241765476387348142152208356410574924206784964481424`49.14863916632634 w^3)-157.435024833734894698476867440517228497778666467763397979584`49.5314635990309 THRSub[2,1]+83.3101140708453612705846016159937159020935690317813682382875`49.93878278515144 THRSub[2,2])/(1-7.60606211333270238478277233542184964366882406325211079345710583775760012723763`50. z),((-43.96237330090157969640385891933871652333380237341092793511438265517079153893353`49.69897000433602- 205.0119836652799966033852584778299499400737172890919223452115`49.69897000433602 w-1208.6833170518509421561546793816154842043797233334412199783112`49.69897000433602 w^2-979.4616800662637201935112037902937565214148359465954818400293`49.244239779529174 w^3+762.2168128751025404253231351340599170176236627229625872091751`49.69897000433602 w^4)/(1+2.13978038549205561568592551351344697301784591756900188137236840031514201343733`49.52287874528033 w+0.92713281080185129788839235589469354877421290629253303582590514873662493681903`49.212700196600196 w^2-0.3303363540522074769145004667837593108158516918517498629012591048846746997927`49.13338694548725 w^3)-125.775959791064536071489787825875566182408628241854176219439`49.517324037991116 THRSub[2,1]+66.5570419836993679519731233415985679724757238497535444103939`49.924643224111655 THRSub[2,2])/(1-6.27762995319049550352794835538786202295616664978939136792052453478619274587361`50. z),((-40.24861340460672197527543733693395440633197939666558168506700754738406097753653`49.69897000433602- 187.3046839291184153851168328974722671524669081756043352451946`49.69897000433602 w-1125.9121097781377530551439661842031846346682989138918004497197`49.69897000433602 w^2-914.1618031108514544741515724500071664412178078493693053428229`49.24407766004428 w^3+709.9342501187552161959057110355444038326667757504396745529897`49.69897000433602 w^4)/(1+2.13929389245456516559740867571953995597800685700509563738973495480164739760145`49.52287874528033 w+0.93188479392184933975434864818094611093915459162517882445931544086707551094424`49.214076365381146 w^2-0.32658092619185324419279721490335806402415916981853532753256710941927148909758`49.12755622898804 w^3)-116.724372527704987556661030998215803772028252947679794482733`49.511992124311995 THRSub[2,1]+61.76720078902824295857720142559539951354567232239843178134639403475845538893343`49.91931131043254 THRSub[2,2])/(1-5.89782026504039390444604098450241155777004018604784852775304440230052656537124`50. z),((-35.34523647476921650928731997216063373634080565465549004620470595247396671731506`49.69897000433602- 163.9324862020504993065419073832161738721030159669371447026533`49.69897000433602 w-1016.6338295801823811986220336353994352750674529546690676046874`49.69897000433602 w^2-828.0222506826859700317934238560842277252407436810817763280328`49.24384146748477 w^3+640.9907456268132799069179139725917102146040753747440462065345`49.69897000433602 w^4)/(1+2.13869939446624666463398304902115078476016645770935698514075656954689723670361`49.52287874528033 w+0.93934977285550683379447055704257554567216729859195892999612008014787270476789`49.216213432512376 w^2-0.32072870749348136249269928997059923479412826810761301336976417385062709896596`49.118366593091615 w^3)-104.7733187695316157172820727924555478851634810314362032213095`49.50367291535688 THRSub[2,1]+55.44304482111884529619087413292318983507204409894066156029372085422009873863422`49.910992101477426 THRSub[2,2])/(1-5.39634733339987128462450599448769969122211160169354110890732230468750191836264`50. z),((-10.51982221790482863328008871033179674115146031575043701045512966678013443266036`49.69897000433602- 45.79004865346324544979109262817886958005599377177579866615458094365818622132683`49.69897000433602 w-463.269819281317643391793087210799357953823469842675193620727`49.69897000433602 w^2-394.9765711976283708030717846220705336096206154596136917970913`49.24246691780719 w^3+295.4572192640937335311665827181839614631719000253519054789333`49.69897000433602 w^4)/(1+2.14516614986553646945537386856814406814041683752116747072377909038198817952746`49.52287874528033 w+1.03153573748102737668549741446363010576581090379614758045152469352157041791818`49.24033198992265 w^2-0.25220944424317971338942420714325422200146952583249285089609845543757727616573`48.99926991050238 w^3)-44.266067420502234578662685196784506865809185955834565904306`49.40561759298675 THRSub[2,1]+23.42433731099177294294652950346316236078396680724591983272029711899483579224068`49.81293677910729 THRSub[2,2])/(1-2.857429064476831102056534643802667428087240383384967759828515466953540169633`50. z),((-53.98356238016229103240607129416945139292555182242043630350014209912247702684297`49.69897000433602- 252.8118850012850496097858044317274328856363894352559205252211`49.69897000433602 w-1432.0538758931116445139797789041262838549647107616178281146755`49.69897000433602 w^2-1155.8524023605381800927143650162795241882300434012073913107497`49.24461504007656 w^3+903.5017597560554907482739861868921188754106262822971857836588`49.69897000433602 w^4)/(1+2.14110409286771096617720397539958160086361595511008225678667033092158059481006`49.52287874528033 w+0.91706120126208646792248646143369942447064360774935655430530145495725495507006`49.209742040658284 w^2-0.33837775839356450319034060873602137468111921101665049348846558316785373005929`49.14570495613826 w^3)-150.2007125932182886858660188760634360251281231669323019609519`49.52872216209081 THRSub[2,1]+79.4819228623258723930227984240478676589533672528974201480432`49.936041348211354 THRSub[2,2])/(1-7.3025063063668350012573568671994415393303924988771939712323100835523127812953`50. z),((-11.84392057046860258330733018128107084695982823672730320837846632917900804400073`49.69897000433602- 52.08271712587473480768252767783630415519361769214680738296694890173451237300368`49.69897000433602 w-492.82126185008546165286990647313427231954818757537198329258`49.69897000433602 w^2-417.8095129378047126591864678413410181443533649226125535897456`49.24249916431102 w^3+313.576399066007890418527907303504100492053931050909165770881`49.69897000433602 w^4)/(1+2.1434086668205439129386722559483850871744878031357768494260151796483517292051`49.52287874528033 w+1.02137495672928943899738584740121587240324582557732201018825827230286768176291`49.23786377724775 w^2-0.259484307848302342045685091912009753444525488855971031973346500090304033224`49.01310964346285 w^3)-47.4933066923407284854854759284575551814007667775637702100845`49.41607017100882 THRSub[2,1]+25.13210006679987983345696572101075802005637380611712124233876078869826966177509`49.823389357129365 THRSub[2,2])/(1-2.99284583788457043290161789030115878832205059020566190231147827495356009127498`50. z),((-0.20258691138982395521889855763879118360634769340904340021203070950227751645672`49.69897000433602+ 3.3932492489029702171605905144214897078266310830646910379238738401514510410049`49.69897000433602 w-231.5357966482229359282931143247216997513234455988594527410092`49.69897000433602 w^2-220.5307375764573038990295993849623057624356480141707143556501`49.244789869152854 w^3+158.5971397897098099672728257089905482527566234671447867131748`49.69897000433602 w^4)/(1+2.1980130395407586963369691634838117216474458917432466466922691001398330375041`49.52287874528033 w+1.19865463707383649678323889662367943099994477237475564903782661156374664335275`49.275491003168966 w^2-0.13856636585730865822766902971768951058656928397469899778577780917850901852005`48.71756490868203 w^3)-19.1197579386465771052937097283096639984432446672151098808502`49.2411832511278 THRSub[2,1]+10.11762926678994206254901444441481132823837737285001255664932334224780362430291`49.64850243724835 THRSub[2,2])/(1-1.80227578753822911306411715383490468803216542125965674074863864063545932116552`50. z),((-13.89858206116831971048944590015606440975177086003435027554846661896891799869732`49.69897000433602- 61.84830102609280722840973027784130770638000263929345286589944757865677280694653`49.69897000433602 w-538.6543026697767054139802298097262680116814342521454105704977`49.69897000433602 w^2-453.3428469702242385318895701514545757958191694500092807555169`49.24258294696313 w^3+341.8153922901446871111346231963142274097183005613133541920314`49.69897000433602 w^4)/(1+2.14141457490148616467544766616451054850203911930129149740184951081523426740053`49.52287874528033 w+1.00781630874948552747980320585790204735647998332262326223481340774731441228685`49.234501214464736 w^2-0.26928345707564039998052972823771403516786614759685302192475982337111412446792`49.031240287073516 w^3)-52.5011554222189564907010715354859284379657570754058238020002`49.43013701736512 THRSub[2,1]+27.78211044013514933566514576396891084071977431748653637020651500409272200216355`49.837456203485665 THRSub[2,2])/(1-3.20297798477302489132683923776256396822226088312233189128680466010658091093973`50. z),((-40.3671782994956689874178883838107415172317075761233508453831252998479683083376`49.69897000433602- 187.869936149552954717142295169968883135084609075349740007016`49.69897000433602 w-1128.5545811784808410629942176138389729934419948381462156733111`49.69897000433602 w^2-916.2458426062661380051688214130415539592900739656842759772623`49.244083051439176 w^3+711.6026205011397179474405777658958847624218768980645058957694`49.69897000433602 w^4)/(1+2.13930911911056947647555776477824446681870220764588426024950844589158903782348`49.52287874528033 w+0.93172226441196543345854557748808951384091848091659067272293013806486745798134`49.2140295011682 w^2-0.32670897702890400731803658513245814636928071944719900780049840475541427920826`49.127755883957576 w^3)-117.0133520316112757860398844250000523573457556601409467571129`49.51217401704219 THRSub[2,1]+61.92012048056444580591939185641869661575475210505556573635427428023567317200456`49.91949320316274 THRSub[2,2])/(1-5.90994600741761332037885510472771326860538787288434913313341394946763506267241`50. z),((-50.68082799185570719426780408160663804376799735062921553338233464051374434638695`49.69897000433602- 237.0555975507305706781059480387903328634365383091142865929483`49.69897000433602 w-1358.4332583600855670226500574067668816376001897967056260987552`49.69897000433602 w^2-1097.6930996483709486143603421175321184731306713190161308030239`49.244500486373546 w^3+856.9098089378271341218153542375711165162268675587396468671701`49.69897000433602 w^4)/(1+2.14067376686268405691661922866714876216594452671903709470697091466104663782398`49.52287874528033 w+0.92001316788689753524308327793283117912664251915619797102708214925273063860402`49.210614967458866 w^2-0.33600894197959314024786272540626449087212735361471079364999630551980909969443`49.14209948854203 w^3)-142.1509222572083915025490232331375869411921132529061060833315`49.52536734559497 THRSub[2,1]+75.2222039602098041560296885577023851786538838488196268576313`49.932686531715525 THRSub[2,2])/(1-6.96473258025254315318855390724023741466517465669260074663204147125160751587693`50. z),((-42.64477411764865738106753665869557425584803358451028515807279700340688587728016`49.69897000433602- 198.7291478140254552904527375528890559653057311402681697413911`49.69897000433602 w-1179.3165397985040417138960000010275607596991795631047758133245`49.69897000433602 w^2-956.2889542424970174687730104298075460185376895896046989682808`49.24418383011794 w^3+743.6619119590849860396817811347860637671537293303988314135089`49.69897000433602 w^4)/(1+2.13960598884586371537682654015521706886987462495414671766327782352342029591853`49.52287874528033 w+0.92874209014530277511728372682676347090773759333117046116074513092796038424217`49.213167630040346 w^2-0.32906187022501252741599506639186281309507858816737017985134672971127867964725`49.13141386691024 w^3)-122.564561015057561375628384617889785487515433329446454780865`49.51551514380915 THRSub[2,1]+64.8576615654051421443900138609401241084797335050064372584328`49.922834329929685 THRSub[2,2])/(1-6.14287785588948347878504527120820831317812931434469376734882712918526427493988`50. z),((-5.96598246088673931937495607921461082967653064973513669437142036219999233784465`49.69897000433602- 24.14166497340403557855713134931483271330328588781051498689129847283199289107851`49.68494858030847 w-361.4680805701128844665369224395600149674823734758163491673335`49.69897000433602 w^2-316.9973698883749290712926172579197115412757772762522240989219`49.24262760550973 w^3+233.8089264512096296524946432499142320481720744376134761567444`49.69897000433602 w^4)/(1+2.15605349556438133089848559817335995814216381492107440727882667892023652355432`49.52287874528033 w+1.07914741026955534075690339067817847166550806696201014757234183188566784679917`49.25134272404066 w^2-0.21880081842214900067376656596363719966601196166738280670051887564292380374565`48.93090250983824 w^3)-33.1669444036563936927571920766385652557666567024358477782252`49.35752021062867 THRSub[2,1]+17.55099873467240842155753626277526585510161410273134512726136155300594418370634`49.76483939674922 THRSub[2,2])/(1-2.39170362548866335418928336791314294111087435580577123793702157966929090129179`50. z),((-8.72509393345536309069105893625268886845754858306317458278059400267953164442601`49.69897000433602- 37.26046508991815449106562849880637078574605716561926086447973976207883059411068`49.69763779879203 w-423.1872628891425559935208835059606609098136602481446619955581`49.69897000433602 w^2-364.1289038120760910686829912754392269888096953413098836013326`49.242465974199575 w^3+271.0198349753235628158835973060000414468951075864001651451968`49.69897000433602 w^4)/(1+2.14836714281812215096262764079510093048702406645062468590108677556194770308147`49.52287874528033 w+1.04757284404585521321022415832049942302605154784946697085061546739862197863294`49.244140620133486 w^2-0.2408375494650023057369984581649354174855120179115116832478747870680084584012`48.97693398772717 w^3)-39.8917567126610091116651016147228077813820369674075125480032`49.389263272697875 THRSub[2,1]+21.10957714605111470928029296486469595997099906308488079725054470657321731076992`49.796582458818406 THRSub[2,2])/(1-2.67388052901254549116268899786619927906581071862318696962359845044767149292124`50. z),((-25.56034037668606497601254643323854549488395095388906419047341409878837580153556`49.69897000433602- 117.3236972351458406113812397726088556592299591876940970493739`49.69897000433602 w-798.5825029951407809760015798998861299950705706266974281161462`49.69897000433602 w^2-656.507564736585790318166706466353137378239900986378864343281`49.24328982185802 w^3+503.839309098130623898368697816430185179974126630956847943551`49.69897000433602 w^4)/(1+2.13806057543703292028833265807999608532854880524876882361629223329236928603228`49.52287874528033 w+0.96038443917503834533489439640752028402112438819259879249446381046602920212707`49.22207726878296 w^2-0.30452445595710196406583713654057890647613131225430127360380182144666872072484`49.09222051309815 w^3)-80.924485412515369522650038065881364013769628356652533474685`49.480580247277715 THRSub[2,1]+42.82292404730824568684597224898748578229716546514686950957458815309817132865391`49.88789943339826 THRSub[2,2])/(1-4.39563688378198340531646744659699034773492953195347386646973315857854252250758`50. z),((-43.71661312374894171699058033667343996501509295015759698463179632511605845520985`49.69897000433602- 203.8400625040055904182582924897412836719264538196948629170989`49.69897000433602 w-1203.2057485710539677944711353591055512220999258580027598385773`49.69897000433602 w^2-975.1390759171182280788781806174073739255189823428336787800903`49.244229471035446 w^3+758.7554868663272950775420419409635893792668218625619915965552`49.69897000433602 w^4)/(1+2.13974776004546602309627899122972626753399832696059166999162201279438008175181`49.52287874528033 w+0.92742699080435944229119627859157866626727993885810948256266412917674622766233`49.21278575114196 w^2-0.33010316712884621105995289153614195796364110767597202943988582195776844024104`49.133026373487205 w^3)-125.1769658465246205974955023932180311694906495145499256374453`49.516993119419425 THRSub[2,1]+66.2400715135002041592034518451705830879131941927904590299014`49.92431230553997 THRSub[2,2])/(1-6.25249583067030170884803922732286881988153161715456143634520215072826771943227`50. z),((-55.93542444287059360480570229510390432188361110833383470803356283276282380710154`49.69897000433602- 262.1246441666437823126527302254532756670053714775152949405605`49.69897000433602 w-1475.5638451456948043763088898838225313729752822038086263984214`49.69897000433602 w^2-1190.2333672181908784047135016191179578995407610691658137476867`49.244678973395715 w^3+931.047589978969479767612002086710132718757778828589804317606`49.69897000433602 w^4)/(1+2.14135330236116513284694430072418148724682685405429730540899158293572526964743`49.52287874528033 w+0.91545565107541168948301328850269597769409061139429019748073233043630642409023`49.20926518677807 w^2-0.33967041039511823708151096930541153109921908208508567187036226813495394741202`49.14766447445523 w^3)-154.9580071626037842846946773540842934655485267075506329120497`49.53055183267429 THRSub[2,1]+81.9993471372778953808371559303092781595595873198781703105974`49.93787101879484 THRSub[2,2])/(1-7.50212505988099469023818871121739902706605643490694192145396580007817962981683`50. z),((-26.1240662161699436717936897487205415504877826146257652355803781095410607249779`49.69897000433602- 120.0075579323898650327343640733321896926425588099703294275382`49.69897000433602 w-811.1445687168563949902191771493299858023672978219822603407601`49.69897000433602 w^2-666.370472836638023681482895993371594804422969815041927979969`49.243324340160285 w^3+511.7200194411622763628633328632513838708993564871169760423067`49.69897000433602 w^4)/(1+2.1380584154465528179632882370362628058184043704991249154291743082891976069635`49.52287874528033 w+0.95886419472513777248335911968833627910827536002667266508071009935977208608088`49.221661093357234 w^2-0.30568234745196996545760381438620935086264430627719810227436100779512722490076`49.094124778844325 w^3)-82.2984605135416148978170921858637639739480302575518781959639`49.48223287756154 THRSub[2,1]+43.54999238878997045529565569976636942898053928142248201853838713780292649205703`49.88955206368209 THRSub[2,2])/(1-4.4532896511324354106356348118224121280306446083855116157380161797984604906932`50. z),((-39.84380751793645128214014399513238258328556871537840157345406767939606006957337`49.69897000433602- 185.3748277739969316087238869805050854971041860122325693491958`49.69897000433602 w-1116.8901819764740185196259946423038708545042880108293572446031`49.69897000433602 w^2-907.0468277062071823917916785826995600491572951344828657996796`49.24405914216492 w^3+704.2385014583863895653514931052695762784673664063628453711699`49.69897000433602 w^4)/(1+2.1392421187995528647508483351372192224272666540857470973989324654309403137525`49.52287874528033 w+0.93244552467539198474330503110347878375676163913767818864968507426523170637278`49.214237937613895 w^2-0.32613935901925185921285539871620563238387378122591364159466037755369575791597`49.12686728341046 w^3)-115.7377347508327604686597339820447745886575828407594942915427`49.511364843703966 THRSub[2,1]+61.24510028550536037843211759366945857472239114825868839681906572801628248631752`49.91868402982451 THRSub[2,2])/(1-5.85642038947736859658194781347652683694327977442600547291174389582797355921998`50. z),((-65.0512037962522912941533358249017057127433874579124013075827`49.69897000433602- 249.1783005825616476167967656701187731859632425658662092598449`49.69897000433602 w-1518.4031896116300077294226536285179790873553405811910627770332`49.69897000433602 w^2-237.462472372053939482117082809579589635304901150925130804695`48.77241020691629 w^3)/(1+1.27469935657484179038632449900697632033771622730005793149092933699594040693385`49.52287874528033 w+0.66146324905845426126354363123491060182686092749448956712167297890851472119787`49.27734589765703 w^2+0.02574055112989619215665248810701153410204534913581451481636758749291580565535`48.30560468521382 w^3+0.34807749178854299579432845686302945403902652946663286242808235156188127231775`49.69897000433602 w^4)-177.1759950225584684530503557253511231837877411842498028229466`49.53787257440402 THRSub[2,1]+93.7564710999557150289195810900016831306899363164959927736827`49.94519176052456 THRSub[2,2])/(1-8.43440431598133243410099989593020932183735178365302480303219907735388246985348`50. z),((16.142266252361500415175382038072949269903277394832096609805252885606260413551`49.69897000433602+ 72.3318021713535020661372312931171465094403548200612107131957`49.69897000433602 w+117.501239900877663773796175265637911473411128537222249714601`49.635865581719436 w^2+93.9158887391713315242170269255420958202711193155077616672649`49.69897000433602 w^3)/(1+1.58721027820984838561748965413918997871994500814340334656826397496095871378415`49.52287874528033 w+1.55294387784284781503539836988192245121906927718927707145496267790539983439848`49.69897000433602 w^2-0.69854827026699636413022665450102823303701636771308655952928314459623248480352`49.67936756133724 w^3+0.64151653855410747088115447814064683448344329574245717071766421739414525370232`49.57198431268174 w^4)+20.71772990382193281095742840173677021973193036380910278022032081391868072979577`50.4156803729879 THRSub[2,1]-10.96323034470361322476280366849598499520223276846820477880176133900884731751826`50.822999559108446 THRSub[2,2])/(1-0.1306724108155927466302426232325336165818487686663387274219224972145430356065`50. z),((16.05287074101293283552185578761122687174639191829134916181986089009243017447871`49.69897000433602+ 72.0395150426858853387149053369742150405733789738990444957958`49.69897000433602 w+112.2687947113372749393291442876052492406839976357616172862584`49.626413190355336 w^2+84.6268423056177896020993254835656320313718092570008289599944`49.69897000433602 w^3)/(1+1.59244823698973165447980691585254563514325076885975368003834150500111789220862`49.52287874528033 w+1.33157112221853371214041746942012867506209517240859188644741228866747096994174`49.69897000433602 w^2-0.5850501589230537456907824157747169500404595713939217821943411702389900122229`49.601273979472744 w^3+0.58249624865873859532812704561335919491380836938969744161525700721910871494731`49.52047487847997 w^4)+20.49984525470083537382908628000680471149563741466909987009888385862494517323398`50.38171900887441 THRSub[2,1]-10.84793201771611579557108198581159073200069551170900065277853668865873329493136`50.78903819499495 THRSub[2,2])/(1-0.13981497313395716622082410145113175827703298385717313034500612170040108869629`50. z),((-20.75434860016661092498993051112892212517472785006793592260513909523242274745618`49.69897000433602- 76.6132452132608350265529358497506057605476722341645986460056`49.69897000433602 w-642.2384441642142578048050557909124233883730325700961615385944`49.69897000433602 w^2-79.5749184648919705447905892421498019790897213322978959534385`48.67064823028897 w^3)/(1+1.2790132199823536237929916600131692337173272949173853361275374633743116174309`49.52287874528033 w+0.67626766949044871040842668217315473070030731152624704457456841789125411952376`49.27130110973851 w^2+0.03871452196813173159697115706887931143890023225337301466680365649876967664028`48.43677286959652 w^3+0.36140987301878622056578576827262057752232910146525847603182355582905488929208`49.69897000433602 w^4)-69.2107895444666220072203036359996510297405161733082230915254`49.46417235234511 THRSub[2,1]+36.62437108878498068263694091154558080915953508632571271711647034411196082572489`49.871491538465655 THRSub[2,2])/(1-3.90412362259540718520925614236099282648896282606704397880682210617991252287404`50. z),((15.45792446118285332418541980426536215990863484730271835025490326308691688389616`49.69897000433602+ 67.5450380705134951185275311887593920173125962418083297267811`49.69897000433602 w+86.0523228691245796325170727579914270653521446739197643942434`49.616876919645534 w^2+58.74657154445349090796875946527232251811369905022623103095735263551638823888882`49.69897000433602 w^3)/(1+1.46393626583400930403700381615782183717177314799019247227923850350330438226707`49.52287874528033 w+0.82859020860515379552716536110932098388286851657594659927875207744954973398037`49.69897000433602 w^2-0.35814457643734945992952553010924097456578813370287850923198164270799772276397`49.26856313165963 w^3+0.43771561968734352796610393929372461860290687126446692402092643497212363525133`49.287671325805945 w^4)+19.04977623589706036692634070082730449807301092674950365515987750524273508768021`50.19294970001188 THRSub[2,1]-10.08059695047347173516264589740537100607035021720295631314773396350053804085808`50.600268886132426 THRSub[2,2])/(1-0.20066068403566828549273456108975615458382045333776351527996130234307427164717`50. z),((16.13914989496699786836193056463049898249126076627278459925017553030377801811692`49.69897000433602+ 72.3317570031395193569943827471854548719308378432785241644897`49.69897000433602 w+117.31400673961084874341588628300984627403275397210412590665`49.6354195537307 w^2+93.523925330021392162218703702645674631449884564369836539687`49.69897000433602 w^3)/(1+1.58802043641302621747981253321054839937567754340968092728540506571265756623969`49.52287874528033 w+1.54315027593264487158471489167064210913614995211923412092742915574436746783955`49.69897000433602 w^2-0.69344298067494049573434471572075637971796167489630240208416236195221117871861`49.67632316249982 w^3+0.63896408087161274900402156900202813941107283644268171227331081267897915739432`49.56991553448407 w^4)+20.71013437215379828073519168314476730535205311271802575006447833712101564246975`50.414463159038846 THRSub[2,1]-10.9592110065012705011237843911849597047519090088742980066218016835169715199924`50.8217823451594 THRSub[2,2])/(1-0.13099112359273031861868402732899112020496953309814843203019906937871037556185`50. z),((-59.96980281995389774157463279464331946951764947811952954338576016106218158235994`49.69897000433602- 229.3916681152913054274186435943393442536549301215410555038041`49.69897000433602 w-1417.9366420010672510386201625864007108109613826713788543990315`49.69897000433602 w^2-219.5038351145209762266106521633340864911885851923253148876649`48.76788273962562 w^3)/(1+1.27501616478828552807008494372573615180275395993260636554330526384970946924654`49.52287874528033 w+0.66233091886739550371584248918038130998713223374646020662844169888882646856874`49.27704491780494 w^2+0.02641719923934918017263292052433457840515892141536655198187885003837538189082`48.3143533709068 w^3+0.34875065042444406832561449713291004028869163763006095901744556026913505084518`49.69897000433602 w^4)-164.7910413256397932025366022990919668837205927480191577711127`49.53401989456091 THRSub[2,1]+87.2027076896720442488055046324232535796455154193648992203669`49.94133908068146 THRSub[2,2])/(1-7.91472469907906538601389616765909164708883381349837152876864712222233200618056`50. z),((15.45317702161742378708883643717509109944653677349360385023363193438746037452127`49.69897000433602+ 67.5111057671735666940702343338700622630416745602564219539308`49.69897000433602 w+85.8839038868878697834354044140588538098838720005785921604634`49.61697318199072 w^2+58.63370482235992309737880712806364148744641501311826189486286754371153663534897`49.69897000433602 w^3)/(1+1.4629960091486185649108253411336883901042097346936158548492284145382688511872`49.52287874528033 w+0.82670767890960852724122781238031889420840233281230521475840340957059033754565`49.69897000433602 w^2-0.35747360655457841254262598830595002358793132441812307202713799444169911051977`49.266342456210914 w^3+0.43716656940478093397517810850025512014285752427981808076680268875989665431642`49.28586043910931 w^4)+19.0382052499679798851411629085059853324848712585470661048507081634527257983043`50.1916362622467 THRSub[2,1]-10.07447391553456987021879323836878678018456028471529798876712383253064273684479`50.598955448367256 THRSub[2,2])/(1-0.20114620910761927128815208553502440731161136099269786672424467960361162510997`50. z),((-0.7070285835776795807724098497647841640894956062617888235608604288231188117607`49.69897000433602+ 1.61721692504914959666345407235594253743000068788015782040164894986081598037056`49.67555741841043 w-244.9882842553124371449349746497425306656706822367509557757296`49.69897000433602 w^2-1.9945299913539911301353115778547221135293948187591942370413`47.50432254772338 w^3)/(1+1.27036530119400231713430976025219409695169996257350429287667565762231549578773`49.52287874528033 w+0.69361509892043450843364974421145366442068209466333983943901633808460770369307`49.249983084101 w^2+0.07066470462696282804586039695774734779212925194225296814783627671054476627643`48.591582026926645 w^3+0.40307454022471679870256131130055414841495100115503985845597783391190153977736`49.69897000433602 w^4)-20.3492390959068483453480075569094998741069726205371849838407`49.255992060081375 THRSub[2,1]+10.76823554431605979069773625239469705763361878701041487648895537292063289009512`49.663311246201914 THRSub[2,2])/(1-1.85386550780924945498250233912256060814367614803198793995450612619312768659947`50. z),((16.18588041171816104143287654753022713911066147176016601947244398456419599624244`49.69897000433602+ 72.1959784368233579376382446766453573025302296840292037674463`49.69897000433602 w+120.1256102367527067314890012042510692162726094084683529874855`49.64353270181345 w^2+100.163629866506024695282020333443657228017218203967792499501`49.69897000433602 w^3)/(1+1.56747410753089542308754679546244196667765197579249832362328265682855804899833`49.52287874528033 w+1.71423930368721537892262903739858973662210807843288711577846619282826927514656`49.69897000433602 w^2-0.78347988519220679120859324120190464779274495384397346733900034342081512413101`49.69897000433602 w^3+0.68288127972100988246087854397902533440425077221571454867617072927598904934531`49.60409033034521 w^4)+20.82403116732815579289616598413410549130650216392581701430926735472850908731422`50.43298643787389 THRSub[2,1]-11.01948193419541216976621793828480775496902220850905415857213557238300864938295`50.84030562399444 THRSub[2,2])/(1-0.12621195006240599646831883211563034964870987478521913859702309300869706796401`50. z),((-24.55214849150138389272225058579718977053441135924226246659021927442650437049381`49.69897000433602- 91.4198869539794686644138563120889328299901153376843664679061`49.69897000433602 w-717.4120546641071621641280475925421159280171588178115314309393`49.69897000433602 w^2-93.3486167819441651203103804111251377193005099769328047896833`48.69180048898234 w^3)/(1+1.2785115298604644225646497630842943138631354292707419984417406874597016985361`49.52287874528033 w+0.67388526562365531781291420189137727605272454920364211019526498083535738961129`49.272441728128435 w^2+0.03637818811806064903467678154329372796854101279342448416653341373084828706403`48.41774180954661 w^3+0.35892964047782519282838205860354417554960785837431921835972083106442453875888`49.69897000433602 w^4)-78.4672083989785836510156133730038826001314855332767803621321`49.47749715898407 THRSub[2,1]+41.52260330535381834761712122724315815401920579663638497722571567915157079972866`49.88481634510462 THRSub[2,2])/(1-4.29252815941628349759236189340626086957351519840139040819704629896273098681434`50. z),((2.10459665989647777586470004183260660494702508342239568080371483156977216968224`49.69897000433602+ 12.53202284872722717423192265794840320235748578129071282151794114139650054877234`49.69897000433602 w-189.4466674861562439290142125151089845142131467733588332875678`49.69897000433602 w^2+11.4497032657057813880127987889280407446566037313579730715624`48.37289127062822 w^3)/(1+1.25525565489796252565574913297248174988600753753706027430514762170968216342387`49.52287874528033 w+0.68752200235128591447449092331407422032870179410737310209547620308318181308724`49.23635477298578 w^2+0.08083979932683537091044999006141407206973935020664401881617725643591395132303`48.608658727330564 w^3+0.42464204723204162549321516288459775422161431562141282536351454906491623924034`49.69897000433602 w^4)-13.49643440366988152538823893290386253113826736877137413664604575311139057148642`49.15086122689008 THRSub[2,1]+7.14192722303612491078934870746476562924472573977379096952200994335864697877357`49.558180413010625 THRSub[2,2])/(1-1.56631797195905146048757468008892510882202049335182879879495419106397601361245`50. z),((15.82432968562345382180331824997325965664464937278612219727392965118324857855016`49.69897000433602+ 70.3469721497919232088104537048166715481801420718047032016758`49.69897000433602 w+100.6702909119901198518444821537785647329501205495742489213947`49.61681749626881 w^2+70.6036564413593338180369892956366438859072876653451954660745`49.69897000433602 w^3)/(1+1.54637069048623620526386952178784961628150851275202930884267570900867664712984`49.52287874528033 w+1.03974881560429457794422087426143868622913326127265702019780397672947964094355`49.69897000433602 w^2-0.44493916965916740707942033655974085490106687104866529911060785509588204116709`49.45216989637372 w^3+0.49990772148375795811931740954041497301157566494754872177654928799694738331492`49.42339164581073 w^4)+19.94281966234037706458528733254989787699707330115301331238284911524260999577813`50.30262023900092 THRSub[2,1]-10.55316999961411703041888986335422640434442740797124966384443188382443513140804`50.70993942512147 THRSub[2,2])/(1-0.16318808001239963285328311209609126773504204866802949713898084307592699598484`50. z),((9.79595418572225829136079582522703674939006832399566644826783344323166122549257`49.69897000433602+ 38.61006599284827381944558735236191936262189989825348780742211811177035735790865`49.69897000433602 w-54.31770780887751594178185943366100794985315237805359446701658518496351717053806`49.69897000433602 w^2+49.9074293595865380056140702707746664941769070618226510248815`48.92253396397682 w^3)/(1+0.87236361751661191109333405241407591072302718937030714699377518192384392934825`49.52287874528033 w+0.13739883205652744998960018509912957228527590788177245760088168678541506166958`48.28157982998616 w^2-0.22127847678231304092323341211030958284904256144497042072223059350660095935952`48.04809178271402 w^3+0.53153197625866168576498103492498377367062192338296504855159213498920645395744`48.41181440249604 w^4)+5.24979469104533973454499399916882454089914341853374725016122725190651597186384`49.043728169697495 THRSub[2,1]-2.7780412587440244402681579178683737972440019560987957201921969403454977425647`49.45104735581804 THRSub[2,2])/(1-0.77971566461836953614721558188195930880119358507182568550536029786417979338098`50. z),((-59.3184998135252486135623417064023509049158944472893970703719068042477192521054`49.69897000433602- 226.8554525634171043878907674314663215772496263050501312021323`49.69897000433602 w-1405.0590627179465990371224585194811312799220360645675996184401`49.69897000433602 w^2-217.2007208934351539117978658888059523648616279111048156482559`48.767250212200935 w^3)/(1+1.27505925260427340060946931976812664161597292647154610277087479095127457245833`49.52287874528033 w+0.66245028026943275306863765164515402123868450248177858096612504449913515572265`49.27700312758117 w^2+0.02651094166870236295037718443694945418339935828795032227688861566844730783202`48.315543802194874 w^3+0.34884405704910718596869899347951942498877359266466142002031365794986630337643`49.69897000433602 w^4)-163.2036134460240461679744589069197832315010115023349624689048`49.53348650316185 THRSub[2,1]+86.3626862403808568653827425683826074871412224197373454409466`49.9408056892824 THRSub[2,2])/(1-7.84811533318826398551020473223567934033412308558636266753501949278160529169362`50. z),((-28.96768418233208003749436937538325152319079181088750913306420072210238066069618`49.69897000433602- 108.630292344681203096431382996881539225635034857188833758187`49.69897000433602 w-804.7908344607880716168049867568416563030178181276038822113135`49.69897000433602 w^2-109.2557564643442095574842790340985466823608206721762834223908`48.71021318935568 w^3)/(1+1.27793382773898375286435604539460258894105863600771402279276942546610098393914`49.52287874528033 w+0.67155133266901701284141024792532688475049985869649716372042918109530651899816`49.27348140647303 w^2+0.03419950213273249520227345063877942605168833449002591595051967680527531451343`48.39848386999823 w^3+0.35665274533283876652891221874126896038315182124995520643349767594306538626125`49.69897000433602 w^4)-89.2292414156815476606307874385305949232916052095808514617229`49.489874641475204 THRSub[2,1]+47.21756349100882813853963107285598916399142745430158500521665711107511707733919`49.89719382759575 THRSub[2,2])/(1-4.74410911256923821968566724459084113710476313557509434605923007839619859778133`50. z),((-31.53302252193230728555891038694458601485696845077499561207528125942158451845377`49.69897000433602- 118.627332257274883575138298692342666998059251500625619833423`49.69897000433602 w-855.5473130825071967890144271288088438892964952073883360803277`49.69897000433602 w^2-118.4581922282710633051213830026133022612512125044890511312519`48.71879929363677 w^3)/(1+1.27761341612654677521761448225650266642375066838018394823602124316176584566807`49.52287874528033 w+0.67037187649112741991113559388571468331607492098570851090338863948538349514984`49.273981742177064 w^2+0.03313512976053836112639293453272008343627783296368584798746931515488158370744`48.388487019815344 w^3+0.35555191796872111443245695200612886049289369909460870827979775393344996304486`49.69897000433602 w^4)-95.4817683666295211729368489941639644817653335470942943021524`49.49591106183355 THRSub[2,1]+50.52622199355376733746050995789588933789393473659346010998230496878844117341627`49.903230247954106 THRSub[2,2])/(1-5.00646865706621584695711582198749154160658091046330227706291749255698275997699`50. z),((-63.33006476859227202548662079375315223332524266194615276241386878652368583529257`49.69897000433602- 242.476427587093091709496492907445789272513407772597635641549`49.69897000433602 w-1484.3743892248596029613112357343325187620978893881845441267338`49.69897000433602 w^2-231.3815230317048018389054071709411283971720984670021711781222`48.77095278083173 w^3)/(1+1.27480296319821487485456128721557523877157961609158838455733581827549013007131`49.52287874528033 w+0.66174512676397314602526811197179321289502515238583477153554126530198208884544`49.27724865316025 w^2+0.02595945636050930907531857371067280890372172209899249024924559760939572662597`48.30846542161579 w^3+0.34829506602049660147057921619676189657197699410474784935112034061517036600428`49.69897000433602 w^4)-172.9810442082149354454861982070769478455880690376185719033109`49.53662566571665 THRSub[2,1]+91.5366230627503432024358359305363415467089963279747567733946`49.943944851837195 THRSub[2,2])/(1-8.25838182244029619434526501078648159976084101441167906211928779956037377271936`50. z),((-6.05389481332038788881834628609163391135822664056280414243875437966718558641526`49.69897000433602- 19.2490789240636620166272968703638783648044820939984145034670875729975058568322`49.69897000433602 w-350.9915061820111331994384080800018492138528036974311383359255`49.69897000433602 w^2-24.3603114345479764417812561702399693576845781816092608047632`48.42358031355224 w^3)/(1+1.2784826766134651312728673300860429127517962497665509801057249857718704611015`49.52287874528033 w+0.68994171691373767583633943191949371630517424820314862944074619434158979198101`49.26138724721656 w^2+0.05635547182869234997488798666408281157538531039995458961015231876268604273293`48.54157880202589 w^3+0.38198701273394468710331221485614298790102449841509804784642534866069776639287`49.69897000433602 w^4)-33.3812141334723381846367097462055127940874957388524007934876`49.35868734021079 THRSub[2,1]+17.66438414971424926368211689163800747223030251944914309021860107642197833568434`49.76600652633134 THRSub[2,2])/(1-2.40069450376156364905067006905594006935159917946070337107524122530155574107266`50. z),((-26.31060460238550397985822729878241749399374815410656306581568317856566545454189`49.69897000433602- 98.2743449708617922711308613275043848246099002010437449563429`49.69897000433602 w-752.2125954387114610857815508547319379850762044157019374003996`49.69897000433602 w^2-99.695226918932997144850104943445144538231184186519988371786`48.69978054057201 w^3)/(1+1.27827855683415145344238897637593737708450258282460577310145106887722300182252`49.52287874528033 w+0.67290522639573628312604647476878031962691609609362865073254309761612677485875`49.27288684259706 w^2+0.03545101265163224685963037285990741234130974235675037398484788047370411719546`48.409735407280266 w^3+0.35795664624282162224493332248595764908396673901431797173230466459064117407176`49.69897000433602 w^4)-82.753112544891557719951932266661378544920682636743495792548`49.48276900273659 THRSub[2,1]+43.7905812452677893483633494987429708818467166012242186612348530892694844552596`49.89008818885714 THRSub[2,2])/(1-4.47236710586160081939094481823878753755751967576198608071285733393025497283974`50. z),((-72.0412112759694335418555714180599575550658464247664594390926`49.69897000433602- 264.6915379864615965929235212399661015003281714254138712128056`49.69897000433602 w-1613.6042109129997402854209112782309548834379742247643483017767`49.52957621840654 w^2)/(1+1.11185485666941911618143447162370120873383252184764590379183931219658010031644`49.52287874528033 w+0.47990319361526043117178981783998365070201665253913361754062524072044204994556`47.98265167609135 w^2-0.05326295058820334001171524275742301057078631675560157822140462320077052685172`46.8001023805796 w^3+0.3545557616908369763131689003610972212293373505114273648316`46.65909390006321 w^4-0.0470675599031091516411043005649003410198540349567741677414`44.99687819267462 w^5)-194.2128160451882588949549881674459776749465785897366098963804`49.542413128667725 THRSub[2,1]+102.7718697020063728140397630064852806261951832470142608575055`49.94973231478826 THRSub[2,2])/(1-9.14927890000787584931180009127636181841230931845377140031177210733897107907178`50. z),((-4.59286136948521031535527750298029400502936556091762634198478661090633589418211`49.69897000433602- 13.27960624536964039299071111037468884594424427792108331511533133639548199355168`49.69897000433602 w-321.2542290628898202356072959513189710216074581508946069614151`49.69897000433602 w^2)/(1+1.21984454401869106726222583450212928443811972717409714961817929390783587501765`49.52287874528033 w+0.62127069390621277060967952654039155941327416987373703674825491628984184124375`48.541774367792826 w^2+0.0237984643579026826991902326030326988483815080698807424845`46.09105884566994 w^3+0.3848466436880024191805241402494571660204556819344160271001`46.783249554273176 w^4-0.0206520714301010465303099922304508861695291042831516165097`44.12944512245373 w^5)-29.8202214788974379496042189492157502398120550383988372156857`49.33760476320971 THRSub[2,1]+15.78000864577931951851396068497764304832575875668113375410137573815231953555163`49.74492394933025 THRSub[2,2])/(1-2.25127325086001371974024086161119586302451484880249902620682949819595191205983`50. z),((1.59780540902336942801522033147314265103005335636794233415496379807151589235956`49.69897000433602+ 10.64418392023671610628357202489510293897093146433921922109145008963877726877234`49.69897000433602 w-198.9517043744410838256493794301935396922051937192032995674068`49.69897000433602 w^2)/(1+1.30383037560560236359986056591339122651190439710987531639775191615447293498954`49.52287874528033 w+0.74790896026469316716284304499206462900575891091885320617190346103397910048202`48.53136629382644 w^2+0.1123591195673919889989018117266602653736262459780970659502`46.68682625578465 w^3+0.4248695346498073346019044820870526177644299847223676082322`46.57328303664595 w^4+0.0200122498602789725044149501695313368068178092434362763693`43.97480409817448 w^5)-14.73164221453608800131732306418939171671518100882985220408261265585113138329747`49.17475503537475 THRSub[2,1]+7.79556388192533848814550208278550257044719604218748723209909946621640341406661`49.5820742214953 THRSub[2,2])/(1-1.61814798583349519123720714281822468129008138991275597817264617574863464443276`50. z),((-14.89662455638057384649879576349779180824416294748178017567865292275989325602256`49.69897000433602- 52.10386805205200283045377195733882835291831131738421857916408751142274050982007`49.69897000433602 w-520.4305444369359421292882728481749612062111177594564993523541`49.59640299077529 w^2)/(1+1.16807371807799833185108150978729160545739518674668887648552325900373628646903`49.52287874528033 w+0.55050018243480480491456447178524431050286908930079818298294733925545403532948`48.053607855274066 w^2-0.0179648199167088557839262314822022011961116806853853605245`45.98476533552077 w^3+0.368305938840189675288140387087514935703819842819079921066`46.56582749622174 w^4-0.0358272188784444387453744852017307360249306302110083775613`44.55425340594545 w^5)-54.9336952175265984189104888442233238328241410774750825019916`49.43618305729145 THRSub[2,1]+29.06934095344038107527314093968528950691041913846999041353020090531668837453276`49.843502243412 THRSub[2,2])/(1-3.30504872156064062113340119732248844374273349342652483725894467551235829112586`50. z),((-43.88399949256755069460495614098663140576000471811697442948897564944228803713823`49.69897000433602- 160.1153551594801582963399818974273626905092220980632182077853`49.69897000433602 w-1075.6677301051113889980329375613793714493409733976686887925082`49.2957794168714 w^2)/(1+1.12521120372832784887643754399266949092244507999264438445333165914241485445943`49.52287874528033 w+0.49608987135959014832625780922553903739532519250459832504256196429174778045149`47.67143622751711 w^2-0.0457829619828976461144159490396210899204068066434170411203`46.322463673037475 w^3+0.3575379059578618482490229733064504987091844153270260287419`46.31400923908228 w^4-0.0447891460790980576795458912791744591334745011199546275131`44.58433823790572 w^5)-125.5849384582085696518312180877118086865151619419202702815213`49.5172188223503 THRSub[2,1]+66.4559589556565162190741805659811166801476586223669333139747`49.92453800847085 THRSub[2,2])/(1-6.26961459071857548325726234611278412929487798576073178068447539483231252945627`50. z),((-16.01726476989301871705426974386336613104398138573491956167357388563399651820794`49.69897000433602- 56.29927525346967404206551827652867839991004609071163525625839378471070473598086`49.69897000433602 w-541.9776355692874057314773459323600484353513625022981447041147`49.56059245701201 w^2)/(1+1.16476534046373200558509893710001698167529774586158474882040920112458479979081`49.52287874528033 w+0.54616596777041158372888764919119482603194508411447101334971024199963519167847`48.00250581807196 w^2-0.0203242975735501246922446983142702749794580672656997022298`46.01238085808406 w^3+0.367395939384638604395601571836571041865539196635843711268`46.526598922027 w^4-0.0366199268492079539973507197470948373300027533710309664259`44.54159340791731 w^5)-57.6650437609684633529834078720290777246684292241725393048401`49.44245210676014 THRSub[2,1]+30.51469251330890857508141276941852971908339454726765534963227528997411078386459`49.84977129288069 THRSub[2,2])/(1-3.41965764133686721904709000698968958374478392708669563435336063318729366129248`50. z),((-49.24140596915973433259205601004689222584113863809914721145309718826719083121852`49.69897000433602- 180.0243417129933992978119157679090897925423696067681463893561`49.69897000433602 w-1178.066221240624112523857574202608856916488918181576298371708`49.37870451070767 w^2)/(1+1.12172724971909911276640067734052297862461200514798431950206978424058975952205`49.52287874528033 w+0.49183263229941652886651264532902223594765104702601963760058886259471992108527`47.776502013568866 w^2-0.0477873508124548245057846507014439329778586382151832029393`46.47212168437968 w^3+0.3567460128910720825128590486573181137699329796541091818402`46.42827620378228 w^4-0.0454046615666237220719328699983611574855134048768420296177`44.71692152051913 w^5)-138.64260335370767579291607597575770565849679144321230624299`49.523792295174076 THRSub[2,1]+73.365701899399515875800060759234251250158887326849493792151`49.93111148129462 THRSub[2,2])/(1-6.81752154754631361476144398588133221850587655121428595000711641148790668166011`50. z),((-11.07279390065474301828006065500678531922865718844273055051391406161327665772049`49.69897000433602- 37.75958410986682959853720947243754804437897727028037555462494250880026668333422`49.69897000433602 w-446.7867048726613565383320813316328157772523983017233500065685`49.69897000433602 w^2)/(1+1.18180405223759960486376729807654172456292381820102510721364480477905357646462`49.52287874528033 w+0.56872931073325094041314004077076352490588857991510388157097235279136087993612`48.22128617357392 w^2-0.0077827185136416740576653028659522878195484008910598089503`45.67979596242503 w^3+0.3722513132717997400668701819987052811909180089653977272719`46.6791420413255 w^4-0.0323312644518679661261175504114546696438687467866209040909`44.5448626153259 w^5)-45.6138312987139840609002397757328448381246162922095534895325`49.410131797818835 THRSub[2,1]+24.13753542273956060020132781002371089196200159165368754724108539331873826360385`49.81745098393937 THRSub[2,2])/(1-2.91398199418847415935003062364166125847686826845612307974189473599183072013073`50. z),((-0.78792279023623332237688189086740807236200530500010695260258991266250623242417`49.69897000433602+ 1.30959935500222395265801599253415611554662101871656632268875910541436798431237`49.59904095522795 w-246.6029104392220916443727035323142992695465071124776116447639`49.69897000433602 w^2)/(1+1.26106125775489717890497607975213448396005854839495380185975062395546882684721`49.52287874528033 w+0.68158614030536344784293453291769705202473901900264096548812837502185486071486`48.85610743287792 w^2+0.0638782613507636170815856980055784138009434082500772000243`45.89007464984052 w^3+0.4019973992935995264999705773123325939170633875546488257822`46.46435347282684 w^4-0.0037979403784097914807305318293234353672008058849451911821`42.16493859903406 w^5)-20.5464034229277368290921294433966432387133430892845619443833`49.258245910316326 THRSub[2,1]+10.872569269242636552767637187413060656340114591729271606499268438755632743276`49.665565096436865 THRSub[2,2])/(1-1.86213863376841237170085638323307544416851494201477172917620999178059411530018`50. z),((-70.8111916229947018610948415281089201488719949989750159612018`49.69897000433602- 260.1255489110455620151155517689329007166391581285842394839693`49.69897000433602 w-1590.1143373533817202358319932586295037179722685205463129447355`49.525001456777304 w^2)/(1+1.11224916503320620781331721625752431408122048823166210908860294773080869841847`49.52287874528033 w+0.48037586460615441152407963468301881811097415049199320468227919499244634549314`47.97605263063049 w^2-0.05305000478427163181033512955113641267863553521355101082541440266139709264673`46.78873848591297 w^3+0.3546418092794893112448719383045015179726500287038933512399`46.651547727608204 w^4-0.0470033844478110306481642373830909977276166865673436098274`44.98744301117829 w^5)-191.2148758079489564283686905331843652951617357131834259114271`49.54166955004138 THRSub[2,1]+101.1854454396432138538190121033579955812209667330208388916543`49.94898873616192 THRSub[2,2])/(1-9.02348364294752621448943360213494689350830291387730450390264945673049794815274`50. z),((14.788757761220097531290069376599511096517045733887557747643169187135384476378`49.69897000433602+ 61.98316253505246224651356195165722671199927114418336796752429906968488823552933`49.69897000433602 w+46.4364044488373976633755802322974529138139619279068168863345`49.441400077842 w^2)/(1+1.27277399129919623963462793300012135637071942061002879277463005404087636062272`49.52287874528033 w-0.36675539531518957726408465079577865965227776458577608579355453198279652406445`49.499328602447214 w^2-0.57924528782934096633568664317518436560547691563526292115294842521742087062264`49.388128791170466 w^3+1.12866722931588446035356535454205820359138545743917824475175781085289184193326`49.69897000433602 w^4-0.44147218863797479771756755605670622570695846961808638052419893960251307271618`49.344017674500144 w^5)+17.41880898233546460271939253591856325612976916215033764880462538030715303795865`50.02663173198547 THRSub[2,1]-9.21753570928189520010989565859105942075846098933207858554106914030249976896471`50.433950918106014 THRSub[2,2])/(1-0.26909698652438144080391220787515738296601946612661109301033057455204544598178`50. z),((-44.6608730054362360555270366295886903605198400704870207940538979060862999065429`49.69897000433602- 163.0028385366086622534594475514396072034168243428021566537083`49.69897000433602 w-1090.5184711907270589521099866414799863011470715476004942225928`49.31045581819043 w^2)/(1+1.12466529120732121235888977723182816375278034903366896901796011821610480540342`49.52287874528033 w+0.49542115520452865367327370647127266690438256348176910436185658783449716089912`47.68968648447832 w^2-0.0460995349895309627311798656196985066791249738250165661007`46.34776867832894 w^3+0.3574131295332779940560580964970175229736492644280020484956`46.3337191248528 w^4-0.0448866089955220803110766085668660976156735502375963732172`44.6069539121293 w^5)-127.4784206947255840692280186855218244829203133246091697618618`49.518248930872254 THRSub[2,1]+67.4579356205183893813605380095124846510266801662918275796692`49.9255681169928 THRSub[2,2])/(1-6.34906616941355485761418068831389707687065599384069853231393186843422867423976`50. z),((-13.8742217999347535204308596035156899583883936266944145182301121996678318043504`49.69897000433602- 48.27326289007501339356329443313507313278359428395516585361322093479890126819748`49.69897000433602 w-500.759817772109813896796986778224944208232314501780050341822`49.62747225176286 w^2)/(1+1.171343847562499702000235070228950683104615758331911120503487968273728135769`49.52287874528033 w+0.55480647429863039066553419177125805004841354959278376657487175248728638394684`48.099124481012836 w^2-0.0155969497177768589596667586746165408640043439005896831902`45.9436581256759 w^3+0.369220445031404195278108511808135399530144073214262965901`46.59917010487546 w^4-0.0350252063453604205884646346466331336653803836960065693258`44.560279973402565 w^5)-52.4417818933772436859216517945730744412435335875736687294718`49.42998353127104 THRSub[2,1]+27.75069166616274029526831434107391682066085388333865348754514832091016713881317`49.837302717391594 THRSub[2,2])/(1-3.20048663813760923677983563547711877192916831457434771924271831007557877992639`50. z),((-8.88315211662802462684388963765152773079674941126992756857908302985239711030733`49.69897000433602- 29.5187222102030520719758581473746013951306636237994124071965223169366357375569`49.69897000433602 w-404.5019709391597695313698426114340775814911692419578691277124`49.69897000433602 w^2)/(1+1.19196203171753564690725491275450262853057879952762506653331517590156946258514`49.52287874528033 w+0.58246629784555415063411971186917625111740433754837176817944526793080043917159`48.3180115664002 w^2+0.0001599168464270970260955035772119519146339848525132362999`44.000992167449674 w^3+0.3753597079194872990003205082939096302964926340719199378904`46.729331129072314 w^4-0.029516358679993938297791458770494296772157027683831773372`44.488189438817294 w^5)-40.2769936363250217713734458774568055776917244469168165375358`49.39081956470105 THRSub[2,1]+21.31343351212114672141044434841121339822738662048108528639662635394855915054593`49.7981387508216 THRSub[2,2])/(1-2.69004528681508219844414326008972801421229840261475306276786990490182672334565`50. z),((-12.06887673404951840073569561898998740075529539342729692962718449199857687452854`49.69897000433602- 41.50116587527947136139937511474704045459222825413026294417475225571824825174544`49.69897000433602 w-465.9915255783215145162076211733500145036155340756876891165514`49.67947882269423 w^2)/(1+1.17780281698320581417315919664748097358035794571721308560395130619564647874738`49.52287874528033 w+0.56337686150336585429628497737986572457104908741196841246443908543600224014106`48.17800519972848 w^2-0.0108152221567483655871983494795322208936260551209259365942`45.812277666825544 w^3+0.3710723894856927408344994768940023126618947118346040132146`46.65262096110203 w^4-0.0333854326892298997376631934922517564222561091496662453655`44.55638319865523 w^5)-48.0415947890253661071731886223239407582919161684860727415706`49.417729455079865 THRSub[2,1]+25.42223845199544695562708915118258854529976064556523920322114174713279067804625`49.82504864120041 THRSub[2,2])/(1-3.01585231453438108667372745499023143746021117266121934975446980498110729292027`50. z),((-34.68928246373522792049346572181263911351845971667256429534034984227700790675559`49.69897000433602- 125.9237138069954948764496739465046047819373392124908761666724`49.69897000433602 w-899.8331850090464961733307440517113588718668033648527810723898`48.934322774938344 w^2)/(1+1.1330477227995496345213027811720594998690859620438286001559369113606401482797`49.52287874528033 w+0.5057562759939238966147725429893976593125542831182595061645`47.253735215354524 w^2-0.0411357165693143135575512382877605512148237109777664154185`45.80021301319857 w^3+0.3593588189416214930967543633830623374102935115011791749187`45.87459208851468 w^4-0.0433474407369707927020280274050355631248977469702960553457`44.101658567031514 w^5)-103.1745549459606553820379504285870934715406391131519050362668`49.50242761725304 THRSub[2,1]+54.59702471438147084333460963949094410269037785877395313273344818577862606598904`49.90974680337359 THRSub[2,2])/(1-5.3292623049304252430139013614034913645279787338338817392769140820860239499355`50. z),((-60.60122632906964959136193104045688612054584937893629548651071907112225934372853`49.69897000433602- 222.2185551091242406249574752934920286124137780728418617614596`49.69897000433602 w-1395.1076939756764899541787714492114272683342324134665398866002`49.47608069661455 w^2)/(1+1.1160359757787930504111710822407981251324094946016988427925818300946023851404`49.52287874528033 w+0.48493131741464927567778812148402803175742868199330507040162139943812706535595`47.90696005529424 w^2-0.05098063609389083104084261777428927364186505093410608487543123279155300505255`46.67350571210181 w^3+0.355474082970084013857261494669657096884363396852215523675`46.573200719344726 w^4-0.0463776802037897118527026038739726634391540761252933684169`44.89065097512624 w^5)-166.3300166909023816410380184368654085110030422061432404623354`49.534527894324455 THRSub[2,1]+88.017089453626097155550072454659723769547726101018906705511`49.941847080444994 THRSub[2,2])/(1-7.97930097023950330685464148001121599222547642052057634487343277252931181736217`50. z),((-68.5234479193943857205144916615824621571395814490874624934658`49.69897000433602- 251.6327617469039986003433861243255595236723388038337082040036`49.69897000433602 w-1546.4233691964232591288417569428513057039139564296537640618361`49.51586785892976 w^2)/(1+1.11301447530196738588240377398820202625298074978165011765938557879880360600082`49.52287874528033 w+0.48129416883653595112439512422131914999095377227181095515294635575038203822915`47.9629503715023 w^2-0.05263533935289063305893188496010943655918860797969757150353574074425983285669`46.76636824889765 w^3+0.3548091442048773197612790354653919617672566689596072840242`46.63659839543711 w^4-0.0468783040661318939118651839066151058863956023721133114632`44.968810535033 w^5)-185.6389332732688646697199135986894022085248406640827122484645`49.54022631361073 THRSub[2,1]+98.2348160666224151805378240571767758972048581229391162062181`49.94754549973128 THRSub[2,2])/(1-8.78951396076675693544226799967202823431146870521394274127161548156781404348126`50. z),((-52.59319097880373450531442381333906067246310509037699796333747220421121711710218`49.69897000433602- 192.4765408727858065208861537111116465579368493170566656340827`49.69897000433602 w-1242.1158966316143942357076758011416815286816829649120280934967`49.41509232041435 w^2)/(1+1.11984054376860945203699920886566966093699067109535375893810778879872432303154`49.52287874528033 w+0.48953748329849782540368901274165033001467138635589712681792212979631743691542`47.824255486270445 w^2-0.0488570613683823208386638021920739840045819142675982891583`46.54362842587913 w^3+0.3563214494021729136671208559181621489414198179239577417369`46.48090155796566 w^4-0.0457316377923590538733126760703950089514877082991145774617`44.77924539182763 w^5)-146.8119453009567878556905510071435897103015327814948011775143`49.52735157306748 THRSub[2,1]+77.6886840961999202592080739460125885401935995458392990287249`49.934670759188016 THRSub[2,2])/(1-7.16031172645076012220549721323237369571047756700403676122342946238877976243774`50. z),((14.65073766846980260986921389771446782930561103133257864485381421427908086935269`49.69897000433602+ 59.8944348102122803495643485993731404355926627049333764230647862928550010877213`49.69897000433602 w+39.0046532256347107265820612740406869324419182880848966565836`49.41079248709519 w^2)/(1+1.1669065239267576438753749333765103528408892514718363124267745214155383563238`49.52287874528033 w-0.38803910781143527313149431337420800063473608988438851861863472252776452685529`49.49309110294402 w^2-0.55210433347798829523524408042798059373825385330564780707885451351571775550789`49.394881789940925 w^3+1.10566841563861735932754694420320851387362648279753405417189694222937291843558`49.69897000433602 w^4-0.43910184246312598194177459735070424954572466636408368846801534566821093488745`49.32426238544357 w^5)+17.08241111372993761776699397618994517570193056254392684417164750976518956539352`49.995958968780045 THRSub[2,1]-9.03952357483904864194050105536698627128013680643467365927496505501658016618783`50.40327815490059 THRSub[2,2])/(1-0.28321243013134088358675474892646544128814254999121569514695365504000835511978`50. z)} /. {w->w[z],pi1->pi1full[z]};
(* and 20 each of [3/4] and [2/5] Pades for the Ls part *)
Ftri3LoopLsPade61Spacelike[z_] = {((3.65882238095646339645572168130938037842620809144072448735131255325882000817612`49.69897000433602- 1.4878476718799326281967071148763250114388983478787930974117351678847658879435`49.000906437005696 w-8.40467041597684496925191349732595132211530032101933751578788712719752106172629`49.54948713040379 w^2+5.92151993352918003396305141888886175315402711452917872647078070071226724745432`49.029292439760994 w^3)/(1+1.82567045515797185240841573820580042281793034782359176704850949323535978133756`49.52287874528033 w+1.01021135791616016869666184194680411468730024190684380440444291522131730473269`48.879067175634106 w^2+0.24220436371110732034769989478479387274279070761242587357028979563928596292491`48.324840472242684 w^3+1.03986073017004515041512661548324456653899976619470521152528568523686415860209`49.08876031794903 w^4)-0.35763435747112827404856921775963737208041027136074852990832015915157107037919`48.14553942897072 THRSub[2,1])/(1-1.01417927946483804135521989585438251645377708130166673641199300634214117374964`50. z),((1.29483906289490748574011795892414907722400636717982908575604529810262543850612`49.69897000433602- 5.29558789591148735440892197639750362814092966420348831725001421628523209854587`49.66287555689724 w-14.32646415833985876582967926256115266920563470976262718138627316032994928565974`49.60115692594474 w^2-1.1541592450356430376149934235541903099296490164704958397859`48.08980661436947 w^3)/(1+2.39930956681558111425904981145785966774389176926538713648124040312345368347137`49.52287874528033 w+2.30198382557803782489642361468334099410656584632091882565108826962092643705474`49.13713996339713 w^2+1.00668665672640980840959056472515058228692237715769594133750261211523793211217`48.89453321006855 w^3+1.3744176796131242094483492177774356966948022700830642121671259366918115255564`49.18367029406546 w^4)-6.11939653114007565348161652962859380158314875747750331021967097199988811870335`49.29058578496842 THRSub[2,1])/(1-1.24261828249597195690554798620682599717705452787989443422823541751171980723932`50. z),((3.71671463250284870139503417033591271470498538887512279450431182318634708507135`49.69897000433602- 1.42224197419367669592367911293130310894892040344591628645015507844122984673316`48.97974151993181 w-8.32849760723302303905267461763669675164643938096253825535056315653261727199456`49.53238758672398 w^2+6.01643516650459973665875195138962680944587784325570686357475170686005543129955`49.04300948489721 w^3)/(1+1.81333885639694087546051197231489986126362369729895171444491933540076283359776`49.52287874528033 w+0.98534450616018439138031734034966434946703452755714145005579150576524415888413`48.870207412009734 w^2+0.23004614680996842603161701733669718121867462498589253053040624637102781587043`48.30272912851776 w^3+1.03610485580300435515131389573169073249608465844891530839695836781310154400457`49.08697139961881 w^4)-0.2165329450542218494579480921654042025884020975247524979852491713336394851601`47.93002641770276 THRSub[2,1])/(1-1.00858497254843893116158802887395541237805748296792323589885089080956377404227`50. z),((5.95746511913009799627652487447188134114480928645181636403013579202363479582376`49.69897000433602- 0.08630810966591024824838820351065214562513053334653525147090995080393935034678`47.7375964629192 w-7.12064506543533747234440386033277290424914933293118016764380195549087483504092`49.12067944448162 w^2+8.67914895305772372195218145971892699778831588141423450176941235046439611649716`49.670288152695086 w^3)/(1+1.31820718620718178345485936415443852650131905573411666453324411386067834270107`49.52287874528033 w+0.09659788377372781677827822567332342881689882084906622504404477499580102976415`47.925495420196256 w^2-0.08852645295057260590147266859077595281803738388752015873678238893712083310136`47.85501656365042 w^3+0.9986411435483386252770992476469351049973511777099357383942261250426037701343`49.032344447398486 w^4)+5.24487251235222069362090188817879567884754224810272336178304138585102410046973`49.41919488718783 THRSub[2,1])/(1-0.79205433830251306478186815568796374632892815882511259650916821101247289156651`50. z),((3.25580965915879424056397489660836481465304100008309948391954909039258853378245`49.69897000433602- 1.98150964322486861456257972508391844477296830429789904156687905027485103103879`49.137615445585034 w-9.00736087127898093993020385242250644289031216271189400971626640365726010887848`49.6842388697207 w^2+5.19330688822651311581477451297378320913093489397086638748812412005965648125511`48.927773086415904 w^3)/(1+1.91231885459917323881665552973269521232848585838953901449539463837046504959964`49.52287874528033 w+1.18881337448770486959483379329598602264122098415467213147945295553477460563601`48.935615767184125 w^2+0.33347233632852798038586046033803099569737656131075402492660948764668119151418`48.46074606319282 w^3+1.07064042042402344327800043105174727221436066550712530034889255783463247817265`49.101896957815036 w^4)-1.3399016341561630917638751139207542778322055160482318524547827236459573808085`48.70280848211615 THRSub[2,1])/(1-1.05312364242752372728378344384577174577385115468444158421223785750209372489653`50. z),((4.33807803798375266126089520388511083069922120225482900737450314562713564824694`49.69897000433602- 0.80613023296785390939404849748250732706229909234383654568429040938956739753768`48.71904461293464 w-7.66320441858898880750767325561563686295582719438462128964166202301525266336077`49.37529915281497 w^2+6.91324540863030406092536528553819807011541412646513990393919311569903171810753`49.18509797394662 w^3)/(1+1.68141198678954699365589488338966265916573256595001374214325462458190633804181`49.52287874528033 w+0.72799351516564516314421320610366558137802049054079976269049530419582928922681`48.75884321277679 w^2+0.11320858285762219840623657652545870534106069706925564225876609215373689534806`47.99478460283693 w^3+1.00545575060805610082286717210249577741750335310055745149678800562316975085852`49.06923939345604 w^4)+1.29792282053793154985954703811054741210291385461393291709381213762301342379418`48.73440782189441 THRSub[2,1])/(1-0.9485407092139242192392374597518231978287735609167860536585162267024968873306`50. z),((3.06673907632704583810913299492417354204628519268616514725365098018208852779731`49.69897000433602- 2.23495154610307007686842986299066770393868432210433030779546104920822599760879`49.19643279232847 w-9.3362838869291552391060887308611071124655892291077841123107573066208951555806`49.69897000433602 w^2+4.80536011577622686471698411334764607582558748186766430474202173274812397875007`48.87465373166134 w^3)/(1+1.9536947414359869144903045428006649541032799747070173025882995473740339191647`49.52287874528033 w+1.27644841808267605051687685442016057590844772401201779436456758924931961708044`48.9595561490847 w^2+0.3805693431049918679748093536730465448496000421239230028964292410815304055879`48.51600631150623 w^3+1.08804500090295333612582808575640657240163702645289364923307473693864141419044`49.1084806133795 w^4)-1.80072541577522738165565996790960695088354070089635948118563795542851233066605`48.82371316530212 THRSub[2,1])/(1-1.07139411629872528950403526599950655989505011857525212457073941908126016705584`50. z),((3.50726153640979601609712515501377690666698032570113576927573634342889045645296`49.69897000433602- 1.66597278899874059643113972066956840520241675181935101304104988967749777691113`49.054367729362816 w-8.61621222704489786049206226787848260342328897175457750089561968283382681486173`49.59671573237559 w^2+5.66209475327834993229544704028472740154907974164907306199980613939866227125528`48.992528001535035 w^3)/(1+1.85806593533960584718025376091386552175360952342673612940357877484841762265362`49.52287874528033 w+1.07619535565027598836353624133516456294257725141577846274705994131820044483432`48.901323782520805 w^2+0.27513867997515509120678027958972888869529206164455241846765409293642642806927`48.37933683865037 w^3+1.05046797196145694502794269530841329864449808499327015413536884473685541961983`49.093559308121996 w^4)-0.72703524725167488404699110404943163832738044139998706555084785569415297657143`48.44742885525873 THRSub[2,1])/(1-1.02882507157439802548584249231110241715797605283190170904049602563715242574599`50. z),((6.59603876394675406801486380258418107692690297955838922394032920458672860046622`49.69897000433602- 0.2504373961959440671242219918364110050897534028446130411195652254800414094745`48.208318394323 w-7.36563581538202150400160742412621065234276947248378281231984046313080628777461`49.06264688856638 w^2+9.36085985355049596983396080718649919735095657080774766832629518014390902068215`49.69897000433602 w^3)/(1+1.15609649797027173206463619030769945877369529515336703176475077776341885513979`49.52287874528033 w-0.15441480005005022542745963954992247537430397582665417130801511095812515938973`48.12930013063459 w^2-0.13000501642888147671147045281815733648665584295233120899651498471762106900955`47.99494847286617 w^3+1.02192752476835337361995630672239716845598985253985045301223003768978308663814`49.018025502292815 w^4)+6.80127498088720079933802807715908478744919804552065307435400600587023233126699`49.567276014541804 THRSub[2,1])/(1-0.73034699643197458701181923222642258681339975184277952760756438225745311942857`50. z),((4.7221684610328944392204127160367327695575730369616747076326139720408923337801`49.69897000433602- 0.51094010319381173994922039392826057502190293414675223182468384629417723504917`48.51487636445764 w-7.38339927035662781737024876391331939686065038307236028545204996679092585871674`49.29761800071263 w^2+7.38108978770757547330782938205726991365861405313732997547476058859238651742553`49.2747300870672 w^3)/(1+1.59908750413773894575609084302123157712722775576673553515580692937006951683242`49.52287874528033 w+0.57535139944242569950309010357973768246788121987789087899211795765155219237446`48.66821476816361 w^2+0.05254600257683251608835291925408291019458804169359283348002078145211879596258`47.65882958939637 w^3+0.99475326844142668544332939440427710348017979802571275171002155503808863308668`49.05950968540599 w^4)+2.23407057330960456504067229737510835740361368229512017822905522014967249207831`48.9875909429533 THRSub[2,1])/(1-0.91142486637155619748254495360673671937864915907408541215665779147579760497863`50. z),((6.84902759794340260564472566606640333248127303318586582489762843107691321754774`49.69897000433602- 0.40375100764415541254178285118847566209416129289379301182695961610862700157864`48.421472899940326 w-7.53776916541339338258543459789795447375656013446075526852568868679583714149241`49.0441094161943 w^2+9.65648207061886295318563013395796136682146133853202008096507300456321081585163`49.69897000433602 w^3)/(1+1.08734140274869568830217519296519691351406219911668901636111314837498965780301`49.52287874528033 w-0.25623976946921656483450386446611041918874698368357944776983677422810974274874`48.34451800299843 w^2-0.14033851367881746281487685967243837785194458715223132684372573883104935585759`48.01482716663973 w^3+1.03492859796562912616842290969113463939005336592306501526057694569619001945965`49.01138155357058 w^4)+7.41788740913300199531759940319271671881351269800654965568892953968094615758252`49.61975204196004 THRSub[2,1])/(1-0.7058999047056282476782867165214199324789437909341878110799275258034376916784`50. z),((3.11169391260289833686142516394001579793976758479978057230964881936544297480464`49.69897000433602- 2.17344255671613160902932468311717929105126416458517002262808680957949236990459`49.18270958988749 w-9.25526573454492179409179862053701278813624817437464034718435866361261293659632`49.69897000433602 w^2+4.90057530233780961258559729878323307153842815055278550149714147455148973345571`48.88771234378882 w^3)/(1+1.94380257652643685761373388626419037461513955723767875395308238636198387078029`49.52287874528033 w+1.2553611998463585707689688487199611684858681841891940446474266816404448019472`48.95399296583641 w^2+0.36910810857534649679202286455313867010614945098823440475647019342070423415991`48.503270508715055 w^3+1.08372587052561554929783588862344882403846957384212151372651625301066031859101`49.106890534689164 w^4)-1.69115650587696263995702319092273510846360216844885331645932711943410913677552`48.79821396192713 THRSub[2,1])/(1-1.06704999174343678584676843259381342567628704012208038442260881825050539610063`50. z),((2.63573593337919916671439223076712276722815022901241871660701145832053722748463`49.69897000433602- 2.86399170480209546873313602099057372851939389448681192908416153422326227169058`49.32106281799278 w-10.20809449333279764256385019529788872326483553351947403302459539944935955751229`49.69897000433602 w^2+3.78640753583130448823923643471317744661883023942485172876512962314227297508029`48.72972523197959 w^3)/(1+2.05074204911432398064341762036905749211534110704080857162640523407617042965925`49.52287874528033 w+1.48768951704297939222414313800359302404784812254549353635609880731483295188451`49.00938586201248 w^2+0.49945074997363455713529233043593033814475871059818020267942889164638462670697`48.62750307163672 w^3+1.13558297336650730477699085845432595875799334747565234306546905478917028302858`49.124515955982545 w^4)-2.85121404942838131711318484694620696037378605489273398828744744625262040621903`49.00673269844411 THRSub[2,1])/(1-1.11304328003268343153038282923790661488476650093451032235719160907806396378586`50. z),((6.55567107061650068691754644670164250363899419241152438039494660440097205717442`49.69897000433602- 0.23088695893070613808898865296478339673670685647838846204491491440560440313416`48.17224706225197 w-7.34219179808769173600918976076416967919330190392678080818955552059453069173807`49.06580467405187 w^2+9.31538095543864687389935966213215802104223683424613117325194120101814778215598`49.69897000433602 w^3)/(1+1.1668088115315817786750550507779377658388896467936503816292383980259275989555`49.52287874528033 w-0.1383157210506515484089790541232609067715008207505674168566636249141971839911`48.082123549729175 w^2-0.1280305539733089699654810395530366993608136575460538100621596671926426517711`47.990268919173886 w^3+1.02004750714170819749779475984742922775648717956909566767967787305249409186225`49.019013200230816 w^4)+6.70288636422841531230929672034832671251486673972289465843623814842260711080487`49.558634100557356 THRSub[2,1])/(1-0.73424785120898343043970156950616418542512900765270352209445660337204372587785`50. z),((2.11691043993685972532699610787023521022692267923924522706978521081728603114556`49.69897000433602- 3.7164464537800055937014324003048563265410287359261967994696949122078595869758`49.4586984600413 w-11.51489120405379214710522456348985724614445882961100581738231667642381144369258`49.69897000433602 w^2+2.2514357201742650413353239910877440887493845216886696320042`48.45803738735969 w^3)/(1+2.17499042146800769411768552220707243969623205658778634284215385252959339005764`49.52287874528033 w+1.76889511606333671326551960687857840075881040662476250453488908935989378823664`49.06269069918747 w^2+0.66733888797907400088246872370352661595052114698919777709540285376901661549976`48.74211403432057 w^3+1.20943427669720674465001170331170085333251034145622695930862881084445910618383`49.14573663046304 w^4)-4.1157530501952886132016227136369378502144301428782477652198697793481026442881`49.14701768819491 THRSub[2,1])/(1-1.16317898850557121689244695617213660282934429570978558930656817320972589632105`50. z),((6.7893997818709788599768661830807422827850394135643515787378664902933833045141`49.69897000433602- 0.3627197949603924952239985922881056964690035491445123228653038726312410993319`48.37343225321653 w-7.49324682690161759695166833551100809249425875329663687671659613563522535142223`49.048299223972194 w^2+9.58502490220976183908378089408401273291167558354443540501869336075437748618493`49.69897000433602 w^3)/(1+1.1038061632259019329304604143507572123022840971409782585390880920303704814915`49.52287874528033 w-0.23208711676776838091323321229731792043882844354889186474880488430375071342285`48.302761277327626 w^2-0.13822239830203973736241386024737969172482889045095124887380935799752483915103`48.011540199410305 w^3+1.03167664144165514412915924955818006463730326096606783590541838116195470585212`49.013028515631134 w^4)+7.27255588647813932539147282251152844840411201767527101719611648279823263874621`49.60762826455975 THRSub[2,1])/(1-0.71166192457795021355737865224471618184646159431489162560530321581040405849609`50. z),((1.59518046076837636487459685078015587460763174503178777909084339853551328370713`49.69897000433602- 4.68390196942371188001448090096393287430950406110473842010110574719094916231582`49.589221319725866 w-13.17582613648064237970439280087354807995632047265222937679324568901336146856551`49.65154238212562 w^2+0.2583452471940393818524039543228587692214105309916490043983`47.47456907472205 w^3)/(1+2.31233580336775907615910019429935682760845612456764349528052134312838501566245`49.52287874528033 w+2.09189730503810004132257426303585211545024648704320677781737272786225774406033`49.1110511108161 w^2+0.87033202666789379396842249459358186946706265730133555305437196434196064536904`48.84215006978559 w^3+1.30614572412601369260920874102073497502924968819614195707906771645375354063436`49.16919936972896 w^4)-5.38737118551572563752450171343589743198450570553690453766304995851780528739532`49.24551791753746 THRSub[2,1])/(1-1.21359536639711739528186888862423997447124025157366988476262149665593880048729`50. z),((6.5774483698433643756211688457970365504029652944194691538428014182035505830341`49.69897000433602- 0.24127048093063271335724922433624425114194827876463062962415880793896608852475`48.191763337639586 w-7.3547031219647406627995621705083118087986862637463172570660526380160701282216`49.06409370600191 w^2+9.33986324951252993269588783310106018611346808111336364266145043548264496015585`49.69897000433602 w^3)/(1+1.16103831447249071084616398854673805302978700950839559436488814947172845504449`49.52287874528033 w-0.14699602859118108173912666660802868203272057977486586481263981606633250984211`48.10821551344905 w^2-0.12910676121421873438973717810290623622258839337629051996725004617246362171451`47.99284828262137 w^3+1.02105501379671494244299590013858944084975254500052307604366514084612799410377`49.01848244043666 w^4)+6.75596441176425919540629400752897624603202531103690005350831786528746677960496`49.5633061036365 THRSub[2,1])/(1-0.732143443582209354476692459095169718286882065267090482475911391471227088807`50. z),((1.6718155355673619616030277767339068112068824305836204019848785015139963564273`49.69897000433602- 4.53447210230690635916562122856732630688591940913517368966540038377343428325023`49.57033411898659 w-12.90669473792124749456286456816699027109411932151340450330161511615901494813596`49.66672554859166 w^2+0.5849657697674818017958380636190527834136412564660072987898`47.83570902093511 w^3)/(1+2.291171275296177840396736091866995542054391183027268194959902794301371486782`49.52287874528033 w+2.04138393482323819903137065517662968188665235235236245692212838807029157715329`49.104210290495466 w^2+0.8380048585739359717909491139241170947635430676628049372174947974892367132405`48.82822858246951 w^3+1.2903105406724404699409568765765120389112494270696111695520417930210400436043`49.16561968599339 w^4)-5.2005876867577246751469629491293084557084019670525669838103707729933733937429`49.23285167007431 THRSub[2,1])/(1-1.20618988263141478393311144628326907935182697615383287359525896673078245852281`50. z),((6.77375289885054438282903800532219900187224184737792536766627361773908675853296`49.69897000433602- 0.35246193573832398311987240495878094988430263759830741116464101529561559464217`48.360595299286494 w-7.48197030165350431156157132166852190870197533021829027124185119786790776796444`49.049415741985584 w^2+9.56646624362718584853214446069668665888418972348444800859650636826337187490406`49.69897000433602 w^3)/(1+1.10809952053749758191425328803355540518209949512981867346908409564144130944724`49.52287874528033 w-0.22576555391384454537762387117504819860167682780201431270717334551771343234503`48.29107978965794 w^2-0.13763428828353970039676378606696358798571093347644237103660395774997628852468`48.01053934294775 w^3+1.03084233653129748949744254300636869802017375509439899699459914100364690000361`49.013451538369075 w^4)+7.23441956883403369042764693060961988353349256834192902263647572838903440141141`49.60442316070355 THRSub[2,1])/(1-0.7131739311688697169827188884040451918922502244514186112023283530526076249602`50. z),((9.35736432442305879051327853861375750435286730625614372529035096546674969170524`49.69897000433602+ 7.01575609158484263288850863126385737776354933686111803528185681311101575625298`49.28675134196619 w+9.5180617355422893250791783738408655972863866176371230945695`48.9877340172051 w^2)/(1+1.56216567654071990224271547752544991287029801719381856727133351053101053930545`49.52287874528033 w+1.99674509058877865675370321543696975726819086056390244193631277941294846908545`49.154786952481444 w^2+0.78390797728313916432251094600347278153145871903259226219126007972860406795806`48.911301643119415 w^3+0.40619257460944286534657787093019055526383807441822530248830862351484502442011`49.14556769404056 w^4-0.93832012751832918025840168532030715793498264153673641174580918087918723277654`49.47803596280684 w^5)+13.53148371035645578614760779621023888761127390664630266000902905317929432782078`50.06349975245353 THRSub[2,1])/(1-0.4635115863594366571733589535194287883519034641754023472268673556968668263401`50. z),((10.77160268770688987453071731084160060424033576909662769271302611918902241177971`49.69897000433602+ 5.85743626078849549231068269996440867808247414368680701233115848876688380597708`49.25588380931611 w+12.97585792802247991994170092224182346660440125464013824606480733482906184826403`49.168572363615475 w^2)/(1+1.23649677737810066034174449219645774097402107563613551679597065208148709644234`49.52287874528033 w+1.81197469063791768773528246561997249831280994307954214063771944311708934117015`49.237311870369716 w^2+0.71645620078100100276704384922093658466542696452088958972198468283866425231687`49.06896028094539 w^3+0.33962451896766554112502083899417520747728401193076417822992483802067105359787`49.40245176006876 w^4-0.73459809366427120908136147141047008682162696187220710912925922535463298066609`49.575934465621536 w^5)+16.97842220770674952922747855221899422380876976557462690150053090823042384313995`50.31376460611231 THRSub[2,1])/(1-0.32684936912270377538005130970260778890625599474132242277159850696815593261508`50. z),((1.17473944400232770814287625425136634306067020717232235573430528373068578017705`49.69897000433602- 5.69273391319779390967078333275664563271134971307370000424685043202295085887905`49.69897000433602 w-14.1672811843823439513305621208138324291510579659175333591228549492199841711402`49.44897353821239 w^2)/(1+2.31667983485406549780030764046927710582506015299172472174863907681190596798782`49.52287874528033 w+2.10351847164127206502059150719262534037245173175713804744936796450834000013107`49.67370927174955 w^2+0.8088351602085109536992962737130426216484749858865565274136447855316382264591`49.10026845644236 w^3+1.29474271977195205681394340819542517117276023082193486073111842782320971398418`49.27970508519006 w^4-0.13458300734133439503872982921836525827931142997405409496139605739777399788962`47.782629929516744 w^5)-6.41211663450135664274385535874778168504248498189480788888543525572001397474342`49.30684127638445 THRSub[2,1])/(1-1.25422387928450465280538748815625052172703756879260858668096615331800096501776`50. z),((7.16304327658415536087542674235814657458687389011412168358759853842987936282534`49.69897000433602+ 4.31920735935706763279500518209870850131890348889300414656810610884699997114705`49.17907983746869 w+3.27240447340120236211194886881665105756927529425736682664833434940031660371394`48.54063542680417 w^2)/(1+1.69467348426942979176537970387203598190157279738395562311399590757854256410497`49.52287874528033 w+1.92321720503632907924006896528619622695228698997136226098534277463112244636657`49.02103675181559 w^2+0.7008967754900709960065228207528950107984453773180170163076928077208326560978`48.607515505349305 w^3+0.57355610645374193512642121220820721003070447447080804344874669627089003396398`48.764273812512066 w^4-1.31328171683530833848145653480598676588679457021443019944562177809341396907055`49.555041938628975 w^5)+8.18324122754102224825477869762136526700008713954706840884034452023935849436495`49.68147918280586 THRSub[2,1])/(1-0.67555560065882167840957236278113880529244020865678424254010587832596526418291`50. z),((10.49445981129750920480629416960973403788435892832014455907097027502272787101315`49.69897000433602+ 6.39018610192837887744595262068114593621260702049049582486056925880206672191852`49.27213793382009 w+12.27830094095502198074443554844010896842777231598024268576174981670954802473797`49.13101228671877 w^2)/(1+1.32253704639864705177773177133031083013854366164797001372329369632533936285905`49.52287874528033 w+1.85753004203891122511381942004945690141452464664374772251109552696476473842668`49.21862841667145 w^2+0.72895175979163527305143015104934513333974697798164360135605565581965321097949`49.03415043495748 w^3+0.34805966409630457214388822809335237955561410487178228509338905384187052491178`49.350327666822665 w^4-0.77130663820529455857304258355919854943768168135094114573459510933991234522479`49.55262695367278 w^5)+16.30293886998727514245786695059719968088164727746566822658895465645972133054131`50.261931063316794 THRSub[2,1])/(1-0.35363054050425713012940237942132872300931897418539512871870794739937395659076`50. z),((6.8124948626875055526098771238939881296555049416788587569308443624612404373458`49.69897000433602+ 3.67164269403038871024995834619498790403521435040461268208877407235919646830217`49.13795658610099 w+2.2221563848238293198419733319330067862820955661360066888809`48.40341839674642 w^2)/(1+1.69192807603686390675772101537446196710326146337205579313916452044457631435435`49.52287874528033 w+1.87259123865065479892044340574840136751269345881850108453217137477982441936901`49.009236206323834 w^2+0.64694784505460435625184790860630750075116332107140982836388574127667052250943`48.54946871589717 w^3+0.5921707761803537144496897174619774720908623539232761010871831190091608896349`48.7141073144664 w^4-1.38483908613493059173378706928390864161050142904794256534596886659175951525941`49.687184398460474 w^5)+7.32884577737111129904128490022945875889252124346018294443537403921822647060872`49.612340853594276 THRSub[2,1])/(1-0.70943017564962996449461818354735984272019312003129760430943693148349765869215`50. z),((11.342534827837625864702627186745053411110067824747163446053190827344105265701`49.69897000433602+ 4.05134073111523102990432478570552493051905289723279700187235860792039438060185`49.176815920283715 w+14.59717714531320007561047742432567256985548454912078097763243687555425380486456`49.262116450132474 w^2)/(1+1.01002855386257923798185847028646166522653723501213392425988862513912986256177`49.52287874528033 w+1.71057634700279075598003562598934088125345928359525832876141473870676469997447`49.28963255785745 w^2+0.69977447145635719685369889047732118156926974037783734747737687460446386617156`49.160203884991894 w^3+0.32954401856565341402519396836672781402358410540794135826905226734604108776285`49.51627561916534 w^4-0.663833258860167595624764502859007935441325077496526989942493051864258903685`49.6341113961571 w^5)+18.36996130343715180504536344524259953000912785513197328724653037014442065908478`50.42826800333377 THRSub[2,1])/(1-0.27167843458461966392255895822678367753191417759269897532861753800292865570393`50. z),((11.21936360035173288836703979147569090621110496322680044332029750362499347811411`49.69897000433602+ 4.53751699484796483231416771958371146428813907324008821839343906768684073334692`49.20278346651507 w+14.21687954027601794460212871872150916775480485197777757722735812621754732532409`49.23920968458076 w^2)/(1+1.06554053182063816236368459278026979235846626087537319923669041524455204350371`49.52287874528033 w+1.73306417869626473036421293241666361160753838149981891313967598195427561751054`49.275978532634824 w^2+0.7019952203398673016777356507853600248764593144028289571743787542436545622823`49.13733987247285 w^3+0.33086934956328028163138919717005480374312595008694756266649760438547327344557`49.490626842423666 w^4-0.6785888084999037701366291348016697899598322622132478338696607136619987385794`49.62002669760745 w^5)+18.06975473514608418452882615690748630626520345242452180994832706319433407413949`50.40249028533613 THRSub[2,1])/(1-0.2835808503901891204109793202563920107863341041632644564693107711623230001587`50. z),((10.6798851846240935786003243127708769751989256676719829963565131238321222786309`49.69897000433602+ 6.05484035981256933115855894601711876859674159283296024252330636187828966159087`49.26219649953595 w+12.74088859816135960020073357028687452872742111037488750392092671532959828421084`49.15577914780477 w^2)/(1+1.26645184188655237303733574954306955805231557190324079090523991868384522665547`49.52287874528033 w+1.82739007665027866305496622498724874076205074771869641908809466726726430824557`49.230818127152 w^2+0.7203673943730444691548702072914022690869663077885558797125676739756852451433`49.05697377710804 w^3+0.34216263693450357147626076057901775029917899131680320534558410494964530520795`49.385049071532414 w^4-0.74656724681571042836464940915671637925135641958079671844843589178851621318066`49.567944483820746 w^5)+16.75487814295457165036448437649030798318531544453498210349817322924290977760324`50.296388929451666 THRSub[2,1])/(1-0.33571231447627727746558371898065093916754814266531383240642400410001414769246`50. z),((11.25737202492675470486422531753648091435928193260928746659968179835429052458151`49.69897000433602+ 4.39393709023677819092449878327870700868773468031803957963249730409232918447799`49.19556235681359 w+14.33198990332154050932039044154859289648852425440591497812043392909612752422126`49.24607195678771 w^2)/(1+1.04885348878640212252326553227440139810860826314447888661104129093431086861556`49.52287874528033 w+1.72615196559415682393859511032859054340744418002281979628690662054622123645573`49.280009389953825 w^2+0.7012144277198689138609816593440618078502531757282307948131022953651094334735`49.14415825200266 w^3+0.33040919219717112173250673226125831273654047489026298936844057074089055519015`49.49845620079581 w^4-0.67400786143347216857235916278733950759607104542199348124685670103789508917138`49.62426164906893 w^5)+18.16239308048630604020795597191537510388509396183302177403560587916099373258406`50.41037272011028 THRSub[2,1])/(1-0.27990797903345649789952011446393231885366960115692336344305085997363490965352`50. z),((7.35889550261557099925202424880272809750851067580038533350711832028347626095857`49.69897000433602+ 4.6664719810405588603472699826759205865178127682481458353065146884496866700654`49.19769462618275 w+3.86420270899738201148666671644736483858571130526415709833548569211416616716263`48.6021049879736 w^2)/(1+1.69411880452856621655039383865565272141925681093172554685006524495869984080966`49.52287874528033 w+1.94785920447186957821601484697679330150182594307166535465456945851998588393026`49.03090695472906 w^2+0.72551135295510115976858691968076369999881473528812955149284012742126591988406`48.63986084334584 w^3+0.56081183913453664437638923755751535892725445583176305791907927431267363537844`48.795605664341906 w^4-1.27612493055479259446097617203272591825150883622307405034239963195602424724285`49.51249702233284 w^5)+8.66059398166366681620859957069600565644227385346701376339442370445942648411306`49.71844202121919 THRSub[2,1])/(1-0.65662979567779013010939479356081802981393103358185022619078256800171842587987`50. z),((10.49894250103209583278005896341040579338343932081090770415194204430004247473224`49.69897000433602+ 6.3830272699317516119307538018567519813421753483014488729098656643474207827817`49.27193567013477 w+12.28932529310624184047470550661774766494714235790444407378688695029610549437635`49.131596751306525 w^2)/(1+1.32124812416432296133880324948984624595468508435515891095091109649395352081405`49.52287874528033 w+1.85681915440809063718859844572100873805585935295538566460788394003443997480868`49.218910676429175 w^2+0.72873533759423460588376131781605534141417490557576929070963060419771797571457`49.034683154652946 w^3+0.34790503090995132145450421403748984930807093210403009293397997546770758425348`49.35116062590533 w^4-0.77069994657211073034636759764895362706128366194979789409135395538741328517963`49.552985048558575 w^5)+16.31386457828297250849032475430917642555876419465495075472543998486782704205902`50.26275432681752 THRSub[2,1])/(1-0.35319736436208936080372972105962542107946351207964415910309614904329563558311`50. z),((11.06684014946979934317630857943797098718649795695911593235094869369523326747306`49.69897000433602+ 5.06015915959892222439899685635921079301743525623161967444743315486873732858586`49.22639057141013 w+13.77261242286121851635354304353199006426023124628096246970061773240235240403048`49.21325911252242 w^2)/(1+1.12881984263652365584647412912180783090981087317607110806029125868876466334374`49.52287874528033 w+1.7605155888287097417440892728775227754255775874755824406093032885864105201576`49.261187616293775 w^2+0.7059086817580634889302571991459210003891974051026009236676168832621702859365`49.111816880396496 w^3+0.33316711585211806836256684566153664292185639589437079902136429692561072686629`49.45984882978433 w^4-0.69723321697081545114341754602082715291375282771444922814465084458134338524991`49.60390709313336 w^5)+17.69800767450709911548282951597106852278721637560033430247058146274349488331125`50.37145742865823 THRSub[2,1])/(1-0.29831966212042898711883232311634665301445426688451593930989255748576692288093`50. z),((6.95713301595594129818034161615868295257289407976747644342835242436269178818646`49.69897000433602+ 3.94255397504985110020333613892441699859392972165067636137145398335865476492592`49.15631603084761 w+2.6534136026110299174874851011205639081660108685543125254055`48.4655798790572 w^2)/(1+1.69362945403033748230434756837872572855615905277907569058149381686185242490189`49.52287874528033 w+1.89444305076080488530662767893854342438351627460472189052559214816485861424683`49.01299869434619 w^2+0.67078767319693540122887041536560907840600111240671411722270370029022923857528`48.57335268047759 w^3+0.58523880678920445388074290787117254732259674024224826548667945236582427723826`48.73368567345169 w^4-1.35435745496934466649828492481280968819195710015475852512675488087774622355717`49.62129294549218 w^5)+7.68137391663681508377439382460574386850835746178373935968516185793052858856247`49.64138583433352 THRSub[2,1])/(1-0.6954533445609913565252559599443690519054029978591623940773988511701680896258`50. z),((11.34578362994307471857269751809206634681282509557529106551189016582611943362559`49.69897000433602+ 4.03767784876768322849385704900850843234721551695614860667840828530966570829454`49.176019905771696 w+14.60750466648426474958942106132942538135483180561410508553804989557205155390645`49.26274819919815 w^2)/(1+1.00850668885832186195217119802700938476354724525208419703563594593407284006567`49.52287874528033 w+1.70997994469050248054079852067584830598095686229705531412609265521099504865142`49.29001719721161 w^2+0.69972838068260580537160244537487265982791000072235731008188431899934435784746`49.16083853133869 w^3+0.32951560161927660053397020081524980277985140071522962777321396606894412911564`49.51696364793169 w^4-0.66344750333809774487396295642713908886417997753323359125089146346426150065398`49.63449768063192 w^5)+18.37787964403536740565250485729529039047217726023243307505956072713100490381992`50.42895731007912 THRSub[2,1])/(1-0.27136449281170447112413885330207895455639587822449804361918816959608165252208`50. z),((9.21313763176521670415912705539987667022296139202280725059636123650851449839873`49.69897000433602+ 6.95954285083065041156962261114221146758862760901901374295474532901370186654431`49.28493812086391 w+9.1519037298840582109192048988823945687668862556218426527451`48.968251028682865 w^2)/(1+1.5820730228004034191976817511544766737107813617038226189800254876437002890076`49.52287874528033 w+2.00686643652637098638177254033753595421734847567282444659929211459734064883271`49.146691460639474 w^2+0.78887323037409214621532373971391604427430852366990168846877916078026369872891`48.89556138036995 w^3+0.41607585045612150093056610253302152041358465897008775298606026474353944636936`49.120147978126745 w^4-0.96113146883373555460174668976937538964405212101865823691339961394522349856436`49.47093406597781 w^5)+13.1799584284983995550603727956096867083760036010926123951965220286170048186496`50.039202292637306 THRSub[2,1])/(1-0.47744865673954891604824978481090799408900598425442011437032204807709501466298`50. z),((1.72241150757118178556754703534239979434736322205743602917285831842680420824611`49.69897000433602- 4.32817246121558991115332150225280308705158099630249098762079538735700843917731`49.54317862263173 w-13.01521707702698028354407779313061474884746517252943494662397241868188883059237`49.43862852490524 w^2)/(1+2.34072580714246528175080295152109137172488227983181682694663167294081453306295`49.52287874528033 w+2.1527700846499953995546699297337155841709334297981434536788805991816667095161`49.642040653766266 w^2+0.95120394934780159423827576442226439823002398341160778656034583958261129328365`49.15910735810264 w^3+1.33612694980335505348612031588683157627518372157628093896923768063859563438438`49.439120569188674 w^4+0.09071361497134616265342302077867120769798529868686707747785976818918462652208`47.632616179868705 w^5)-5.07726957558312155662062980601463732671167583502628072815970647921562710039613`49.22419344311723 THRSub[2,1])/(1-1.20130063772277418853675214889122356176044170348889242779284529912200114433037`50. z),((10.40251535550875490890206917021926268948795308450455029817428015853507549964352`49.69897000433602+ 6.52724082715135955774527474984381337621592828490962135395302574240524508059192`49.2759269104564 w+12.05352934503644938086494957673032776957229774063736718086799770158067535706953`49.11914966028996 w^2)/(1+1.34827902770802382272945971949904756464458630175538713430001468726588026508236`49.52287874528033 w+1.87189917691092665816882215008483809797940680968928252608985221769823678886136`49.21295158488487 w^2+0.73346808216695063028704032485314672222505607676149808049216454778906073242918`49.023399661204685 w^3+0.35136318133401294690064301664248208414970828576509862882737378370084394718741`49.333305481512966 w^4-0.78384492264307747989641035338951647273262463817645067968848279535028059647406`49.545406604958266 w^5)+16.07884165094402854570736648113121511937159129041471126215510128434373728711031`50.24514320530026 THRSub[2,1])/(1-0.36251541699815981858568287048119797181379668629323442827661104786935875282399`50. z),((2.21878142394103700977622259151038625943454822982792962672423595846378955762282`49.69897000433602- 2.9670234935799237528693224578956365383127865859922592219427292639612955073782`49.33705583098058 w-12.18083747237541924800849801642427591655146760073899768981489085569879672082694`49.43276052894915 w^2)/(1+2.40833586129637235123671108855489507994271397222026041017678311554436719458863`49.52287874528033 w+2.25245325151757142973317108293803616360437567032692217817146008417146950089741`49.61103882163251 w^2+1.16522781650219987990971249409008395947927246615168654470013427768760501888147`49.20716505728169 w^3+1.41437721985947629826475479566828996242962841767064366545656497179809516508811`49.66489973873966 w^4+0.46828993321752193377523103424031088279390575652635290674303134912713070080909`48.34487382480627 w^5)-3.86746179629972314328530165234631514400740575457381876977591318109608160697165`49.12368553352275 THRSub[2,1])/(1-1.15333488095797773328116831001974130658433382031487796549287027839231037978928`50. z),((9.22636823979065848355998679898611407725095385190871095115507361831067537884522`49.69897000433602+ 6.96571568503979607397908647924615732459192498189596342072299011496504181768963`49.28513206907526 w+9.1857753510136525953253334670167105229000670039697326111684`48.97006728288573 w^2)/(1+1.58033103038002790709260657233314783606327086766823337484195201850415740872765`49.52287874528033 w+2.00602228337580746250825150201184961755795916511905861603816722047546292992565`49.14744099048368 w^2+0.78845527970684779774195705207253013515992427446190478844136655546245010278861`48.89702097927526 w^3+0.41514888677344045597749973888807674846115100174627015590742285203595012867025`49.12247800854124 w^4-0.95902669195279499250824106785857513482137936531504567702854311149808120340368`49.47155901994204 w^5)+13.2122055328976558305453811148840570860985633568101432830365544019310645210505`50.04142808916708 THRSub[2,1])/(1-0.47617014225776908344177752167803855218505496314403301450135950615518776248397`50. z)} /. {w->w[z],pi1->pi1full[z]};
